@@ -227,7 +227,6 @@ static unsigned long long cur_buffers;
  */
 static struct GNUNET_SCHEDULER_Task *timeout_task;
 
-
 /**
  * Get the route corresponding to a hash.
  *
@@ -724,6 +723,7 @@ handle_connection_create (
   uint16_t size = ntohs (msg->header.size) - sizeof(*msg);
   unsigned int path_length;
   unsigned int off;
+  struct CadetTunnel *t;
 
   path_length = size / sizeof(struct GNUNET_PeerIdentity);
   if (0 == path_length)
@@ -822,8 +822,19 @@ handle_connection_create (
          GCP_2s (origin),
          GNUNET_sh2s (&msg->cid.connection_of_tunnel));
     path = GCPP_get_path_from_route (path_length - 1, pids);
+    t = GCP_get_tunnel (origin, GNUNET_YES);
+
+    // Check for CADET state in case the other side has lost the tunnel (xrs,t3ss)
+    if ((GNUNET_YES == msg->has_monotime) &&
+        (GNUNET_YES == GCP_check_and_update_monotime(origin, msg->monotime)) &&
+        ( GNUNET_OK == GCP_check_monotime_sig(origin, msg)) &&
+         (CADET_TUNNEL_KEY_OK == GCT_get_estate(t)))
+    {
+      GCT_change_estate (t, CADET_TUNNEL_KEY_UNINITIALIZED);
+    }
+
     if (GNUNET_OK !=
-        GCT_add_inbound_connection (GCP_get_tunnel (origin, GNUNET_YES),
+        GCT_add_inbound_connection (t,
                                     &msg->cid,
                                     path))
     {
