@@ -25,6 +25,7 @@
  */
 #include "platform.h"
 #include <jansson.h>
+#include <microhttpd.h>
 #include "gnunet_curl_lib.h"
 
 #if ENABLE_BENCHMARK
@@ -181,7 +182,8 @@ struct GNUNET_CURL_Context
  * @return library context
  */
 struct GNUNET_CURL_Context *
-GNUNET_CURL_init (GNUNET_CURL_RescheduleCallback cb, void *cb_cls)
+GNUNET_CURL_init (GNUNET_CURL_RescheduleCallback cb,
+                  void *cb_cls)
 {
   struct GNUNET_CURL_Context *ctx;
   CURLM *multi;
@@ -189,7 +191,8 @@ GNUNET_CURL_init (GNUNET_CURL_RescheduleCallback cb, void *cb_cls)
 
   if (curl_fail)
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR, "Curl was not initialised properly\n");
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Curl was not initialised properly\n");
     return NULL;
   }
   if (NULL == (multi = curl_multi_init ()))
@@ -227,6 +230,27 @@ GNUNET_CURL_enable_async_scope_header (struct GNUNET_CURL_Context *ctx,
 }
 
 
+/**
+ * Return #GNUNET_YES if given a valid scope ID and
+ * #GNUNET_NO otherwise.  See #setup_job_headers,
+ * logic related to
+ * #GNUNET_CURL_enable_async_scope_header() for the
+ * code that generates such a @a scope_id.
+ *
+ * @returns #GNUNET_YES iff given a valid scope ID
+ */
+int
+GNUNET_CURL_is_valid_scope_id (const char *scope_id)
+{
+  if (strlen (scope_id) >= 64)
+    return GNUNET_NO;
+  for (size_t i = 0; i < strlen (scope_id); i++)
+    if (! (isalnum (scope_id[i]) || (scope_id[i] == '-')))
+      return GNUNET_NO;
+  return GNUNET_YES;
+}
+
+
 /**
  * Callback used when downloading the reply to an HTTP request.
  * Just appends all of the data to the `buf` in the
@@ -241,7 +265,10 @@ GNUNET_CURL_enable_async_scope_header (struct GNUNET_CURL_Context *ctx,
  * @return number of bytes processed from @a bufptr
  */
 static size_t
-download_cb (char *bufptr, size_t size, size_t nitems, void *cls)
+download_cb (char *bufptr,
+             size_t size,
+             size_t nitems,
+             void *cls)
 {
   struct GNUNET_CURL_DownloadBuffer *db = cls;
   size_t msize;
@@ -354,7 +381,9 @@ setup_job (CURL *eh,
   }
   job->easy_handle = eh;
   job->ctx = ctx;
-  GNUNET_CONTAINER_DLL_insert (ctx->jobs_head, ctx->jobs_tail, job);
+  GNUNET_CONTAINER_DLL_insert (ctx->jobs_head,
+                               ctx->jobs_tail,
+                               job);
   return job;
 }
 
@@ -475,7 +504,11 @@ GNUNET_CURL_job_add (struct GNUNET_CURL_Context *ctx,
                  curl_slist_append (NULL, "Content-Type: application/json")));
   }
 
-  job = GNUNET_CURL_job_add2 (ctx, eh, job_headers, jcc, jcc_cls);
+  job = GNUNET_CURL_job_add2 (ctx,
+                              eh,
+                              job_headers,
+                              jcc,
+                              jcc_cls);
   curl_slist_free_all (job_headers);
   return job;
 }
@@ -496,13 +529,47 @@ GNUNET_CURL_job_cancel (struct GNUNET_CURL_Job *job)
   GNUNET_break (CURLM_OK ==
                 curl_multi_remove_handle (ctx->multi, job->easy_handle));
   curl_easy_cleanup (job->easy_handle);
-  GNUNET_free_non_null (job->db.buf);
+  GNUNET_free (job->db.buf);
   curl_slist_free_all (job->job_headers);
   ctx->cb (ctx->cb_cls);
   GNUNET_free (job);
 }
 
 
+/**
+ * Test if the given content type @a ct is JSON
+ *
+ * @param ct a content type, i.e. "application/json; charset=UTF-8"
+ * @return true if @a ct denotes JSON
+ */
+static bool
+is_json (const char *ct)
+{
+  const char *semi;
+
+  /* check for "application/json" exact match */
+  if (0 == strcasecmp (ct,
+                       "application/json"))
+    return true;
+  /* check for "application/json;[ANYTHING]" */
+  semi = strchr (ct,
+                 ';');
+  /* also allow "application/json [ANYTHING]" (note the space!) */
+  if (NULL == semi)
+    semi = strchr (ct,
+                   ' ');
+  if (NULL == semi)
+    return false; /* no delimiter we accept, forget it */
+  if (semi - ct != strlen ("application/json"))
+    return false; /* delimiter past desired length, forget it */
+  if (0 == strncasecmp (ct,
+                        "application/json",
+                        strlen ("application/json")))
+    return true; /* OK */
+  return false;
+}
+
+
 /**
  * Obtain information about the final result about the
  * HTTP download. If the download was successful, parses
@@ -540,8 +607,7 @@ GNUNET_CURL_download_get_result_ (struct GNUNET_CURL_DownloadBuffer *db,
                           CURLINFO_CONTENT_TYPE,
                           &ct)) ||
       (NULL == ct) ||
-      (0 != strcasecmp (ct,
-                        "application/json")))
+      (! is_json (ct)))
   {
     /* No content type or explicitly not JSON, refuse to parse
        (but keep response code) */
@@ -556,9 +622,13 @@ GNUNET_CURL_download_get_result_ (struct GNUNET_CURL_DownloadBuffer *db,
     }
     if (0 != db->buf_size)
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                  "Did NOT detect response as JSON\n");
+                  "Did NOT detect response `%.*s' as JSON\n",
+                  (int) db->buf_size,
+                  (const char *) db->buf);
     return NULL;
   }
+  if (MHD_HTTP_NO_CONTENT == *response_code)
+    return NULL;
   json = NULL;
   if (0 == db->eno)
   {
@@ -572,7 +642,7 @@ GNUNET_CURL_download_get_result_ (struct GNUNET_CURL_DownloadBuffer *db,
       *response_code = 0;
     }
   }
-  GNUNET_free_non_null (db->buf);
+  GNUNET_free (db->buf);
   db->buf = NULL;
   db->buf_size = 0;
   if (NULL != json)
@@ -680,7 +750,7 @@ do_benchmark (CURLMsg *cmsg)
 
 
 /**
- * Run the main event loop for the Taler interaction.
+ * Run the main event loop for the HTTP interaction.
  *
  * @param ctx the library context
  * @param rp parses the raw response returned from
