@@ -65,7 +65,9 @@
  */
 #include "platform.h"
 
-#include <linux/if_tun.h>
+#ifdef IF_TUN_HDR
+#include IF_TUN_HDR
+#endif
 
 /**
  * Need 'struct GNUNET_MessageHeader'.
@@ -1189,4 +1191,5 @@ cleanup_rest:
   return r;
 }
 
+
 /* end of gnunet-helper-dns.c */
