@@ -11,12 +11,12 @@
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
      Affero General Public License for more details.
-    
+
      You should have received a copy of the GNU Affero General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 /**
  * @file fragmentation/test_fragmentation.c
  * @brief test for fragmentation.c
@@ -60,7 +60,7 @@ static struct GNUNET_BANDWIDTH_Tracker trackers[NUM_MSGS];
 
 static struct GNUNET_FRAGMENT_Context *frag;
 
-static struct GNUNET_SCHEDULER_Task * shutdown_task;
+static struct GNUNET_SCHEDULER_Task *shutdown_task;
 
 static struct GNUNET_TIME_Relative msg_delay;
 
@@ -98,15 +98,15 @@ proc_msgs (void *cls, const struct GNUNET_MessageHeader *hdr)
   const char *buf;
 
 #if DETAILS
-  FPRINTF (stderr, "%s",  "M! ");        /* message complete, good! */
+  fprintf (stderr, "%s", "M! ");          /* message complete, good! */
 #endif
   buf = (const char *) hdr;
-  for (i = sizeof (struct GNUNET_MessageHeader); i < ntohs (hdr->size); i++)
+  for (i = sizeof(struct GNUNET_MessageHeader); i < ntohs (hdr->size); i++)
     GNUNET_assert (buf[i] == (char) i);
   total++;
 #if ! DETAILS
   if (0 == (total % (NUM_MSGS / 100)))
-    FPRINTF (stderr, "%s",  ".");
+    fprintf (stderr, "%s", ".");
 #endif
   /* tolerate 10% loss, i.e. due to duplicate fragment IDs */
   if ((total >= NUM_MSGS - (NUM_MSGS / 10)) && (ret != 0))
@@ -131,27 +131,27 @@ proc_frac (void *cls, const struct GNUNET_MessageHeader *hdr)
   {
     frag_drops++;
 #if DETAILS
-    FPRINTF (stderr, "%s",  "DF ");    /* dropped Frag */
+    fprintf (stderr, "%s", "DF ");     /* dropped Frag */
 #endif
     return;                     /* random drop */
   }
   if (NULL == defrag)
   {
-    FPRINTF (stderr, "%s",  "?E ");      /* Error: frag after shutdown!? */
+    fprintf (stderr, "%s", "?E ");       /* Error: frag after shutdown!? */
     return;
   }
   ret = GNUNET_DEFRAGMENT_process_fragment (defrag, hdr);
   if (ret == GNUNET_NO)
   {
 #if DETAILS
-    FPRINTF (stderr, "%s",  "FF ");      /* duplicate fragment */
+    fprintf (stderr, "%s", "FF ");       /* duplicate fragment */
 #endif
     dups++;
   }
   else if (ret == GNUNET_OK)
   {
 #if DETAILS
-    FPRINTF (stderr, "%s",  "F! ");      /* good fragment */
+    fprintf (stderr, "%s", "F! ");       /* good fragment */
 #endif
     fragc++;
   }
@@ -168,7 +168,7 @@ next_transmission ()
 
   if (0 == i)
   {
-    for (j = 0; j < sizeof (buf); j++)
+    for (j = 0; j < sizeof(buf); j++)
       buf[j] = (char) j;
   }
   else
@@ -181,13 +181,13 @@ next_transmission ()
   if (i == NUM_MSGS)
     return;
 #if DETAILS
-  FPRINTF (stderr, "%s",  "T! ");        /* sending message */
+  fprintf (stderr, "%s", "T! ");          /* sending message */
 #endif
   msg = (struct GNUNET_MessageHeader *) buf;
   msg->type = htons ((uint16_t) i);
   msg->size =
-    htons (sizeof (struct GNUNET_MessageHeader) + (17 * i) % (32 * 1024));
-  frag = GNUNET_FRAGMENT_context_create (NULL /* no stats */ ,
+    htons (sizeof(struct GNUNET_MessageHeader) + (17 * i) % (32 * 1024));
+  frag = GNUNET_FRAGMENT_context_create (NULL /* no stats */,
                                          MTU, &trackers[i],
                                          msg_delay,
                                          ack_delay,
@@ -212,7 +212,7 @@ proc_acks (void *cls,
   {
     ack_drops++;
 #if DETAILS
-    FPRINTF (stderr, "%s",  "DA ");    /* dropped ACK */
+    fprintf (stderr, "%s", "DA ");     /* dropped ACK */
 #endif
     return;                     /* random drop */
   }
@@ -224,7 +224,7 @@ proc_acks (void *cls,
     if (ret == GNUNET_OK)
     {
 #if DETAILS
-      FPRINTF (stderr, "%s",  "GA ");    /* good ACK */
+      fprintf (stderr, "%s", "GA ");     /* good ACK */
 #endif
       next_transmission ();
       acks++;
@@ -233,14 +233,14 @@ proc_acks (void *cls,
     if (ret == GNUNET_NO)
     {
 #if DETAILS
-      FPRINTF (stderr, "%s",  "AA ");    /* duplciate ACK */
+      fprintf (stderr, "%s", "AA ");     /* duplicate ACK */
 #endif
       acks++;
       return;
     }
   }
 #if DETAILS
-  FPRINTF (stderr, "%s",  "?A ");        /* BAD: ack that nobody feels responsible for... */
+  fprintf (stderr, "%s", "?A ");          /* BAD: ack that nobody feels responsible for... */
 #endif
 }
 
@@ -293,7 +293,7 @@ main (int argc, char *argv[])
                       "test-fragmentation", "nohelp",
                       options,
                       &run, NULL);
-  FPRINTF (stderr,
+  fprintf (stderr,
            "\nHad %u good fragments, %u duplicate fragments, %u acks and %u simulated drops of acks\n",
            fragc,
            dups,
