@@ -764,6 +764,12 @@ transmit_lookup_dns_result (struct GNS_ResolverHandle *rh)
       rd[i].data = pos->data;
       rd[i].data_size = pos->data_size;
       rd[i].record_type = pos->record_type;
+      /**
+       * If this is a LEHO, we added this before. It must be a supplemental
+       * record #LSD0001
+       */
+      if (GNUNET_GNSRECORD_TYPE_LEHO == rd[i].record_type)
+        rd[i].flags |= GNUNET_GNSRECORD_RF_SUPPLEMENTAL;
       if (0 == pos->expiration_time)
       {
         rd[i].flags = GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION;
@@ -1130,6 +1136,7 @@ dns_result_parser (void *cls,
     {
       rd[rd_count - skip].record_type = GNUNET_GNSRECORD_TYPE_LEHO;
       rd[rd_count - skip].flags = GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION;
+      rd[rd_count - skip].flags |= GNUNET_GNSRECORD_RF_SUPPLEMENTAL;
       rd[rd_count - skip].expiration_time = GNUNET_TIME_UNIT_HOURS.rel_value_us;
       rd[rd_count - skip].data = rh->leho;
       rd[rd_count - skip].data_size = strlen (rh->leho);
@@ -1350,6 +1357,7 @@ handle_gns_cname_result (struct GNS_ResolverHandle *rh,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Doing standard DNS lookup for `%s'\n",
               rh->name);
+
   rh->std_resolve = GNUNET_RESOLVER_ip_get (rh->name,
                                             af,
                                             DNS_LOOKUP_TIMEOUT,
@@ -1667,7 +1675,7 @@ recursive_cname_resolution (struct GNS_ResolverHandle *rh,
       (off != rd->data_size))
   {
     GNUNET_break_op (0);  /* record not well-formed */
-    GNUNET_free_non_null (cname);
+    GNUNET_free (cname);
     fail_resolution (rh);
     return;
   }
@@ -1751,7 +1759,12 @@ recursive_gns2dns_resolution (struct GNS_ResolverHandle *rh,
     struct sockaddr_in6 v6;
 
     if (GNUNET_GNSRECORD_TYPE_GNS2DNS != rd[i].record_type)
-      continue;
+    {
+      /**
+       * Records other than GNS2DNS not allowed
+       */
+      return GNUNET_SYSERR;
+    }
     off = 0;
     n = GNUNET_DNSPARSER_parse_name (rd[i].data,
                                      rd[i].data_size,
@@ -1764,8 +1777,8 @@ recursive_gns2dns_resolution (struct GNS_ResolverHandle *rh,
         (off != rd[i].data_size))
     {
       GNUNET_break_op (0);
-      GNUNET_free_non_null (n);
-      GNUNET_free_non_null (ip);
+      GNUNET_free (n);
+      GNUNET_free (ip);
       continue;
     }
     /* resolve 'ip' to determine the IP(s) of the DNS
@@ -1970,7 +1983,7 @@ handle_gns_resolution_result (void *cls,
           (off != rd[0].data_size))
       {
         GNUNET_break_op (0);
-        GNUNET_free_non_null (cname);
+        GNUNET_free (cname);
         fail_resolution (rh);
         return;
       }
@@ -2124,7 +2137,7 @@ handle_gns_resolution_result (void *cls,
               rd_off++;
             }
           }
-          GNUNET_free_non_null (cname);
+          GNUNET_free (cname);
         }
         break;
 
@@ -2243,10 +2256,6 @@ handle_gns_resolution_result (void *cls,
         }
         break;
 
-      case GNUNET_GNSRECORD_TYPE_NICK:
-        /* ignore */
-        break;
-
       case GNUNET_GNSRECORD_TYPE_PKEY:
         {
           struct GNUNET_CRYPTO_EcdsaPublicKey pub;
@@ -2984,7 +2993,7 @@ GNS_resolver_lookup_cancel (struct GNS_ResolverHandle *rh)
                                  dr);
     GNUNET_free (dr);
   }
-  GNUNET_free_non_null (rh->leho);
+  GNUNET_free (rh->leho);
   GNUNET_free (rh->name);
   GNUNET_free (rh);
 }
