@@ -200,6 +200,7 @@ do_error (void *cls)
     handle->response_code = MHD_HTTP_INTERNAL_SERVER_ERROR;
   response = json_dumps (json_error, 0);
   resp = GNUNET_REST_create_response (response);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, handle->response_code);
   json_decref (json_error);
   GNUNET_free (response);
@@ -252,6 +253,7 @@ handle_gns_response (void *cls,
   result = json_dumps (result_obj, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result);
   resp = GNUNET_REST_create_response (result);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
   GNUNET_free (result);
   json_decref (result_obj);
@@ -319,7 +321,7 @@ get_gns_cont (struct GNUNET_REST_RequestHandle *con_handle,
   handle->gns_lookup = GNUNET_GNS_lookup_with_tld (handle->gns,
                                                    handle->name,
                                                    handle->record_type,
-                                                   GNUNET_NO,
+                                                   GNUNET_GNS_LO_DEFAULT,
                                                    &handle_gns_response,
                                                    handle);
 }
@@ -459,7 +461,7 @@ libgnunet_plugin_rest_gns_done (void *cls)
 
   plugin->cfg = NULL;
 
-  GNUNET_free_non_null (allow_methods);
+  GNUNET_free (allow_methods);
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Gns REST plugin is finished\n");
   return NULL;
