@@ -75,6 +75,11 @@ static char *create_ego;
  */
 static char *delete_ego;
 
+/**
+ * -P option
+ */
+static char *privkey_ego;
+
 /**
  * -s option.
  */
@@ -100,6 +105,11 @@ static struct GNUNET_IDENTITY_Operation *create_op;
  */
 static struct GNUNET_IDENTITY_Operation *delete_op;
 
+/**
+ * Private key from command line option, or NULL.
+ */
+struct GNUNET_CRYPTO_EcdsaPrivateKey pk;
+
 /**
  * Value to return from #main().
  */
@@ -143,10 +153,14 @@ shutdown_task (void *cls)
  * Test if we are finished yet.
  */
 static void
-test_finished ()
+test_finished (void)
 {
-  if ((NULL == create_op) && (NULL == delete_op) && (NULL == set_op) &&
-      (NULL == set_subsystem) && (! list) && (! monitor))
+  if ( (NULL == create_op) &&
+       (NULL == delete_op) &&
+       (NULL == set_op) &&
+       (NULL == set_subsystem) &&
+       (! list) &&
+       (! monitor))
   {
     if (TIMEOUT_STATUS_CODE == global_ret)
       global_ret = 0;
@@ -162,7 +176,8 @@ test_finished ()
  * @param emsg NULL on success, otherwise an error message
  */
 static void
-delete_finished (void *cls, const char *emsg)
+delete_finished (void *cls,
+                 const char *emsg)
 {
   struct GNUNET_IDENTITY_Operation **op = cls;
 
@@ -190,7 +205,9 @@ create_finished (void *cls,
   *op = NULL;
   if (NULL == pk)
   {
-    fprintf (stderr, _ ("Failed to create ego: %s\n"), emsg);
+    fprintf (stderr,
+             _ ("Failed to create ego: %s\n"),
+             emsg);
     global_ret = 1;
   }
   else if (verbose)
@@ -280,16 +297,25 @@ print_ego (void *cls,
   char *s;
   char *privs;
 
-  if ((NULL != set_ego) && (NULL != set_subsystem) && (NULL != ego) &&
-      (NULL != identifier) && (0 == strcmp (identifier, set_ego)))
+  if ( (NULL != set_ego) &&
+       (NULL != set_subsystem) &&
+       (NULL != ego) &&
+       (NULL != identifier) &&
+       (0 == strcmp (identifier, set_ego)))
   {
-    set_op = GNUNET_IDENTITY_set (sh, set_subsystem, ego, &set_done, NULL);
+    set_op = GNUNET_IDENTITY_set (sh,
+                                  set_subsystem,
+                                  ego,
+                                  &set_done,
+                                  NULL);
     GNUNET_free (set_subsystem);
     set_subsystem = NULL;
     GNUNET_free (set_ego);
     set_ego = NULL;
   }
-  if ((NULL == ego) && (NULL != set_ego) && (NULL != set_subsystem))
+  if ( (NULL == ego) &&
+       (NULL != set_ego) &&
+       (NULL != set_subsystem) )
   {
     fprintf (stderr,
              "Could not set ego to `%s' for subsystem `%s', ego not known\n",
@@ -308,9 +334,12 @@ print_ego (void *cls,
   }
   if (! (list | monitor))
     return;
-  if ((NULL == ego) || (NULL == identifier))
+  if ( (NULL == ego) ||
+       (NULL == identifier) )
     return;
-  if ((NULL != set_ego) && (0 != strcmp (identifier, set_ego)))
+  if ( (NULL != set_ego) &&
+       (0 != strcmp (identifier,
+                     set_ego)) )
     return;
   GNUNET_IDENTITY_ego_get_public_key (ego, &pk);
   s = GNUNET_CRYPTO_ecdsa_public_key_to_string (&pk);
@@ -358,18 +387,43 @@ run (void *cls,
     return;
   }
   sh = GNUNET_IDENTITY_connect (cfg,
-                                (monitor | list) || (NULL != set_ego) ||
+                                (monitor | list) ||
+                                (NULL != set_ego) ||
                                 (NULL != set_subsystem)
                                 ? &print_ego
                                 : NULL,
                                 NULL);
   if (NULL != delete_ego)
     delete_op =
-      GNUNET_IDENTITY_delete (sh, delete_ego, &delete_finished, &delete_op);
+      GNUNET_IDENTITY_delete (sh,
+                              delete_ego,
+                              &delete_finished,
+                              &delete_op);
   if (NULL != create_ego)
-    create_op =
-      GNUNET_IDENTITY_create (sh, create_ego, &create_finished, &create_op);
-  GNUNET_SCHEDULER_add_shutdown (&shutdown_task, NULL);
+  {
+    if (NULL != privkey_ego)
+    {
+      GNUNET_STRINGS_string_to_data (privkey_ego,
+                                     strlen (privkey_ego),
+                                     &pk,
+                                     sizeof(struct GNUNET_CRYPTO_EcdsaPrivateKey));
+      create_op =
+        GNUNET_IDENTITY_create (sh,
+                                create_ego,
+                                &pk,
+                                &create_finished,
+                                &create_op);
+    }
+    else
+      create_op =
+        GNUNET_IDENTITY_create (sh,
+                                create_ego,
+                                NULL,
+                                &create_finished,
+                                &create_op);
+  }
+  GNUNET_SCHEDULER_add_shutdown (&shutdown_task,
+                                 NULL);
   test_finished ();
 }
 
@@ -384,8 +438,8 @@ run (void *cls,
 int
 main (int argc, char *const *argv)
 {
-  struct GNUNET_GETOPT_CommandLineOption options[] =
-  { GNUNET_GETOPT_option_string ('C',
+  struct GNUNET_GETOPT_CommandLineOption options[] = {
+    GNUNET_GETOPT_option_string ('C',
                                  "create",
                                  "NAME",
                                  gettext_noop ("create ego NAME"),
@@ -395,6 +449,11 @@ main (int argc, char *const *argv)
                                  "NAME",
                                  gettext_noop ("delete ego NAME "),
                                  &delete_ego),
+    GNUNET_GETOPT_option_string ('P',
+                                 "privkey",
+                                 "PRIVATE_KEY",
+                                 gettext_noop ("set the private key for the identity to PRIVATE_KEY (use together with -C)"),
+                                 &privkey_ego),
     GNUNET_GETOPT_option_flag ('d',
                                "display",
                                gettext_noop ("display all egos"),
@@ -426,10 +485,13 @@ main (int argc, char *const *argv)
         "set default identity to EGO for a subsystem SUBSYSTEM (use together with -e)"),
       &set_subsystem),
     GNUNET_GETOPT_option_verbose (&verbose),
-    GNUNET_GETOPT_OPTION_END };
+    GNUNET_GETOPT_OPTION_END
+  };
   int res;
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
+  if (GNUNET_OK !=
+      GNUNET_STRINGS_get_utf8_args (argc, argv,
+                                    &argc, &argv))
     return 4;
   global_ret = TIMEOUT_STATUS_CODE; /* timeout */
   res = GNUNET_PROGRAM_run (argc,
@@ -439,7 +501,7 @@ main (int argc, char *const *argv)
                             options,
                             &run,
                             NULL);
-  GNUNET_free ((void *) argv);
+  GNUNET_free_nz ((void *) argv);
 
   if (GNUNET_OK != res)
     return 3;
