@@ -57,7 +57,7 @@ struct Ego
   /**
    * Private key of the ego.
    */
-  struct GNUNET_CRYPTO_EcdsaPrivateKey *pk;
+  struct GNUNET_CRYPTO_EcdsaPrivateKey pk;
 
   /**
    * String identifier for the ego.
@@ -140,7 +140,9 @@ client_disconnect_cb (void *cls,
                       struct GNUNET_SERVICE_Client *client,
                       void *app_ctx)
 {
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Client %p disconnected\n", client);
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Client %p disconnected\n",
+              client);
 }
 
 
@@ -189,8 +191,9 @@ shutdown_task (void *cls)
   ego_directory = NULL;
   while (NULL != (e = ego_head))
   {
-    GNUNET_CONTAINER_DLL_remove (ego_head, ego_tail, e);
-    GNUNET_free (e->pk);
+    GNUNET_CONTAINER_DLL_remove (ego_head,
+                                 ego_tail,
+                                 e);
     GNUNET_free (e->identifier);
     GNUNET_free (e);
   }
@@ -247,7 +250,7 @@ create_update_message (struct Ego *ego)
   env = GNUNET_MQ_msg_extra (um, name_len, GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE);
   um->name_len = htons (name_len);
   um->end_of_list = htons (GNUNET_NO);
-  um->private_key = *ego->pk;
+  um->private_key = ego->pk;
   GNUNET_memcpy (&um[1], ego->identifier, name_len);
   return env;
 }
@@ -261,7 +264,8 @@ create_update_message (struct Ego *ego)
  * @return corresponding set default message
  */
 static struct GNUNET_MQ_Envelope *
-create_set_default_message (struct Ego *ego, const char *servicename)
+create_set_default_message (struct Ego *ego,
+                            const char *servicename)
 {
   struct SetDefaultMessage *sdm;
   struct GNUNET_MQ_Envelope *env;
@@ -273,7 +277,7 @@ create_set_default_message (struct Ego *ego, const char *servicename)
                              GNUNET_MESSAGE_TYPE_IDENTITY_SET_DEFAULT);
   sdm->name_len = htons (name_len);
   sdm->reserved = htons (0);
-  sdm->private_key = *ego->pk;
+  sdm->private_key = ego->pk;
   GNUNET_memcpy (&sdm[1], servicename, name_len);
   return env;
 }
@@ -289,26 +293,34 @@ create_set_default_message (struct Ego *ego, const char *servicename)
  * @param message the message received
  */
 static void
-handle_start_message (void *cls, const struct GNUNET_MessageHeader *message)
+handle_start_message (void *cls,
+                      const struct GNUNET_MessageHeader *message)
 {
   struct GNUNET_SERVICE_Client *client = cls;
-  struct UpdateMessage *ume;
-  struct GNUNET_MQ_Envelope *env;
-  struct Ego *ego;
 
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Received START message from client\n");
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Received START message from client\n");
   GNUNET_SERVICE_client_mark_monitor (client);
   GNUNET_SERVICE_client_disable_continue_warning (client);
-  GNUNET_notification_context_add (nc, GNUNET_SERVICE_client_get_mq (client));
-  for (ego = ego_head; NULL != ego; ego = ego->next)
+  GNUNET_notification_context_add (nc,
+                                   GNUNET_SERVICE_client_get_mq (client));
+  for (struct Ego *ego = ego_head; NULL != ego; ego = ego->next)
   {
-    env = create_update_message (ego);
-    GNUNET_MQ_send (GNUNET_SERVICE_client_get_mq (client), env);
+    GNUNET_MQ_send (GNUNET_SERVICE_client_get_mq (client),
+                    create_update_message (ego));
+  }
+  {
+    struct UpdateMessage *ume;
+    struct GNUNET_MQ_Envelope *env;
+
+    env = GNUNET_MQ_msg_extra (ume,
+                               0,
+                               GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE);
+    ume->end_of_list = htons (GNUNET_YES);
+    ume->name_len = htons (0);
+    GNUNET_MQ_send (GNUNET_SERVICE_client_get_mq (client),
+                    env);
   }
-  env = GNUNET_MQ_msg_extra (ume, 0, GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE);
-  ume->end_of_list = htons (GNUNET_YES);
-  ume->name_len = htons (0);
-  GNUNET_MQ_send (GNUNET_SERVICE_client_get_mq (client), env);
   GNUNET_SERVICE_client_continue (client);
 }
 
@@ -322,7 +334,8 @@ handle_start_message (void *cls, const struct GNUNET_MessageHeader *message)
  * @return #GNUNET_SYSERR if message was ill-formed
  */
 static int
-check_lookup_message (void *cls, const struct LookupMessage *message)
+check_lookup_message (void *cls,
+                      const struct LookupMessage *message)
 {
   GNUNET_MQ_check_zero_termination (message);
   return GNUNET_OK;
@@ -337,14 +350,16 @@ check_lookup_message (void *cls, const struct LookupMessage *message)
  * @param message the message received
  */
 static void
-handle_lookup_message (void *cls, const struct LookupMessage *message)
+handle_lookup_message (void *cls,
+                       const struct LookupMessage *message)
 {
   struct GNUNET_SERVICE_Client *client = cls;
   const char *name;
   struct GNUNET_MQ_Envelope *env;
   struct Ego *ego;
 
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Received LOOKUP message from client\n");
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Received LOOKUP message from client\n");
   name = (const char *) &message[1];
   for (ego = ego_head; NULL != ego; ego = ego->next)
   {
@@ -369,7 +384,8 @@ handle_lookup_message (void *cls, const struct LookupMessage *message)
  * @return #GNUNET_SYSERR if message was ill-formed
  */
 static int
-check_lookup_by_suffix_message (void *cls, const struct LookupMessage *message)
+check_lookup_by_suffix_message (void *cls,
+                                const struct LookupMessage *message)
 {
   GNUNET_MQ_check_zero_termination (message);
   return GNUNET_OK;
@@ -384,7 +400,8 @@ check_lookup_by_suffix_message (void *cls, const struct LookupMessage *message)
  * @param message the message received
  */
 static void
-handle_lookup_by_suffix_message (void *cls, const struct LookupMessage *message)
+handle_lookup_by_suffix_message (void *cls,
+                                 const struct LookupMessage *message)
 {
   struct GNUNET_SERVICE_Client *client = cls;
   const char *name;
@@ -429,7 +446,8 @@ handle_lookup_by_suffix_message (void *cls, const struct LookupMessage *message)
  * @return #GNUNET_OK if @a msg is well-formed
  */
 static int
-check_get_default_message (void *cls, const struct GetDefaultMessage *msg)
+check_get_default_message (void *cls,
+                           const struct GetDefaultMessage *msg)
 {
   uint16_t size;
   uint16_t name_len;
@@ -462,31 +480,32 @@ check_get_default_message (void *cls, const struct GetDefaultMessage *msg)
  * @param message the message received
  */
 static void
-handle_get_default_message (void *cls, const struct GetDefaultMessage *gdm)
+handle_get_default_message (void *cls,
+                            const struct GetDefaultMessage *gdm)
 {
   struct GNUNET_MQ_Envelope *env;
   struct GNUNET_SERVICE_Client *client = cls;
-  struct Ego *ego;
   char *name;
   char *identifier;
 
-
   name = GNUNET_strdup ((const char *) &gdm[1]);
-  GNUNET_STRINGS_utf8_tolower ((const char *) &gdm[1], name);
+  GNUNET_STRINGS_utf8_tolower ((const char *) &gdm[1],
+                               name);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Received GET_DEFAULT for service `%s' from client\n",
               name);
-  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_string (subsystem_cfg,
-                                                          name,
-                                                          "DEFAULT_IDENTIFIER",
-                                                          &identifier))
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_string (subsystem_cfg,
+                                             name,
+                                             "DEFAULT_IDENTIFIER",
+                                             &identifier))
   {
     send_result_code (client, 1, gettext_noop ("no default known"));
     GNUNET_SERVICE_client_continue (client);
     GNUNET_free (name);
     return;
   }
-  for (ego = ego_head; NULL != ego; ego = ego->next)
+  for (struct Ego *ego = ego_head; NULL != ego; ego = ego->next)
   {
     if (0 == strcmp (ego->identifier, identifier))
     {
@@ -499,7 +518,9 @@ handle_get_default_message (void *cls, const struct GetDefaultMessage *gdm)
     }
   }
   GNUNET_free (identifier);
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Failed to find ego `%s'\n", name);
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Failed to find ego `%s'\n",
+              name);
   GNUNET_free (name);
   send_result_code (client,
                     1,
@@ -532,7 +553,8 @@ key_cmp (const struct GNUNET_CRYPTO_EcdsaPrivateKey *pk1,
  * @return #GNUNET_OK if @a msg is well-formed
  */
 static int
-check_set_default_message (void *cls, const struct SetDefaultMessage *msg)
+check_set_default_message (void *cls,
+                           const struct SetDefaultMessage *msg)
 {
   uint16_t size;
   uint16_t name_len;
@@ -570,7 +592,8 @@ check_set_default_message (void *cls, const struct SetDefaultMessage *msg)
  * @param message the message received
  */
 static void
-handle_set_default_message (void *cls, const struct SetDefaultMessage *sdm)
+handle_set_default_message (void *cls,
+                            const struct SetDefaultMessage *sdm)
 {
   struct Ego *ego;
   struct GNUNET_SERVICE_Client *client = cls;
@@ -584,7 +607,8 @@ handle_set_default_message (void *cls, const struct SetDefaultMessage *sdm)
               str);
   for (ego = ego_head; NULL != ego; ego = ego->next)
   {
-    if (0 == key_cmp (ego->pk, &sdm->private_key))
+    if (0 == key_cmp (&ego->pk,
+                      &sdm->private_key))
     {
       GNUNET_CONFIGURATION_set_value_string (subsystem_cfg,
                                              str,
@@ -627,7 +651,7 @@ notify_listeners (struct Ego *ego)
   um->header.size = htons (sizeof(struct UpdateMessage) + name_len);
   um->name_len = htons (name_len);
   um->end_of_list = htons (GNUNET_NO);
-  um->private_key = *ego->pk;
+  um->private_key = ego->pk;
   GNUNET_memcpy (&um[1], ego->identifier, name_len);
   GNUNET_notification_context_broadcast (nc, &um->header, GNUNET_NO);
   GNUNET_free (um);
@@ -642,7 +666,8 @@ notify_listeners (struct Ego *ego)
  * @return #GNUNET_OK if @a msg is well-formed
  */
 static int
-check_create_message (void *cls, const struct CreateRequestMessage *msg)
+check_create_message (void *cls,
+                      const struct CreateRequestMessage *msg)
 {
   uint16_t size;
   uint16_t name_len;
@@ -680,7 +705,8 @@ check_create_message (void *cls, const struct CreateRequestMessage *msg)
  * @param message the message received
  */
 static void
-handle_create_message (void *cls, const struct CreateRequestMessage *crm)
+handle_create_message (void *cls,
+                       const struct CreateRequestMessage *crm)
 {
   struct GNUNET_SERVICE_Client *client = cls;
   struct Ego *ego;
@@ -704,10 +730,11 @@ handle_create_message (void *cls, const struct CreateRequestMessage *crm)
     }
   }
   ego = GNUNET_new (struct Ego);
-  ego->pk = GNUNET_new (struct GNUNET_CRYPTO_EcdsaPrivateKey);
-  *ego->pk = crm->private_key;
+  ego->pk = crm->private_key;
   ego->identifier = GNUNET_strdup (str);
-  GNUNET_CONTAINER_DLL_insert (ego_head, ego_tail, ego);
+  GNUNET_CONTAINER_DLL_insert (ego_head,
+                               ego_tail,
+                               ego);
   send_result_code (client, 0, NULL);
   fn = get_ego_filename (ego);
   (void) GNUNET_DISK_directory_create_for_file (fn);
@@ -997,7 +1024,6 @@ handle_delete_message (void *cls, const struct DeleteMessage *dm)
       GNUNET_free (ego->identifier);
       ego->identifier = NULL;
       notify_listeners (ego);
-      GNUNET_free (ego->pk);
       GNUNET_free (ego);
       GNUNET_free (name);
       send_result_code (client, 0, NULL);
@@ -1023,7 +1049,8 @@ handle_delete_message (void *cls, const struct DeleteMessage *dm)
  *  #GNUNET_SYSERR to abort iteration with error!
  */
 static int
-process_ego_file (void *cls, const char *filename)
+process_ego_file (void *cls,
+                  const char *filename)
 {
   struct Ego *ego;
   const char *fn;
@@ -1035,8 +1062,10 @@ process_ego_file (void *cls, const char *filename)
     return GNUNET_OK;
   }
   ego = GNUNET_new (struct Ego);
-  ego->pk = GNUNET_CRYPTO_ecdsa_key_create_from_file (filename);
-  if (NULL == ego->pk)
+  if (GNUNET_OK !=
+      GNUNET_CRYPTO_ecdsa_key_from_file (filename,
+                                         GNUNET_NO,
+                                         &ego->pk))
   {
     GNUNET_free (ego);
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
@@ -1044,7 +1073,9 @@ process_ego_file (void *cls, const char *filename)
                 filename);
     return GNUNET_OK;
   }
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Loaded ego `%s'\n", fn + 1);
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Loaded ego `%s'\n",
+              fn + 1);
   ego->identifier = GNUNET_strdup (fn + 1);
   GNUNET_CONTAINER_DLL_insert (ego_head, ego_tail, ego);
   return GNUNET_OK;
@@ -1108,7 +1139,9 @@ run (void *cls,
                 _ ("Failed to create directory `%s' for storing egos\n"),
                 ego_directory);
   }
-  GNUNET_DISK_directory_scan (ego_directory, &process_ego_file, NULL);
+  GNUNET_DISK_directory_scan (ego_directory,
+                              &process_ego_file,
+                              NULL);
   GNUNET_SCHEDULER_add_shutdown (&shutdown_task, NULL);
 }
 
