@@ -74,7 +74,7 @@ struct GNUNET_IDENTITY_Operation
   /**
    * Private key to return to @e create_cont, or NULL.
    */
-  struct GNUNET_CRYPTO_EcdsaPrivateKey *pk;
+  struct GNUNET_CRYPTO_EcdsaPrivateKey pk;
 
   /**
    * Continuation to invoke with the result of the transmission for
@@ -105,7 +105,7 @@ struct GNUNET_IDENTITY_Handle
   struct GNUNET_MQ_Handle *mq;
 
   /**
-   * Hash map from the hash of the public key to the
+   * Hash map from the hash of the private key to the
    * respective `GNUNET_IDENTITY_Ego` handle.
    */
   struct GNUNET_CONTAINER_MultiHashMap *egos;
@@ -156,14 +156,18 @@ const struct GNUNET_IDENTITY_Ego *
 GNUNET_IDENTITY_ego_get_anonymous ()
 {
   static struct GNUNET_IDENTITY_Ego anon;
+  static int setup;
   struct GNUNET_CRYPTO_EcdsaPublicKey pub;
 
-  if (NULL != anon.pk)
+  if (setup)
     return &anon;
-  anon.pk = (struct GNUNET_CRYPTO_EcdsaPrivateKey *)
-            GNUNET_CRYPTO_ecdsa_key_get_anonymous ();
-  GNUNET_CRYPTO_ecdsa_key_get_public (anon.pk, &pub);
-  GNUNET_CRYPTO_hash (&pub, sizeof(pub), &anon.id);
+  anon.pk = *GNUNET_CRYPTO_ecdsa_key_get_anonymous ();
+  GNUNET_CRYPTO_ecdsa_key_get_public (&anon.pk,
+                                      &pub);
+  GNUNET_CRYPTO_hash (&anon.pk,
+                      sizeof(anon.pk),
+                      &anon.id);
+  setup = 1;
   return &anon;
 }
 
@@ -186,17 +190,22 @@ reconnect (void *cls);
  * @return #GNUNET_OK (continue to iterate)
  */
 static int
-free_ego (void *cls, const struct GNUNET_HashCode *key, void *value)
+free_ego (void *cls,
+          const struct GNUNET_HashCode *key,
+          void *value)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   struct GNUNET_IDENTITY_Ego *ego = value;
 
   if (NULL != h->cb)
-    h->cb (h->cb_cls, ego, &ego->ctx, NULL);
-  GNUNET_free (ego->pk);
+    h->cb (h->cb_cls, ego,
+           &ego->ctx,
+           NULL);
   GNUNET_free (ego->name);
   GNUNET_assert (GNUNET_YES ==
-                 GNUNET_CONTAINER_multihashmap_remove (h->egos, key, value));
+                 GNUNET_CONTAINER_multihashmap_remove (h->egos,
+                                                       key,
+                                                       value));
   GNUNET_free (ego);
   return GNUNET_OK;
 }
@@ -221,24 +230,31 @@ reschedule_connect (struct GNUNET_IDENTITY_Handle *h)
   }
   while (NULL != (op = h->op_head))
   {
-    GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
+    GNUNET_CONTAINER_DLL_remove (h->op_head,
+                                 h->op_tail,
+                                 op);
     if (NULL != op->cont)
-      op->cont (op->cls, "Error in communication with the identity service");
+      op->cont (op->cls,
+                "Error in communication with the identity service");
     else if (NULL != op->cb)
       op->cb (op->cls, NULL, NULL, NULL);
     else if (NULL != op->create_cont)
       op->create_cont (op->cls,
                        NULL,
                        "Failed to communicate with the identity service");
-    GNUNET_free_non_null (op->pk);
     GNUNET_free (op);
   }
-  GNUNET_CONTAINER_multihashmap_iterate (h->egos, &free_ego, h);
+  GNUNET_CONTAINER_multihashmap_iterate (h->egos,
+                                         &free_ego,
+                                         h);
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Scheduling task to reconnect to identity service in %s.\n",
-       GNUNET_STRINGS_relative_time_to_string (h->reconnect_delay, GNUNET_YES));
+       GNUNET_STRINGS_relative_time_to_string (h->reconnect_delay,
+                                               GNUNET_YES));
   h->reconnect_task =
-    GNUNET_SCHEDULER_add_delayed (h->reconnect_delay, &reconnect, h);
+    GNUNET_SCHEDULER_add_delayed (h->reconnect_delay,
+                                  &reconnect,
+                                  h);
   h->reconnect_delay = GNUNET_TIME_STD_BACKOFF (h->reconnect_delay);
 }
 
@@ -252,7 +268,8 @@ reschedule_connect (struct GNUNET_IDENTITY_Handle *h)
  * @param error error code
  */
 static void
-mq_error_handler (void *cls, enum GNUNET_MQ_Error error)
+mq_error_handler (void *cls,
+                  enum GNUNET_MQ_Error error)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
 
@@ -269,7 +286,8 @@ mq_error_handler (void *cls, enum GNUNET_MQ_Error error)
  * @return #GNUNET_OK if the message is well-formed
  */
 static int
-check_identity_result_code (void *cls, const struct ResultCodeMessage *rcm)
+check_identity_result_code (void *cls,
+                            const struct ResultCodeMessage *rcm)
 {
   if (sizeof(*rcm) != htons (rcm->header.size))
     GNUNET_MQ_check_zero_termination (rcm);
@@ -284,7 +302,8 @@ check_identity_result_code (void *cls, const struct ResultCodeMessage *rcm)
  * @param rcm result message received
  */
 static void
-handle_identity_result_code (void *cls, const struct ResultCodeMessage *rcm)
+handle_identity_result_code (void *cls,
+                             const struct ResultCodeMessage *rcm)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   struct GNUNET_IDENTITY_Operation *op;
@@ -304,8 +323,7 @@ handle_identity_result_code (void *cls, const struct ResultCodeMessage *rcm)
   else if (NULL != op->cb)
     op->cb (op->cls, NULL, NULL, NULL);
   else if (NULL != op->create_cont)
-    op->create_cont (op->cls, (NULL == str) ? op->pk : NULL, str);
-  GNUNET_free_non_null (op->pk);
+    op->create_cont (op->cls, (NULL == str) ? &op->pk : NULL, str);
   GNUNET_free (op);
 }
 
@@ -318,7 +336,8 @@ handle_identity_result_code (void *cls, const struct ResultCodeMessage *rcm)
  * @return #GNUNET_OK if the message is well-formed
  */
 static int
-check_identity_update (void *cls, const struct UpdateMessage *um)
+check_identity_update (void *cls,
+                       const struct UpdateMessage *um)
 {
   uint16_t size = ntohs (um->header.size);
   uint16_t name_len = ntohs (um->name_len);
@@ -341,12 +360,12 @@ check_identity_update (void *cls, const struct UpdateMessage *um)
  * @param um message received
  */
 static void
-handle_identity_update (void *cls, const struct UpdateMessage *um)
+handle_identity_update (void *cls,
+                        const struct UpdateMessage *um)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   uint16_t name_len = ntohs (um->name_len);
   const char *str = (0 == name_len) ? NULL : (const char *) &um[1];
-  struct GNUNET_CRYPTO_EcdsaPublicKey pub;
   struct GNUNET_HashCode id;
   struct GNUNET_IDENTITY_Ego *ego;
 
@@ -357,9 +376,11 @@ handle_identity_update (void *cls, const struct UpdateMessage *um)
       h->cb (h->cb_cls, NULL, NULL, NULL);
     return;
   }
-  GNUNET_CRYPTO_ecdsa_key_get_public (&um->private_key, &pub);
-  GNUNET_CRYPTO_hash (&pub, sizeof(pub), &id);
-  ego = GNUNET_CONTAINER_multihashmap_get (h->egos, &id);
+  GNUNET_CRYPTO_hash (&um->private_key,
+                      sizeof (um->private_key),
+                      &id);
+  ego = GNUNET_CONTAINER_multihashmap_get (h->egos,
+                                           &id);
   if (NULL == ego)
   {
     /* ego was created */
@@ -371,8 +392,8 @@ handle_identity_update (void *cls, const struct UpdateMessage *um)
       return;
     }
     ego = GNUNET_new (struct GNUNET_IDENTITY_Ego);
-    ego->pk = GNUNET_new (struct GNUNET_CRYPTO_EcdsaPrivateKey);
-    *ego->pk = um->private_key;
+    ego->pub_initialized = GNUNET_NO;
+    ego->pk = um->private_key;
     ego->name = GNUNET_strdup (str);
     ego->id = id;
     GNUNET_assert (GNUNET_YES ==
@@ -385,9 +406,10 @@ handle_identity_update (void *cls, const struct UpdateMessage *um)
   if (NULL == str)
   {
     /* ego was deleted */
-    GNUNET_assert (GNUNET_YES == GNUNET_CONTAINER_multihashmap_remove (h->egos,
-                                                                       &ego->id,
-                                                                       ego));
+    GNUNET_assert (GNUNET_YES ==
+                   GNUNET_CONTAINER_multihashmap_remove (h->egos,
+                                                         &ego->id,
+                                                         ego));
   }
   else
   {
@@ -397,11 +419,13 @@ handle_identity_update (void *cls, const struct UpdateMessage *um)
   }
   /* inform application about change */
   if (NULL != h->cb)
-    h->cb (h->cb_cls, ego, &ego->ctx, str);
+    h->cb (h->cb_cls,
+           ego,
+           &ego->ctx,
+           str);
   /* complete deletion */
   if (NULL == str)
   {
-    GNUNET_free (ego->pk);
     GNUNET_free (ego->name);
     GNUNET_free (ego);
   }
@@ -417,7 +441,8 @@ handle_identity_update (void *cls, const struct UpdateMessage *um)
  * @return #GNUNET_OK if the message is well-formed
  */
 static int
-check_identity_set_default (void *cls, const struct SetDefaultMessage *sdm)
+check_identity_set_default (void *cls,
+                            const struct SetDefaultMessage *sdm)
 {
   uint16_t size = ntohs (sdm->header.size) - sizeof(*sdm);
   uint16_t name_len = ntohs (sdm->name_len);
@@ -441,17 +466,19 @@ check_identity_set_default (void *cls, const struct SetDefaultMessage *sdm)
  * @param sdm message received
  */
 static void
-handle_identity_set_default (void *cls, const struct SetDefaultMessage *sdm)
+handle_identity_set_default (void *cls,
+                             const struct SetDefaultMessage *sdm)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
   struct GNUNET_IDENTITY_Operation *op;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pub;
   struct GNUNET_HashCode id;
   struct GNUNET_IDENTITY_Ego *ego;
 
-  GNUNET_CRYPTO_ecdsa_key_get_public (&sdm->private_key, &pub);
-  GNUNET_CRYPTO_hash (&pub, sizeof(pub), &id);
-  ego = GNUNET_CONTAINER_multihashmap_get (h->egos, &id);
+  GNUNET_CRYPTO_hash (&sdm->private_key,
+                      sizeof(sdm->private_key),
+                      &id);
+  ego = GNUNET_CONTAINER_multihashmap_get (h->egos,
+                                           &id);
   if (NULL == ego)
   {
     GNUNET_break (0);
@@ -467,9 +494,14 @@ handle_identity_set_default (void *cls, const struct SetDefaultMessage *sdm)
   }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Received SET_DEFAULT message from identity service\n");
-  GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
+  GNUNET_CONTAINER_DLL_remove (h->op_head,
+                               h->op_tail,
+                               op);
   if (NULL != op->cb)
-    op->cb (op->cls, ego, &ego->ctx, ego->name);
+    op->cb (op->cls,
+            ego,
+            &ego->ctx,
+            ego->name);
   GNUNET_free (op);
 }
 
@@ -483,8 +515,8 @@ static void
 reconnect (void *cls)
 {
   struct GNUNET_IDENTITY_Handle *h = cls;
-  struct GNUNET_MQ_MessageHandler handlers[] =
-  { GNUNET_MQ_hd_var_size (identity_result_code,
+  struct GNUNET_MQ_MessageHandler handlers[] = {
+    GNUNET_MQ_hd_var_size (identity_result_code,
                            GNUNET_MESSAGE_TYPE_IDENTITY_RESULT_CODE,
                            struct ResultCodeMessage,
                            h),
@@ -496,21 +528,28 @@ reconnect (void *cls)
                            GNUNET_MESSAGE_TYPE_IDENTITY_SET_DEFAULT,
                            struct SetDefaultMessage,
                            h),
-    GNUNET_MQ_handler_end () };
+    GNUNET_MQ_handler_end ()
+  };
   struct GNUNET_MQ_Envelope *env;
   struct GNUNET_MessageHeader *msg;
 
   h->reconnect_task = NULL;
-  LOG (GNUNET_ERROR_TYPE_DEBUG, "Connecting to identity service.\n");
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Connecting to identity service.\n");
   GNUNET_assert (NULL == h->mq);
-  h->mq =
-    GNUNET_CLIENT_connect (h->cfg, "identity", handlers, &mq_error_handler, h);
+  h->mq = GNUNET_CLIENT_connect (h->cfg,
+                                 "identity",
+                                 handlers,
+                                 &mq_error_handler,
+                                 h);
   if (NULL == h->mq)
     return;
   if (NULL != h->cb)
   {
-    env = GNUNET_MQ_msg (msg, GNUNET_MESSAGE_TYPE_IDENTITY_START);
-    GNUNET_MQ_send (h->mq, env);
+    env = GNUNET_MQ_msg (msg,
+                         GNUNET_MESSAGE_TYPE_IDENTITY_START);
+    GNUNET_MQ_send (h->mq,
+                    env);
   }
 }
 
@@ -534,7 +573,8 @@ GNUNET_IDENTITY_connect (const struct GNUNET_CONFIGURATION_Handle *cfg,
   h->cfg = cfg;
   h->cb = cb;
   h->cb_cls = cb_cls;
-  h->egos = GNUNET_CONTAINER_multihashmap_create (16, GNUNET_YES);
+  h->egos = GNUNET_CONTAINER_multihashmap_create (16,
+                                                  GNUNET_YES);
   reconnect (h);
   if (NULL == h->mq)
   {
@@ -554,7 +594,7 @@ GNUNET_IDENTITY_connect (const struct GNUNET_CONFIGURATION_Handle *cfg,
 const struct GNUNET_CRYPTO_EcdsaPrivateKey *
 GNUNET_IDENTITY_ego_get_private_key (const struct GNUNET_IDENTITY_Ego *ego)
 {
-  return ego->pk;
+  return &ego->pk;
 }
 
 
@@ -565,10 +605,16 @@ GNUNET_IDENTITY_ego_get_private_key (const struct GNUNET_IDENTITY_Ego *ego)
  * @param pk set to ego's public key
  */
 void
-GNUNET_IDENTITY_ego_get_public_key (const struct GNUNET_IDENTITY_Ego *ego,
+GNUNET_IDENTITY_ego_get_public_key (struct GNUNET_IDENTITY_Ego *ego,
                                     struct GNUNET_CRYPTO_EcdsaPublicKey *pk)
 {
-  GNUNET_CRYPTO_ecdsa_key_get_public (ego->pk, pk);
+  if (GNUNET_NO == ego->pub_initialized)
+  {
+    GNUNET_CRYPTO_ecdsa_key_get_public (&ego->pk,
+                                        &ego->pub);
+    ego->pub_initialized = GNUNET_YES;
+  }
+  *pk = ego->pub;
 }
 
 
@@ -657,7 +703,7 @@ GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *h,
     GNUNET_MQ_msg_extra (sdm, slen, GNUNET_MESSAGE_TYPE_IDENTITY_SET_DEFAULT);
   sdm->name_len = htons (slen);
   sdm->reserved = htons (0);
-  sdm->private_key = *ego->pk;
+  sdm->private_key = ego->pk;
   GNUNET_memcpy (&sdm[1], service_name, slen);
   GNUNET_MQ_send (h->mq, env);
   return op;
@@ -669,6 +715,7 @@ GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *h,
  *
  * @param h identity service to use
  * @param name desired name
+ * @param privkey desired private key or NULL to create one
  * @param cont function to call with the result (will only be called once)
  * @param cont_cls closure for @a cont
  * @return handle to abort the operation
@@ -676,13 +723,13 @@ GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *h,
 struct GNUNET_IDENTITY_Operation *
 GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *h,
                         const char *name,
+                        const struct GNUNET_CRYPTO_EcdsaPrivateKey *privkey,
                         GNUNET_IDENTITY_CreateContinuation cont,
                         void *cont_cls)
 {
   struct GNUNET_IDENTITY_Operation *op;
   struct GNUNET_MQ_Envelope *env;
   struct CreateRequestMessage *crm;
-  struct GNUNET_CRYPTO_EcdsaPrivateKey *pk;
   size_t slen;
 
   if (NULL == h->mq)
@@ -701,9 +748,11 @@ GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *h,
   env = GNUNET_MQ_msg_extra (crm, slen, GNUNET_MESSAGE_TYPE_IDENTITY_CREATE);
   crm->name_len = htons (slen);
   crm->reserved = htons (0);
-  pk = GNUNET_CRYPTO_ecdsa_key_create ();
-  crm->private_key = *pk;
-  op->pk = pk;
+  if (NULL == privkey)
+    GNUNET_CRYPTO_ecdsa_key_create (&crm->private_key);
+  else
+    crm->private_key = *privkey;
+  op->pk = crm->private_key;
   GNUNET_memcpy (&crm[1], name, slen);
   GNUNET_MQ_send (h->mq, env);
   return op;
@@ -820,11 +869,9 @@ GNUNET_IDENTITY_cancel (struct GNUNET_IDENTITY_Operation *op)
   op->cont = NULL;
   op->cb = NULL;
   op->create_cont = NULL;
-  if (NULL != op->pk)
-  {
-    GNUNET_free (op->pk);
-    op->pk = NULL;
-  }
+  memset (&op->pk,
+          0,
+          sizeof (op->pk));
 }
 
 
@@ -846,7 +893,9 @@ GNUNET_IDENTITY_disconnect (struct GNUNET_IDENTITY_Handle *h)
   }
   if (NULL != h->egos)
   {
-    GNUNET_CONTAINER_multihashmap_iterate (h->egos, &free_ego, h);
+    GNUNET_CONTAINER_multihashmap_iterate (h->egos,
+                                           &free_ego,
+                                           h);
     GNUNET_CONTAINER_multihashmap_destroy (h->egos);
     h->egos = NULL;
   }
@@ -854,7 +903,9 @@ GNUNET_IDENTITY_disconnect (struct GNUNET_IDENTITY_Handle *h)
   {
     GNUNET_break (NULL == op->cont);
     GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
-    GNUNET_free_non_null (op->pk);
+    memset (&op->pk,
+            0,
+            sizeof (op->pk));
     GNUNET_free (op);
   }
   if (NULL != h->mq)
