@@ -36,11 +36,6 @@
  */
 #define GNUNET_REST_API_NS_IDENTITY "/identity"
 
-/**
- * Identity Namespace with public key specifier
- */
-#define GNUNET_REST_API_NS_IDENTITY_ALL "/identity/all"
-
 /**
  * Identity Namespace with public key specifier
  */
@@ -61,6 +56,11 @@
  */
 #define GNUNET_REST_IDENTITY_PARAM_PUBKEY "pubkey"
 
+/**
+ * Parameter private key
+ */
+#define GNUNET_REST_IDENTITY_PARAM_PRIVKEY "privkey"
+
 /**
  * Parameter subsystem
  */
@@ -314,6 +314,7 @@ do_error (void *cls)
     handle->response_code = MHD_HTTP_OK;
   response = json_dumps (json_error, 0);
   resp = GNUNET_REST_create_response (response);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, handle->response_code);
   json_decref (json_error);
   GNUNET_free (response);
@@ -403,7 +404,7 @@ ego_get_for_subsystem (void *cls,
   result_str = json_dumps (json_root, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result_str);
   resp = GNUNET_REST_create_response (result_str);
-
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   json_decref (json_root);
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
   GNUNET_free (result_str);
@@ -467,9 +468,11 @@ ego_get_all (struct GNUNET_REST_RequestHandle *con_handle,
   struct RequestHandle *handle = cls;
   struct EgoEntry *ego_entry;
   struct MHD_Response *resp;
+  struct GNUNET_HashCode key;
   json_t *json_root;
   json_t *json_ego;
   char *result_str;
+  char *privkey_str;
 
   json_root = json_array ();
   // Return ego/egos
@@ -480,6 +483,19 @@ ego_get_all (struct GNUNET_REST_RequestHandle *con_handle,
     json_object_set_new (json_ego,
                          GNUNET_REST_IDENTITY_PARAM_PUBKEY,
                          json_string (ego_entry->keystring));
+    GNUNET_CRYPTO_hash ("private", strlen ("private"), &key);
+    if (GNUNET_YES ==
+        GNUNET_CONTAINER_multihashmap_contains (
+          handle->rest_handle->url_param_map, &key))
+    {
+      privkey_str = GNUNET_CRYPTO_ecdsa_private_key_to_string (
+        GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego));
+      json_object_set_new (json_ego,
+                           GNUNET_REST_IDENTITY_PARAM_PRIVKEY,
+                           json_string (privkey_str));
+      GNUNET_free (privkey_str);
+    }
+
     json_object_set_new (json_ego,
                          GNUNET_REST_IDENTITY_PARAM_NAME,
                          json_string (ego_entry->identifier));
@@ -490,7 +506,7 @@ ego_get_all (struct GNUNET_REST_RequestHandle *con_handle,
   result_str = json_dumps (json_root, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result_str);
   resp = GNUNET_REST_create_response (result_str);
-
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   json_decref (json_root);
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
   GNUNET_free (result_str);
@@ -508,8 +524,10 @@ void
 ego_get_response (struct RequestHandle *handle, struct EgoEntry *ego_entry)
 {
   struct MHD_Response *resp;
+  struct GNUNET_HashCode key;
   json_t *json_ego;
   char *result_str;
+  char *privkey_str;
 
   json_ego = json_object ();
   json_object_set_new (json_ego,
@@ -518,12 +536,24 @@ ego_get_response (struct RequestHandle *handle, struct EgoEntry *ego_entry)
   json_object_set_new (json_ego,
                        GNUNET_REST_IDENTITY_PARAM_NAME,
                        json_string (ego_entry->identifier));
+  GNUNET_CRYPTO_hash ("private", strlen ("private"), &key);
+  if (GNUNET_YES ==
+      GNUNET_CONTAINER_multihashmap_contains (
+        handle->rest_handle->url_param_map, &key))
+  {
+    privkey_str = GNUNET_CRYPTO_ecdsa_private_key_to_string (
+      GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego));
+    json_object_set_new (json_ego,
+                         GNUNET_REST_IDENTITY_PARAM_PRIVKEY,
+                         json_string (privkey_str));
+    GNUNET_free (privkey_str);
+  }
 
   result_str = json_dumps (json_ego, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result_str);
   resp = GNUNET_REST_create_response (result_str);
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
-
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   json_decref (json_ego);
   GNUNET_free (result_str);
   GNUNET_SCHEDULER_add_now (&cleanup_handle, handle);
@@ -960,6 +990,9 @@ ego_create (struct GNUNET_REST_RequestHandle *con_handle,
   json_t *data_js;
   json_error_t err;
   char *egoname;
+  char *privkey;
+  struct GNUNET_CRYPTO_EcdsaPrivateKey pk;
+  struct GNUNET_CRYPTO_EcdsaPrivateKey *pk_ptr;
   int json_unpack_state;
   char term_data[handle->data_size + 1];
 
@@ -986,8 +1019,11 @@ ego_create (struct GNUNET_REST_RequestHandle *con_handle,
     return;
   }
   json_unpack_state = 0;
+  privkey = NULL;
   json_unpack_state =
-    json_unpack (data_js, "{s:s!}", GNUNET_REST_IDENTITY_PARAM_NAME, &egoname);
+    json_unpack (data_js, "{s:s, s?:s!}",
+                 GNUNET_REST_IDENTITY_PARAM_NAME, &egoname,
+                 GNUNET_REST_IDENTITY_PARAM_PRIVKEY, &privkey);
   if (0 != json_unpack_state)
   {
     handle->emsg = GNUNET_strdup (GNUNET_REST_ERROR_DATA_INVALID);
@@ -1024,10 +1060,21 @@ ego_create (struct GNUNET_REST_RequestHandle *con_handle,
     }
   }
   handle->name = GNUNET_strdup (egoname);
+  if (NULL != privkey)
+  {
+    GNUNET_STRINGS_string_to_data (privkey,
+                                   strlen (privkey),
+                                   &pk,
+                                   sizeof(struct GNUNET_CRYPTO_EcdsaPrivateKey));
+    pk_ptr = &pk;
+  }
+  else
+    pk_ptr = NULL;
   json_decref (data_js);
   handle->response_code = MHD_HTTP_CREATED;
   handle->op = GNUNET_IDENTITY_create (handle->identity_handle,
                                        handle->name,
+                                       pk_ptr,
                                        &do_finished_create,
                                        handle);
 }
@@ -1155,7 +1202,7 @@ init_cont (struct RequestHandle *handle)
 {
   struct GNUNET_REST_RequestHandlerError err;
   static const struct GNUNET_REST_RequestHandler handlers[] =
-  { { MHD_HTTP_METHOD_GET, GNUNET_REST_API_NS_IDENTITY_ALL, &ego_get_all },
+  { { MHD_HTTP_METHOD_GET, GNUNET_REST_API_NS_IDENTITY, &ego_get_all },
     { MHD_HTTP_METHOD_GET, GNUNET_REST_API_NS_IDENTITY_PUBKEY,
       &ego_get_pubkey },
     { MHD_HTTP_METHOD_GET, GNUNET_REST_API_NS_IDENTITY_NAME, &ego_get_name },
@@ -1375,7 +1422,7 @@ libgnunet_plugin_rest_identity_done (void *cls)
 
   plugin->cfg = NULL;
 
-  GNUNET_free_non_null (allow_methods);
+  GNUNET_free (allow_methods);
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Identity REST plugin is finished\n");
   return NULL;
