@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     Copyright (C) 2006-2013 GNUnet e.V.
+     Copyright (C) 2006-2020 GNUnet e.V.
 
      GNUnet is free software: you can redistribute it and/or modify it
      under the terms of the GNU Affero General Public License as published
@@ -16,7 +16,7 @@
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 
 /**
  * @file include/gnunet_common.h
@@ -36,21 +36,26 @@
 #ifndef GNUNET_COMMON_H
 #define GNUNET_COMMON_H
 
+#include <stdlib.h>
 #if HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
 #if HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#ifdef MINGW
-#include "winproc.h"
-#endif
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
 #ifdef HAVE_STDARG_H
 #include <stdarg.h>
 #endif
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
+
 
 #ifdef HAVE_BYTESWAP_H
 #include <byteswap.h>
@@ -66,7 +71,7 @@ extern "C" {
 /**
  * Version of the API (for entire gnunetutil.so library).
  */
-#define GNUNET_UTIL_VERSION 0x000A0102
+#define GNUNET_UTIL_VERSION 0x000A0103
 
 
 /**
@@ -75,10 +80,15 @@ extern "C" {
  * GNUNET_SYSERR`, `GNUNET_OK != GNUNET_NO`, `GNUNET_NO !=
  * GNUNET_SYSERR` and finally `GNUNET_YES != GNUNET_NO`.
  */
-#define GNUNET_OK 1
-#define GNUNET_SYSERR -1
-#define GNUNET_YES 1
-#define GNUNET_NO 0
+enum GNUNET_GenericReturnValue
+{
+  GNUNET_SYSERR = -1,
+  GNUNET_NO = 0,
+  GNUNET_OK = 1,
+  /* intentionally identical to #GNUNET_OK! */
+  GNUNET_YES = 1,
+};
+
 
 #define GNUNET_MIN(a, b) (((a) < (b)) ? (a) : (b))
 
@@ -189,11 +199,7 @@ extern "C" {
 /**
  * gcc-ism to get gcc bitfield layout when compiling with -mms-bitfields
  */
-#if MINGW
-#define GNUNET_GCC_STRUCT_LAYOUT __attribute__ ((gcc_struct))
-#else
 #define GNUNET_GCC_STRUCT_LAYOUT
-#endif
 
 /**
  * gcc-ism to force alignment; we use this to align char-arrays
@@ -216,28 +222,6 @@ extern "C" {
  */
 #define GNUNET_NORETURN __attribute__ ((noreturn))
 
-#if MINGW
-#if __GNUC__ > 3
-/**
- * gcc 4.x-ism to pack structures even on W32 (to be used before structs);
- * Using this would cause structs to be unaligned on the stack on Sparc,
- * so we *only* use this on W32 (see #670578 from Debian); fortunately,
- * W32 doesn't run on sparc anyway.
- */
-#define GNUNET_NETWORK_STRUCT_BEGIN _Pragma ("pack(push)") _Pragma ("pack(1)")
-
-/**
- * gcc 4.x-ism to pack structures even on W32 (to be used after structs)
- * Using this would cause structs to be unaligned on the stack on Sparc,
- * so we *only* use this on W32 (see #670578 from Debian); fortunately,
- * W32 doesn't run on sparc anyway.
- */
-#define GNUNET_NETWORK_STRUCT_END _Pragma ("pack(pop)")
-
-#else
-#error gcc 4.x or higher required on W32 systems
-#endif
-#else
 /**
  * Define as empty, GNUNET_PACKED should suffice, but this won't work on W32
  */
@@ -247,7 +231,6 @@ extern "C" {
  * Define as empty, GNUNET_PACKED should suffice, but this won't work on W32;
  */
 #define GNUNET_NETWORK_STRUCT_END
-#endif
 
 /* ************************ super-general types *********************** */
 
@@ -258,7 +241,7 @@ GNUNET_NETWORK_STRUCT_BEGIN
  */
 struct GNUNET_HashCode
 {
-  uint32_t bits[512 / 8 / sizeof (uint32_t)]; /* = 16 */
+  uint32_t bits[512 / 8 / sizeof(uint32_t)];  /* = 16 */
 };
 
 
@@ -268,7 +251,19 @@ struct GNUNET_HashCode
  */
 struct GNUNET_ShortHashCode
 {
-  uint32_t bits[256 / 8 / sizeof (uint32_t)]; /* = 8 */
+  uint32_t bits[256 / 8 / sizeof(uint32_t)];  /* = 8 */
+};
+
+
+/**
+ * A UUID, a 128 bit random value.
+ */
+struct GNUNET_Uuid
+{
+  /**
+   * 128 random bits.
+   */
+  uint32_t value[4];
 };
 
 
@@ -277,7 +272,6 @@ struct GNUNET_ShortHashCode
  */
 struct GNUNET_MessageHeader
 {
-
   /**
    * The length of the struct (in bytes, including the length field itself),
    * in big-endian format.
@@ -319,7 +313,7 @@ struct GNUNET_OperationResultMessage
  */
 struct GNUNET_AsyncScopeId
 {
-  uint32_t bits[16 / sizeof (uint32_t)]; /* = 16 bytes */
+  uint32_t bits[16 / sizeof(uint32_t)];  /* = 16 bytes */
 };
 
 GNUNET_NETWORK_STRUCT_END
@@ -351,7 +345,9 @@ struct GNUNET_AsyncScopeSave
  *  #GNUNET_NO to stop iteration with no error,
  *  #GNUNET_SYSERR to abort iteration with error!
  */
-typedef int (*GNUNET_FileNameCallback) (void *cls, const char *filename);
+typedef int
+(*GNUNET_FileNameCallback) (void *cls,
+                            const char *filename);
 
 
 /**
@@ -359,7 +355,8 @@ typedef int (*GNUNET_FileNameCallback) (void *cls, const char *filename);
  *
  * @param cls  Closure.
  */
-typedef void (*GNUNET_ContinuationCallback) (void *cls);
+typedef void
+(*GNUNET_ContinuationCallback) (void *cls);
 
 
 /**
@@ -374,10 +371,11 @@ typedef void (*GNUNET_ContinuationCallback) (void *cls);
  * @param data_size
  *        Size of @a data.
  */
-typedef void (*GNUNET_ResultCallback) (void *cls,
-                                       int64_t result_code,
-                                       const void *data,
-                                       uint16_t data_size);
+typedef void
+(*GNUNET_ResultCallback) (void *cls,
+                          int64_t result_code,
+                          const void *data,
+                          uint16_t data_size);
 
 
 /* ****************************** logging ***************************** */
@@ -437,6 +435,7 @@ GNUNET_get_log_call_status (int caller_level,
                             const char *file,
                             const char *function,
                             int line);
+
 #endif
 
 
@@ -450,12 +449,12 @@ GNUNET_get_log_call_status (int caller_level,
  */
 void
 GNUNET_log_nocheck (enum GNUNET_ErrorType kind, const char *message, ...)
-  __attribute__ ((format (printf, 2, 3)));
+__attribute__ ((format (printf, 2, 3)));
 
 /* from glib */
 #if defined(__GNUC__) && (__GNUC__ > 2) && defined(__OPTIMIZE__)
 #define _GNUNET_BOOLEAN_EXPR(expr) \
-  __extension__({                  \
+  __extension__ ({                  \
     int _gnunet_boolean_var_;      \
     if (expr)                      \
       _gnunet_boolean_var_ = 1;    \
@@ -495,7 +494,6 @@ GNUNET_log_from_nocheck (enum GNUNET_ErrorType kind,
 #define GNUNET_log_from(kind, comp, ...)                                  \
   do                                                                      \
   {                                                                       \
-    int log_line = __LINE__;                                              \
     static int log_call_enabled = GNUNET_LOG_CALL_STATUS;                 \
     if ((GNUNET_EXTRA_LOGGING > 0) ||                                     \
         ((GNUNET_ERROR_TYPE_DEBUG & (kind)) == 0))                        \
@@ -506,7 +504,7 @@ GNUNET_log_from_nocheck (enum GNUNET_ErrorType kind,
                                       (comp),                             \
                                       __FILE__,                           \
                                       __FUNCTION__,                       \
-                                      log_line);                          \
+                                      __LINE__);                          \
       if (GN_UNLIKELY (GNUNET_get_log_skip () > 0))                       \
       {                                                                   \
         GNUNET_log_skip (-1, GNUNET_NO);                                  \
@@ -522,7 +520,6 @@ GNUNET_log_from_nocheck (enum GNUNET_ErrorType kind,
 #define GNUNET_log(kind, ...)                                             \
   do                                                                      \
   {                                                                       \
-    int log_line = __LINE__;                                              \
     static int log_call_enabled = GNUNET_LOG_CALL_STATUS;                 \
     if ((GNUNET_EXTRA_LOGGING > 0) ||                                     \
         ((GNUNET_ERROR_TYPE_DEBUG & (kind)) == 0))                        \
@@ -533,7 +530,7 @@ GNUNET_log_from_nocheck (enum GNUNET_ErrorType kind,
                                       NULL,                               \
                                       __FILE__,                           \
                                       __FUNCTION__,                       \
-                                      log_line);                          \
+                                      __LINE__);                          \
       if (GN_UNLIKELY (GNUNET_get_log_skip () > 0))                       \
       {                                                                   \
         GNUNET_log_skip (-1, GNUNET_NO);                                  \
@@ -653,6 +650,19 @@ const char *
 GNUNET_sh2s (const struct GNUNET_ShortHashCode *shc);
 
 
+/**
+ * @ingroup logging
+ * Convert a UUID to a string (for printing debug messages).
+ * This is one of the very few calls in the entire API that is
+ * NOT reentrant!
+ *
+ * @param uuid the UUID
+ * @return string
+ */
+const char *
+GNUNET_uuid2s (const struct GNUNET_Uuid *uuid);
+
+
 /**
  * @ingroup logging
  * Convert a hash value to a string (for printing debug messages).
@@ -759,6 +769,12 @@ const char *
 GNUNET_e2s2 (const struct GNUNET_CRYPTO_EcdhePublicKey *p);
 
 
+/**
+ * Forward declaration to make compiler happy depending on include order.
+ */
+struct GNUNET_PeerIdentity;
+
+
 /**
  * @ingroup logging
  * Convert a peer identity to a string (for printing debug messages).
@@ -887,6 +903,28 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
   } while (0)
 
 
+#if HAVE_STATIC_ASSERT
+/**
+ * Assertion to be checked (if supported by C compiler) at
+ * compile time, otherwise checked at runtime and resulting
+ * in an abort() on failure.
+ *
+ * @param cond condition to test, 0 implies failure
+ */
+#define GNUNET_static_assert(cond) _Static_assert (cond, "")
+#else
+/**
+ * Assertion to be checked (if supported by C compiler) at
+ * compile time, otherwise checked at runtime and resulting
+ * in an abort() on failure.  This is the case where the
+ * compiler does not support static assertions.
+ *
+ * @param cond condition to test, 0 implies failure
+ */
+#define GNUNET_static_assert(cond) GNUNET_assert (cond)
+#endif
+
+
 /**
  * @ingroup logging
  * Use this for internal assertion violations that are
@@ -941,7 +979,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                 cmd,                                         \
                 __FILE__,                                    \
                 __LINE__,                                    \
-                STRERROR (errno));                           \
+                strerror (errno));                           \
   } while (0)
 
 
@@ -960,7 +998,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                      cmd,                                         \
                      __FILE__,                                    \
                      __LINE__,                                    \
-                     STRERROR (errno));                           \
+                     strerror (errno));                           \
   } while (0)
 
 
@@ -979,7 +1017,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                 filename,                                                 \
                 __FILE__,                                                 \
                 __LINE__,                                                 \
-                STRERROR (errno));                                        \
+                strerror (errno));                                        \
   } while (0)
 
 
@@ -999,11 +1037,16 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                      filename,                                                 \
                      __FILE__,                                                 \
                      __LINE__,                                                 \
-                     STRERROR (errno));                                        \
+                     strerror (errno));                                        \
   } while (0)
 
 /* ************************* endianess conversion ****************** */
 
+#ifdef htonbe64
+
+#define GNUNET_htonll(n) htobe64 (n)
+
+#else
 /**
  * Convert unsigned 64-bit integer to network byte order.
  *
@@ -1015,7 +1058,14 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
 uint64_t
 GNUNET_htonll (uint64_t n);
 
+#endif
 
+
+#ifdef be64toh
+
+#define GNUNET_ntohll(n) be64toh (n)
+
+#else
 /**
  * Convert unsigned 64-bit integer to host byte order.
  *
@@ -1027,6 +1077,8 @@ GNUNET_htonll (uint64_t n);
 uint64_t
 GNUNET_ntohll (uint64_t n);
 
+#endif
+
 
 /**
  * Convert double to network byte order.
@@ -1068,32 +1120,75 @@ GNUNET_ntoh_double (double d);
  *
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
-#define GNUNET_new(type) (type *) GNUNET_malloc (sizeof (type))
+#define GNUNET_new(type) (type *) GNUNET_malloc (sizeof(type))
 
 
 /**
  * Compare memory in @a a and @a b, where both must be of
  * the same pointer type.
+ *
+ * Do NOT use this function on arrays, it would only compare
+ * the first element!
  */
 #define GNUNET_memcmp(a, b)       \
   ({                              \
-    const typeof (*b) *_a = (a);  \
-    const typeof (*a) *_b = (b);  \
-    memcmp (_a, _b, sizeof (*a)); \
+    const typeof (*b) * _a = (a);  \
+    const typeof (*a) * _b = (b);  \
+    memcmp (_a, _b, sizeof(*a)); \
   })
 
 
+/**
+ * Compare memory in @a b1 and @a b2 in constant time, suitable for private
+ * data.
+ *
+ * @param b1 some buffer of size @a len
+ * @param b2 another buffer of size @a len
+ * @param len number of bytes in @a b1 and @a b2
+ * @return 0 if buffers are equal,
+ */
+int
+GNUNET_memcmp_ct_ (const void *b1,
+                   const void *b2,
+                   size_t len);
+
+/**
+ * Compare memory in @a a and @a b in constant time, suitable for private
+ * data. Both @a a and @a b must be of the same pointer type.
+ *
+ * Do NOT use this function on arrays, it would only compare
+ * the first element!
+ */
+#define GNUNET_memcmp_priv(a, b)       \
+  ({                              \
+    const typeof (*b) * _a = (a);  \
+    const typeof (*a) * _b = (b);  \
+    GNUNET_memcmp_ct_ (_a, _b, sizeof(*a)); \
+  })
+
+
+/**
+ * Check that memory in @a a is all zeros. @a a must be a pointer.
+ *
+ * @param a pointer to @a n bytes which should be tested for the
+ *          entire memory being zero'ed out.
+ * @param n number of bytes in @a to be tested
+ * @return 0 if a is zero, non-zero otherwise
+ */
+int
+GNUNET_is_zero_ (const void *a,
+                 size_t n);
+
+
 /**
  * Check that memory in @a a is all zeros. @a a must be a pointer.
  *
  * @param a pointer to a struct which should be tested for the
  *          entire memory being zero'ed out.
+ * @return 0 if a is zero, non-zero otherwise
  */
 #define GNUNET_is_zero(a)           \
-  ({                                \
-    static const typeof (*a) _z;    \
-    memcmp ((a), &_z, sizeof (_z)); \
-  })
+  GNUNET_is_zero_ (a, sizeof (*a))
 
 
 /**
@@ -1124,7 +1219,10 @@ GNUNET_ntoh_double (double d);
  * @param n number of elements in the array
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
-#define GNUNET_new_array(n, type) (type *) GNUNET_malloc ((n) * sizeof (type))
+#define GNUNET_new_array(n, type) ({ \
+    GNUNET_assert (SIZE_MAX / sizeof (type) >= n);     \
+    (type *) GNUNET_malloc ((n) * sizeof(type));   \
+  })
 
 /**
  * @ingroup memory
@@ -1136,7 +1234,7 @@ GNUNET_ntoh_double (double d);
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
 #define GNUNET_new_array_2d(n, m, type) \
-  (type **) GNUNET_xnew_array_2d_ (n, m, sizeof (type), __FILE__, __LINE__)
+  (type **) GNUNET_xnew_array_2d_ (n, m, sizeof(type), __FILE__, __LINE__)
 
 /**
  * @ingroup memory
@@ -1149,7 +1247,7 @@ GNUNET_ntoh_double (double d);
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
 #define GNUNET_new_array_3d(n, m, o, type) \
-  (type ***) GNUNET_xnew_array_3d_ (n, m, o, sizeof (type), __FILE__, __LINE__)
+  (type ***) GNUNET_xnew_array_3d_ (n, m, o, sizeof(type), __FILE__, __LINE__)
 
 /**
  * @ingroup memory
@@ -1183,6 +1281,7 @@ GNUNET_ntoh_double (double d);
 #define GNUNET_malloc_large(size) \
   GNUNET_xmalloc_unchecked_ (size, __FILE__, __LINE__)
 
+
 /**
  * @ingroup memory
  * Wrapper around realloc. Reallocates size bytes of memory.
@@ -1195,33 +1294,35 @@ GNUNET_ntoh_double (double d);
 #define GNUNET_realloc(ptr, size) \
   GNUNET_xrealloc_ (ptr, size, __FILE__, __LINE__)
 
+
 /**
  * @ingroup memory
  * Wrapper around free. Frees the memory referred to by ptr.
  * Note that it is generally better to free memory that was
- * allocated with #GNUNET_array_grow using #GNUNET_array_grow(mem, size, 0) instead of #GNUNET_free.
+ * allocated with #GNUNET_array_grow using #GNUNET_array_grow(mem, size, 0) instead of #GNUNET_free_nz.
  *
  * @param ptr location where to free the memory. ptr must have
- *     been returned by #GNUNET_strdup, #GNUNET_strndup, #GNUNET_malloc or #GNUNET_array_grow earlier.
+ *     been returned by #GNUNET_strdup, #GNUNET_strndup, #GNUNET_malloc or #GNUNET_array_grow earlier.  NULL is allowed.
  */
-#define GNUNET_free(ptr) GNUNET_xfree_ (ptr, __FILE__, __LINE__)
+#define GNUNET_free_nz(ptr) GNUNET_xfree_ (ptr, __FILE__, __LINE__)
+
 
 /**
  * @ingroup memory
- * Free the memory pointed to by ptr if ptr is not NULL.
- * Equivalent to `if (NULL != ptr) GNUNET_free(ptr)`.
+ * Wrapper around free. Frees the memory referred to by ptr and sets ptr to NULL.
+ * Note that it is generally better to free memory that was
+ * allocated with #GNUNET_array_grow using #GNUNET_array_grow(mem, size, 0) instead of #GNUNET_free.
  *
- * @param ptr the location in memory to free
+ * @a ptr will be set to NULL. Use #GNUNET_free_nz() if @a ptr is not an L-value.
+ *
+ * @param ptr location where to free the memory. ptr must have
+ *     been returned by #GNUNET_strdup, #GNUNET_strndup, #GNUNET_malloc or #GNUNET_array_grow earlier.  NULL is allowed.
  */
-#define GNUNET_free_non_null(ptr) \
-  do                              \
-  {                               \
-    void *__x__ = ptr;            \
-    if (__x__ != NULL)            \
-    {                             \
-      GNUNET_free (__x__);        \
-    }                             \
-  } while (0)
+#define GNUNET_free(ptr) do { \
+    GNUNET_xfree_ (ptr, __FILE__, __LINE__); \
+    ptr = NULL; \
+} while (0)
+
 
 /**
  * @ingroup memory
@@ -1282,7 +1383,7 @@ GNUNET_ntoh_double (double d);
  */
 #define GNUNET_array_grow(arr, size, tsize) \
   GNUNET_xgrow_ ((void **) &(arr),          \
-                 sizeof ((arr)[0]),         \
+                 sizeof((arr)[0]),         \
                  &size,                     \
                  tsize,                     \
                  __FILE__,                  \
@@ -1290,22 +1391,58 @@ GNUNET_ntoh_double (double d);
 
 /**
  * @ingroup memory
- * Append an element to a list (growing the list by one).
+ * Append an element to an array (growing the array by one).
  *
- * @param arr base-pointer of the vector, may be NULL if size is 0;
+ * @param arr base-pointer of the vector, may be NULL if @a len is 0;
  *        will be updated to reflect the new address. The TYPE of
  *        arr is important since size is the number of elements and
  *        not the size in bytes
- * @param size the number of elements in the existing vector (number
+ * @param len the number of elements in the existing vector (number
  *        of elements to copy over), will be updated with the new
- *        array size
+ *        array length
  * @param element the element that will be appended to the array
  */
-#define GNUNET_array_append(arr, size, element) \
+#define GNUNET_array_append(arr, len, element) \
   do                                            \
   {                                             \
-    GNUNET_array_grow (arr, size, size + 1);    \
-    (arr)[size - 1] = element;                  \
+    GNUNET_assert ((len) + 1 > (len)); \
+    GNUNET_array_grow (arr, len, len + 1);    \
+    (arr) [len - 1] = element;                  \
+  } while (0)
+
+
+/**
+ * @ingroup memory
+ * Append @a arr2 to @a arr1 (growing @a arr1
+ * as needed).  The @a arr2 array is left unchanged. Naturally
+ * this function performs a shallow copy. Both arrays must have
+ * the same type for their elements.
+ *
+ * @param arr1 base-pointer of the vector, may be NULL if @a len is 0;
+ *        will be updated to reflect the new address. The TYPE of
+ *        arr is important since size is the number of elements and
+ *        not the size in bytes
+ * @param len1 the number of elements in the existing vector (number
+ *        of elements to copy over), will be updated with the new
+ *        array size
+ * @param arr2 base-pointer a second array to concatenate, may be NULL if @a len2 is 0;
+ *        will be updated to reflect the new address. The TYPE of
+ *        arr is important since size is the number of elements and
+ *        not the size in bytes
+ * @param len the number of elements in the existing vector (number
+ *        of elements to copy over), will be updated with the new
+ *        array size
+
+ */
+#define GNUNET_array_concatenate(arr1, len1, arr2, len2)   \
+  do                                            \
+  {                                             \
+    const typeof (*arr2) * _a1 = (arr1);  \
+    const typeof (*arr1) * _a2 = (arr2);  \
+    GNUNET_assert ((len1) + (len2) >= (len1));                    \
+    GNUNET_assert (SIZE_MAX / sizeof (*_a1) >= ((len1) + (len2))); \
+    GNUNET_array_grow (arr1, len1, (len1) + (len2));            \
+    memcpy (&(arr1) [(len1) - (len2)], _a2, (len2) * sizeof (*arr1));    \
   } while (0)
 
 /**
