@@ -1,30 +1,33 @@
 /*
-  This file is part of GNUnet
-  (C) 2013 Christian Grothoff (and other contributing authors)
+   This file is part of GNUnet
+   Copyright (C) 2013, 2014, 2016 GNUnet e.V.
 
-  GNUnet is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published
-  by the Free Software Foundation; either version 3, or (at your
-  option) any later version.
+   GNUnet is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Affero General Public License as published
+   by the Free Software Foundation, either version 3 of the License,
+   or (at your option) any later version.
 
-  GNUnet is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+   GNUnet is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Affero General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with GNUnet; see the file COPYING.  If not, write to the
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU Affero General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     SPDX-License-Identifier: AGPL3.0-or-later
  */
 
 /**
- * @file include/gnunet_conversation_service.h
- * @brief API to the conversation service
  * @author Simon Dieterle
  * @author Andreas Fuchs
  * @author Christian Grothoff
  *
+ * @file
+ * API to the conversation service
+ *
+ * @defgroup conversation  Conversation service
+ * One-to-one voice communication over CADET
  *
  * NOTE: This API is deliberately deceptively simple; the idea
  * is that advanced features (such as answering machines) will
@@ -41,6 +44,8 @@
  * course provided as part of the basic implementation, as only the
  * CONVERSATION service can know for sure who it is that we are
  * talking to.
+ *
+ * @{
  */
 #ifndef GNUNET_CONVERSATION_SERVICE_H
 #define GNUNET_CONVERSATION_SERVICE_H
@@ -48,7 +53,7 @@
 #ifdef __cplusplus
 extern "C"
 {
-#if 0				/* keep Emacsens' auto-indent happy */
+#if 0                           /* keep Emacsens' auto-indent happy */
 }
 #endif
 #endif
@@ -63,7 +68,7 @@ extern "C"
 /**
  * Version of the conversation API.
  */
-#define GNUNET_CONVERSATION_VERSION 0x00000003
+#define GNUNET_CONVERSATION_VERSION 0x00000004
 
 /**
  * Handle to identify a particular caller.  A caller is an entity that
@@ -83,24 +88,27 @@ GNUNET_NETWORK_STRUCT_BEGIN
  */
 struct GNUNET_CONVERSATION_PhoneRecord
 {
-
   /**
-   * Version of the phone record, for now always zero.  We may
+   * Version of the phone record, for now always one.  We may
    * use other versions for anonymously hosted phone lines in
    * the future.
    */
   uint32_t version GNUNET_PACKED;
 
   /**
-   * Phone line to use at the peer.
+   * Reserved. In v1. always zero.
    */
-  uint32_t line GNUNET_PACKED;
+  uint32_t reserved GNUNET_PACKED;
 
   /**
    * Identity of the peer hosting the phone service.
    */
   struct GNUNET_PeerIdentity peer;
 
+  /**
+   * Phone line (CADET port) to connect to.
+   */
+  struct GNUNET_HashCode line_port;
 };
 
 GNUNET_NETWORK_STRUCT_END
@@ -121,7 +129,6 @@ enum GNUNET_CONVERSATION_PhoneEventCode
    * We must no longer use the caller's handle.
    */
   GNUNET_CONVERSATION_EC_PHONE_HUNG_UP
-
 };
 
 
@@ -131,12 +138,16 @@ enum GNUNET_CONVERSATION_PhoneEventCode
  * @param cls closure
  * @param code type of the event
  * @param caller handle for the caller
- * @param caller_id name of the caller in GNS
+ * @param caller_id public key of the caller (in GNS)
  */
-typedef void (*GNUNET_CONVERSATION_PhoneEventHandler)(void *cls,
-                                                      enum GNUNET_CONVERSATION_PhoneEventCode code,
-                                                      struct GNUNET_CONVERSATION_Caller *caller,
-                                                      const char *caller_id);
+typedef void
+(*GNUNET_CONVERSATION_PhoneEventHandler)(void *cls,
+                                         enum GNUNET_CONVERSATION_PhoneEventCode
+                                         code,
+                                         struct GNUNET_CONVERSATION_Caller *
+                                         caller,
+                                         const struct
+                                         GNUNET_CRYPTO_EcdsaPublicKey *caller_id);
 
 
 /**
@@ -146,7 +157,6 @@ typedef void (*GNUNET_CONVERSATION_PhoneEventHandler)(void *cls,
  */
 enum GNUNET_CONVERSATION_CallerEventCode
 {
-
   /**
    * We are the callee and the caller suspended the call.  Note that
    * both sides can independently suspend and resume calls; a call is
@@ -160,7 +170,6 @@ enum GNUNET_CONVERSATION_CallerEventCode
    * only "working" of both sides are active.
    */
   GNUNET_CONVERSATION_EC_CALLER_RESUME
-
 };
 
 
@@ -172,8 +181,11 @@ enum GNUNET_CONVERSATION_CallerEventCode
  * @param cls closure
  * @param code type of the event for this caller
  */
-typedef void (*GNUNET_CONVERSATION_CallerEventHandler)(void *cls,
-                                                       enum GNUNET_CONVERSATION_CallerEventCode code);
+typedef void
+(*GNUNET_CONVERSATION_CallerEventHandler)(void *cls,
+                                          enum
+                                          GNUNET_CONVERSATION_CallerEventCode
+                                          code);
 
 
 /**
@@ -202,8 +214,9 @@ struct GNUNET_CONVERSATION_Phone;
 struct GNUNET_CONVERSATION_Phone *
 GNUNET_CONVERSATION_phone_create (const struct GNUNET_CONFIGURATION_Handle *cfg,
                                   const struct GNUNET_IDENTITY_Ego *ego,
-				  GNUNET_CONVERSATION_PhoneEventHandler event_handler,
-				  void *event_handler_cls);
+                                  GNUNET_CONVERSATION_PhoneEventHandler
+                                  event_handler,
+                                  void *event_handler_cls);
 
 
 /**
@@ -216,7 +229,7 @@ GNUNET_CONVERSATION_phone_create (const struct GNUNET_CONFIGURATION_Handle *cfg,
  */
 void
 GNUNET_CONVERSATION_phone_get_record (struct GNUNET_CONVERSATION_Phone *phone,
-				      struct GNUNET_GNSRECORD_Data *rd);
+                                      struct GNUNET_GNSRECORD_Data *rd);
 
 
 /**
@@ -231,7 +244,8 @@ GNUNET_CONVERSATION_phone_get_record (struct GNUNET_CONVERSATION_Phone *phone,
  */
 void
 GNUNET_CONVERSATION_caller_pick_up (struct GNUNET_CONVERSATION_Caller *caller,
-                                    GNUNET_CONVERSATION_CallerEventHandler event_handler,
+                                    GNUNET_CONVERSATION_CallerEventHandler
+                                    event_handler,
                                     void *event_handler_cls,
                                     struct GNUNET_SPEAKER_Handle *speaker,
                                     struct GNUNET_MICROPHONE_Handle *mic);
@@ -341,7 +355,6 @@ enum GNUNET_CONVERSATION_CallEventCode
    * is restarted during a call.
    */
   GNUNET_CONVERSATION_EC_CALL_ERROR
-
 };
 
 
@@ -351,8 +364,10 @@ enum GNUNET_CONVERSATION_CallEventCode
  * @param cls closure
  * @param code type of the event on the call
  */
-typedef void (*GNUNET_CONVERSATION_CallEventHandler)(void *cls,
-                                                     enum GNUNET_CONVERSATION_CallEventCode code);
+typedef void
+(*GNUNET_CONVERSATION_CallEventHandler)(void *cls,
+                                        enum GNUNET_CONVERSATION_CallEventCode
+                                        code);
 
 
 /**
@@ -368,15 +383,17 @@ typedef void (*GNUNET_CONVERSATION_CallEventHandler)(void *cls,
  *        #GNUNET_CONVERSATION_EC_CALL_PICKED_UP event is generated)
  * @param event_handler how to notify the owner of the phone about events
  * @param event_handler_cls closure for @a event_handler
+ * @return handle for the call
  */
 struct GNUNET_CONVERSATION_Call *
 GNUNET_CONVERSATION_call_start (const struct GNUNET_CONFIGURATION_Handle *cfg,
-				struct GNUNET_IDENTITY_Ego *caller_id,
-				const char *callee,
-				struct GNUNET_SPEAKER_Handle *speaker,
-				struct GNUNET_MICROPHONE_Handle *mic,
-				GNUNET_CONVERSATION_CallEventHandler event_handler,
-				void *event_handler_cls);
+                                struct GNUNET_IDENTITY_Ego *caller_id,
+                                const char *callee,
+                                struct GNUNET_SPEAKER_Handle *speaker,
+                                struct GNUNET_MICROPHONE_Handle *mic,
+                                GNUNET_CONVERSATION_CallEventHandler
+                                event_handler,
+                                void *event_handler_cls);
 
 
 /**
@@ -411,7 +428,7 @@ void
 GNUNET_CONVERSATION_call_stop (struct GNUNET_CONVERSATION_Call *call);
 
 
-#if 0				/* keep Emacsens' auto-indent happy */
+#if 0                           /* keep Emacsens' auto-indent happy */
 {
 #endif
 #ifdef __cplusplus
@@ -419,3 +436,5 @@ GNUNET_CONVERSATION_call_stop (struct GNUNET_CONVERSATION_Call *call);
 #endif
 
 #endif
+
+/** @} */  /* end of group */
