@@ -1,32 +1,38 @@
 /*
       This file is part of GNUnet
-      (C) 2012 Christian Grothoff (and other contributing authors)
+      Copyright (C) 2012 GNUnet e.V.
 
-      GNUnet is free software; you can redistribute it and/or modify
-      it under the terms of the GNU General Public License as published
-      by the Free Software Foundation; either version 2, or (at your
-      option) any later version.
+      GNUnet is free software: you can redistribute it and/or modify it
+      under the terms of the GNU Affero General Public License as published
+      by the Free Software Foundation, either version 3 of the License,
+      or (at your option) any later version.
 
       GNUnet is distributed in the hope that it will be useful, but
       WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-      General Public License for more details.
+      Affero General Public License for more details.
 
-      You should have received a copy of the GNU General Public License
-      along with GNUnet; see the file COPYING.  If not, write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-      Boston, MA 02111-1307, USA.
+      You should have received a copy of the GNU Affero General Public License
+      along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     SPDX-License-Identifier: AGPL3.0-or-later
  */
 
 /**
- * @file include/gnunet_dns_service.h
- * @brief API to access the DNS service. 
  * @author Christian Grothoff
+ *
+ * @file
+ * API to access the DNS service.
+ *
+ * @defgroup dns  DNS service
+ *
+ * @see [Documentation](https://gnunet.org/gnunet-service-dns)
+ *
+ * @{
  */
-#ifndef GNUNET_DNS_SERVICE_NEW_H
-#define GNUNET_DNS_SERVICE_NEW_H
+#ifndef GNUNET_DNS_SERVICE_H
+#define GNUNET_DNS_SERVICE_H
 
-#include "gnunet_common.h"
 #include "gnunet_util_lib.h"
 
 
@@ -42,10 +48,9 @@ struct GNUNET_DNS_RequestHandle;
 
 /**
  * Flags that specify when to call the client's handler.
- */ 
+ */
 enum GNUNET_DNS_Flags
 {
-
   /**
    * Useless option: never call the client.
    */
@@ -88,11 +93,9 @@ enum GNUNET_DNS_Flags
    * not allowed for MONITOR peers.
    */
   GNUNET_DNS_FLAG_RESPONSE_MONITOR = 8
-
 };
 
 
-
 /**
  * Signature of a function that is called whenever the DNS service
  * encounters a DNS request and needs to do something with it.  The
@@ -116,10 +119,11 @@ enum GNUNET_DNS_Flags
  * @param request_length number of bytes in request
  * @param request udp payload of the DNS request
  */
-typedef void (*GNUNET_DNS_RequestHandler)(void *cls,
-					  struct GNUNET_DNS_RequestHandle *rh,
-					  size_t request_length,
-					  const char *request);
+typedef void
+(*GNUNET_DNS_RequestHandler)(void *cls,
+                             struct GNUNET_DNS_RequestHandle *rh,
+                             size_t request_length,
+                             const char *request);
 
 
 /**
@@ -150,29 +154,29 @@ GNUNET_DNS_request_drop (struct GNUNET_DNS_RequestHandle *rh);
  * must always be a valid DNS reply and not a mutated DNS request.
  *
  * @param rh request that should now be answered
- * @param reply_length size of reply (uint16_t to force sane size)
+ * @param reply_length size of @a reply (uint16_t to force sane size)
  * @param reply reply data
  */
 void
-GNUNET_DNS_request_answer (struct GNUNET_DNS_RequestHandle *rh,		   
-			   uint16_t reply_length,
-			   const char *reply);
+GNUNET_DNS_request_answer (struct GNUNET_DNS_RequestHandle *rh,
+                           uint16_t reply_length,
+                           const char *reply);
 
 
 /**
  * Connect to the service-dns
  *
  * @param cfg configuration to use
- * @param flags when to call rh
+ * @param flags when to call @a rh
  * @param rh function to call with DNS requests
- * @param rh_cls closure to pass to rh
- * @return DNS handle 
+ * @param rh_cls closure to pass to @a rh
+ * @return DNS handle
  */
 struct GNUNET_DNS_Handle *
 GNUNET_DNS_connect (const struct GNUNET_CONFIGURATION_Handle *cfg,
-		    enum GNUNET_DNS_Flags flags,
-		    GNUNET_DNS_RequestHandler rh,
-		    void *rh_cls);
+                    enum GNUNET_DNS_Flags flags,
+                    GNUNET_DNS_RequestHandler rh,
+                    void *rh_cls);
 
 
 /**
@@ -183,4 +187,7 @@ GNUNET_DNS_connect (const struct GNUNET_CONFIGURATION_Handle *cfg,
 void
 GNUNET_DNS_disconnect (struct GNUNET_DNS_Handle *dh);
 
+
 #endif
+
+/** @} */  /* end of group */
