@@ -95,7 +95,7 @@ extern "C" {
 /**
  * Record type for identity attributes (of RECLAIM).
  */
-#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR 65544
+#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE 65544
 
 /**
  * Record type for local ticket references
@@ -123,7 +123,7 @@ extern "C" {
 /**
  * Record type for reclaim records
  */
-#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF 65550
+#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF 65550
 
 /**
  * Record type for RECLAIM master
@@ -140,6 +140,17 @@ extern "C" {
  */
 #define GNUNET_GNSRECORD_TYPE_RECLAIM_OIDC_REDIRECT 65553
 
+/**
+ * Record type for an attribute attestation
+ */
+#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION 65554
+
+/**
+ * Record type for an attestation reference in a ticket
+ */
+#define GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION_REF 65555
+
+
 /**
  * Flags that can be set for a record.
  */
@@ -157,10 +168,9 @@ enum GNUNET_GNSRECORD_Flags
   GNUNET_GNSRECORD_RF_PRIVATE = 2,
 
   /**
-   * This flag is currently unused; former RF_PENDING flag
-   *
-   * GNUNET_GNSRECORD_RF_UNUSED = 4,
+   * This is a supplemental record.
    */
+  GNUNET_GNSRECORD_RF_SUPPLEMENTAL = 4,
 
   /**
    * This expiration time of the record is a relative
