@@ -1,27 +1,31 @@
 /*
      This file is part of GNUnet.
-     (C) 2009 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2009 GNUnet e.V.
 
-     GNUnet is free software; you can redistribute it and/or modify
-     it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 3, or (at your
-     option) any later version.
+     GNUnet is free software: you can redistribute it and/or modify it
+     under the terms of the GNU Affero General Public License as published
+     by the Free Software Foundation, either version 3 of the License,
+     or (at your option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-     General Public License for more details.
+     Affero General Public License for more details.
 
-     You should have received a copy of the GNU General Public License
-     along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
-*/
+     You should have received a copy of the GNU Affero General Public License
+     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     SPDX-License-Identifier: AGPL3.0-or-later
+ */
 
 /**
- * @file include/gnunet_signatures.h
- * @brief constants for network signatures
  * @author Christian Grothoff
+ *
+ * @file
+ * Constants for network signatures
+ *
+ * @defgroup signatures  Network signature definitions
+ * @{
  */
 
 #ifndef GNUNET_SIGNATURES_H
@@ -132,12 +136,12 @@ extern "C"
 
 /**
  * Accept state in regex DFA.  Peer affirms that
- * he offers the matching service.
+ * it offers the matching service.
  */
 #define GNUNET_SIGNATURE_PURPOSE_REGEX_ACCEPT 18
 
 /**
- * Signature of a multicast message.
+ * Signature of a multicast message sent by the origin.
  */
 #define GNUNET_SIGNATURE_PURPOSE_MULTICAST_MESSAGE 19
 
@@ -146,26 +150,101 @@ extern "C"
  */
 #define GNUNET_SIGNATURE_PURPOSE_CONVERSATION_RING 20
 
-/**
- * Key exchange in MESH
- */
-#define GNUNET_SIGNATURE_PURPOSE_MESH_KX                21
-
 /**
  * Signature for the first round of distributed key generation.
  */
-#define GNUNET_SIGNATURE_PURPOSE_SECRETSHARING_DKG1 22
+#define GNUNET_SIGNATURE_PURPOSE_SECRETSHARING_DKG1 21
 
 /**
  * Signature for the second round of distributed key generation.
  */
-#define GNUNET_SIGNATURE_PURPOSE_SECRETSHARING_DKG2 23
+#define GNUNET_SIGNATURE_PURPOSE_SECRETSHARING_DKG2 22
 
 /**
  * Signature for cooperatice decryption.
  */
 #define GNUNET_SIGNATURE_PURPOSE_SECRETSHARING_DECRYPTION 23
 
+/**
+ * Signature of a multicast request sent by a member.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_MULTICAST_REQUEST 24
+
+/**
+ * Signature for a sensor anomaly report message.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_SENSOR_ANOMALY_REPORT 25
+
+/**
+ * Signature for a GNUid Token
+ */
+#define GNUNET_SIGNATURE_PURPOSE_GNUID_TOKEN 26
+
+/**
+ * Signature for a GNUid Ticket
+ */
+#define GNUNET_SIGNATURE_PURPOSE_RECLAIM_CODE_SIGN 27
+
+/**
+ * Signature for a GNUnet credential
+ */
+#define GNUNET_SIGNATURE_PURPOSE_DELEGATE 28
+
+/**
+ * Signature by a peer affirming that this is one of its
+ * addresses (for the given time period).
+ */
+#define GNUNET_SIGNATURE_PURPOSE_TRANSPORT_ADDRESS 29
+
+/**
+ * Signature by a peer affirming that the given ephemeral
+ * key is currently in use by that peer's transport service.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_TRANSPORT_EPHEMERAL 30
+
+/**
+ * Signature used by TCP communicator handshake,
+ */
+#define GNUNET_SIGNATURE_COMMUNICATOR_TCP_HANDSHAKE 31
+
+/**
+ * Signature used by TCP communicator rekey.
+ */
+#define GNUNET_SIGNATURE_COMMUNICATOR_TCP_REKEY 32
+
+/**
+ * Signature used by UDP communicator handshake
+ */
+#define GNUNET_SIGNATURE_COMMUNICATOR_UDP_HANDSHAKE 33
+
+/**
+ * Signature used by UDP broadcasts.
+ */
+#define GNUNET_SIGNATURE_COMMUNICATOR_UDP_BROADCAST 34
+
+/**
+ * Signature by a peer affirming that it received a
+ * challenge (and stating how long it expects the
+ * address on which the challenge was received to
+ * remain valid).
+ */
+#define GNUNET_SIGNATURE_PURPOSE_TRANSPORT_CHALLENGE 35
+
+/**
+ * Signature by a peer affirming that it is on a DV path.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_TRANSPORT_DV_HOP 36
+
+/**
+ * Signature by a peer affirming that it originated the
+ * DV path.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_TRANSPORT_DV_INITIATOR 37
+
+/**
+ * Signature by a peer that like to create a connection.
+ */
+#define GNUNET_SIGNATURE_PURPOSE_CADET_CONNECTION_INITIATOR 38
 
 #if 0                           /* keep Emacsens' auto-indent happy */
 {
@@ -176,4 +255,7 @@ extern "C"
 
 /* ifndef GNUNET_SIGNATURES_H */
 #endif
+
+/** @} */  /* end of group */
+
 /* end of gnunet_signatures.h */
