@@ -16,7 +16,7 @@
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 
 /**
  * @author Christian Grothoff
@@ -41,6 +41,9 @@
    but "stdlib.h" should be portable 'enough' to be
    unconditionally available... */
 #include <stdlib.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netinet/ip.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -117,9 +120,10 @@ GNUNET_STRINGS_byte_size_fancy (unsigned long long size);
  *  string is returned.
  */
 char *
-GNUNET_STRINGS_conv (const char *input, size_t len,
-		     const char *input_charset,
-		     const char *output_charset);
+GNUNET_STRINGS_conv (const char *input,
+                     size_t len,
+                     const char *input_charset,
+                     const char *output_charset);
 
 
 /**
@@ -134,8 +138,8 @@ GNUNET_STRINGS_conv (const char *input, size_t len,
  */
 char *
 GNUNET_STRINGS_to_utf8 (const char *input,
-			size_t len,
-			const char *charset);
+                        size_t len,
+                        const char *charset);
 
 
 /**
@@ -151,8 +155,8 @@ GNUNET_STRINGS_to_utf8 (const char *input,
  */
 char *
 GNUNET_STRINGS_from_utf8 (const char *input,
-			  size_t len,
-			  const char *charset);
+                          size_t len,
+                          const char *charset);
 
 
 /**
@@ -164,7 +168,7 @@ GNUNET_STRINGS_from_utf8 (const char *input,
  */
 void
 GNUNET_STRINGS_utf8_tolower (const char *input,
-			     char *output);
+                             char *output);
 
 
 /**
@@ -176,7 +180,7 @@ GNUNET_STRINGS_utf8_tolower (const char *input,
  */
 void
 GNUNET_STRINGS_utf8_toupper (const char *input,
-			     char *output);
+                             char *output);
 
 
 /**
@@ -212,9 +216,9 @@ GNUNET_STRINGS_filename_expand (const char *fil);
  */
 size_t
 GNUNET_STRINGS_buffer_fill (char *buffer,
-			    size_t size,
-			    unsigned int count,
-			    ...);
+                            size_t size,
+                            unsigned int count,
+                            ...);
 
 
 /**
@@ -235,7 +239,6 @@ GNUNET_STRINGS_buffer_tokenize (const char *buffer,
                                 unsigned int count, ...);
 
 
-
 /**
  * @ingroup time
  * Like `asctime`, except for GNUnet time.  Converts a GNUnet internal
@@ -262,7 +265,7 @@ GNUNET_STRINGS_absolute_time_to_string (struct GNUNET_TIME_Absolute t);
  */
 const char *
 GNUNET_STRINGS_relative_time_to_string (struct GNUNET_TIME_Relative delta,
-					int do_round);
+                                        int do_round);
 
 
 /**
@@ -294,9 +297,9 @@ GNUNET_STRINGS_get_short_name (const char *filename);
  */
 char *
 GNUNET_STRINGS_data_to_string (const void *data,
-			       size_t size,
-			       char *out,
-			       size_t out_size);
+                               size_t size,
+                               char *out,
+                               size_t out_size);
 
 
 /**
@@ -326,9 +329,9 @@ GNUNET_STRINGS_data_to_string_alloc (const void *buf,
  */
 int
 GNUNET_STRINGS_string_to_data (const char *enc,
-			       size_t enclen,
-			       void *out,
-			       size_t out_size);
+                               size_t enclen,
+                               void *out,
+                               size_t out_size);
 
 
 /**
@@ -346,6 +349,19 @@ GNUNET_STRINGS_base64_encode (const void *in,
                               char **output);
 
 
+/**
+ * Encode into Base64url. RFC7515
+ *
+ * @param in the data to encode
+ * @param len the length of the input
+ * @param output where to write the output (*output should be NULL,
+ *   is allocated)
+ * @return the size of the output
+ */
+size_t
+GNUNET_STRINGS_base64url_encode (const void *in, size_t len, char **output);
+
+
 /**
  * Decode from Base64.
  *
@@ -357,8 +373,21 @@ GNUNET_STRINGS_base64_encode (const void *in,
  */
 size_t
 GNUNET_STRINGS_base64_decode (const char *data,
-			      size_t len,
-			      void **output);
+                              size_t len,
+                              void **output);
+
+
+/**
+ * Decode from Base64url. RFC7515
+ *
+ * @param data the data to decode
+ * @param len the length of the input
+ * @param output where to write the output (*output should be NULL,
+ *   is allocated)
+ * @return the size of the output
+ */
+size_t
+GNUNET_STRINGS_base64url_decode (const char *data, size_t len, void **out);
 
 
 /**
@@ -391,8 +420,8 @@ GNUNET_STRINGS_pp2s (const struct GNUNET_PeerIdentity *pids,
  */
 int
 GNUNET_STRINGS_parse_uri (const char *path,
-			  char **scheme_part,
-			  const char **path_part);
+                          char **scheme_part,
+                          const char **path_part);
 
 
 /**
@@ -411,9 +440,9 @@ GNUNET_STRINGS_parse_uri (const char *path,
  */
 int
 GNUNET_STRINGS_path_is_absolute (const char *filename,
-				 int can_be_uri,
-				 int *r_is_uri,
-				 char **r_uri_scheme);
+                                 int can_be_uri,
+                                 int *r_is_uri,
+                                 char **r_uri_scheme);
 
 
 /**
@@ -454,7 +483,7 @@ enum GNUNET_STRINGS_FilenameCheck
  */
 int
 GNUNET_STRINGS_check_filename (const char *filename,
-			       enum GNUNET_STRINGS_FilenameCheck checks);
+                               enum GNUNET_STRINGS_FilenameCheck checks);
 
 
 /**
@@ -470,8 +499,8 @@ GNUNET_STRINGS_check_filename (const char *filename,
  */
 int
 GNUNET_STRINGS_to_address_ipv6 (const char *zt_addr,
-				uint16_t addrlen,
-				struct sockaddr_in6 *r_buf);
+                                uint16_t addrlen,
+                                struct sockaddr_in6 *r_buf);
 
 
 /**
@@ -486,8 +515,8 @@ GNUNET_STRINGS_to_address_ipv6 (const char *zt_addr,
  */
 int
 GNUNET_STRINGS_to_address_ipv4 (const char *zt_addr,
-				uint16_t addrlen,
-				struct sockaddr_in *r_buf);
+                                uint16_t addrlen,
+                                struct sockaddr_in *r_buf);
 
 
 /**
@@ -501,8 +530,8 @@ GNUNET_STRINGS_to_address_ipv4 (const char *zt_addr,
  */
 size_t
 GNUNET_STRINGS_parse_socket_addr (const char *addr,
-				  uint8_t *af,
-				  struct sockaddr **sa);
+                                  uint8_t *af,
+                                  struct sockaddr **sa);
 
 
 /**
@@ -518,8 +547,8 @@ GNUNET_STRINGS_parse_socket_addr (const char *addr,
  */
 int
 GNUNET_STRINGS_to_address_ip (const char *addr,
-			      uint16_t addrlen,
-			      struct sockaddr_storage *r_buf);
+                              uint16_t addrlen,
+                              struct sockaddr_storage *r_buf);
 
 
 /**
@@ -536,8 +565,8 @@ GNUNET_STRINGS_to_address_ip (const char *addr,
  */
 int
 GNUNET_STRINGS_get_utf8_args (int argc,
-			      char *const *argv,
-			      int *u8argc,
+                              char *const *argv,
+                              int *u8argc,
                               char *const **u8argv);
 
 
@@ -554,17 +583,16 @@ GNUNET_STRINGS_get_utf8_args (int argc,
  * @param n the length of the string to copy, including its terminating null
  *          byte
  * @return the length of the string that was copied, excluding the terminating
- * 	   null byte
+ *         null byte
  */
 size_t
-GNUNET_strlcpy(char *dst, const char *src, size_t n);
+GNUNET_strlcpy (char *dst, const char *src, size_t n);
 
 
 /* ***************** IPv4/IPv6 parsing ****************** */
 
 struct GNUNET_STRINGS_PortPolicy
 {
-
   /**
    * Starting port range (0 if none given).
    */
@@ -580,7 +608,6 @@ struct GNUNET_STRINGS_PortPolicy
    * ("!" in policy).
    */
   int negate_portrange;
-
 };
 
 
@@ -603,7 +630,6 @@ struct GNUNET_STRINGS_IPv4NetworkPolicy
    * Policy for port access.
    */
   struct GNUNET_STRINGS_PortPolicy pp;
-
 };
 
 
@@ -626,7 +652,6 @@ struct GNUNET_STRINGS_IPv6NetworkPolicy
    * Policy for port access.
    */
   struct GNUNET_STRINGS_PortPolicy pp;
-
 };
 
 
