@@ -1,33 +1,41 @@
 /*
      This file is part of GNUnet.
-     (C) 2010-2013 Christian Grothoff
+     Copyright (C) 2010-2013 Christian Grothoff
 
-     GNUnet is free software; you can redistribute it and/or modify
-     it under the terms of the GNU General Public License as published
-     by the Free Software Foundation; either version 3, or (at your
-     option) any later version.
+     GNUnet is free software: you can redistribute it and/or modify it
+     under the terms of the GNU Affero General Public License as published
+     by the Free Software Foundation, either version 3 of the License,
+     or (at your option) any later version.
 
      GNUnet is distributed in the hope that it will be useful, but
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-     General Public License for more details.
+     Affero General Public License for more details.
 
-     You should have received a copy of the GNU General Public License
-     along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
-*/
+     You should have received a copy of the GNU Affero General Public License
+     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     SPDX-License-Identifier: AGPL3.0-or-later
+ */
 
 /**
- * @file include/gnunet_tun_lib.h
- * @brief standard TCP/IP network structs and IP checksum calculations for TUN interaction
  * @author Philipp Toelke
  * @author Christian Grothoff
+ *
+ * @file
+ * Standard TCP/IP network structs and IP checksum calculations for TUN
+ * interaction
+ *
+ * @defgroup tun  TUN library
+ * Standard TCP/IP network structs and IP checksum calculations for TUN
+ * interaction
+ * @{
  */
 #ifndef GNUNET_TUN_LIB_H
 #define GNUNET_TUN_LIB_H
 
-#include "gnunet_util_lib.h"
+#include "gnunet_common.h"
+#include "gnunet_crypto_lib.h"
 
 
 /* see http://www.iana.org/assignments/ethernet-numbers */
@@ -52,6 +60,7 @@
  * 8 bytes for IPv4, 4 bytes for port, 1 byte for "4", 2 bytes for "-",
  * one byte for 0-termination.
  */
+
 #define GNUNET_TUN_IPV4_REGEXLEN 16
 
 
@@ -89,13 +98,13 @@ struct GNUNET_TUN_Layer2PacketHeader
 struct GNUNET_TUN_IPv4Header
 {
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-  unsigned int header_length:4 GNUNET_PACKED;
-  unsigned int version:4 GNUNET_PACKED;
+  unsigned int header_length : 4 GNUNET_PACKED;
+  unsigned int version : 4 GNUNET_PACKED;
 #elif __BYTE_ORDER == __BIG_ENDIAN
-  unsigned int version:4 GNUNET_PACKED;
-  unsigned int header_length:4 GNUNET_PACKED;
+  unsigned int version : 4 GNUNET_PACKED;
+  unsigned int header_length : 4 GNUNET_PACKED;
 #else
-  #error byteorder undefined
+#error byteorder undefined
 #endif
   uint8_t diff_serv;
 
@@ -109,9 +118,9 @@ struct GNUNET_TUN_IPv4Header
    */
   uint16_t identification GNUNET_PACKED;
 
-  unsigned int flags:3 GNUNET_PACKED;
+  unsigned int flags : 3 GNUNET_PACKED;
 
-  unsigned int fragmentation_offset:13 GNUNET_PACKED;
+  unsigned int fragmentation_offset : 13 GNUNET_PACKED;
 
   /**
    * How many more hops can this packet be forwarded?
@@ -131,12 +140,12 @@ struct GNUNET_TUN_IPv4Header
   /**
    * Origin of the packet.
    */
-  struct in_addr source_address GNUNET_PACKED;
+  struct in_addr source_address;
 
   /**
    * Destination of the packet.
    */
-  struct in_addr destination_address GNUNET_PACKED;
+  struct in_addr destination_address;
 } GNUNET_GCC_STRUCT_LAYOUT;
 
 
@@ -146,16 +155,16 @@ struct GNUNET_TUN_IPv4Header
 struct GNUNET_TUN_IPv6Header
 {
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-  unsigned int traffic_class_h:4 GNUNET_PACKED;
-  unsigned int version:4 GNUNET_PACKED;
-  unsigned int traffic_class_l:4 GNUNET_PACKED;
-  unsigned int flow_label:20 GNUNET_PACKED;
+  unsigned int traffic_class_h : 4 GNUNET_PACKED;
+  unsigned int version : 4 GNUNET_PACKED;
+  unsigned int traffic_class_l : 4 GNUNET_PACKED;
+  unsigned int flow_label : 20 GNUNET_PACKED;
 #elif __BYTE_ORDER == __BIG_ENDIAN
-  unsigned int version:4 GNUNET_PACKED;
-  unsigned int traffic_class:8 GNUNET_PACKED;
-  unsigned int flow_label:20 GNUNET_PACKED;
+  unsigned int version : 4 GNUNET_PACKED;
+  unsigned int traffic_class : 8 GNUNET_PACKED;
+  unsigned int flow_label : 20 GNUNET_PACKED;
 #else
-  #error byteorder undefined
+#error byteorder undefined
 #endif
   /**
    * Length of the payload, excluding this header.
@@ -184,6 +193,18 @@ struct GNUNET_TUN_IPv6Header
 } GNUNET_GCC_STRUCT_LAYOUT;
 
 
+/**
+ * TCP flags.
+ */
+#define GNUNET_TUN_TCP_FLAGS_FIN 1
+#define GNUNET_TUN_TCP_FLAGS_SYN 2
+#define GNUNET_TUN_TCP_FLAGS_RST 4
+#define GNUNET_TUN_TCP_FLAGS_PSH 8
+#define GNUNET_TUN_TCP_FLAGS_ACK 16
+#define GNUNET_TUN_TCP_FLAGS_URG 32
+#define GNUNET_TUN_TCP_FLAGS_ECE 64
+#define GNUNET_TUN_TCP_FLAGS_CWR 128
+
 /**
  * TCP packet header.
  */
@@ -227,7 +248,7 @@ struct GNUNET_TUN_TcpHeader
    */
   unsigned int reserved : 4 GNUNET_PACKED;
 #else
-  #error byteorder undefined
+#error byteorder undefined
 #endif
 
   /**
@@ -279,7 +300,6 @@ struct GNUNET_TUN_UdpHeader
 };
 
 
-
 /**
  * A few common DNS classes (ok, only one is common, but I list a
  * couple more to make it clear what we're talking about here).
@@ -322,12 +342,12 @@ struct GNUNET_TUN_DnsFlags
   /**
    * Set to 1 if recursion is desired (client -> server)
    */
-  unsigned int recursion_desired    : 1 GNUNET_PACKED;
+  unsigned int recursion_desired : 1 GNUNET_PACKED;
 
   /**
    * Set to 1 if message is truncated
    */
-  unsigned int message_truncated    : 1 GNUNET_PACKED;
+  unsigned int message_truncated : 1 GNUNET_PACKED;
 
   /**
    * Set to 1 if this is an authoritative answer
@@ -337,48 +357,47 @@ struct GNUNET_TUN_DnsFlags
   /**
    * See GNUNET_TUN_DNS_OPCODE_ defines.
    */
-  unsigned int opcode               : 4 GNUNET_PACKED;
+  unsigned int opcode : 4 GNUNET_PACKED;
 
   /**
    * query:0, response:1
    */
-  unsigned int query_or_response    : 1 GNUNET_PACKED;
+  unsigned int query_or_response : 1 GNUNET_PACKED;
 
   /**
    * See GNUNET_TUN_DNS_RETURN_CODE_ defines.
    */
-  unsigned int return_code          : 4 GNUNET_PACKED;
+  unsigned int return_code : 4 GNUNET_PACKED;
 
   /**
    * See RFC 4035.
    */
-  unsigned int checking_disabled    : 1 GNUNET_PACKED;
+  unsigned int checking_disabled : 1 GNUNET_PACKED;
 
   /**
    * Response has been cryptographically verified, RFC 4035.
    */
-  unsigned int authenticated_data   : 1 GNUNET_PACKED;
+  unsigned int authenticated_data : 1 GNUNET_PACKED;
 
   /**
    * Always zero.
    */
-  unsigned int zero                 : 1 GNUNET_PACKED;
+  unsigned int zero : 1 GNUNET_PACKED;
 
   /**
    * Set to 1 if recursion is available (server -> client)
    */
-  unsigned int recursion_available  : 1 GNUNET_PACKED;
+  unsigned int recursion_available : 1 GNUNET_PACKED;
 #elif __BYTE_ORDER == __BIG_ENDIAN
-
   /**
    * query:0, response:1
    */
-  unsigned int query_or_response    : 1 GNUNET_PACKED;
+  unsigned int query_or_response : 1 GNUNET_PACKED;
 
   /**
    * See GNUNET_TUN_DNS_OPCODE_ defines.
    */
-  unsigned int opcode               : 4 GNUNET_PACKED;
+  unsigned int opcode : 4 GNUNET_PACKED;
 
   /**
    * Set to 1 if this is an authoritative answer
@@ -388,46 +407,44 @@ struct GNUNET_TUN_DnsFlags
   /**
    * Set to 1 if message is truncated
    */
-  unsigned int message_truncated    : 1 GNUNET_PACKED;
+  unsigned int message_truncated : 1 GNUNET_PACKED;
 
   /**
    * Set to 1 if recursion is desired (client -> server)
    */
-  unsigned int recursion_desired    : 1 GNUNET_PACKED;
+  unsigned int recursion_desired : 1 GNUNET_PACKED;
 
 
   /**
    * Set to 1 if recursion is available (server -> client)
    */
-  unsigned int recursion_available  : 1 GNUNET_PACKED;
+  unsigned int recursion_available : 1 GNUNET_PACKED;
 
   /**
    * Always zero.
    */
-  unsigned int zero                 : 1 GNUNET_PACKED;
+  unsigned int zero : 1 GNUNET_PACKED;
 
   /**
    * Response has been cryptographically verified, RFC 4035.
    */
-  unsigned int authenticated_data   : 1 GNUNET_PACKED;
+  unsigned int authenticated_data : 1 GNUNET_PACKED;
 
   /**
    * See RFC 4035.
    */
-  unsigned int checking_disabled    : 1 GNUNET_PACKED;
+  unsigned int checking_disabled : 1 GNUNET_PACKED;
 
   /**
    * See GNUNET_TUN_DNS_RETURN_CODE_ defines.
    */
-  unsigned int return_code          : 4 GNUNET_PACKED;
+  unsigned int return_code : 4 GNUNET_PACKED;
 #else
-  #error byteorder undefined
+#error byteorder undefined
 #endif
-
 } GNUNET_GCC_STRUCT_LAYOUT;
 
 
-
 /**
  * DNS header.
  */
@@ -505,7 +522,6 @@ struct GNUNET_TUN_DnsSoaRecord
  */
 struct GNUNET_TUN_DnsSrvRecord
 {
-
   /**
    * Preference for this entry (lower value is higher preference).  Clients
    * will contact hosts from the lowest-priority group first and fall back
@@ -534,7 +550,6 @@ struct GNUNET_TUN_DnsSrvRecord
  */
 struct GNUNET_TUN_DnsCertRecord
 {
-
   /**
    * Certificate type
    */
@@ -560,7 +575,6 @@ struct GNUNET_TUN_DnsCertRecord
  */
 struct GNUNET_TUN_DnsTlsaRecord
 {
-
   /**
    * Certificate usage
    * 0: CA cert
@@ -664,21 +678,21 @@ struct GNUNET_TUN_DnsRecordLine
 };
 
 
-#define	GNUNET_TUN_ICMPTYPE_ECHO_REPLY 0
-#define	GNUNET_TUN_ICMPTYPE_DESTINATION_UNREACHABLE 3
-#define	GNUNET_TUN_ICMPTYPE_SOURCE_QUENCH 4
-#define	GNUNET_TUN_ICMPTYPE_REDIRECT_MESSAGE 5
-#define	GNUNET_TUN_ICMPTYPE_ECHO_REQUEST 8
-#define	GNUNET_TUN_ICMPTYPE_ROUTER_ADVERTISEMENT 9
-#define	GNUNET_TUN_ICMPTYPE_ROUTER_SOLICITATION 10
-#define	GNUNET_TUN_ICMPTYPE_TIME_EXCEEDED 11
+#define GNUNET_TUN_ICMPTYPE_ECHO_REPLY 0
+#define GNUNET_TUN_ICMPTYPE_DESTINATION_UNREACHABLE 3
+#define GNUNET_TUN_ICMPTYPE_SOURCE_QUENCH 4
+#define GNUNET_TUN_ICMPTYPE_REDIRECT_MESSAGE 5
+#define GNUNET_TUN_ICMPTYPE_ECHO_REQUEST 8
+#define GNUNET_TUN_ICMPTYPE_ROUTER_ADVERTISEMENT 9
+#define GNUNET_TUN_ICMPTYPE_ROUTER_SOLICITATION 10
+#define GNUNET_TUN_ICMPTYPE_TIME_EXCEEDED 11
 
-#define	GNUNET_TUN_ICMPTYPE6_DESTINATION_UNREACHABLE 1
-#define	GNUNET_TUN_ICMPTYPE6_PACKET_TOO_BIG 2
-#define	GNUNET_TUN_ICMPTYPE6_TIME_EXCEEDED 3
-#define	GNUNET_TUN_ICMPTYPE6_PARAMETER_PROBLEM 4
-#define	GNUNET_TUN_ICMPTYPE6_ECHO_REQUEST 128
-#define	GNUNET_TUN_ICMPTYPE6_ECHO_REPLY 129
+#define GNUNET_TUN_ICMPTYPE6_DESTINATION_UNREACHABLE 1
+#define GNUNET_TUN_ICMPTYPE6_PACKET_TOO_BIG 2
+#define GNUNET_TUN_ICMPTYPE6_TIME_EXCEEDED 3
+#define GNUNET_TUN_ICMPTYPE6_PARAMETER_PROBLEM 4
+#define GNUNET_TUN_ICMPTYPE6_ECHO_REQUEST 128
+#define GNUNET_TUN_ICMPTYPE6_ECHO_REPLY 129
 
 
 /**
@@ -697,8 +711,8 @@ struct GNUNET_TUN_IcmpHeader
      */
     struct
     {
-      uint16_t	identifier GNUNET_PACKED;
-      uint16_t	sequence_number GNUNET_PACKED;
+      uint16_t identifier GNUNET_PACKED;
+      uint16_t sequence_number GNUNET_PACKED;
     } echo;
 
     /**
@@ -708,21 +722,20 @@ struct GNUNET_TUN_IcmpHeader
     {
       uint16_t empty GNUNET_PACKED;
       uint16_t next_hop_mtu GNUNET_PACKED;
-      /* followed by original IP header + first 8 bytes of original IP datagram */
+      /* followed by original IP header + first 8 bytes of original IP datagram
+       */
     } destination_unreachable;
 
     /**
      * ICMP Redirect
      */
-    struct in_addr redirect_gateway_address GNUNET_PACKED;
+    struct in_addr redirect_gateway_address;
 
     /**
      * MTU for packets that are too big (IPv6).
      */
     uint32_t packet_too_big_mtu GNUNET_PACKED;
-
   } quench;
-
 };
 
 
@@ -734,16 +747,17 @@ GNUNET_NETWORK_STRUCT_END
  *
  * @param ip header to initialize
  * @param protocol protocol to use (i.e. IPPROTO_UDP)
- * @param payload_length number of bytes of payload that follow (excluding IPv4 header)
+ * @param payload_length number of bytes of payload that follow (excluding IPv4
+ * header)
  * @param src source IP address to use
  * @param dst destination IP address to use
  */
 void
 GNUNET_TUN_initialize_ipv4_header (struct GNUNET_TUN_IPv4Header *ip,
-				   uint8_t protocol,
-				   uint16_t payload_length,
-				   const struct in_addr *src,
-				   const struct in_addr *dst);
+                                   uint8_t protocol,
+                                   uint16_t payload_length,
+                                   const struct in_addr *src,
+                                   const struct in_addr *dst);
 
 
 /**
@@ -751,16 +765,17 @@ GNUNET_TUN_initialize_ipv4_header (struct GNUNET_TUN_IPv4Header *ip,
  *
  * @param ip header to initialize
  * @param protocol protocol to use (i.e. IPPROTO_UDP)
- * @param payload_length number of bytes of payload that follow (excluding IPv4 header)
+ * @param payload_length number of bytes of payload that follow (excluding IPv4
+ * header)
  * @param src source IP address to use
  * @param dst destination IP address to use
  */
 void
 GNUNET_TUN_initialize_ipv6_header (struct GNUNET_TUN_IPv6Header *ip,
-				   uint8_t protocol,
-				   uint16_t payload_length,
-				   const struct in6_addr *src,
-				   const struct in6_addr *dst);
+                                   uint8_t protocol,
+                                   uint16_t payload_length,
+                                   const struct in6_addr *src,
+                                   const struct in6_addr *dst);
 
 /**
  * Calculate IPv4 TCP checksum.
@@ -772,9 +787,9 @@ GNUNET_TUN_initialize_ipv6_header (struct GNUNET_TUN_IPv6Header *ip,
  */
 void
 GNUNET_TUN_calculate_tcp4_checksum (const struct GNUNET_TUN_IPv4Header *ip,
-				    struct GNUNET_TUN_TcpHeader *tcp,
-				    const void *payload,
-				    uint16_t payload_length);
+                                    struct GNUNET_TUN_TcpHeader *tcp,
+                                    const void *payload,
+                                    uint16_t payload_length);
 
 /**
  * Calculate IPv6 TCP checksum.
@@ -786,9 +801,9 @@ GNUNET_TUN_calculate_tcp4_checksum (const struct GNUNET_TUN_IPv4Header *ip,
  */
 void
 GNUNET_TUN_calculate_tcp6_checksum (const struct GNUNET_TUN_IPv6Header *ip,
-				    struct GNUNET_TUN_TcpHeader *tcp,
-				    const void *payload,
-				    uint16_t payload_length);
+                                    struct GNUNET_TUN_TcpHeader *tcp,
+                                    const void *payload,
+                                    uint16_t payload_length);
 
 /**
  * Calculate IPv4 UDP checksum.
@@ -800,9 +815,9 @@ GNUNET_TUN_calculate_tcp6_checksum (const struct GNUNET_TUN_IPv6Header *ip,
  */
 void
 GNUNET_TUN_calculate_udp4_checksum (const struct GNUNET_TUN_IPv4Header *ip,
-				    struct GNUNET_TUN_UdpHeader *udp,
-				    const void *payload,
-				    uint16_t payload_length);
+                                    struct GNUNET_TUN_UdpHeader *udp,
+                                    const void *payload,
+                                    uint16_t payload_length);
 
 
 /**
@@ -815,9 +830,9 @@ GNUNET_TUN_calculate_udp4_checksum (const struct GNUNET_TUN_IPv4Header *ip,
  */
 void
 GNUNET_TUN_calculate_udp6_checksum (const struct GNUNET_TUN_IPv6Header *ip,
-				    struct GNUNET_TUN_UdpHeader *udp,
-				    const void *payload,
-				    uint16_t payload_length);
+                                    struct GNUNET_TUN_UdpHeader *udp,
+                                    const void *payload,
+                                    uint16_t payload_length);
 
 
 /**
@@ -829,8 +844,8 @@ GNUNET_TUN_calculate_udp6_checksum (const struct GNUNET_TUN_IPv6Header *ip,
  */
 void
 GNUNET_TUN_calculate_icmp_checksum (struct GNUNET_TUN_IcmpHeader *icmp,
-				    const void *payload,
-				    uint16_t payload_length);
+                                    const void *payload,
+                                    uint16_t payload_length);
 
 
 /**
@@ -893,10 +908,41 @@ GNUNET_TUN_ipv4policy2regex (const char *policy);
  * the network.
  *
  * @param service_name a string
- * @param hc corresponding hash
+ * @param[out] hc corresponding hash
  */
 void
 GNUNET_TUN_service_name_to_hash (const char *service_name,
                                  struct GNUNET_HashCode *hc);
 
+
+/**
+ * Check if two sockaddrs are equal.
+ *
+ * @param sa one address
+ * @param sb another address
+ * @param include_port also check ports
+ * @return #GNUNET_YES if they are equal
+ */
+int
+GNUNET_TUN_sockaddr_cmp (const struct sockaddr *sa,
+                         const struct sockaddr *sb,
+                         int include_port);
+
+
+/**
+ * Compute the CADET port given a service descriptor
+ * (returned from #GNUNET_TUN_service_name_to_hash) and
+ * a TCP/UDP port @a ip_port.
+ *
+ * @param desc service shared secret
+ * @param ip_port TCP/UDP port, use 0 for ICMP
+ * @param[out] cadet_port CADET port to use
+ */
+void
+GNUNET_TUN_compute_service_cadet_port (const struct GNUNET_HashCode *desc,
+                                       uint16_t ip_port,
+                                       struct GNUNET_HashCode *cadet_port);
+
 #endif
+
+/** @} */ /* end of group */
