@@ -45,6 +45,7 @@ GNUNET_JSON_from_data (const void *data,
   buf = GNUNET_STRINGS_data_to_string_alloc (data, size);
   json = json_string (buf);
   GNUNET_free (buf);
+  GNUNET_break (NULL != json);
   return json;
 }
 
@@ -64,17 +65,34 @@ GNUNET_JSON_from_time_abs (struct GNUNET_TIME_Absolute stamp)
                  GNUNET_TIME_round_abs (&stamp));
 
   j = json_object ();
-
+  if (NULL == j)
+  {
+    GNUNET_break (0);
+    return NULL;
+  }
   if (stamp.abs_value_us == GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us)
   {
-    json_object_set_new (j,
-                         "t_ms",
-                         json_string ("never"));
+    if (0 !=
+        json_object_set_new (j,
+                             "t_ms",
+                             json_string ("never")))
+    {
+      GNUNET_break (0);
+      json_decref (j);
+      return NULL;
+    }
     return j;
   }
-  json_object_set_new (j,
-                       "t_ms",
-                       json_integer ((json_int_t) (stamp.abs_value_us / 1000LL)));
+  if (0 !=
+      json_object_set_new (j,
+                           "t_ms",
+                           json_integer ((json_int_t) (stamp.abs_value_us
+                                                       / 1000LL))))
+  {
+    GNUNET_break (0);
+    json_decref (j);
+    return NULL;
+  }
   return j;
 }
 
@@ -107,17 +125,34 @@ GNUNET_JSON_from_time_rel (struct GNUNET_TIME_Relative stamp)
                  GNUNET_TIME_round_rel (&stamp));
 
   j = json_object ();
-
+  if (NULL == j)
+  {
+    GNUNET_break (0);
+    return NULL;
+  }
   if (stamp.rel_value_us == GNUNET_TIME_UNIT_FOREVER_REL.rel_value_us)
   {
-    json_object_set_new (j,
-                         "d_ms",
-                         json_string ("forever"));
+    if (0 !=
+        json_object_set_new (j,
+                             "d_ms",
+                             json_string ("forever")))
+    {
+      GNUNET_break (0);
+      json_decref (j);
+      return NULL;
+    }
     return j;
   }
-  json_object_set_new (j,
-                       "d_ms",
-                       json_integer ((json_int_t) (stamp.rel_value_us / 1000LL)));
+  if (0 !=
+      json_object_set_new (j,
+                           "d_ms",
+                           json_integer ((json_int_t) (stamp.rel_value_us
+                                                       / 1000LL))))
+  {
+    GNUNET_break (0);
+    json_decref (j);
+    return NULL;
+  }
   return j;
 }
 
@@ -131,7 +166,7 @@ GNUNET_JSON_from_time_rel (struct GNUNET_TIME_Relative stamp)
 json_t *
 GNUNET_JSON_from_rsa_public_key (const struct GNUNET_CRYPTO_RsaPublicKey *pk)
 {
-  char *buf;
+  void *buf;
   size_t buf_len;
   json_t *ret;
 
@@ -153,7 +188,7 @@ GNUNET_JSON_from_rsa_public_key (const struct GNUNET_CRYPTO_RsaPublicKey *pk)
 json_t *
 GNUNET_JSON_from_rsa_signature (const struct GNUNET_CRYPTO_RsaSignature *sig)
 {
-  char *buf;
+  void *buf;
   size_t buf_len;
   json_t *ret;
 
@@ -178,7 +213,8 @@ GNUNET_JSON_from_gnsrecord (const char*rname,
                             const struct GNUNET_GNSRECORD_Data *rd,
                             unsigned int rd_count)
 {
-  struct GNUNET_TIME_Absolute expiration_time;
+  struct GNUNET_TIME_Absolute abs_exp;
+  struct GNUNET_TIME_Relative rel_exp;
   const char *expiration_time_str;
   const char *record_type_str;
   char *value_str;
@@ -187,36 +223,87 @@ GNUNET_JSON_from_gnsrecord (const char*rname,
   json_t *records;
 
   data = json_object ();
-  json_object_set_new (data,
-                       "record_name",
-                       json_string (rname));
+  if (NULL == data)
+  {
+    GNUNET_break (0);
+    return NULL;
+  }
+  if (0 !=
+      json_object_set_new (data,
+                           "record_name",
+                           json_string (rname)))
+  {
+    GNUNET_break (0);
+    json_decref (data);
+    return NULL;
+  }
   records = json_array ();
+  if (NULL == records)
+  {
+    GNUNET_break (0);
+    json_decref (data);
+    return NULL;
+  }
   for (int i = 0; i < rd_count; i++)
   {
     value_str = GNUNET_GNSRECORD_value_to_string (rd[i].record_type,
                                                   rd[i].data,
                                                   rd[i].data_size);
-    expiration_time = GNUNET_GNSRECORD_record_get_expiration_time (1, &rd[i]);
-    expiration_time_str = GNUNET_STRINGS_absolute_time_to_string (
-      expiration_time);
+    if (GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION & rd[i].flags)
+    {
+      rel_exp.rel_value_us = rd[i].expiration_time;
+      expiration_time_str = GNUNET_STRINGS_relative_time_to_string (rel_exp,
+                                                                    GNUNET_NO);
+    } else {
+      abs_exp.abs_value_us = rd[i].expiration_time;
+      expiration_time_str = GNUNET_STRINGS_absolute_time_to_string (abs_exp);
+    }
     record_type_str = GNUNET_GNSRECORD_number_to_typename (rd[i].record_type);
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Packing %s %s %s %d\n",
                 value_str, record_type_str, expiration_time_str, rd[i].flags);
-    record = json_pack ("{s:s,s:s,s:s,s:i}",
+    record = json_pack ("{s:s,s:s,s:s,s:b,s:b,s:b,s:b}",
                         "value",
                         value_str,
                         "record_type",
                         record_type_str,
                         "expiration_time",
                         expiration_time_str,
-                        "flag",
-                        rd[i].flags);
-    GNUNET_assert (NULL != record);
+                        "private",
+                        rd[i].flags & GNUNET_GNSRECORD_RF_PRIVATE,
+                        "relative_expiration",
+                        rd[i].flags & GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION,
+                        "supplemental",
+                        rd[i].flags & GNUNET_GNSRECORD_RF_SUPPLEMENTAL,
+                        "shadow",
+                        rd[i].flags & GNUNET_GNSRECORD_RF_SHADOW_RECORD);
     GNUNET_free (value_str);
-    json_array_append_new (records, record);
+    if (NULL == record)
+    {
+      GNUNET_break (0);
+      json_decref (records);
+      json_decref (data);
+      return NULL;
+    }
+    if (0 !=
+        json_array_append_new (records,
+                               record))
+    {
+      GNUNET_break (0);
+      json_decref (records);
+      json_decref (data);
+      return NULL;
+    }
+  }
+  if (0 !=
+      json_object_set_new (data,
+                           "data",
+                           records))
+  {
+    GNUNET_break (0);
+    json_decref (data);
+    return NULL;
   }
-  json_object_set_new (data, "data", records);
   return data;
 }
 
