@@ -326,6 +326,60 @@ GNUNET_JSON_spec_json (const char *name,
 }
 
 
+/**
+ * Parse given JSON object to a bool.
+ *
+ * @param cls closure, NULL
+ * @param root the json object representing data
+ * @param[out] spec where to write the data
+ * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
+ */
+static int
+parse_bool (void *cls,
+            json_t *root,
+            struct GNUNET_JSON_Specification *spec)
+{
+  bool *b = spec->ptr;
+
+  if (json_true () == root)
+  {
+    *b = true;
+    return GNUNET_OK;
+  }
+  if (json_false () == root)
+  {
+    *b = false;
+    return GNUNET_OK;
+  }
+  GNUNET_break_op (0);
+  return GNUNET_SYSERR;
+}
+
+
+/**
+ * boolean.
+ *
+ * @param name name of the JSON field
+ * @param[out] b where to store the boolean found under @a name
+ */
+struct GNUNET_JSON_Specification
+GNUNET_JSON_spec_bool (const char *name,
+                       bool *b)
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_bool,
+    .cleaner = NULL,
+    .cls = NULL,
+    .field = name,
+    .ptr = b,
+    .ptr_size = sizeof(bool),
+    .size_ptr = NULL
+  };
+
+  return ret;
+}
+
+
 /**
  * Parse given JSON object to a uint8_t.
  *
@@ -495,7 +549,7 @@ GNUNET_JSON_spec_uint32 (const char *name,
 
 
 /**
- * Parse given JSON object to a uint8_t.
+ * Parse given JSON object to a uint64_t.
  *
  * @param cls closure, NULL
  * @param root the json object representing data
@@ -545,6 +599,57 @@ GNUNET_JSON_spec_uint64 (const char *name,
 }
 
 
+/**
+ * Parse given JSON object to a int64_t.
+ *
+ * @param cls closure, NULL
+ * @param root the json object representing data
+ * @param[out] spec where to write the data
+ * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
+ */
+static int
+parse_i64 (void *cls,
+           json_t *root,
+           struct GNUNET_JSON_Specification *spec)
+{
+  json_int_t val;
+  int64_t *up = spec->ptr;
+
+  if (! json_is_integer (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+  val = json_integer_value (root);
+  *up = (int64_t) val;
+  return GNUNET_OK;
+}
+
+
+/**
+ * 64-bit signed integer.
+ *
+ * @param name name of the JSON field
+ * @param[out] i64 where to store the integer found under @a name
+ */
+struct GNUNET_JSON_Specification
+GNUNET_JSON_spec_int64 (const char *name,
+                        int64_t *i64)
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_i64,
+    .cleaner = NULL,
+    .cls = NULL,
+    .field = name,
+    .ptr = i64,
+    .ptr_size = sizeof(int64_t),
+    .size_ptr = NULL
+  };
+
+  return ret;
+}
+
+
 /* ************ GNUnet-specific parser specifications ******************* */
 
 /**
@@ -616,7 +721,7 @@ GNUNET_JSON_spec_absolute_time (const char *name,
     .cls = NULL,
     .field = name,
     .ptr = at,
-    .ptr_size = sizeof(uint64_t),
+    .ptr_size = sizeof(struct GNUNET_TIME_Absolute),
     .size_ptr = NULL
   };
 
@@ -670,7 +775,7 @@ GNUNET_JSON_spec_absolute_time_nbo (const char *name,
     .cls = NULL,
     .field = name,
     .ptr = at,
-    .ptr_size = sizeof(uint64_t),
+    .ptr_size = sizeof(struct GNUNET_TIME_AbsoluteNBO),
     .size_ptr = NULL
   };
 
@@ -747,7 +852,7 @@ GNUNET_JSON_spec_relative_time (const char *name,
     .cls = NULL,
     .field = name,
     .ptr = rt,
-    .ptr_size = sizeof(uint64_t),
+    .ptr_size = sizeof(struct GNUNET_TIME_Relative),
     .size_ptr = NULL
   };
 
