@@ -11,12 +11,12 @@
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
      Affero General Public License for more details.
-    
+
      You should have received a copy of the GNU Affero General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 /**
  * @file my/my_query_helper.c
  * @brief library to help with access to a MySQL database
@@ -76,7 +76,7 @@ my_conv_fixed_size (void *cls,
  */
 struct GNUNET_MY_QueryParam
 GNUNET_MY_query_param_fixed_size (const void *ptr,
-				  size_t ptr_size)
+                                  size_t ptr_size)
 {
   struct GNUNET_MY_QueryParam qp = {
     .conv = &my_conv_fixed_size,
@@ -86,6 +86,7 @@ GNUNET_MY_query_param_fixed_size (const void *ptr,
     .data = ptr,
     .data_len = (unsigned long) ptr_size
   };
+
   return qp;
 }
 
@@ -128,6 +129,7 @@ GNUNET_MY_query_param_string (const char *ptr)
     .data = ptr,
     .data_len = strlen (ptr)
   };
+
   return qp;
 }
 
@@ -148,7 +150,7 @@ my_conv_uint16 (void *cls,
   (void) cls;
   GNUNET_assert (1 == qp->num_params);
   qbind->buffer = (void *) qp->data;
-  qbind->buffer_length = sizeof (uint16_t);
+  qbind->buffer_length = sizeof(uint16_t);
   qbind->buffer_type = MYSQL_TYPE_SHORT;
   qbind->is_unsigned = 1;
   return 1;
@@ -169,7 +171,7 @@ GNUNET_MY_query_param_uint16 (const uint16_t *x)
     .conv_cls = NULL,
     .num_params = 1,
     .data = x,
-    .data_len = sizeof (*x)
+    .data_len = sizeof(*x)
   };
 
   return res;
@@ -213,7 +215,7 @@ GNUNET_MY_query_param_uint32 (const uint32_t *x)
     .conv_cls = NULL,
     .num_params = 1,
     .data = x,
-    .data_len = sizeof (*x)
+    .data_len = sizeof(*x)
   };
 
   return res;
@@ -231,12 +233,12 @@ GNUNET_MY_query_param_uint32 (const uint32_t *x)
 static int
 my_conv_uint64 (void *cls,
                 const struct GNUNET_MY_QueryParam *qp,
-                MYSQL_BIND * qbind)
+                MYSQL_BIND *qbind)
 {
   (void) cls;
   GNUNET_assert (1 == qp->num_params);
   qbind->buffer = (void *) qp->data;
-  qbind->buffer_length = sizeof (uint64_t);
+  qbind->buffer_length = sizeof(uint64_t);
   qbind->buffer_type = MYSQL_TYPE_LONGLONG;
   qbind->is_unsigned = 1;
   return 1;
@@ -275,16 +277,16 @@ GNUNET_MY_query_param_uint64 (const uint64_t *x)
 static int
 my_conv_rsa_public_key (void *cls,
                         const struct GNUNET_MY_QueryParam *qp,
-                        MYSQL_BIND * qbind)
+                        MYSQL_BIND *qbind)
 {
   const struct GNUNET_CRYPTO_RsaPublicKey *rsa = qp->data;
   char *buf;
   size_t buf_size;
 
   (void) cls;
-  GNUNET_assert(1 == qp->num_params);
+  GNUNET_assert (1 == qp->num_params);
   buf_size = GNUNET_CRYPTO_rsa_public_key_encode (rsa,
-						  &buf);
+                                                  &buf);
   qbind->buffer = (void *) buf;
   qbind->buffer_length = buf_size;
   qbind->buffer_type = MYSQL_TYPE_BLOB;
@@ -300,7 +302,8 @@ my_conv_rsa_public_key (void *cls,
  * @return array entry for the query parameters to use
  */
 struct GNUNET_MY_QueryParam
-GNUNET_MY_query_param_rsa_public_key (const struct GNUNET_CRYPTO_RsaPublicKey *x)
+GNUNET_MY_query_param_rsa_public_key (const struct
+                                      GNUNET_CRYPTO_RsaPublicKey *x)
 {
   struct GNUNET_MY_QueryParam res = {
     .conv = &my_conv_rsa_public_key,
@@ -316,13 +319,13 @@ GNUNET_MY_query_param_rsa_public_key (const struct GNUNET_CRYPTO_RsaPublicKey *x
 
 
 /**
-  * Function called to convert input argument into SQL parameters
-  *
-  *@param cls closure
-  *@param pq data about the query
-  *@param qbind array of parameters to initialize
-  *@return -1 on error
-  */
+ * Function called to convert input argument into SQL parameters
+ *
+ *@param cls closure
+ *@param pq data about the query
+ *@param qbind array of parameters to initialize
+ *@return -1 on error
+ */
 static int
 my_conv_rsa_signature (void *cls,
                        const struct GNUNET_MY_QueryParam *qp,
@@ -333,7 +336,7 @@ my_conv_rsa_signature (void *cls,
   size_t buf_size;
 
   (void) cls;
-  GNUNET_assert(1 == qp->num_params);
+  GNUNET_assert (1 == qp->num_params);
   buf_size = GNUNET_CRYPTO_rsa_signature_encode (sig,
                                                  &buf);
   qbind->buffer = (void *) buf;
@@ -361,6 +364,7 @@ GNUNET_MY_query_param_rsa_signature (const struct GNUNET_CRYPTO_RsaSignature *x)
     .data = (x),
     .data_len = 0
   };
+
   return res;
 }
 
@@ -386,7 +390,8 @@ GNUNET_MY_query_param_absolute_time (const struct GNUNET_TIME_Absolute *x)
  * @param x pointer to the query parameter to pass
  */
 struct GNUNET_MY_QueryParam
-GNUNET_MY_query_param_absolute_time_nbo (const struct GNUNET_TIME_AbsoluteNBO *x)
+GNUNET_MY_query_param_absolute_time_nbo (const struct
+                                         GNUNET_TIME_AbsoluteNBO *x)
 {
   return GNUNET_MY_query_param_auto_from_type (&x->abs_value_us__);
 }
