@@ -260,7 +260,7 @@ database_shutdown (struct Plugin *plugin)
                 GNUNET_ERROR_TYPE_ERROR,
                 "sqlite3_close");
 
-  GNUNET_free_non_null (plugin->fn);
+  GNUNET_free (plugin->fn);
 }
 
 
