@@ -878,7 +878,7 @@ del_monitor (void *cls,
                                                       rd[i].data_size)))) ||
             (0 == strcmp (vs, value)))))
       rdx[rd_left++] = rd[i];
-    GNUNET_free_non_null (vs);
+    GNUNET_free (vs);
   }
   if (rd_count == rd_left)
   {
@@ -1038,6 +1038,24 @@ run_with_zone_pkey (const struct GNUNET_CONFIGURATION_Handle *cfg)
     GNUNET_free (rd);
     return;
   }
+  if (NULL != nickstring)
+  {
+    if (0 == strlen (nickstring))
+    {
+      fprintf (stderr, _ ("Invalid nick `%s'\n"), nickstring);
+      GNUNET_SCHEDULER_shutdown ();
+      ret = 1;
+      return;
+    }
+    add = 1;
+    typestring = GNUNET_strdup (GNUNET_GNSRECORD_number_to_typename (GNUNET_GNSRECORD_TYPE_NICK));
+    name = GNUNET_strdup (GNUNET_GNS_EMPTY_LABEL_AT);
+    value = GNUNET_strdup (nickstring);
+    is_public = 0;
+    expirationstring = GNUNET_strdup ("never");
+    GNUNET_free (nickstring);
+    nickstring = NULL;
+  }
 
   if (add)
   {
@@ -1069,6 +1087,17 @@ run_with_zone_pkey (const struct GNUNET_CONFIGURATION_Handle *cfg)
       ret = 1;
       return;
     }
+    if ((GNUNET_DNSPARSER_TYPE_SRV == type) ||
+        (GNUNET_DNSPARSER_TYPE_TLSA == type) ||
+        (GNUNET_DNSPARSER_TYPE_OPENPGPKEY == type))
+    {
+      fprintf (stderr,
+               _ ("For DNS record types `SRV', `TLSA' and `OPENPGPKEY'"));
+      fprintf (stderr, ", please use a `BOX' record instead\n");
+      GNUNET_SCHEDULER_shutdown ();
+      ret = 1;
+      return;
+    }
     if (NULL == value)
     {
       fprintf (stderr,
@@ -1193,6 +1222,23 @@ run_with_zone_pkey (const struct GNUNET_CONFIGURATION_Handle *cfg)
       ret = 1;
       return;
     }
+    if (NULL == expirationstring)
+    {
+      fprintf (stderr,
+               _ ("Missing option `%s' for operation `%s'\n"),
+               "-e",
+               _ ("add"));
+      GNUNET_SCHEDULER_shutdown ();
+      ret = 1;
+      return;
+    }
+    if (GNUNET_OK != parse_expiration (expirationstring, &etime_is_rel, &etime))
+    {
+      fprintf (stderr, _ ("Invalid time format `%s'\n"), expirationstring);
+      GNUNET_SCHEDULER_shutdown ();
+      ret = 1;
+      return;
+    }
     memset (&rd, 0, sizeof(rd));
     rd.data = &pkey;
     rd.data_size = sizeof(struct GNUNET_CRYPTO_EcdsaPublicKey);
@@ -1210,21 +1256,6 @@ run_with_zone_pkey (const struct GNUNET_CONFIGURATION_Handle *cfg)
                                                  &add_continuation,
                                                  &add_qe_uri);
   }
-  if (NULL != nickstring)
-  {
-    if (0 == strlen (nickstring))
-    {
-      fprintf (stderr, _ ("Invalid nick `%s'\n"), nickstring);
-      GNUNET_SCHEDULER_shutdown ();
-      ret = 1;
-      return;
-    }
-    add_qe_uri = GNUNET_NAMESTORE_set_nick (ns,
-                                            &zone_pkey,
-                                            nickstring,
-                                            &add_continuation,
-                                            &add_qe_uri);
-  }
   if (monitor)
   {
     zm = GNUNET_NAMESTORE_zone_monitor_start (cfg,
@@ -1248,7 +1279,7 @@ run_with_zone_pkey (const struct GNUNET_CONFIGURATION_Handle *cfg)
  * @param ego an ego known to identity service, or NULL
  */
 static void
-identity_cb (void *cls, const struct GNUNET_IDENTITY_Ego *ego)
+identity_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
 
@@ -1276,7 +1307,7 @@ identity_cb (void *cls, const struct GNUNET_IDENTITY_Ego *ego)
     return;
   }
   zone_pkey = *GNUNET_IDENTITY_ego_get_private_key (ego);
-  GNUNET_free_non_null (ego_name);
+  GNUNET_free (ego_name);
   ego_name = NULL;
   run_with_zone_pkey (cfg);
 }
@@ -1671,11 +1702,11 @@ main (int argc, char *const *argv)
                                   &run,
                                   NULL)))
   {
-    GNUNET_free ((void *) argv);
+    GNUNET_free_nz ((void *) argv);
     GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
     return lret;
   }
-  GNUNET_free ((void *) argv);
+  GNUNET_free_nz ((void *) argv);
   GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
   return ret;
 }
