@@ -123,6 +123,13 @@ struct EgoEntry
   struct GNUNET_IDENTITY_Ego *ego;
 };
 
+
+enum UpdateStrategy
+{
+  UPDATE_STRATEGY_REPLACE,
+  UPDATE_STRATEGY_APPEND
+};
+
 /**
  * The request handle
  */
@@ -133,6 +140,16 @@ struct RequestHandle
    */
   char *record_name;
 
+  /**
+   * Record type filter
+   */
+  uint32_t record_type;
+
+  /**
+   * How to update the record set
+   */
+  enum UpdateStrategy update_strategy;
+
   /**
    * Records to store
    */
@@ -146,7 +163,7 @@ struct RequestHandle
   /**
    * NAMESTORE Operation
    */
-  struct GNUNET_NAMESTORE_QueueEntry *add_qe;
+  struct GNUNET_NAMESTORE_QueueEntry *ns_qe;
 
   /**
    * Response object
@@ -267,7 +284,7 @@ cleanup_handle (void *cls)
     for (int i = 0; i < handle->rd_count; i++)
     {
       if (NULL != handle->rd[i].data)
-        GNUNET_free ((void *) handle->rd[i].data);
+        GNUNET_free_nz ((void *) handle->rd[i].data);
     }
     GNUNET_free (handle->rd);
   }
@@ -275,8 +292,8 @@ cleanup_handle (void *cls)
     GNUNET_SCHEDULER_cancel (handle->timeout_task);
   if (NULL != handle->list_it)
     GNUNET_NAMESTORE_zone_iteration_stop (handle->list_it);
-  if (NULL != handle->add_qe)
-    GNUNET_NAMESTORE_cancel (handle->add_qe);
+  if (NULL != handle->ns_qe)
+    GNUNET_NAMESTORE_cancel (handle->ns_qe);
   if (NULL != handle->identity_handle)
     GNUNET_IDENTITY_disconnect (handle->identity_handle);
   if (NULL != handle->ns_handle)
@@ -324,6 +341,7 @@ do_error (void *cls)
     handle->response_code = MHD_HTTP_INTERNAL_SERVER_ERROR;
   response = json_dumps (json_error, 0);
   resp = GNUNET_REST_create_response (response);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, handle->response_code);
   json_decref (json_error);
   GNUNET_free (response);
@@ -344,17 +362,21 @@ struct EgoEntry *
 get_egoentry_namestore (struct RequestHandle *handle, char *name)
 {
   struct EgoEntry *ego_entry;
+  char *copy = GNUNET_strdup (name);
+  char *tmp;
 
-  if (NULL != name)
+  if (NULL == name)
+    return NULL;
+  tmp = strtok (copy, "/");
+  for (ego_entry = handle->ego_head; NULL != ego_entry;
+       ego_entry = ego_entry->next)
   {
-    for (ego_entry = handle->ego_head; NULL != ego_entry;
-         ego_entry = ego_entry->next)
-    {
-      if (0 != strcasecmp (name, ego_entry->identifier))
-        continue;
-      return ego_entry;
-    }
+    if (0 != strcasecmp (tmp, ego_entry->identifier))
+      continue;
+    GNUNET_free (copy);
+    return ego_entry;
   }
+  GNUNET_free (copy);
   return NULL;
 }
 
@@ -388,7 +410,7 @@ create_finished (void *cls, int32_t success, const char *emsg)
   struct RequestHandle *handle = cls;
   struct MHD_Response *resp;
 
-  handle->add_qe = NULL;
+  handle->ns_qe = NULL;
   if (GNUNET_YES != success)
   {
     if (NULL != emsg)
@@ -419,7 +441,7 @@ del_finished (void *cls, int32_t success, const char *emsg)
 {
   struct RequestHandle *handle = cls;
 
-  handle->add_qe = NULL;
+  handle->ns_qe = NULL;
   if (GNUNET_NO == success)
   {
     handle->response_code = MHD_HTTP_NOT_FOUND;
@@ -467,8 +489,9 @@ namestore_list_finished (void *cls)
   result_str = json_dumps (handle->resp_object, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result_str);
   resp = GNUNET_REST_create_response (result_str);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
-  GNUNET_free_non_null (result_str);
+  GNUNET_free (result_str);
   GNUNET_SCHEDULER_add_now (&cleanup_handle, handle);
 }
 
@@ -486,17 +509,86 @@ namestore_list_iteration (void *cls,
                           const struct GNUNET_GNSRECORD_Data *rd)
 {
   struct RequestHandle *handle = cls;
+  struct GNUNET_GNSRECORD_Data rd_filtered[rd_len];
   json_t *record_obj;
+  int i = 0;
+  int j = 0;
 
   if (NULL == handle->resp_object)
     handle->resp_object = json_array ();
-  record_obj = GNUNET_JSON_from_gnsrecord (rname,
-                                           rd,
-                                           rd_len);
-  json_array_append_new (handle->resp_object, record_obj);
+  for (i = 0; i < rd_len; i++)
+  {
+    if ((GNUNET_GNSRECORD_TYPE_ANY != handle->record_type) &&
+        (rd[i].record_type != handle->record_type))
+      continue; /* Apply filter */
+    rd_filtered[j] = rd[i];
+    rd_filtered[j].data = rd[i].data;
+    j++;
+  }
+  /** Only add if not empty **/
+  if (j > 0)
+  {
+    record_obj = GNUNET_JSON_from_gnsrecord (rname,
+                                             rd_filtered,
+                                             j);
+    json_array_append_new (handle->resp_object, record_obj);
+  }
   GNUNET_NAMESTORE_zone_iterator_next (handle->list_it, 1);
 }
 
+/**
+ * Handle lookup error
+ *
+ * @param cls the request handle
+ */
+static void
+ns_lookup_error_cb (void *cls)
+{
+  struct RequestHandle *handle = cls;
+
+  handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
+  GNUNET_SCHEDULER_add_now (&do_error, handle);
+}
+
+
+static void
+ns_get_lookup_cb (void *cls,
+              const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
+              const char *label,
+              unsigned int rd_len,
+              const struct GNUNET_GNSRECORD_Data *rd)
+{
+  struct RequestHandle *handle = cls;
+  struct GNUNET_GNSRECORD_Data rd_filtered[rd_len];
+  json_t *record_obj;
+  int i = 0;
+  int j = 0;
+
+  handle->ns_qe = NULL;
+  if (NULL == handle->resp_object)
+    handle->resp_object = json_array ();
+  for (i = 0; i < rd_len; i++)
+  {
+    if ((GNUNET_GNSRECORD_TYPE_ANY != handle->record_type) &&
+        (rd[i].record_type != handle->record_type))
+      continue; /* Apply filter */
+    rd_filtered[j] = rd[i];
+    rd_filtered[j].data = rd[i].data;
+    j++;
+  }
+  /** Only add if not empty **/
+  if (j > 0)
+  {
+    record_obj = GNUNET_JSON_from_gnsrecord (label,
+                                             rd_filtered,
+                                             j);
+    json_array_append_new (handle->resp_object, record_obj);
+  }
+  GNUNET_SCHEDULER_add_now (&namestore_list_finished, handle);
+}
+
+
+
 
 /**
  * Handle namestore GET request
@@ -512,38 +604,75 @@ namestore_get (struct GNUNET_REST_RequestHandle *con_handle,
 {
   struct RequestHandle *handle = cls;
   struct EgoEntry *ego_entry;
+  struct GNUNET_HashCode key;
   char *egoname;
+  char *labelname;
+  char *typename;
 
   egoname = NULL;
   ego_entry = NULL;
 
   // set zone to name if given
-  if (strlen (GNUNET_REST_API_NS_NAMESTORE) < strlen (handle->url))
+  if (strlen (GNUNET_REST_API_NS_NAMESTORE) + 1  >= strlen (handle->url))
   {
-    egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
-    ego_entry = get_egoentry_namestore (handle, egoname);
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    return;
+  }
+  egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
+  ego_entry = get_egoentry_namestore (handle, egoname);
+  if (NULL == ego_entry)
+  {
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    return;
+  }
+  handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
 
-    if (NULL == ego_entry)
+  GNUNET_CRYPTO_hash ("record_type", strlen ("record_type"), &key);
+  if (GNUNET_NO ==
+      GNUNET_CONTAINER_multihashmap_contains (con_handle->url_param_map, &key))
+  {
+    handle->record_type = GNUNET_GNSRECORD_TYPE_ANY;
+  }
+  else
+  {
+    typename = GNUNET_CONTAINER_multihashmap_get (con_handle->url_param_map,
+                                                  &key);
+    handle->record_type = GNUNET_GNSRECORD_typename_to_number (typename);
+  }
+  labelname = &egoname[strlen (ego_entry->identifier)];
+  // set zone to name if given
+  if (1 >= strlen (labelname))
+  {
+    handle->list_it =
+      GNUNET_NAMESTORE_zone_iteration_start (handle->ns_handle,
+                                             handle->zone_pkey,
+                                             &namestore_iteration_error,
+                                             handle,
+                                             &namestore_list_iteration,
+                                             handle,
+                                             &namestore_list_finished,
+                                             handle);
+    if (NULL == handle->list_it)
     {
-      handle->response_code = MHD_HTTP_NOT_FOUND;
-      handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+      handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
       GNUNET_SCHEDULER_add_now (&do_error, handle);
       return;
     }
+    return;
   }
-  if (NULL != ego_entry)
-    handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
-
-  handle->list_it =
-    GNUNET_NAMESTORE_zone_iteration_start (handle->ns_handle,
-                                           handle->zone_pkey,
-                                           &namestore_iteration_error,
-                                           handle,
-                                           &namestore_list_iteration,
-                                           handle,
-                                           &namestore_list_finished,
-                                           handle);
-  if (NULL == handle->list_it)
+  handle->record_name = GNUNET_strdup (labelname + 1);
+  handle->ns_qe = GNUNET_NAMESTORE_records_lookup (handle->ns_handle,
+                                                    handle->zone_pkey,
+                                                    handle->record_name,
+                                                    &ns_lookup_error_cb,
+                                                    handle,
+                                                    &ns_get_lookup_cb,
+                                                    handle);
+  if (NULL == handle->ns_qe)
   {
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
@@ -552,15 +681,6 @@ namestore_get (struct GNUNET_REST_RequestHandle *con_handle,
 }
 
 
-static void
-ns_lookup_error_cb (void *cls)
-{
-  struct RequestHandle *handle = cls;
-
-  handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
-  GNUNET_SCHEDULER_add_now (&do_error, handle);
-}
-
 
 static void
 ns_lookup_cb (void *cls,
@@ -571,19 +691,24 @@ ns_lookup_cb (void *cls,
 {
   struct RequestHandle *handle = cls;
   struct GNUNET_GNSRECORD_Data rd_new[rd_count + handle->rd_count];
+  int i = 0;
+  int j = 0;
 
-  for (int i = 0; i < rd_count; i++)
-    rd_new[i] = rd[i];
-  for (int j = 0; j < handle->rd_count; j++)
-    rd_new[rd_count + j] = handle->rd[j];
-  handle->add_qe = GNUNET_NAMESTORE_records_store (handle->ns_handle,
+  if (UPDATE_STRATEGY_APPEND == handle->update_strategy)
+  {
+    for (i = 0; i < rd_count; i++)
+      rd_new[i] = rd[i];
+  }
+  for (j = 0; j < handle->rd_count; j++)
+    rd_new[i + j] = handle->rd[j];
+  handle->ns_qe = GNUNET_NAMESTORE_records_store (handle->ns_handle,
                                                    handle->zone_pkey,
                                                    handle->record_name,
-                                                   rd_count + handle->rd_count,
+                                                   i + j,
                                                    rd_new,
                                                    &create_finished,
                                                    handle);
-  if (NULL == handle->add_qe)
+  if (NULL == handle->ns_qe)
   {
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
@@ -593,16 +718,16 @@ ns_lookup_cb (void *cls,
 
 
 /**
- * Handle namestore POST request
+ * Handle namestore POST/PUT request
  *
  * @param con_handle the connection handle
  * @param url the url
  * @param cls the RequestHandle
  */
 void
-namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
-               const char *url,
-               void *cls)
+namestore_add_or_update (struct GNUNET_REST_RequestHandle *con_handle,
+                         const char *url,
+                         void *cls)
 {
   struct RequestHandle *handle = cls;
   struct EgoEntry *ego_entry;
@@ -614,6 +739,7 @@ namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
 
   if (0 >= handle->rest_handle->data_size)
   {
+    handle->response_code = MHD_HTTP_BAD_REQUEST;
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_NO_DATA);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
     return;
@@ -637,6 +763,7 @@ namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
   GNUNET_JSON_parse_free (gnsspec);
   if (0 >= strlen (handle->record_name))
   {
+    handle->response_code = MHD_HTTP_BAD_REQUEST;
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_INVALID_DATA);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
     json_decref (data_js);
@@ -648,29 +775,32 @@ namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
   ego_entry = NULL;
 
   // set zone to name if given
-  if (strlen (GNUNET_REST_API_NS_NAMESTORE) < strlen (handle->url))
+  if (strlen (GNUNET_REST_API_NS_NAMESTORE) + 1 >= strlen (handle->url))
   {
-    egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
-    ego_entry = get_egoentry_namestore (handle, egoname);
-
-    if (NULL == ego_entry)
-    {
-      handle->response_code = MHD_HTTP_NOT_FOUND;
-      handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
-      GNUNET_SCHEDULER_add_now (&do_error, handle);
-      return;
-    }
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    return;
   }
-  if (NULL != ego_entry)
-    handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
-  handle->add_qe = GNUNET_NAMESTORE_records_lookup (handle->ns_handle,
+  egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
+  ego_entry = get_egoentry_namestore (handle, egoname);
+
+  if (NULL == ego_entry)
+  {
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    return;
+  }
+  handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
+  handle->ns_qe = GNUNET_NAMESTORE_records_lookup (handle->ns_handle,
                                                     handle->zone_pkey,
                                                     handle->record_name,
                                                     &ns_lookup_error_cb,
                                                     handle,
                                                     &ns_lookup_cb,
                                                     handle);
-  if (NULL == handle->add_qe)
+  if (NULL == handle->ns_qe)
   {
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
@@ -679,6 +809,42 @@ namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
 }
 
 
+/**
+ * Handle namestore PUT request
+ *
+ * @param con_handle the connection handle
+ * @param url the url
+ * @param cls the RequestHandle
+ */
+void
+namestore_update (struct GNUNET_REST_RequestHandle *con_handle,
+                  const char *url,
+                  void *cls)
+{
+  struct RequestHandle *handle = cls;
+  handle->update_strategy = UPDATE_STRATEGY_REPLACE;
+  namestore_add_or_update (con_handle, url, cls);
+}
+
+
+/**
+ * Handle namestore POST request
+ *
+ * @param con_handle the connection handle
+ * @param url the url
+ * @param cls the RequestHandle
+ */
+void
+namestore_add (struct GNUNET_REST_RequestHandle *con_handle,
+               const char *url,
+               void *cls)
+{
+  struct RequestHandle *handle = cls;
+  handle->update_strategy = UPDATE_STRATEGY_APPEND;
+  namestore_add_or_update (con_handle, url, cls);
+}
+
+
 /**
  * Handle namestore DELETE request
  *
@@ -692,49 +858,50 @@ namestore_delete (struct GNUNET_REST_RequestHandle *con_handle,
                   void *cls)
 {
   struct RequestHandle *handle = cls;
-  struct GNUNET_HashCode key;
   struct EgoEntry *ego_entry;
   char *egoname;
+  char *labelname;
 
   egoname = NULL;
   ego_entry = NULL;
 
   // set zone to name if given
-  if (strlen (GNUNET_REST_API_NS_NAMESTORE) < strlen (handle->url))
+  if (strlen (GNUNET_REST_API_NS_NAMESTORE) + 1 >= strlen (handle->url))
   {
-    egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
-    ego_entry = get_egoentry_namestore (handle, egoname);
-
-    if (NULL == ego_entry)
-    {
-      handle->response_code = MHD_HTTP_NOT_FOUND;
-      handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
-      GNUNET_SCHEDULER_add_now (&do_error, handle);
-      return;
-    }
-  }
-  if (NULL != ego_entry)
-    handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
-
-  GNUNET_CRYPTO_hash ("record_name", strlen ("record_name"), &key);
-  if (GNUNET_NO ==
-      GNUNET_CONTAINER_multihashmap_contains (con_handle->url_param_map, &key))
-  {
-    handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_INVALID_DATA);
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
     return;
   }
-  handle->record_name = GNUNET_strdup (
-    GNUNET_CONTAINER_multihashmap_get (con_handle->url_param_map, &key));
+  egoname = &handle->url[strlen (GNUNET_REST_API_NS_NAMESTORE) + 1];
+  ego_entry = get_egoentry_namestore (handle, egoname);
+  if (NULL == ego_entry)
+  {
+    handle->response_code = MHD_HTTP_NOT_FOUND;
+    handle->emsg = GNUNET_strdup (GNUNET_REST_IDENTITY_NOT_FOUND);
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    return;
+  }
+  handle->zone_pkey = GNUNET_IDENTITY_ego_get_private_key (ego_entry->ego);
+  labelname = &egoname[strlen (ego_entry->identifier)];
+  // set zone to name if given
+  if (1 >= strlen (labelname))
+  {
+    /* label is only "/" */
+    handle->response_code = MHD_HTTP_BAD_REQUEST;
+    handle->emsg = GNUNET_strdup ("Label missing");
+    GNUNET_SCHEDULER_add_now (&do_error, handle);
+  }
 
-  handle->add_qe = GNUNET_NAMESTORE_records_store (handle->ns_handle,
-                                                   handle->zone_pkey,
-                                                   handle->record_name,
-                                                   0,
+  handle->record_name = GNUNET_strdup (labelname + 1);
+  handle->ns_qe = GNUNET_NAMESTORE_records_store (handle->ns_handle,
+                                                  handle->zone_pkey,
+                                                  handle->record_name,
+                                                  0,
                                                    NULL,
                                                    &del_finished,
                                                    handle);
-  if (NULL == handle->add_qe)
+  if (NULL == handle->ns_qe)
   {
     handle->emsg = GNUNET_strdup (GNUNET_REST_NAMESTORE_FAILED);
     GNUNET_SCHEDULER_add_now (&do_error, handle);
@@ -779,6 +946,7 @@ init_cont (struct RequestHandle *handle)
   static const struct GNUNET_REST_RequestHandler handlers[] =
   { { MHD_HTTP_METHOD_GET, GNUNET_REST_API_NS_NAMESTORE, &namestore_get },
     { MHD_HTTP_METHOD_POST, GNUNET_REST_API_NS_NAMESTORE, &namestore_add },
+    { MHD_HTTP_METHOD_PUT, GNUNET_REST_API_NS_NAMESTORE, &namestore_update },
     { MHD_HTTP_METHOD_DELETE, GNUNET_REST_API_NS_NAMESTORE, &namestore_delete },
     { MHD_HTTP_METHOD_OPTIONS, GNUNET_REST_API_NS_NAMESTORE, &options_cont },
     GNUNET_REST_HANDLER_END };
@@ -941,7 +1109,7 @@ libgnunet_plugin_rest_namestore_done (void *cls)
 
   plugin->cfg = NULL;
 
-  GNUNET_free_non_null (allow_methods);
+  GNUNET_free (allow_methods);
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Namestore REST plugin is finished\n");
   return NULL;
