@@ -23,6 +23,7 @@
  */
 #include "platform.h"
 #include "gnunet_namestore_service.h"
+#include "gnunet_gns_service.h"
 #include "gnunet_testing_lib.h"
 #include "gnunet_dnsparser_lib.h"
 
@@ -40,7 +41,7 @@ static struct GNUNET_NAMESTORE_Handle *nsh;
 
 static struct GNUNET_SCHEDULER_Task *endbadly_task;
 
-static struct GNUNET_CRYPTO_EcdsaPrivateKey *privkey;
+static struct GNUNET_CRYPTO_EcdsaPrivateKey privkey;
 
 static struct GNUNET_CRYPTO_EcdsaPublicKey pubkey;
 
@@ -53,21 +54,17 @@ static struct GNUNET_NAMESTORE_QueueEntry *nsqe;
 // static const char * name = "dummy.dummy.gnunet";
 static const char *name = "d";
 
+static char *record_data;
 
 static void
 cleanup ()
 {
-  GNUNET_free_non_null ((void *) rd_orig.data);
+  GNUNET_free (record_data);
   if (NULL != nsh)
   {
     GNUNET_NAMESTORE_disconnect (nsh);
     nsh = NULL;
   }
-  if (NULL != privkey)
-  {
-    GNUNET_free (privkey);
-    privkey = NULL;
-  }
   GNUNET_SCHEDULER_shutdown ();
 }
 
@@ -111,7 +108,7 @@ lookup_it (void *cls,
   int found_record = GNUNET_NO;
   int found_nick = GNUNET_NO;
 
-  if (0 != GNUNET_memcmp (privkey, zone))
+  if (0 != GNUNET_memcmp (&privkey, zone))
   {
     GNUNET_break (0);
     GNUNET_SCHEDULER_cancel (endbadly_task);
@@ -247,7 +244,7 @@ put_cont (void *cls, int32_t success, const char *emsg)
   }
   /* Lookup */
   nsqe = GNUNET_NAMESTORE_records_lookup (nsh,
-                                          privkey,
+                                          &privkey,
                                           name,
                                           &fail_cb,
                                           NULL,
@@ -268,12 +265,16 @@ nick_cont (void *cls, int32_t success, const char *emsg)
   rd_orig.expiration_time = GNUNET_TIME_absolute_get ().abs_value_us;
   rd_orig.record_type = TEST_RECORD_TYPE;
   rd_orig.data_size = TEST_RECORD_DATALEN;
-  rd_orig.data = GNUNET_malloc (TEST_RECORD_DATALEN);
+  record_data = GNUNET_malloc (TEST_RECORD_DATALEN);
+  rd_orig.data = record_data;
   rd_orig.flags = 0;
   memset ((char *) rd_orig.data, 'a', TEST_RECORD_DATALEN);
 
-  nsqe = GNUNET_NAMESTORE_records_store (nsh, privkey, name,
-                                         1, &rd_orig, &put_cont, (void *) name);
+  nsqe = GNUNET_NAMESTORE_records_store (nsh, &privkey,
+                                         name,
+                                         1,
+                                         &rd_orig,
+                                         &put_cont, (void *) name);
 }
 
 
@@ -282,22 +283,32 @@ run (void *cls,
      const struct GNUNET_CONFIGURATION_Handle *cfg,
      struct GNUNET_TESTING_Peer *peer)
 {
+  struct GNUNET_GNSRECORD_Data rd;
+
   endbadly_task = GNUNET_SCHEDULER_add_delayed (TIMEOUT,
                                                 &endbadly,
                                                 NULL);
-  privkey = GNUNET_CRYPTO_ecdsa_key_create ();
-  GNUNET_assert (privkey != NULL);
-  GNUNET_CRYPTO_ecdsa_key_get_public (privkey,
+  GNUNET_CRYPTO_ecdsa_key_create (&privkey);
+  GNUNET_CRYPTO_ecdsa_key_get_public (&privkey,
                                       &pubkey);
 
   nsh = GNUNET_NAMESTORE_connect (cfg);
   GNUNET_break (NULL != nsh);
 
-  nsqe = GNUNET_NAMESTORE_set_nick (nsh,
-                                    privkey,
-                                    TEST_NICK,
-                                    &nick_cont,
-                                    (void *) name);
+  memset (&rd, 0, sizeof(rd));
+  rd.data = TEST_NICK;
+  rd.data_size = strlen (TEST_NICK) + 1;
+  rd.record_type = GNUNET_GNSRECORD_TYPE_NICK;
+  rd.expiration_time = GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us;
+  rd.flags |= GNUNET_GNSRECORD_RF_PRIVATE;
+  nsqe = GNUNET_NAMESTORE_records_store (nsh,
+                                         &privkey,
+                                         GNUNET_GNS_EMPTY_LABEL_AT,
+                                         1,
+                                         &rd,
+                                         &nick_cont,
+                                         (void *) name);
+
   if (NULL == nsqe)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
