@@ -272,7 +272,7 @@ cleanup_handle (void *cls)
   if (NULL != handle->emsg)
     GNUNET_free (handle->emsg);
   if (NULL != handle->address)
-    GNUNET_free ((char *) handle->address);
+    GNUNET_free_nz ((char *) handle->address);
   if (NULL != handle->expiration_str)
     GNUNET_free (handle->expiration_str);
   if (NULL != handle->pubkey)
@@ -326,6 +326,7 @@ do_error (void *cls)
     handle->response_code = MHD_HTTP_OK;
   response = json_dumps (json_error, 0);
   resp = GNUNET_REST_create_response (response);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, handle->response_code);
   json_decref (json_error);
   GNUNET_free (response);
@@ -356,8 +357,9 @@ peerinfo_list_finished (void *cls)
   result_str = json_dumps (handle->response, 0);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Result %s\n", result_str);
   resp = GNUNET_REST_create_response (result_str);
+  MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
-  GNUNET_free_non_null (result_str);
+  GNUNET_free (result_str);
   GNUNET_SCHEDULER_add_now (&cleanup_handle, handle);
 }
 
@@ -450,7 +452,7 @@ dump_pc (struct PrintContext *pc)
   json_decref (temp_array);
   json_decref (response_entry);
 
-  GNUNET_free_non_null (pc->address_list);
+  GNUNET_free (pc->address_list);
   GNUNET_CONTAINER_DLL_remove (pc_head,
                                pc_tail,
                                pc);
@@ -811,7 +813,7 @@ libgnunet_plugin_rest_peerinfo_done (void *cls)
 
   plugin->cfg = NULL;
 
-  GNUNET_free_non_null (allow_methods);
+  GNUNET_free (allow_methods);
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Peerinfo REST plugin is finished\n");
