@@ -294,7 +294,7 @@ qconv_rsa_public_key (void *cls,
                       unsigned int scratch_length)
 {
   const struct GNUNET_CRYPTO_RsaPublicKey *rsa = data;
-  char *buf;
+  void *buf;
   size_t buf_size;
 
   GNUNET_break (NULL == cls);
@@ -354,7 +354,7 @@ qconv_rsa_signature (void *cls,
                      unsigned int scratch_length)
 {
   const struct GNUNET_CRYPTO_RsaSignature *sig = data;
-  char *buf;
+  void *buf;
   size_t buf_size;
 
   GNUNET_break (NULL == cls);
@@ -387,6 +387,68 @@ GNUNET_PQ_query_param_rsa_signature (const struct GNUNET_CRYPTO_RsaSignature *x)
 }
 
 
+/**
+ * Function called to convert input argument into SQL parameters.
+ *
+ * @param cls closure
+ * @param data pointer to input argument
+ * @param data_len number of bytes in @a data (if applicable)
+ * @param[out] param_values SQL data to set
+ * @param[out] param_lengths SQL length data to set
+ * @param[out] param_formats SQL format data to set
+ * @param param_length number of entries available in the @a param_values, @a param_lengths and @a param_formats arrays
+ * @param[out] scratch buffer for dynamic allocations (to be done via #GNUNET_malloc()
+ * @param scratch_length number of entries left in @a scratch
+ * @return -1 on error, number of offsets used in @a scratch otherwise
+ */
+static int
+qconv_rel_time (void *cls,
+                const void *data,
+                size_t data_len,
+                void *param_values[],
+                int param_lengths[],
+                int param_formats[],
+                unsigned int param_length,
+                void *scratch[],
+                unsigned int scratch_length)
+{
+  const struct GNUNET_TIME_Relative *u = data;
+  struct GNUNET_TIME_Relative rel;
+  uint64_t *u_nbo;
+
+  GNUNET_break (NULL == cls);
+  if (1 != param_length)
+    return -1;
+  rel = *u;
+  if (rel.rel_value_us > INT64_MAX)
+    rel.rel_value_us = INT64_MAX;
+  u_nbo = GNUNET_new (uint64_t);
+  scratch[0] = u_nbo;
+  *u_nbo = GNUNET_htonll (rel.rel_value_us);
+  param_values[0] = (void *) u_nbo;
+  param_lengths[0] = sizeof(uint64_t);
+  param_formats[0] = 1;
+  return 1;
+}
+
+
+/**
+ * Generate query parameter for a relative time value.
+ * The database must store a 64-bit integer.
+ *
+ * @param x pointer to the query parameter to pass
+ * @return array entry for the query parameters to use
+ */
+struct GNUNET_PQ_QueryParam
+GNUNET_PQ_query_param_relative_time (const struct GNUNET_TIME_Relative *x)
+{
+  struct GNUNET_PQ_QueryParam res =
+  { &qconv_rel_time, NULL, x, sizeof(*x), 1 };
+
+  return res;
+}
+
+
 /**
  * Function called to convert input argument into SQL parameters.
  *
