@@ -42,6 +42,31 @@ static int ret;
  */
 static int list;
 
+/**
+ * List attestations flag
+ */
+static int list_attestations;
+
+/**
+ * Attestation ID string
+ */
+static char *attestation_id;
+
+/**
+ * Attestation ID
+ */
+static struct GNUNET_RECLAIM_Identifier attestation;
+
+/**
+ * Attestation name
+ */
+static char *attestation_name;
+
+/**
+ * Attestation exists
+ */
+static int attestation_exists;
+
 /**
  * Relying party
  */
@@ -107,6 +132,12 @@ static struct GNUNET_RECLAIM_Operation *reclaim_op;
  */
 static struct GNUNET_RECLAIM_AttributeIterator *attr_iterator;
 
+/**
+ * Attestation iterator
+ */
+static struct GNUNET_RECLAIM_AttestationIterator *attest_iterator;
+
+
 /**
  * Ticket iterator
  */
@@ -135,7 +166,7 @@ static struct GNUNET_RECLAIM_Ticket ticket;
 /**
  * Attribute list
  */
-static struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attr_list;
+static struct GNUNET_RECLAIM_AttributeList *attr_list;
 
 /**
  * Attribute expiration interval
@@ -155,7 +186,7 @@ static struct GNUNET_SCHEDULER_Task *cleanup_task;
 /**
  * Claim to store
  */
-struct GNUNET_RECLAIM_ATTRIBUTE_Claim *claim;
+struct GNUNET_RECLAIM_Attribute *claim;
 
 /**
  * Claim to delete
@@ -165,7 +196,7 @@ static char *attr_delete;
 /**
  * Claim object to delete
  */
-static struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr_to_delete;
+static struct GNUNET_RECLAIM_Attribute *attr_to_delete;
 
 static void
 do_cleanup (void *cls)
@@ -177,6 +208,8 @@ do_cleanup (void *cls)
     GNUNET_RECLAIM_cancel (reclaim_op);
   if (NULL != attr_iterator)
     GNUNET_RECLAIM_get_attributes_stop (attr_iterator);
+  if (NULL != attest_iterator)
+    GNUNET_RECLAIM_get_attestations_stop (attest_iterator);
   if (NULL != ticket_iterator)
     GNUNET_RECLAIM_ticket_iteration_stop (ticket_iterator);
   if (NULL != reclaim_handle)
@@ -212,7 +245,7 @@ ticket_issue_cb (void *cls, const struct GNUNET_RECLAIM_Ticket *ticket)
 
 
 static void
-store_attr_cont (void *cls, int32_t success, const char *emsg)
+store_cont (void *cls, int32_t success, const char *emsg)
 {
   reclaim_op = NULL;
   if (GNUNET_SYSERR == success)
@@ -226,9 +259,8 @@ store_attr_cont (void *cls, int32_t success, const char *emsg)
 static void
 process_attrs (void *cls,
                const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
-               const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
-               const struct GNUNET_RECLAIM_ATTESTATION_Claim *attest, 
-               const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *reference)
+               const struct GNUNET_RECLAIM_Attribute *attr,
+               const struct GNUNET_RECLAIM_Attestation *attest)
 {
   char *value_str;
   char *id;
@@ -245,18 +277,43 @@ process_attrs (void *cls,
     ret = 1;
     return;
   }
-  value_str = GNUNET_RECLAIM_ATTRIBUTE_value_to_string (attr->type,
-                                                        attr->data,
-                                                        attr->data_size);
-  attr_type = GNUNET_RECLAIM_ATTRIBUTE_number_to_typename (attr->type);
-  id = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(uint64_t));
+  attr_type = GNUNET_RECLAIM_attribute_number_to_typename (attr->type);
+  id = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(attr->id));
+  value_str = NULL;
+  if (NULL == attest)
+  {
+    value_str = GNUNET_RECLAIM_attribute_value_to_string (attr->type,
+                                                          attr->data,
+                                                          attr->data_size);
+  }
+  else
+  {
+    struct GNUNET_RECLAIM_AttributeListEntry *ale;
+    struct GNUNET_RECLAIM_AttributeList *al
+      = GNUNET_RECLAIM_attestation_get_attributes (attest);
+
+    for (ale = al->list_head; NULL != ale; ale = ale->next)
+    {
+      if (0 != strncmp (attr->data, ale->attribute->name, attr->data_size))
+        continue;
+      value_str
+        = GNUNET_RECLAIM_attribute_value_to_string (ale->attribute->type,
+                                                    ale->attribute->
+                                                    data,
+                                                    ale->attribute->
+                                                    data_size);
+      break;
+    }
+  }
   fprintf (stdout,
-           "Name: %s; Value: %s (%s); Version %u; ID: %s\n",
+           "Name: %s; Value: %s (%s); Flag %u; ID: %s %s\n",
            attr->name,
-           value_str,
+           (NULL != value_str) ? value_str : "???",
            attr_type,
            attr->flag,
-           id);
+           id,
+           (NULL == attest) ? "" : "(ATTESTED)");
+  GNUNET_free (value_str);
   GNUNET_free (id);
 }
 
@@ -289,7 +346,7 @@ ticket_iter (void *cls, const struct GNUNET_RECLAIM_Ticket *ticket)
     GNUNET_STRINGS_data_to_string_alloc (&ticket->audience,
                                          sizeof(struct
                                                 GNUNET_CRYPTO_EcdsaPublicKey));
-  ref = GNUNET_STRINGS_data_to_string_alloc (&ticket->rnd, sizeof(uint64_t));
+  ref = GNUNET_STRINGS_data_to_string_alloc (&ticket->rnd, sizeof(ticket->rnd));
   tkt =
     GNUNET_STRINGS_data_to_string_alloc (ticket,
                                          sizeof(struct GNUNET_RECLAIM_Ticket));
@@ -305,7 +362,9 @@ static void
 iter_error (void *cls)
 {
   attr_iterator = NULL;
-  fprintf (stderr, "Failed to iterate over attributes\n");
+  attest_iterator = NULL;
+  fprintf (stderr, "Failed\n");
+
   cleanup_task = GNUNET_SCHEDULER_add_now (&do_cleanup, NULL);
 }
 
@@ -412,10 +471,10 @@ iter_finished (void *cls)
     if (NULL == type_str)
       type = GNUNET_RECLAIM_ATTRIBUTE_TYPE_STRING;
     else
-      type = GNUNET_RECLAIM_ATTRIBUTE_typename_to_number (type_str);
+      type = GNUNET_RECLAIM_attribute_typename_to_number (type_str);
 
     GNUNET_assert (GNUNET_SYSERR !=
-                   GNUNET_RECLAIM_ATTRIBUTE_string_to_value (type,
+                   GNUNET_RECLAIM_attribute_string_to_value (type,
                                                              attr_value,
                                                              (void **) &data,
                                                              &data_size));
@@ -428,13 +487,17 @@ iter_finished (void *cls)
     else
     {
       claim =
-        GNUNET_RECLAIM_ATTRIBUTE_claim_new (attr_name, type, data, data_size);
+        GNUNET_RECLAIM_attribute_new (attr_name, NULL, type, data, data_size);
+    }
+    if (NULL != attestation_id)
+    {
+      claim->attestation = attestation;
     }
     reclaim_op = GNUNET_RECLAIM_attribute_store (reclaim_handle,
                                                  pkey,
                                                  claim,
                                                  &exp_interval,
-                                                 &store_attr_cont,
+                                                 &store_cont,
                                                  NULL);
     GNUNET_free (data);
     GNUNET_free (claim);
@@ -447,11 +510,9 @@ iter_finished (void *cls)
 static void
 iter_cb (void *cls,
          const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
-         const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
-         const struct GNUNET_RECLAIM_ATTESTATION_Claim *attest,
-         const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *reference)
+         const struct GNUNET_RECLAIM_Attribute *attr)
 {
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
   char *attrs_tmp;
   char *attr_str;
   char *label;
@@ -462,10 +523,11 @@ iter_cb (void *cls,
   {
     if (0 == strcasecmp (attr_name, attr->name))
     {
-      claim = GNUNET_RECLAIM_ATTRIBUTE_claim_new (attr->name,
-                                                  attr->type,
-                                                  attr->data,
-                                                  attr->data_size);
+      claim = GNUNET_RECLAIM_attribute_new (attr->name,
+                                            &attr->attestation,
+                                            attr->type,
+                                            attr->data,
+                                            attr->data_size);
     }
   }
   else if (issue_attrs)
@@ -479,13 +541,14 @@ iter_cb (void *cls,
         attr_str = strtok (NULL, ",");
         continue;
       }
-      le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-      le->claim = GNUNET_RECLAIM_ATTRIBUTE_claim_new (attr->name,
-                                                      attr->type,
-                                                      attr->data,
-                                                      attr->data_size);
-      le->claim->flag = attr->flag;
-      le->claim->id = attr->id;
+      le = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+      le->attribute = GNUNET_RECLAIM_attribute_new (attr->name,
+                                                    &attr->attestation,
+                                                    attr->type,
+                                                    attr->data,
+                                                    attr->data_size);
+      le->attribute->flag = attr->flag;
+      le->attribute->id = attr->id;
       GNUNET_CONTAINER_DLL_insert (attr_list->list_head,
                                    attr_list->list_tail,
                                    le);
@@ -495,37 +558,149 @@ iter_cb (void *cls,
   }
   else if (attr_delete && (NULL == attr_to_delete))
   {
-    label = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(uint64_t));
+    label = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(attr->id));
     if (0 == strcasecmp (attr_delete, label))
     {
-      attr_to_delete = GNUNET_RECLAIM_ATTRIBUTE_claim_new (attr->name,
-                                                           attr->type,
-                                                           attr->data,
-                                                           attr->data_size);
+      attr_to_delete = GNUNET_RECLAIM_attribute_new (attr->name,
+                                                     &attr->attestation,
+                                                     attr->type,
+                                                     attr->data,
+                                                     attr->data_size);
       attr_to_delete->id = attr->id;
     }
     GNUNET_free (label);
   }
   else if (list)
   {
-    attr_str = GNUNET_RECLAIM_ATTRIBUTE_value_to_string (attr->type,
+    attr_str = GNUNET_RECLAIM_attribute_value_to_string (attr->type,
                                                          attr->data,
                                                          attr->data_size);
-    attr_type = GNUNET_RECLAIM_ATTRIBUTE_number_to_typename (attr->type);
-    id = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(uint64_t));
-    fprintf (stdout,
-             "Name: %s; Value: %s (%s); Version %u; ID: %s\n",
-             attr->name,
-             attr_str,
-             attr_type,
-             attr->flag,
-             id);
+    attr_type = GNUNET_RECLAIM_attribute_number_to_typename (attr->type);
+    id = GNUNET_STRINGS_data_to_string_alloc (&attr->id, sizeof(attr->id));
+    if (GNUNET_YES == GNUNET_RECLAIM_id_is_zero (&attr->attestation))
+    {
+      fprintf (stdout,
+               "%s: ``%s'' (%s); ID: %s\n",
+               attr->name,
+               attr_str,
+               attr_type,
+               id);
+    }
+    else
+    {
+      char *attest_id =
+        GNUNET_STRINGS_data_to_string_alloc (&attr->attestation,
+                                             sizeof(attr->attestation));
+      fprintf (stdout,
+               "%s: <``%s'' in attestation %s> (%s); ID: %s\n",
+               attr->name,
+               attr_str,
+               attest_id,
+               attr_type,
+               id);
+      GNUNET_free (attest_id);
+
+    }
     GNUNET_free (id);
   }
   GNUNET_RECLAIM_get_attributes_next (attr_iterator);
 }
 
 
+static void
+attest_iter_finished (void *cls)
+{
+  attest_iterator = NULL;
+
+  // Add new attestation
+  if ((NULL != attestation_name) &&
+      (NULL != attr_value))
+  {
+    struct GNUNET_RECLAIM_Attestation *attestation =
+      GNUNET_RECLAIM_attestation_new (attestation_name,
+                                      GNUNET_RECLAIM_ATTESTATION_TYPE_JWT, // FIXME hardcoded
+                                      attr_value,
+                                      strlen (attr_value));
+    reclaim_op = GNUNET_RECLAIM_attestation_store (reclaim_handle,
+                                                   pkey,
+                                                   attestation,
+                                                   &exp_interval,
+                                                   store_cont,
+                                                   NULL);
+    return;
+
+  }
+  if (list_attestations)
+  {
+    cleanup_task = GNUNET_SCHEDULER_add_now (&do_cleanup, NULL);
+    return;
+  }
+  attr_iterator = GNUNET_RECLAIM_get_attributes_start (reclaim_handle,
+                                                       pkey,
+                                                       &iter_error,
+                                                       NULL,
+                                                       &iter_cb,
+                                                       NULL,
+                                                       &iter_finished,
+                                                       NULL);
+
+}
+
+
+static void
+attest_iter_cb (void *cls,
+                const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
+                const struct GNUNET_RECLAIM_Attestation *attest)
+{
+  char *attest_str;
+  char *attr_str;
+  char *id;
+  const char *attest_type;
+  struct GNUNET_RECLAIM_AttributeListEntry *ale;
+
+  if (GNUNET_YES == GNUNET_RECLAIM_id_is_equal (&attestation,
+                                                &attest->id))
+    attestation_exists = GNUNET_YES;
+  if (list_attestations)
+  {
+    attest_str = GNUNET_RECLAIM_attestation_value_to_string (attest->type,
+                                                             attest->data,
+                                                             attest->data_size);
+    attest_type = GNUNET_RECLAIM_attestation_number_to_typename (attest->type);
+    id = GNUNET_STRINGS_data_to_string_alloc (&attest->id, sizeof(attest->id));
+    fprintf (stdout,
+             "%s: ``%s'' (%s); ID: %s\n",
+             attest->name,
+             attest_str,
+             attest_type,
+             id);
+    struct GNUNET_RECLAIM_AttributeList *attrs =
+      GNUNET_RECLAIM_attestation_get_attributes (attest);
+    if (NULL != attrs)
+    {
+      fprintf (stdout,
+               "\t Attributes:\n");
+      for (ale = attrs->list_head; NULL != ale; ale = ale->next)
+      {
+        attr_str = GNUNET_RECLAIM_attribute_value_to_string (
+          ale->attribute->type,
+          ale->attribute->
+          data,
+          ale->attribute->
+          data_size);
+
+        fprintf (stdout,
+                 "\t %s: %s\n", ale->attribute->name, attr_str);
+        GNUNET_free (attr_str);
+      }
+      GNUNET_RECLAIM_attribute_list_destroy (attrs);
+    }
+    GNUNET_free (id);
+  }
+  GNUNET_RECLAIM_get_attestations_next (attest_iterator);
+}
+
+
 static void
 start_process ()
 {
@@ -535,7 +710,12 @@ start_process ()
     cleanup_task = GNUNET_SCHEDULER_add_now (&do_cleanup, NULL);
     return;
   }
-
+  attestation = GNUNET_RECLAIM_ID_ZERO;
+  if (NULL != attestation_id)
+    GNUNET_STRINGS_string_to_data (attestation_id,
+                                   strlen (attestation_id),
+                                   &attestation, sizeof(attestation));
+  attestation_exists = GNUNET_NO;
   if (list_tickets)
   {
     ticket_iterator = GNUNET_RECLAIM_ticket_iteration_start (reclaim_handle,
@@ -568,16 +748,18 @@ start_process ()
                                    &ticket,
                                    sizeof(struct GNUNET_RECLAIM_Ticket));
 
-  attr_list = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList);
+  attr_list = GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
   claim = NULL;
-  attr_iterator = GNUNET_RECLAIM_get_attributes_start (reclaim_handle,
-                                                       pkey,
-                                                       &iter_error,
-                                                       NULL,
-                                                       &iter_cb,
-                                                       NULL,
-                                                       &iter_finished,
-                                                       NULL);
+  attest_iterator = GNUNET_RECLAIM_get_attestations_start (reclaim_handle,
+                                                           pkey,
+                                                           &iter_error,
+                                                           NULL,
+                                                           &attest_iter_cb,
+                                                           NULL,
+                                                           &
+                                                           attest_iter_finished,
+                                                           NULL);
+
 }
 
 
@@ -673,13 +855,27 @@ main (int argc, char *const argv[])
                                "dump",
                                gettext_noop ("List attributes for EGO"),
                                &list),
-    GNUNET_GETOPT_option_string (
-      'i',
-      "issue",
-      "A1,A2,...",
-      gettext_noop (
-        "Issue a ticket for a set of attributes separated by comma"),
-      &issue_attrs),
+    GNUNET_GETOPT_option_flag ('A',
+                               "attestations",
+                               gettext_noop ("List attestations for EGO"),
+                               &list_attestations),
+    GNUNET_GETOPT_option_string ('I',
+                                 "Attestation ID",
+                                 "ATTESTATION_ID",
+                                 gettext_noop (
+                                   "Attestation to use for attribute"),
+                                 &attestation_id),
+    GNUNET_GETOPT_option_string ('N',
+                                 "attestation-name",
+                                 "NAME",
+                                 gettext_noop ("Attestation name"),
+                                 &attestation_name),
+    GNUNET_GETOPT_option_string ('i',
+                                 "issue",
+                                 "A1,A2,...",
+                                 gettext_noop (
+                                   "Issue a ticket for a set of attributes separated by comma"),
+                                 &issue_attrs),
     GNUNET_GETOPT_option_string ('C',
                                  "consume",
                                  "TICKET",
