@@ -59,7 +59,7 @@ struct TicketReference
   /**
    * Attributes
    */
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs;
+  struct GNUNET_RECLAIM_AttributeList *attrs;
 
   /**
    * Tickets
@@ -111,7 +111,12 @@ struct RECLAIM_TICKETS_ConsumeHandle
   /**
    * Attributes
    */
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs;
+  struct GNUNET_RECLAIM_AttributeList *attrs;
+
+  /**
+   * Attestations
+   */
+  struct GNUNET_RECLAIM_AttestationList *attests;
 
   /**
    * Lookup time
@@ -165,7 +170,7 @@ struct TicketIssueHandle
   /**
    * Attributes to issue
    */
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs;
+  struct GNUNET_RECLAIM_AttributeList *attrs;
 
   /**
    * Issuer Key
@@ -236,12 +241,12 @@ struct RevokedAttributeEntry
   /**
    * Old ID of the attribute
    */
-  uint64_t old_id;
+  struct GNUNET_RECLAIM_Identifier old_id;
 
   /**
    * New ID of the attribute
    */
-  uint64_t new_id;
+  struct GNUNET_RECLAIM_Identifier new_id;
 };
 
 
@@ -431,11 +436,11 @@ process_tickets (void *cls)
   }
   for (int i = 0; i < le->rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF != rd[i].record_type)
+    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF != rd[i].record_type)
       continue;
     for (ae = rvk->attrs_head; NULL != ae; ae = ae->next)
     {
-      if (0 != memcmp (rd[i].data, &ae->old_id, sizeof(uint64_t)))
+      if (0 != memcmp (rd[i].data, &ae->old_id, sizeof(ae->old_id)))
         continue;
       rd[i].data = &ae->new_id;
     }
@@ -493,11 +498,11 @@ rvk_ticket_update (void *cls,
   /** Let everything point to the old record **/
   for (int i = 0; i < rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF != rd[i].record_type)
+    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF != rd[i].record_type)
       continue;
     for (ae = rvk->attrs_head; NULL != ae; ae = ae->next)
     {
-      if (0 != memcmp (rd[i].data, &ae->old_id, sizeof(uint64_t)))
+      if (0 != memcmp (rd[i].data, &ae->old_id, sizeof(ae->old_id)))
         continue;
       has_changed = GNUNET_YES;
       break;
@@ -532,9 +537,6 @@ rvk_ns_iter_err (void *cls)
   struct RECLAIM_TICKETS_RevokeHandle *rvk = cls;
 
   rvk->ns_it = NULL;
-  GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-              "Namestore error on revocation (id=%" PRIu64 "\n",
-              rvk->move_attr->old_id);
   rvk->cb (rvk->cb_cls, GNUNET_SYSERR);
   cleanup_rvk (rvk);
 }
@@ -551,9 +553,6 @@ rvk_ns_err (void *cls)
   struct RECLAIM_TICKETS_RevokeHandle *rvk = cls;
 
   rvk->ns_qe = NULL;
-  GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-              "Namestore error on revocation (id=%" PRIu64 "\n",
-              rvk->move_attr->old_id);
   rvk->cb (rvk->cb_cls, GNUNET_SYSERR);
   cleanup_rvk (rvk);
 }
@@ -636,7 +635,7 @@ move_attr_finished (void *cls, int32_t success, const char *emsg)
     return;
   }
   label = GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->old_id,
-                                               sizeof(uint64_t));
+                                               sizeof(rvk->move_attr->old_id));
   GNUNET_assert (NULL != label);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Removing attribute %s\n", label);
   rvk->ns_qe = GNUNET_NAMESTORE_records_store (nsh,
@@ -685,81 +684,69 @@ rvk_move_attr_cb (void *cls,
     GNUNET_SCHEDULER_add_now (&move_attrs_cont, rvk);
     return;
   }
-  rvk->move_attr->new_id =GNUNET_CRYPTO_random_u64 (GNUNET_CRYPTO_QUALITY_STRONG, UINT64_MAX);
-  new_label=NULL;
-  attr_data=NULL;
-  //new_rd = *rd;
+  GNUNET_RECLAIM_id_generate (&rvk->move_attr->new_id);
+  new_label = NULL;
+  attr_data = NULL;
+  // new_rd = *rd;
   for (int i = 0; i < rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR == rd[i].record_type)
+    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE == rd[i].record_type)
     {
       /** find a new place for this attribute **/
-      struct GNUNET_RECLAIM_ATTRIBUTE_Claim *claim;
-      claim = GNUNET_RECLAIM_ATTRIBUTE_deserialize (rd[i].data, rd[i].data_size);
+      struct GNUNET_RECLAIM_Attribute *claim;
+      claim = GNUNET_RECLAIM_attribute_deserialize (rd[i].data,
+                                                    rd[i].data_size);
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                  "Attribute to update: Name=%s, ID=%" PRIu64 "\n",
-                  claim->name,
-                  claim->id);
+                  "Attribute to update: Name=%s\n",
+                  claim->name);
       claim->id = rvk->move_attr->new_id;
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTRIBUTE_serialize_get_size (claim);
+      new_rd[i].data_size = GNUNET_RECLAIM_attribute_serialize_get_size (claim);
       attr_data = GNUNET_malloc (rd[i].data_size);
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTRIBUTE_serialize (claim, attr_data);
+      new_rd[i].data_size = GNUNET_RECLAIM_attribute_serialize (claim,
+                                                                attr_data);
       new_rd[i].data = attr_data;
       new_rd[i].record_type = rd[i].record_type;
       new_rd[i].flags = rd[i].flags;
       new_rd[i].expiration_time = rd[i].expiration_time;
-      new_label = GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->new_id,
-                                                       sizeof(uint64_t));
+      new_label =
+        GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->new_id,
+                                             sizeof (rvk->move_attr->new_id));
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Adding attribute %s\n", new_label);
       GNUNET_free (claim);
-    } else if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTEST_ATTR == rd[i].record_type) 
+    }
+    else if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION == rd[i].record_type)
     {
-      struct GNUNET_RECLAIM_ATTESTATION_Claim *attest;
-      attest=GNUNET_RECLAIM_ATTESTATION_deserialize(rd[i].data, rd[i].data_size);
+      struct GNUNET_RECLAIM_Attestation *attest;
+      attest = GNUNET_RECLAIM_attestation_deserialize (rd[i].data,
+                                                       rd[i].data_size);
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                  "Attestation to update: Name=%s, ID=%" PRIu64 "\n",
-                  attest->name,
-                  attest->id);
+                  "Attestation to update: Name=%s\n",
+                  attest->name);
       attest->id = rvk->move_attr->new_id;
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTESTATION_serialize_get_size (attest);
+      new_rd[i].data_size =
+        GNUNET_RECLAIM_attestation_serialize_get_size (attest);
       attr_data = GNUNET_malloc (rd[i].data_size);
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTESTATION_serialize (attest, attr_data);
+      new_rd[i].data_size = GNUNET_RECLAIM_attestation_serialize (attest,
+                                                                  attr_data);
       new_rd[i].data = attr_data;
       new_rd[i].record_type = rd[i].record_type;
       new_rd[i].flags = rd[i].flags;
       new_rd[i].expiration_time = rd[i].expiration_time;
-      new_label = GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->new_id, sizeof(uint64_t));
-      GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Adding attestation %s\n", new_label);
+      new_label =
+        GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->new_id,
+                                             sizeof (rvk->move_attr->new_id));
+      GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Adding attestation %s\n",
+                  new_label);
       GNUNET_free (attest);
-    } else if (GNUNET_GNSRECORD_TYPE_RECLAIM_REFERENCE == rd[i].record_type)
-    {
-      struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *reference;
-      reference=GNUNET_RECLAIM_ATTESTATION_REF_deserialize(rd[i].data, rd[i].data_size);
-      GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                  "Reference to update: Name=%s, ID=%" PRIu64 "\n",
-                  reference->name,
-                  reference->id);
-      reference->id = rvk->move_attr->new_id;
-      reference->id_attest = rvk->move_attr->new_id;
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTESTATION_REF_serialize_get_size (reference);
-      attr_data = GNUNET_malloc (rd[i].data_size);
-      new_rd[i].data_size = GNUNET_RECLAIM_ATTESTATION_REF_serialize (reference, attr_data);
-      new_rd[i].data = attr_data;
-      new_label = GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->new_id, sizeof(uint64_t));
-      new_rd[i].record_type = rd[i].record_type;
-      new_rd[i].flags = rd[i].flags;
-      new_rd[i].expiration_time = rd[i].expiration_time;
-      GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Adding reference %s\n", new_label);
-      GNUNET_free (reference);
     }
   }
   rvk->ns_qe = GNUNET_NAMESTORE_records_store (nsh,
-                                           &rvk->identity,
-                                           new_label,
-                                           rd_count,
-                                           new_rd,
-                                           &move_attr_finished,
-                                           rvk);
+                                               &rvk->identity,
+                                               new_label,
+                                               rd_count,
+                                               new_rd,
+                                               &move_attr_finished,
+                                               rvk);
   GNUNET_free (new_label);
   GNUNET_free (attr_data);
 }
@@ -793,7 +780,7 @@ move_attrs (struct RECLAIM_TICKETS_RevokeHandle *rvk)
     return;
   }
   label = GNUNET_STRINGS_data_to_string_alloc (&rvk->move_attr->old_id,
-                                               sizeof(uint64_t));
+                                               sizeof (rvk->move_attr->old_id));
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Moving claim %s\n", label);
 
   rvk->ns_qe = GNUNET_NAMESTORE_records_lookup (nsh,
@@ -873,10 +860,10 @@ revoke_attrs_cb (void *cls,
    */
   for (int i = 0; i < rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF != rd[i].record_type)
+    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF != rd[i].record_type)
       continue;
     le = GNUNET_new (struct RevokedAttributeEntry);
-    le->old_id = *((uint64_t *) rd[i].data);
+    le->old_id = *((struct GNUNET_RECLAIM_Identifier *) rd[i].data);
     GNUNET_CONTAINER_DLL_insert (rvk->attrs_head, rvk->attrs_tail, le);
     rvk->ticket_attrs++;
   }
@@ -934,7 +921,8 @@ RECLAIM_TICKETS_revoke (const struct GNUNET_RECLAIM_Ticket *ticket,
   rvk->ticket = *ticket;
   GNUNET_CRYPTO_ecdsa_key_get_public (&rvk->identity, &rvk->ticket.identity);
   /** Get shared attributes **/
-  label = GNUNET_STRINGS_data_to_string_alloc (&ticket->rnd, sizeof(uint64_t));
+  label = GNUNET_STRINGS_data_to_string_alloc (&ticket->rnd,
+                                               sizeof(ticket->rnd));
   GNUNET_assert (NULL != label);
   rvk->ns_qe = GNUNET_NAMESTORE_records_lookup (nsh,
                                                 identity,
@@ -983,7 +971,7 @@ cleanup_cth (struct RECLAIM_TICKETS_ConsumeHandle *cth)
   {
     if (NULL != lu->lookup_request)
       GNUNET_GNS_lookup_cancel (lu->lookup_request);
-    GNUNET_free_non_null (lu->label);
+    GNUNET_free (lu->label);
     GNUNET_CONTAINER_DLL_remove (cth->parallel_lookups_head,
                                  cth->parallel_lookups_tail,
                                  lu);
@@ -991,7 +979,9 @@ cleanup_cth (struct RECLAIM_TICKETS_ConsumeHandle *cth)
   }
 
   if (NULL != cth->attrs)
-    GNUNET_RECLAIM_ATTRIBUTE_list_destroy (cth->attrs);
+    GNUNET_RECLAIM_attribute_list_destroy (cth->attrs);
+  if (NULL != cth->attests)
+    GNUNET_RECLAIM_attestation_list_destroy (cth->attests);
   GNUNET_free (cth);
 }
 
@@ -1010,7 +1000,7 @@ process_parallel_lookup_result (void *cls,
 {
   struct ParallelLookup *parallel_lookup = cls;
   struct RECLAIM_TICKETS_ConsumeHandle *cth = parallel_lookup->handle;
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *attr_le;
+  struct GNUNET_RECLAIM_AttributeListEntry *attr_le;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Parallel lookup finished (count=%u)\n",
@@ -1036,67 +1026,40 @@ process_parallel_lookup_result (void *cls,
   // REMARK: It is possible now to find rd_count > 1
   for (int i = 0; i < rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR == rd[i].record_type)
+    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE == rd[i].record_type)
     {
-      attr_le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-      attr_le->claim =
-        GNUNET_RECLAIM_ATTRIBUTE_deserialize (rd[i].data, rd[i].data_size);
+      attr_le = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+      attr_le->attribute =
+        GNUNET_RECLAIM_attribute_deserialize (rd[i].data, rd[i].data_size);
       GNUNET_CONTAINER_DLL_insert (cth->attrs->list_head,
                                    cth->attrs->list_tail,
                                    attr_le);
-      attr_le->reference = NULL;
-      attr_le->attest = NULL;
     }
-    else if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTEST_ATTR == rd[i].record_type)
+    else if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION == rd[i].record_type)
     {
-      /**Ignore all plain attestations
-      *attr_le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-      *attr_le->attest =
-      *  GNUNET_RECLAIM_ATTESTATION_deserialize (rd[i].data, rd[i].data_size);
-      *GNUNET_CONTAINER_DLL_insert (cth->attrs->list_head,
-      *                             cth->attrs->list_tail,
-      *                             attr_le);
-      */
+      struct GNUNET_RECLAIM_AttestationListEntry *ale;
+      ale = GNUNET_new (struct GNUNET_RECLAIM_AttestationListEntry);
+      ale->attestation =
+        GNUNET_RECLAIM_attestation_deserialize (rd[i].data,
+                                                rd[i].data_size);
+      GNUNET_CONTAINER_DLL_insert (cth->attests->list_head,
+                                   cth->attests->list_tail,
+                                   ale);
+    }
+    else
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                  "Parallel Lookup of Reference without Attestation");
       continue;
     }
-    else if (GNUNET_GNSRECORD_TYPE_RECLAIM_REFERENCE == rd[i].record_type)
-    {
-      struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *attr_le2;
-      attr_le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-      attr_le2 = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-      if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTEST_ATTR == rd[0].record_type)
-      {
-        attr_le->attest = GNUNET_RECLAIM_ATTESTATION_deserialize (rd[0].data,
-                                                                  rd[0].
-                                                                  data_size);
-        attr_le2->reference =
-          GNUNET_RECLAIM_ATTESTATION_REF_deserialize (rd[i].data,
-                                                      rd[i].data_size);
-        attr_le->claim = NULL;
-        attr_le->reference = NULL;
-        attr_le2->claim = NULL;
-        attr_le2->attest = NULL;
-        GNUNET_CONTAINER_DLL_insert (cth->attrs->list_head,
-                                     cth->attrs->list_tail,
-                                     attr_le);
-        GNUNET_CONTAINER_DLL_insert (cth->attrs->list_head,
-                                     cth->attrs->list_tail,
-                                     attr_le2);
-      }
-      else
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                    "Parallel Lookup of Reference without Attestation");
-        continue;
-      }
 
 
-    }
   }
   if (NULL != cth->parallel_lookups_head)
     return; // Wait for more
   /* Else we are done */
-  cth->cb (cth->cb_cls, &cth->ticket.identity, cth->attrs, GNUNET_OK, NULL);
+  cth->cb (cth->cb_cls, &cth->ticket.identity,
+           cth->attrs, cth->attests, GNUNET_OK, NULL);
   cleanup_cth (cth);
 }
 
@@ -1125,7 +1088,7 @@ abort_parallel_lookups (void *cls)
     GNUNET_free (lu);
     lu = tmp;
   }
-  cth->cb (cth->cb_cls, NULL, NULL, GNUNET_SYSERR, "Aborted");
+  cth->cb (cth->cb_cls, NULL, NULL, NULL, GNUNET_SYSERR, "Aborted");
 }
 
 
@@ -1162,10 +1125,11 @@ lookup_authz_cb (void *cls,
 
   for (int i = 0; i < rd_count; i++)
   {
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF != rd[i].record_type)
+    if ((GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF != rd[i].record_type) &&
+        (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION_REF != rd[i].record_type))
       continue;
     lbl = GNUNET_STRINGS_data_to_string_alloc (rd[i].data, rd[i].data_size);
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Attribute ref found %s\n", lbl);
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Ticket reference found %s\n", lbl);
     parallel_lookup = GNUNET_new (struct ParallelLookup);
     parallel_lookup->handle = cth;
     parallel_lookup->label = lbl;
@@ -1197,7 +1161,8 @@ lookup_authz_cb (void *cls,
   /**
    * No references found, return empty attribute list
    */
-  cth->cb (cth->cb_cls, &cth->ticket.identity, cth->attrs, GNUNET_OK, NULL);
+  cth->cb (cth->cb_cls, &cth->ticket.identity,
+           cth->attrs, cth->attests, GNUNET_OK, NULL);
   cleanup_cth (cth);
 }
 
@@ -1226,12 +1191,14 @@ RECLAIM_TICKETS_consume (const struct GNUNET_CRYPTO_EcdsaPrivateKey *id,
 
   cth->identity = *id;
   GNUNET_CRYPTO_ecdsa_key_get_public (&cth->identity, &cth->identity_pub);
-  cth->attrs = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList);
+  cth->attrs = GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
+  cth->attests = GNUNET_new (struct GNUNET_RECLAIM_AttestationList);
   cth->ticket = *ticket;
   cth->cb = cb;
   cth->cb_cls = cb_cls;
   label =
-    GNUNET_STRINGS_data_to_string_alloc (&cth->ticket.rnd, sizeof(uint64_t));
+    GNUNET_STRINGS_data_to_string_alloc (&cth->ticket.rnd,
+                                         sizeof(cth->ticket.rnd));
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Looking for AuthZ info under %s\n",
               label);
@@ -1240,7 +1207,7 @@ RECLAIM_TICKETS_consume (const struct GNUNET_CRYPTO_EcdsaPrivateKey *id,
     GNUNET_GNS_lookup (gns,
                        label,
                        &cth->ticket.identity,
-                       GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF,
+                       GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF,
                        GNUNET_GNS_LO_DEFAULT,
                        &lookup_authz_cb,
                        cth);
@@ -1316,74 +1283,50 @@ store_ticket_issue_cont (void *cls, int32_t success, const char *emsg)
 static void
 issue_ticket (struct TicketIssueHandle *ih)
 {
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
   struct GNUNET_GNSRECORD_Data *attrs_record;
   char *label;
-  size_t list_len = 1;
   int i;
-  char *attest_string;
+  int attrs_count = 0;
 
   for (le = ih->attrs->list_head; NULL != le; le = le->next)
-    list_len++;
+    attrs_count++;
 
+  //Worst case we have one attestation per attribute
   attrs_record =
-    GNUNET_malloc (list_len * sizeof(struct GNUNET_GNSRECORD_Data));
+    GNUNET_malloc (2 * attrs_count * sizeof(struct GNUNET_GNSRECORD_Data));
   i = 0;
   for (le = ih->attrs->list_head; NULL != le; le = le->next)
   {
-    if (NULL != le->claim)
-    {
-      attrs_record[i].data = &le->claim->id;
-      attrs_record[i].data_size = sizeof(le->claim->id);
-    }
-    else if (NULL != le->attest)
-    {
-      // REMARK: Since we only store IDs, the references are irrelevant
-      int j = 0;
-      GNUNET_asprintf (&attest_string,"%d",le->attest->id);
-      while (j<i)
-      {
-        if (0 == strcmp (attest_string,GNUNET_STRINGS_data_to_string_alloc (
-                           attrs_record[j].data, attrs_record[j].data_size)))
-          break;
-        j++;
-      }
-      if (j < i)
-      {
-        list_len--;
-        continue;
-      }
-      attrs_record[i].data = &le->attest->id;
-      attrs_record[i].data_size = sizeof(le->attest->id);
-    }
-    else if (NULL != le->reference)
-    {
-      list_len--;
-      continue;
-      /*
-      int j = 0;
-      GNUNET_asprintf (&attest_string,"%d",le->attest->id);
-      while (j<i)
-      {
-        if (strcmp(attest_string, GNUNET_STRINGS_data_to_string_alloc (
-              attrs_record[j].data, attrs_record[j].data_size)))
-          break;
-        j++;
-      }
-      if (j < i)
-        continue;
-      attrs_record[i].data = &le->reference->id;
-      attrs_record[i].data_size = sizeof(le->reference->id);
-      */
-    }
-    /**
-     * FIXME: Should this be the attribute expiration time or ticket
-     * refresh interval? Probably min(attrs.expiration)
-     */
+    attrs_record[i].data = &le->attribute->id;
+    attrs_record[i].data_size = sizeof(le->attribute->id);
     attrs_record[i].expiration_time = ticket_refresh_interval.rel_value_us;
-    attrs_record[i].record_type = GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF;
+    attrs_record[i].record_type = GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF;
     attrs_record[i].flags = GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION;
     i++;
+    if (GNUNET_NO == GNUNET_RECLAIM_id_is_zero (&le->attribute->attestation))
+    {
+      int j;
+      for (j = 0; j < i; j++)
+      {
+        if (attrs_record[j].record_type
+            != GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION_REF)
+          continue;
+        if (0 == memcmp (attrs_record[j].data,
+                         &le->attribute->attestation,
+                         sizeof (le->attribute->attestation)))
+          break;
+      }
+      if (j < i)
+        continue; // Skip as we have already added this attestation.
+      attrs_record[i].data = &le->attribute->attestation;
+      attrs_record[i].data_size = sizeof(le->attribute->attestation);
+      attrs_record[i].expiration_time = ticket_refresh_interval.rel_value_us;
+      attrs_record[i].record_type =
+        GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION_REF;
+      attrs_record[i].flags = GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION;
+      i++;
+    }
   }
   attrs_record[i].data = &ih->ticket;
   attrs_record[i].data_size = sizeof(struct GNUNET_RECLAIM_Ticket);
@@ -1391,14 +1334,16 @@ issue_ticket (struct TicketIssueHandle *ih)
   attrs_record[i].record_type = GNUNET_GNSRECORD_TYPE_RECLAIM_TICKET;
   attrs_record[i].flags =
     GNUNET_GNSRECORD_RF_RELATIVE_EXPIRATION | GNUNET_GNSRECORD_RF_PRIVATE;
+  i++;
 
   label =
-    GNUNET_STRINGS_data_to_string_alloc (&ih->ticket.rnd, sizeof(uint64_t));
+    GNUNET_STRINGS_data_to_string_alloc (&ih->ticket.rnd,
+                                         sizeof(ih->ticket.rnd));
   // Publish record
   ih->ns_qe = GNUNET_NAMESTORE_records_store (nsh,
                                               &ih->identity,
                                               label,
-                                              list_len,
+                                              i,
                                               attrs_record,
                                               &store_ticket_issue_cont,
                                               ih);
@@ -1454,14 +1399,20 @@ filter_tickets_cb (void *cls,
   struct GNUNET_RECLAIM_Ticket *ticket = NULL;
 
   // figure out the number of requested attributes
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
   unsigned int attr_cnt = 0;
+  unsigned int attest_cnt = 0;
 
   for (le = tih->attrs->list_head; NULL != le; le = le->next)
+  {
     attr_cnt++;
+    if (GNUNET_NO == GNUNET_RECLAIM_id_is_zero (&le->attribute->attestation))
+      attest_cnt++;
+  }
 
   // ticket search
   unsigned int found_attrs_cnt = 0;
+  unsigned int found_attests_cnt = 0;
 
   for (int i = 0; i < rd_count; i++)
   {
@@ -1481,39 +1432,20 @@ filter_tickets_cb (void *cls,
     }
 
     // cmp requested attributes with ticket attributes
-    if (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTR_REF != rd[i].record_type)
+    if ((GNUNET_GNSRECORD_TYPE_RECLAIM_ATTRIBUTE_REF != rd[i].record_type) &&
+        (GNUNET_GNSRECORD_TYPE_RECLAIM_ATTESTATION_REF != rd[i].record_type))
       continue;
     for (le = tih->attrs->list_head; NULL != le; le = le->next)
     {
-      // cmp attr_ref id with requested attr id
-      if (NULL !=le->claim)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                    " %" PRIu64 "\n  %" PRIu64 "\n",
-                    *((uint64_t *) rd[i].data),
-                    le->claim->id);
-        if (0 == memcmp (rd[i].data, &le->claim->id, sizeof(uint64_t)))
-          found_attrs_cnt++;
-      }
-      else if (NULL !=le->attest)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                    " %" PRIu64 "\n  %" PRIu64 "\n",
-                    *((uint64_t *) rd[i].data),
-                    le->attest->id);
-        if (0 == memcmp (rd[i].data, &le->attest->id, sizeof(uint64_t)))
-          found_attrs_cnt++;
-      }
-      else if (NULL != le->reference)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                    " %" PRIu64 "\n  %" PRIu64 "\n",
-                    *((uint64_t *) rd[i].data),
-                    le->reference->id);
-        if (0 == memcmp (rd[i].data, &le->reference->id, sizeof(uint64_t)))
-          found_attrs_cnt++;
-      }
-
+      if (GNUNET_YES == GNUNET_RECLAIM_id_is_equal (rd[i].data,
+                                                    &le->attribute->id))
+        found_attrs_cnt++;
+    }
+    for (le = tih->attrs->list_head; NULL != le; le = le->next)
+    {
+      if (GNUNET_YES == GNUNET_RECLAIM_id_is_equal (rd[i].data,
+                                                    &le->attribute->attestation))
+        found_attests_cnt++;
     }
   }
 
@@ -1521,7 +1453,9 @@ filter_tickets_cb (void *cls,
    * If we found a matching ticket, return that to the caller and
    * we are done.
    */
-  if ((attr_cnt == found_attrs_cnt) && (NULL != ticket))
+  if ((attr_cnt == found_attrs_cnt) &&
+      (attest_cnt == found_attests_cnt) &&
+      (NULL != ticket))
   {
     GNUNET_NAMESTORE_zone_iteration_stop (tih->ns_it);
     tih->cb (tih->cb_cls, &tih->ticket, GNUNET_OK, NULL);
@@ -1547,8 +1481,7 @@ filter_tickets_finished_cb (void *cls)
   struct TicketIssueHandle *tih = cls;
 
   GNUNET_CRYPTO_ecdsa_key_get_public (&tih->identity, &tih->ticket.identity);
-  tih->ticket.rnd =
-    GNUNET_CRYPTO_random_u64 (GNUNET_CRYPTO_QUALITY_STRONG, UINT64_MAX);
+  GNUNET_RECLAIM_id_generate (&tih->ticket.rnd);
   issue_ticket (tih);
 }
 
@@ -1566,7 +1499,7 @@ filter_tickets_finished_cb (void *cls)
  */
 void
 RECLAIM_TICKETS_issue (const struct GNUNET_CRYPTO_EcdsaPrivateKey *identity,
-                       const struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs,
+                       const struct GNUNET_RECLAIM_AttributeList *attrs,
                        const struct GNUNET_CRYPTO_EcdsaPublicKey *audience,
                        RECLAIM_TICKETS_TicketResult cb,
                        void *cb_cls)
@@ -1576,7 +1509,7 @@ RECLAIM_TICKETS_issue (const struct GNUNET_CRYPTO_EcdsaPrivateKey *identity,
   tih = GNUNET_new (struct TicketIssueHandle);
   tih->cb = cb;
   tih->cb_cls = cb_cls;
-  tih->attrs = GNUNET_RECLAIM_ATTRIBUTE_list_dup (attrs);
+  tih->attrs = GNUNET_RECLAIM_attribute_list_dup (attrs);
   tih->identity = *identity;
   tih->ticket.audience = *audience;
 
