@@ -27,7 +27,7 @@
 #include "gnunet_util_lib.h"
 #include "gnunet_json_lib.h"
 #include "gnunet_reclaim_service.h"
-#include "gnunet_reclaim_attribute_lib.h"
+#include "gnunet_reclaim_lib.h"
 
 /**
  * JSON Specification for Reclaim claims.
@@ -36,7 +36,7 @@
  * @return JSON Specification
  */
 struct GNUNET_JSON_Specification
-GNUNET_RECLAIM_JSON_spec_claim (struct GNUNET_RECLAIM_ATTRIBUTE_Claim **attr);
+GNUNET_RECLAIM_JSON_spec_claim (struct GNUNET_RECLAIM_Attribute **attr);
 
 /**
  * JSON Specification for Reclaim tickets.
@@ -50,18 +50,10 @@ GNUNET_RECLAIM_JSON_spec_ticket (struct GNUNET_RECLAIM_Ticket **ticket);
 /**
     * JSON Specification for Reclaim attestation claims.
     *
-    * @param ticket struct of GNUNET_RECLAIM_ATTESTATION_Claim to fill
+    * @param ticket struct of GNUNET_RECLAIM_Attestation to fill
     * @return JSON Specification
     */
 struct GNUNET_JSON_Specification
 GNUNET_RECLAIM_JSON_spec_claim_attest (struct
-                                       GNUNET_RECLAIM_ATTESTATION_Claim **attr);
+                                       GNUNET_RECLAIM_Attestation **attr);
 
-  /**
-   * JSON Specification for Reclaim attestation references.
-   *
-   * @param ticket struct of GNUNET_RECLAIM_ATTESTATION_REFERENCE to fill
-   * @return JSON Specification
-   */
-  struct GNUNET_JSON_Specification
-  GNUNET_RECLAIM_JSON_spec_claim_attest_ref(struct GNUNET_RECLAIM_ATTESTATION_REFERENCE **attr);
