@@ -27,7 +27,7 @@
 #include <inttypes.h>
 #include <jansson.h>
 #include "gnunet_util_lib.h"
-#include "gnunet_reclaim_attribute_lib.h"
+#include "gnunet_reclaim_lib.h"
 #include "gnunet_reclaim_service.h"
 #include "gnunet_signatures.h"
 #include "oidc_helper.h"
@@ -60,6 +60,11 @@ struct OIDC_Parameters
    * The length of the attributes list
    */
   uint32_t attr_list_len GNUNET_PACKED;
+
+  /**
+   * The length of the attestation list
+   */
+  uint32_t attest_list_len GNUNET_PACKED;
 };
 
 GNUNET_NETWORK_STRUCT_END
@@ -118,12 +123,14 @@ fix_base64 (char *str)
 char *
 OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
                    const struct GNUNET_CRYPTO_EcdsaPublicKey *sub_key,
-                   struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs,
+                   struct GNUNET_RECLAIM_AttributeList *attrs,
+                   struct GNUNET_RECLAIM_AttestationList *attests,
                    const struct GNUNET_TIME_Relative *expiration_time,
                    const char *nonce,
                    const char *secret_key)
 {
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
+  struct GNUNET_RECLAIM_AttestationListEntry *ale;
   struct GNUNET_HashCode signature;
   struct GNUNET_TIME_Absolute exp_time;
   struct GNUNET_TIME_Absolute time_now;
@@ -133,7 +140,6 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
   char *body_str;
   char *aggr_names_str;
   char *aggr_sources_str;
-  char *aggr_sources_jwt_str;
   char *source_name;
   char *result;
   char *header_base64;
@@ -146,7 +152,12 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
   json_t *aggr_names;
   json_t *aggr_sources;
   json_t *aggr_sources_jwt;
-  uint64_t attest_arr[GNUNET_RECLAIM_ATTRIBUTE_list_count_attest (attrs)];
+  int num_attestations = 0;
+  for (le = attrs->list_head; NULL != le; le = le->next)
+  {
+    if (GNUNET_NO == GNUNET_RECLAIM_id_is_zero (&le->attribute->attestation))
+      num_attestations++;
+  }
 
   // iat REQUIRED time now
   time_now = GNUNET_TIME_absolute_get ();
@@ -191,95 +202,70 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
   // nonce
   if (NULL != nonce)
     json_object_set_new (body, "nonce", json_string (nonce));
-  int i = 0;
   attest_val_str = NULL;
   aggr_names_str = NULL;
   aggr_sources_str = NULL;
-  aggr_sources_jwt_str = NULL;
   source_name = NULL;
+  int i = 0;
+  for (ale = attests->list_head; NULL != ale; ale = ale->next)
+  {
+    // New Attestation
+    GNUNET_asprintf (&source_name,
+                     "src%d",
+                     i);
+    aggr_sources_jwt = json_object ();
+    attest_val_str =
+      GNUNET_RECLAIM_attestation_value_to_string (ale->attestation->type,
+                                                  ale->attestation->data,
+                                                  ale->attestation->data_size);
+    json_object_set_new (aggr_sources_jwt, "JWT",
+                         json_string (attest_val_str) );
+    json_object_set_new (aggr_sources, source_name, aggr_sources_jwt);
+    GNUNET_free (source_name);
+    source_name = NULL;
+    i++;
+  }
+
   for (le = attrs->list_head; NULL != le; le = le->next)
   {
 
-    if (le->claim != NULL)
+    if (GNUNET_YES == GNUNET_RECLAIM_id_is_zero (&le->attribute->attestation))
     {
 
       attr_val_str =
-        GNUNET_RECLAIM_ATTRIBUTE_value_to_string (le->claim->type,
-                                                  le->claim->data,
-                                                  le->claim->data_size);
-      json_object_set_new (body, le->claim->name, json_string (attr_val_str));
+        GNUNET_RECLAIM_attribute_value_to_string (le->attribute->type,
+                                                  le->attribute->data,
+                                                  le->attribute->data_size);
+      json_object_set_new (body, le->attribute->name,
+                           json_string (attr_val_str));
       GNUNET_free (attr_val_str);
     }
-    else if (NULL != le->reference)
+    else
     {
       // Check if attest is there
       int j = 0;
-      while (j<i)
+      for (ale = attests->list_head; NULL != ale; ale = ale->next)
       {
-        if (attest_arr[j] == le->reference->id_attest)
+        if (GNUNET_YES ==
+            GNUNET_RECLAIM_id_is_equal (&ale->attestation->id,
+                                        &le->attribute->attestation))
           break;
         j++;
       }
-      if (j==i)
-      {
-        // Attest not yet existent. Append to the end of the list
-        GNUNET_CONTAINER_DLL_remove (attrs->list_head, attrs->list_tail, le);
-        GNUNET_CONTAINER_DLL_insert_tail (attrs->list_head, attrs->list_tail,
-                                          le);
-        continue;
-      }
-      else
-      {
-        // Attestation is existing, hence take the respective source str
-        GNUNET_asprintf (&source_name,
-                         "src%d",
-                         j);
-        json_object_set_new (aggr_names, le->reference->name, json_string (
-                               source_name));
-      }
-
-    }
-    else if (NULL != le->attest)
-    {
-      // We assume that at max 99 different attestations
-      int j = 0;
-      while (j<i)
-      {
-        if (attest_arr[j] == le->attest->id)
-          break;
-        j++;
-      }
-      if (j==i)
-      {
-        // New Attestation
-        attest_arr[i] = le->attest->id;
-        GNUNET_asprintf (&source_name,
-                         "src%d",
-                         i);
-        aggr_sources_jwt = json_object ();
-        attest_val_str = GNUNET_RECLAIM_ATTESTATION_value_to_string (
-          le->attest->type, le->attest->data, le->attest->data_size);
-        json_object_set_new (aggr_sources_jwt, "JWT",json_string (
-                               attest_val_str) );
-        aggr_sources_jwt_str = json_dumps (aggr_sources_jwt, JSON_INDENT (0)
-                                           | JSON_COMPACT);
-        json_object_set_new (aggr_sources, source_name,json_string (
-                               aggr_sources_jwt_str));
-        i++;
-      }
-      else
-      {
-        // Attestation already existent. Ignore
-        continue;
-      }
-
+      GNUNET_assert (NULL != ale);
+      // Attestation is existing, hence take the respective source str
+      GNUNET_asprintf (&source_name,
+                       "src%d",
+                       j);
+      json_object_set_new (aggr_names, le->attribute->data,
+                           json_string (source_name));
+      GNUNET_free (source_name);
     }
   }
+
   if (NULL != attest_val_str)
     GNUNET_free (attest_val_str);
-  if (NULL != source_name)
-    GNUNET_free (source_name);
-  if (0!=i)
+  if (0 != i)
   {
     aggr_names_str = json_dumps (aggr_names, JSON_INDENT (0) | JSON_COMPACT);
     aggr_sources_str = json_dumps (aggr_sources, JSON_INDENT (0)
@@ -291,16 +277,15 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
 
   json_decref (aggr_names);
   json_decref (aggr_sources);
-  json_decref (aggr_sources_jwt);
 
   body_str = json_dumps (body, JSON_INDENT (0) | JSON_COMPACT);
   json_decref (body);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,"ID-Token: %s\n", body_str);
 
-  GNUNET_STRINGS_base64_encode (header, strlen (header), &header_base64);
+  GNUNET_STRINGS_base64url_encode (header, strlen (header), &header_base64);
   fix_base64 (header_base64);
 
-  GNUNET_STRINGS_base64_encode (body_str, strlen (body_str), &body_base64);
+  GNUNET_STRINGS_base64url_encode (body_str, strlen (body_str), &body_base64);
   fix_base64 (body_base64);
 
   GNUNET_free (subject);
@@ -316,9 +301,9 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
                           signature_target,
                           strlen (signature_target),
                           &signature);
-  GNUNET_STRINGS_base64_encode ((const char *) &signature,
-                                sizeof(struct GNUNET_HashCode),
-                                &signature_base64);
+  GNUNET_STRINGS_base64url_encode ((const char *) &signature,
+                                   sizeof(struct GNUNET_HashCode),
+                                   &signature_base64);
   fix_base64 (signature_base64);
 
   GNUNET_asprintf (&result,
@@ -334,8 +319,6 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
     GNUNET_free (aggr_sources_str);
   if (NULL != aggr_names_str)
     GNUNET_free (aggr_names_str);
-  if (NULL != aggr_sources_jwt_str)
-    GNUNET_free (aggr_sources_jwt_str);
   GNUNET_free (signature_base64);
   GNUNET_free (body_base64);
   GNUNET_free (header_base64);
@@ -343,138 +326,6 @@ OIDC_id_token_new (const struct GNUNET_CRYPTO_EcdsaPublicKey *aud_key,
 }
 
 
-/* Converts a hex character to its integer value */
-static char
-from_hex (char ch)
-{
-  return isdigit (ch) ? ch - '0' : tolower (ch) - 'a' + 10;
-}
-
-
-/* Converts an integer value to its hex character*/
-static char
-to_hex (char code)
-{
-  static char hex[] = "0123456789abcdef";
-
-  return hex[code & 15];
-}
-
-
-/* Returns a url-encoded version of str */
-/* IMPORTANT: be sure to free() the returned string after use */
-static char *
-url_encode (const char *str)
-{
-  char *pstr = (char *) str;
-  char *buf = GNUNET_malloc (strlen (str) * 3 + 1);
-  char *pbuf = buf;
-
-  while (*pstr)
-  {
-    if (isalnum (*pstr) || (*pstr == '-') || (*pstr == '_') || (*pstr == '.') ||
-        (*pstr == '~') )
-      *pbuf++ = *pstr;
-    else if (*pstr == ' ')
-      *pbuf++ = '+';
-    else
-    {
-      *pbuf++ = '%';
-      *pbuf++ = to_hex (*pstr >> 4);
-      *pbuf++ = to_hex (*pstr & 15);
-    }
-    pstr++;
-  }
-  *pbuf = '\0';
-  return buf;
-}
-
-
-/* Returns a url-decoded version of str */
-/* IMPORTANT: be sure to free() the returned string after use */
-static char *
-url_decode (const char *str)
-{
-  char *pstr = (char *) str;
-  char *buf = GNUNET_malloc (strlen (str) + 1);
-  char *pbuf = buf;
-
-  while (*pstr)
-  {
-    if (*pstr == '%')
-    {
-      if (pstr[1] && pstr[2])
-      {
-        *pbuf++ = from_hex (pstr[1]) << 4 | from_hex (pstr[2]);
-        pstr += 2;
-      }
-    }
-    else if (*pstr == '+')
-    {
-      *pbuf++ = ' ';
-    }
-    else
-    {
-      *pbuf++ = *pstr;
-    }
-    pstr++;
-  }
-  *pbuf = '\0';
-  return buf;
-}
-
-
-/**
- * Returns base64 encoded string urlencoded
- *
- * @param string the string to encode
- * @return base64 encoded string
- */
-static char *
-base64_and_urlencode (const char *data, size_t data_size)
-{
-  char *enc;
-  char *urlenc;
-
-  GNUNET_STRINGS_base64_encode (data, data_size, &enc);
-  urlenc = url_encode (enc);
-  GNUNET_free (enc);
-  return urlenc;
-}
-
-
-/**
- * Returns base64 encoded string urlencoded
- *
- * @param string the string to encode
- * @return base64 encoded string
- */
-static char *
-base64url_encode (const char *data, size_t data_size)
-{
-  char *enc;
-  size_t pos;
-
-  GNUNET_STRINGS_base64_encode (data, data_size, &enc);
-  // Replace with correct characters for base64url
-  pos = 0;
-  while ('\0' != enc[pos])
-  {
-    if ('+' == enc[pos])
-      enc[pos] = '-';
-    if ('/' == enc[pos])
-      enc[pos] = '_';
-    if ('=' == enc[pos])
-    {
-      enc[pos] = '\0';
-      break;
-    }
-    pos++;
-  }
-  return enc;
-}
-
-
 static void
 derive_aes_key (struct GNUNET_CRYPTO_SymmetricSessionKey *key,
                 struct GNUNET_CRYPTO_SymmetricInitializationVector *iv,
@@ -572,7 +423,8 @@ encrypt_payload (const struct GNUNET_CRYPTO_EcdsaPublicKey *ecdsa_pub,
 char *
 OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
                        const struct GNUNET_RECLAIM_Ticket *ticket,
-                       struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs,
+                       struct GNUNET_RECLAIM_AttributeList *attrs,
+                       struct GNUNET_RECLAIM_AttestationList *attests,
                        const char *nonce_str,
                        const char *code_challenge)
 {
@@ -585,11 +437,12 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
   size_t payload_len;
   size_t code_payload_len;
   size_t attr_list_len = 0;
+  size_t attests_list_len = 0;
   size_t code_challenge_len = 0;
   uint32_t nonce;
   uint32_t nonce_tmp;
   struct GNUNET_CRYPTO_EccSignaturePurpose *purpose;
-  struct GNUNET_CRYPTO_EcdhePrivateKey *ecdh_priv;
+  struct GNUNET_CRYPTO_EcdhePrivateKey ecdh_priv;
   struct GNUNET_CRYPTO_EcdhePublicKey ecdh_pub;
 
   /** PLAINTEXT **/
@@ -623,7 +476,7 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
   if (NULL != attrs)
   {
     // Get length
-    attr_list_len = GNUNET_RECLAIM_ATTRIBUTE_list_serialize_get_size (attrs);
+    attr_list_len = GNUNET_RECLAIM_attribute_list_serialize_get_size (attrs);
     params.attr_list_len = htonl (attr_list_len);
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Length of serialized attributes: %lu\n",
@@ -631,6 +484,19 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
     // Get serialized attributes
     payload_len += attr_list_len;
   }
+  if (NULL != attests)
+  {
+    // Get length
+    attests_list_len =
+      GNUNET_RECLAIM_attestation_list_serialize_get_size (attests);
+    params.attest_list_len = htonl (attests_list_len);
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                "Length of serialized attestations: %lu\n",
+                attests_list_len);
+    // Get serialized attributes
+    payload_len += attests_list_len;
+  }
+
   // Get plaintext length
   payload = GNUNET_malloc (payload_len);
   memcpy (payload, &params, sizeof(params));
@@ -641,7 +507,10 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
     tmp += code_challenge_len;
   }
   if (0 < attr_list_len)
-    GNUNET_RECLAIM_ATTRIBUTE_list_serialize (attrs, tmp);
+    GNUNET_RECLAIM_attribute_list_serialize (attrs, tmp);
+  if (0 < attests_list_len)
+    GNUNET_RECLAIM_attestation_list_serialize (attests, tmp);
+
   /** END **/
 
   /** ENCRYPT **/
@@ -655,8 +524,8 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
               code_payload_len);
 
   // Generate ECDH key
-  ecdh_priv = GNUNET_CRYPTO_ecdhe_key_create ();
-  GNUNET_CRYPTO_ecdhe_key_get_public (ecdh_priv, &ecdh_pub);
+  GNUNET_CRYPTO_ecdhe_key_create (&ecdh_priv);
+  GNUNET_CRYPTO_ecdhe_key_get_public (&ecdh_priv, &ecdh_pub);
   // Initialize code payload
   code_payload = GNUNET_malloc (code_payload_len);
   GNUNET_assert (NULL != code_payload);
@@ -669,23 +538,26 @@ OIDC_build_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *issuer,
   memcpy (buf_ptr, &ecdh_pub, sizeof(ecdh_pub));
   buf_ptr += sizeof(ecdh_pub);
   // Encrypt plaintext and store
-  encrypt_payload (&ticket->audience, ecdh_priv, payload, payload_len, buf_ptr);
-  GNUNET_free (ecdh_priv);
+  encrypt_payload (&ticket->audience,
+                   &ecdh_priv,
+                   payload,
+                   payload_len,
+                   buf_ptr);
   GNUNET_free (payload);
   buf_ptr += payload_len;
   // Sign and store signature
   if (GNUNET_SYSERR ==
-      GNUNET_CRYPTO_ecdsa_sign (issuer,
-                                purpose,
-                                (struct GNUNET_CRYPTO_EcdsaSignature *)
-                                buf_ptr))
+      GNUNET_CRYPTO_ecdsa_sign_ (issuer,
+                                 purpose,
+                                 (struct GNUNET_CRYPTO_EcdsaSignature *)
+                                 buf_ptr))
   {
     GNUNET_break (0);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR, "Unable to sign code\n");
     GNUNET_free (code_payload);
     return NULL;
   }
-  code_str = base64_and_urlencode (code_payload, code_payload_len);
+  GNUNET_STRINGS_base64url_encode (code_payload, code_payload_len, &code_str);
   GNUNET_free (code_payload);
   return code_str;
 }
@@ -709,13 +581,15 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
                        const char *code,
                        const char *code_verifier,
                        struct GNUNET_RECLAIM_Ticket *ticket,
-                       struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList **attrs,
+                       struct GNUNET_RECLAIM_AttributeList **attrs,
+                       struct GNUNET_RECLAIM_AttestationList **attests,
                        char **nonce_str)
 {
   char *code_payload;
   char *ptr;
   char *plaintext;
   char *attrs_ser;
+  char *attests_ser;
   char *expected_code_challenge;
   char *code_challenge;
   char *code_verifier_hash;
@@ -725,6 +599,7 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
   struct GNUNET_CRYPTO_EcdhePublicKey *ecdh_pub;
   uint32_t code_challenge_len;
   uint32_t attrs_ser_len;
+  uint32_t attests_ser_len;
   size_t plaintext_len;
   size_t code_payload_len;
   uint32_t nonce = 0;
@@ -733,14 +608,15 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Trying to decode `%s'\n", code);
   code_payload = NULL;
   code_payload_len =
-    GNUNET_STRINGS_base64_decode (code, strlen (code), (void **) &code_payload);
+    GNUNET_STRINGS_base64url_decode (code, strlen (code),
+                                     (void **) &code_payload);
   if (code_payload_len < sizeof(struct GNUNET_CRYPTO_EccSignaturePurpose)
       + sizeof(struct GNUNET_CRYPTO_EcdhePublicKey)
       + sizeof(struct OIDC_Parameters)
       + sizeof(struct GNUNET_CRYPTO_EcdsaSignature))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR, "Authorization code malformed\n");
-    GNUNET_free_non_null (code_payload);
+    GNUNET_free (code_payload);
     return GNUNET_SYSERR;
   }
 
@@ -770,7 +646,7 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                   "Expected code verifier!\n");
-      GNUNET_free_non_null (code_payload);
+      GNUNET_free (code_payload);
       return GNUNET_SYSERR;
     }
     code_verifier_hash = GNUNET_malloc (256 / 8);
@@ -780,7 +656,8 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
                          code_verifier,
                          strlen (code_verifier));
     // encode code verifier
-    expected_code_challenge = base64url_encode (code_verifier_hash, 256 / 8);
+    GNUNET_STRINGS_base64url_encode (code_verifier_hash, 256 / 8,
+                                     &expected_code_challenge);
     code_challenge = (char *) &params[1];
     GNUNET_free (code_verifier_hash);
     if ((strlen (expected_code_challenge) != code_challenge_len) ||
@@ -792,7 +669,7 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
                   expected_code_challenge,
                   code_challenge_len,
                   code_challenge);
-      GNUNET_free_non_null (code_payload);
+      GNUNET_free (code_payload);
       GNUNET_free (expected_code_challenge);
       return GNUNET_SYSERR;
     }
@@ -814,10 +691,10 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
     return GNUNET_SYSERR;
   }
   if (GNUNET_OK !=
-      GNUNET_CRYPTO_ecdsa_verify (GNUNET_SIGNATURE_PURPOSE_RECLAIM_CODE_SIGN,
-                                  purpose,
-                                  signature,
-                                  &ticket->identity))
+      GNUNET_CRYPTO_ecdsa_verify_ (GNUNET_SIGNATURE_PURPOSE_RECLAIM_CODE_SIGN,
+                                   purpose,
+                                   signature,
+                                   &ticket->identity))
   {
     GNUNET_free (code_payload);
     GNUNET_free (plaintext);
@@ -827,7 +704,11 @@ OIDC_parse_authz_code (const struct GNUNET_CRYPTO_EcdsaPrivateKey *ecdsa_priv,
   // Attributes
   attrs_ser = ((char *) &params[1]) + code_challenge_len;
   attrs_ser_len = ntohl (params->attr_list_len);
-  *attrs = GNUNET_RECLAIM_ATTRIBUTE_list_deserialize (attrs_ser, attrs_ser_len);
+  *attrs = GNUNET_RECLAIM_attribute_list_deserialize (attrs_ser, attrs_ser_len);
+  attests_ser = ((char*) attrs_ser) + attrs_ser_len;
+  attests_ser_len = ntohl (params->attest_list_len);
+  *attests = GNUNET_RECLAIM_attestation_list_deserialize (attests_ser,
+                                                          attests_ser_len);
 
   *nonce_str = NULL;
   if (nonce != 0)
