@@ -32,7 +32,7 @@
 #include "gnunet_gnsrecord_lib.h"
 #include "gnunet_identity_service.h"
 #include "gnunet_namestore_service.h"
-#include "gnunet_reclaim_attribute_lib.h"
+#include "gnunet_reclaim_lib.h"
 #include "gnunet_reclaim_service.h"
 #include "gnunet_rest_lib.h"
 #include "gnunet_rest_plugin.h"
@@ -426,9 +426,20 @@ struct RequestHandle
   struct GNUNET_NAMESTORE_ZoneIterator *namestore_handle_it;
 
   /**
-   * Attribute claim list
+   * Attribute claim list for id_token
    */
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attr_list;
+  struct GNUNET_RECLAIM_AttributeList *attr_idtoken_list;
+
+  /**
+   * Attribute claim list for userinfo
+   */
+  struct GNUNET_RECLAIM_AttributeList *attr_userinfo_list;
+
+  /**
+   * Attestation list
+   */
+  struct GNUNET_RECLAIM_AttestationList *attests_list;
+
 
   /**
    * IDENTITY Operation
@@ -450,6 +461,12 @@ struct RequestHandle
    */
   struct GNUNET_RECLAIM_AttributeIterator *attr_it;
 
+  /**
+   * Attestation iterator
+   */
+  struct GNUNET_RECLAIM_AttestationIterator *attest_it;
+
+
   /**
    * Ticket iterator
    */
@@ -523,10 +540,7 @@ struct RequestHandle
 static void
 cleanup_handle (struct RequestHandle *handle)
 {
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *claim_entry;
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *claim_tmp;
   struct EgoEntry *ego_entry;
-  struct EgoEntry *ego_tmp;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Cleaning up\n");
   if (NULL != handle->timeout_task)
@@ -535,16 +549,20 @@ cleanup_handle (struct RequestHandle *handle)
     GNUNET_IDENTITY_disconnect (handle->identity_handle);
   if (NULL != handle->attr_it)
     GNUNET_RECLAIM_get_attributes_stop (handle->attr_it);
+  if (NULL != handle->attest_it)
+    GNUNET_RECLAIM_get_attestations_stop (handle->attest_it);
   if (NULL != handle->ticket_it)
     GNUNET_RECLAIM_ticket_iteration_stop (handle->ticket_it);
+  if (NULL != handle->idp_op)
+    GNUNET_RECLAIM_cancel (handle->idp_op);
   if (NULL != handle->idp)
     GNUNET_RECLAIM_disconnect (handle->idp);
-  GNUNET_free_non_null (handle->url);
-  GNUNET_free_non_null (handle->tld);
-  GNUNET_free_non_null (handle->redirect_prefix);
-  GNUNET_free_non_null (handle->redirect_suffix);
-  GNUNET_free_non_null (handle->emsg);
-  GNUNET_free_non_null (handle->edesc);
+  GNUNET_free (handle->url);
+  GNUNET_free (handle->tld);
+  GNUNET_free (handle->redirect_prefix);
+  GNUNET_free (handle->redirect_suffix);
+  GNUNET_free (handle->emsg);
+  GNUNET_free (handle->edesc);
   if (NULL != handle->gns_op)
     GNUNET_GNS_lookup_cancel (handle->gns_op);
   if (NULL != handle->gns_handle)
@@ -554,39 +572,31 @@ cleanup_handle (struct RequestHandle *handle)
     GNUNET_NAMESTORE_disconnect (handle->namestore_handle);
   if (NULL != handle->oidc)
   {
-    GNUNET_free_non_null (handle->oidc->client_id);
-    GNUNET_free_non_null (handle->oidc->login_identity);
-    GNUNET_free_non_null (handle->oidc->nonce);
-    GNUNET_free_non_null (handle->oidc->redirect_uri);
-    GNUNET_free_non_null (handle->oidc->response_type);
-    GNUNET_free_non_null (handle->oidc->scope);
-    GNUNET_free_non_null (handle->oidc->state);
+    GNUNET_free (handle->oidc->client_id);
+    GNUNET_free (handle->oidc->login_identity);
+    GNUNET_free (handle->oidc->nonce);
+    GNUNET_free (handle->oidc->redirect_uri);
+    GNUNET_free (handle->oidc->response_type);
+    GNUNET_free (handle->oidc->scope);
+    GNUNET_free (handle->oidc->state);
     json_decref (handle->oidc->response);
     GNUNET_free (handle->oidc);
   }
-  if (NULL != handle->attr_list)
+  if (NULL!=handle->attr_idtoken_list)
+    GNUNET_RECLAIM_attribute_list_destroy (handle->attr_idtoken_list);
+  if (NULL!=handle->attr_userinfo_list)
+    GNUNET_RECLAIM_attribute_list_destroy (handle->attr_userinfo_list);
+  if (NULL!=handle->attests_list)
+    GNUNET_RECLAIM_attestation_list_destroy (handle->attests_list);
+
+  while (NULL != (ego_entry = handle->ego_head))
   {
-    for (claim_entry = handle->attr_list->list_head; NULL != claim_entry;)
-    {
-      claim_tmp = claim_entry;
-      claim_entry = claim_entry->next;
-      if (NULL != claim_tmp->claim)
-        GNUNET_free (claim_tmp->claim);
-      if (NULL != claim_tmp->attest)
-        GNUNET_free (claim_tmp->attest);
-      if (NULL != claim_tmp->reference)
-        GNUNET_free (claim_tmp->reference);
-      GNUNET_free (claim_tmp);
-    }
-    GNUNET_free (handle->attr_list);
-  }
-  for (ego_entry = handle->ego_head; NULL != ego_entry;)
-  {
-    ego_tmp = ego_entry;
-    ego_entry = ego_entry->next;
-    GNUNET_free (ego_tmp->identifier);
-    GNUNET_free (ego_tmp->keystring);
-    GNUNET_free (ego_tmp);
+    GNUNET_CONTAINER_DLL_remove (handle->ego_head,
+                                 handle->ego_tail,
+                                 ego_entry);
+    GNUNET_free (ego_entry->identifier);
+    GNUNET_free (ego_entry->keystring);
+    GNUNET_free (ego_entry);
   }
   GNUNET_free (handle);
 }
@@ -930,10 +940,10 @@ oidc_ticket_issue_cb (void *cls, const struct GNUNET_RECLAIM_Ticket *ticket)
   ticket_str =
     GNUNET_STRINGS_data_to_string_alloc (&handle->ticket,
                                          sizeof(struct GNUNET_RECLAIM_Ticket));
-  // TODO change if more attributes are needed (see max_age)
   code_string = OIDC_build_authz_code (&handle->priv_key,
                                        &handle->ticket,
-                                       handle->attr_list,
+                                       handle->attr_idtoken_list,
+                                       handle->attests_list,
                                        handle->oidc->nonce,
                                        handle->oidc->code_challenge);
   if ((NULL != handle->redirect_prefix) && (NULL != handle->redirect_suffix) &&
@@ -967,131 +977,256 @@ oidc_ticket_issue_cb (void *cls, const struct GNUNET_RECLAIM_Ticket *ticket)
 }
 
 
+static struct GNUNET_RECLAIM_AttributeList*
+attribute_list_merge (struct GNUNET_RECLAIM_AttributeList *list_a,
+                      struct GNUNET_RECLAIM_AttributeList *list_b)
+{
+  struct GNUNET_RECLAIM_AttributeList *merged_list;
+  struct GNUNET_RECLAIM_AttributeListEntry *le_a;
+  struct GNUNET_RECLAIM_AttributeListEntry *le_b;
+  struct GNUNET_RECLAIM_AttributeListEntry *le_m;
+
+  merged_list = GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
+  for (le_a = list_a->list_head; NULL != le_a; le_a = le_a->next)
+  {
+    le_m = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+    le_m->attribute = GNUNET_RECLAIM_attribute_new (le_a->attribute->name,
+                                                    &le_a->attribute->
+                                                    attestation,
+                                                    le_a->attribute->type,
+                                                    le_a->attribute->data,
+                                                    le_a->attribute->data_size);
+    le_m->attribute->id = le_a->attribute->id;
+    le_m->attribute->flag = le_a->attribute->flag;
+    le_m->attribute->attestation = le_a->attribute->attestation;
+    GNUNET_CONTAINER_DLL_insert (merged_list->list_head,
+                                 merged_list->list_tail,
+                                 le_m);
+  }
+  le_m = NULL;
+  for (le_b = list_b->list_head; NULL != le_b; le_b = le_b->next)
+  {
+    for (le_m = merged_list->list_head; NULL != le_m; le_m = le_m->next)
+    {
+      if (GNUNET_YES == GNUNET_RECLAIM_id_is_equal (&le_m->attribute->id,
+                                                    &le_b->attribute->id))
+        break; /** Attribute already in list **/
+    }
+    if (NULL != le_m)
+      continue; /** Attribute already in list **/
+    le_m = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+    le_m->attribute = GNUNET_RECLAIM_attribute_new (le_b->attribute->name,
+                                                    &le_b->attribute->
+                                                    attestation,
+                                                    le_b->attribute->type,
+                                                    le_b->attribute->data,
+                                                    le_b->attribute->data_size);
+    le_m->attribute->id = le_b->attribute->id;
+    le_m->attribute->flag = le_b->attribute->flag;
+    le_m->attribute->attestation = le_b->attribute->attestation;
+    GNUNET_CONTAINER_DLL_insert (merged_list->list_head,
+                                 merged_list->list_tail,
+                                 le_m);
+  }
+  return merged_list;
+}
+
+
 static void
-oidc_collect_finished_cb (void *cls)
+oidc_attest_collect_finished_cb (void *cls)
+{
+  struct RequestHandle *handle = cls;
+  struct GNUNET_RECLAIM_AttributeList *merged_list;
+
+  handle->attest_it = NULL;
+  merged_list = attribute_list_merge (handle->attr_idtoken_list,
+                                      handle->attr_userinfo_list);
+  handle->idp_op = GNUNET_RECLAIM_ticket_issue (handle->idp,
+                                                &handle->priv_key,
+                                                &handle->oidc->client_pkey,
+                                                merged_list,
+                                                &oidc_ticket_issue_cb,
+                                                handle);
+  GNUNET_RECLAIM_attribute_list_destroy (merged_list);
+}
+
+
+/**
+ * Collects all attributes for an ego if in scope parameter
+ */
+static void
+oidc_attest_collect (void *cls,
+                     const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
+                     const struct GNUNET_RECLAIM_Attestation *attest)
+{
+  struct RequestHandle *handle = cls;
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
+  struct GNUNET_RECLAIM_AttestationListEntry *ale;
+
+  for (ale = handle->attests_list->list_head; NULL != ale; ale = ale->next)
+  {
+    if (GNUNET_NO == GNUNET_RECLAIM_id_is_equal (&ale->attestation->id,
+                                                 &attest->id))
+      continue;
+    /** Attestation already in list **/
+    GNUNET_RECLAIM_get_attestations_next (handle->attest_it);
+    return;
+  }
+
+  for (le = handle->attr_idtoken_list->list_head; NULL != le; le = le->next)
+  {
+    if (GNUNET_NO == GNUNET_RECLAIM_id_is_equal (&le->attribute->attestation,
+                                                 &attest->id))
+      continue;
+    /** Attestation matches for attribute, add **/
+    ale = GNUNET_new (struct GNUNET_RECLAIM_AttestationListEntry);
+    ale->attestation = GNUNET_RECLAIM_attestation_new (attest->name,
+                                                       attest->type,
+                                                       attest->data,
+                                                       attest->data_size);
+    GNUNET_CONTAINER_DLL_insert (handle->attests_list->list_head,
+                                 handle->attests_list->list_tail,
+                                 ale);
+  }
+  GNUNET_RECLAIM_get_attestations_next (handle->attest_it);
+}
+
+
+static void
+oidc_attr_collect_finished_cb (void *cls)
 {
   struct RequestHandle *handle = cls;
 
   handle->attr_it = NULL;
   handle->ticket_it = NULL;
-  if (NULL == handle->attr_list->list_head)
+  if (NULL == handle->attr_idtoken_list->list_head)
   {
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_SCOPE);
     handle->edesc = GNUNET_strdup ("The requested scope is not available.");
     GNUNET_SCHEDULER_add_now (&do_redirect_error, handle);
     return;
   }
-  handle->idp_op = GNUNET_RECLAIM_ticket_issue (handle->idp,
-                                                &handle->priv_key,
-                                                &handle->oidc->client_pkey,
-                                                handle->attr_list,
-                                                &oidc_ticket_issue_cb,
-                                                handle);
+  handle->attests_list = GNUNET_new (struct GNUNET_RECLAIM_AttestationList);
+  handle->attest_it =
+    GNUNET_RECLAIM_get_attestations_start (handle->idp,
+                                           &handle->priv_key,
+                                           &oidc_iteration_error,
+                                           handle,
+                                           &oidc_attest_collect,
+                                           handle,
+                                           &oidc_attest_collect_finished_cb,
+                                           handle);
+
+}
+
+
+static int
+attr_in_claims_request (struct RequestHandle *handle,
+                        const char *attr_name,
+                        const char *claims_parameter)
+{
+  char *scope_variables;
+  char *scope_variable;
+  char delimiter[] = " ";
+  int ret = GNUNET_NO;
+  json_t *root;
+  json_error_t error;
+  json_t *claims_j;
+  const char *key;
+  json_t *value;
+
+  scope_variables = GNUNET_strdup (handle->oidc->scope);
+  scope_variable = strtok (scope_variables, delimiter);
+  while (NULL != scope_variable)
+  {
+    if (0 == strcmp (attr_name, scope_variable))
+      break;
+    scope_variable = strtok (NULL, delimiter);
+  }
+  if (NULL != scope_variable)
+    ret = GNUNET_YES;
+  GNUNET_free (scope_variables);
+
+  /** Try claims parameter if no in scope */
+  if ((NULL != handle->oidc->claims) &&
+      (GNUNET_YES != ret))
+  {
+    root = json_loads (handle->oidc->claims, JSON_DECODE_ANY, &error);
+    claims_j = json_object_get (root, claims_parameter);
+    /* obj is a JSON object */
+    if (NULL != claims_j)
+    {
+      json_object_foreach (claims_j, key, value) {
+        if (0 != strcmp (attr_name, key))
+          continue;
+        ret = GNUNET_YES;
+        break;
+      }
+    }
+    json_decref (root);
+  }
+  return ret;
+}
+
+
+static int
+attr_in_idtoken_request (struct RequestHandle *handle,
+                         const char *attr_name)
+{
+  return attr_in_claims_request (handle, attr_name, "id_token");
+}
+
+
+static int
+attr_in_userinfo_request (struct RequestHandle *handle,
+                          const char *attr_name)
+{
+  return attr_in_claims_request (handle, attr_name, "userinfo");
 }
 
 
 /**
- * Collects all attributes/references for an ego if in scope parameter
+ * Collects all attributes for an ego if in scope parameter
  */
 static void
 oidc_attr_collect (void *cls,
                    const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
-                   const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
-                   const struct GNUNET_RECLAIM_ATTESTATION_Claim *attest,
-                   const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *reference)
+                   const struct GNUNET_RECLAIM_Attribute *attr)
 {
   struct RequestHandle *handle = cls;
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
-  char *scope_variables;
-  char *scope_variable;
-  char delimiter[] = " ";
-
-  if ((NULL == attr) && (NULL == reference))
+  struct GNUNET_RECLAIM_AttributeListEntry *le;
+  if (GNUNET_YES == attr_in_idtoken_request (handle, attr->name))
   {
-    GNUNET_RECLAIM_get_attributes_next (handle->attr_it);
-    return;
-  }
-  if (NULL != reference)
-  {
-    if ((NULL == reference->name) || (NULL == reference->reference_value))
-    {
-      return;
-    }
-    scope_variables = GNUNET_strdup (handle->oidc->scope);
-    scope_variable = strtok (scope_variables, delimiter);
-    while (NULL != scope_variable)
-    {
-      if (0 == strcmp (reference->name, scope_variable))
-        break;
-      scope_variable = strtok (NULL, delimiter);
-    }
-    if (NULL == scope_variable)
-    {
-      GNUNET_free (scope_variables);
-      return;
-    }
-    GNUNET_free (scope_variables);
-    struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le2;
-    le2 = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-    le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-    le->claim = NULL;
-    le->reference = NULL;
-    le->attest = GNUNET_RECLAIM_ATTESTATION_claim_new (attest->name,
-                                                       attest->type,
-                                                       attest->data,
-                                                       attest->data_size);
-    le->attest->id = attest->id;
-    le2->attest = NULL;
-    le2->claim = NULL;
-    le2->reference = GNUNET_RECLAIM_ATTESTATION_reference_new (reference->name,
-                                                               reference->
-                                                               reference_value);
-    le2->reference->id = reference->id;
-    le2->reference->id_attest = reference->id_attest;
-    GNUNET_CONTAINER_DLL_insert (handle->attr_list->list_head,
-                                 handle->attr_list->list_tail,
+    le = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+    le->attribute = GNUNET_RECLAIM_attribute_new (attr->name,
+                                                  &attr->attestation,
+                                                  attr->type,
+                                                  attr->data,
+                                                  attr->data_size);
+    le->attribute->id = attr->id;
+    le->attribute->flag = attr->flag;
+    le->attribute->attestation = attr->attestation;
+    GNUNET_CONTAINER_DLL_insert (handle->attr_idtoken_list->list_head,
+                                 handle->attr_idtoken_list->list_tail,
                                  le);
-    GNUNET_CONTAINER_DLL_insert (handle->attr_list->list_head,
-                                 handle->attr_list->list_tail,
-                                 le2);
   }
-  else if (NULL != attr)
+  if (GNUNET_YES == attr_in_userinfo_request (handle, attr->name))
   {
-    if ((NULL == attr->name) || (NULL == attr->data))
-    {
-      GNUNET_RECLAIM_get_attributes_next (handle->attr_it);
-      return;
-    }
-    scope_variables = GNUNET_strdup (handle->oidc->scope);
-    scope_variable = strtok (scope_variables, delimiter);
-    while (NULL != scope_variable)
-    {
-      if (0 == strcmp (attr->name, scope_variable))
-        break;
-      scope_variable = strtok (NULL, delimiter);
-    }
-    if (NULL == scope_variable)
-    {
-      GNUNET_RECLAIM_get_attributes_next (handle->attr_it);
-      GNUNET_free (scope_variables);
-      return;
-    }
-    GNUNET_free (scope_variables);
-    le = GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry);
-    le->reference = NULL;
-    le->attest = NULL;
-    le->claim = GNUNET_RECLAIM_ATTRIBUTE_claim_new (attr->name,
-                                                    attr->type,
-                                                    attr->data,
-                                                    attr->data_size);
-    le->claim->id = attr->id;
-    le->claim->flag = attr->flag;
-
-    GNUNET_CONTAINER_DLL_insert (handle->attr_list->list_head,
-                                 handle->attr_list->list_tail,
+    le = GNUNET_new (struct GNUNET_RECLAIM_AttributeListEntry);
+    le->attribute = GNUNET_RECLAIM_attribute_new (attr->name,
+                                                  &attr->attestation,
+                                                  attr->type,
+                                                  attr->data,
+                                                  attr->data_size);
+    le->attribute->id = attr->id;
+    le->attribute->flag = attr->flag;
+    le->attribute->attestation = attr->attestation;
+    GNUNET_CONTAINER_DLL_insert (handle->attr_userinfo_list->list_head,
+                                 handle->attr_userinfo_list->list_tail,
                                  le);
-    GNUNET_RECLAIM_get_attributes_next (handle->attr_it);
   }
+
+  GNUNET_RECLAIM_get_attributes_next (handle->attr_it);
 }
 
 
@@ -1148,8 +1283,10 @@ code_redirect (void *cls)
           handle->priv_key =
             *GNUNET_IDENTITY_ego_get_private_key (handle->ego_entry->ego);
           handle->idp = GNUNET_RECLAIM_connect (cfg);
-          handle->attr_list =
-            GNUNET_new (struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList);
+          handle->attr_idtoken_list =
+            GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
+          handle->attr_userinfo_list =
+            GNUNET_new (struct GNUNET_RECLAIM_AttributeList);
           handle->attr_it =
             GNUNET_RECLAIM_get_attributes_start (handle->idp,
                                                  &handle->priv_key,
@@ -1157,7 +1294,7 @@ code_redirect (void *cls)
                                                  handle,
                                                  &oidc_attr_collect,
                                                  handle,
-                                                 &oidc_collect_finished_cb,
+                                                 &oidc_attr_collect_finished_cb,
                                                  handle);
           return;
         }
@@ -1531,8 +1668,7 @@ authorize_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
     }
   }
   handle->oidc->scope = get_url_parameter_copy (handle, OIDC_SCOPE_KEY);
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Scope: %s\n",GNUNET_strdup (
-                handle->oidc->scope));
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Scope: %s\n", handle->oidc->scope);
   if (NULL == handle->tld)
     GNUNET_CONFIGURATION_iterate_section_values (cfg, "gns", tld_iter, handle);
   if (NULL == handle->tld)
@@ -1598,7 +1734,7 @@ login_cont (struct GNUNET_REST_RequestHandle *con_handle,
                                      OIDC_COOKIE_EXPIRATION));
     last_time =
       GNUNET_CONTAINER_multihashmap_get (OIDC_cookie_jar_map, &cache_key);
-    GNUNET_free_non_null (last_time);
+    GNUNET_free (last_time);
     GNUNET_CONTAINER_multihashmap_put (OIDC_cookie_jar_map,
                                        &cache_key,
                                        current_time,
@@ -1668,7 +1804,7 @@ check_authorization (struct RequestHandle *handle,
   client_id = strtok (basic_authorization, ":");
   if (NULL == client_id)
   {
-    GNUNET_free_non_null (basic_authorization);
+    GNUNET_free (basic_authorization);
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_CLIENT);
     handle->response_code = MHD_HTTP_UNAUTHORIZED;
     return GNUNET_SYSERR;
@@ -1676,7 +1812,7 @@ check_authorization (struct RequestHandle *handle,
   pass = strtok (NULL, ":");
   if (NULL == pass)
   {
-    GNUNET_free_non_null (basic_authorization);
+    GNUNET_free (basic_authorization);
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_CLIENT);
     handle->response_code = MHD_HTTP_UNAUTHORIZED;
     return GNUNET_SYSERR;
@@ -1690,7 +1826,7 @@ check_authorization (struct RequestHandle *handle,
   {
     if (0 != strcmp (expected_pass, pass))
     {
-      GNUNET_free_non_null (basic_authorization);
+      GNUNET_free (basic_authorization);
       GNUNET_free (expected_pass);
       handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_CLIENT);
       handle->response_code = MHD_HTTP_UNAUTHORIZED;
@@ -1700,7 +1836,7 @@ check_authorization (struct RequestHandle *handle,
   }
   else
   {
-    GNUNET_free_non_null (basic_authorization);
+    GNUNET_free (basic_authorization);
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_SERVER_ERROR);
     handle->edesc = GNUNET_strdup ("gnunet configuration failed");
     handle->response_code = MHD_HTTP_INTERNAL_SERVER_ERROR;
@@ -1716,7 +1852,7 @@ check_authorization (struct RequestHandle *handle,
   }
   if (NULL == handle->ego_entry)
   {
-    GNUNET_free_non_null (basic_authorization);
+    GNUNET_free (basic_authorization);
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_CLIENT);
     handle->response_code = MHD_HTTP_UNAUTHORIZED;
     return GNUNET_SYSERR;
@@ -1784,7 +1920,8 @@ token_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
   struct RequestHandle *handle = cls;
   const struct EgoEntry *ego_entry;
   struct GNUNET_TIME_Relative expiration_time;
-  struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *cl;
+  struct GNUNET_RECLAIM_AttributeList *cl = NULL;
+  struct GNUNET_RECLAIM_AttestationList *al = NULL;
   struct GNUNET_RECLAIM_Ticket ticket;
   struct GNUNET_CRYPTO_EcdsaPublicKey cid;
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *privkey;
@@ -1872,7 +2009,7 @@ token_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
 
   // decode code
   if (GNUNET_OK != OIDC_parse_authz_code (privkey, code, code_verifier, &ticket,
-                                          &cl, &nonce))
+                                          &cl, &al, &nonce))
   {
     handle->emsg = GNUNET_strdup (OIDC_ERROR_KEY_INVALID_REQUEST);
     handle->edesc = GNUNET_strdup ("invalid code");
@@ -1912,6 +2049,7 @@ token_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
   id_token = OIDC_id_token_new (&ticket.audience,
                                 &ticket.identity,
                                 cl,
+                                al,
                                 &expiration_time,
                                 (NULL != nonce) ? nonce : NULL,
                                 jwt_secret);
@@ -1927,7 +2065,8 @@ token_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
   MHD_add_response_header (resp, "Pragma", "no-cache");
   MHD_add_response_header (resp, "Content-Type", "application/json");
   handle->proc (handle->proc_cls, resp, MHD_HTTP_OK);
-  GNUNET_RECLAIM_ATTRIBUTE_list_destroy (cl);
+  GNUNET_RECLAIM_attribute_list_destroy (cl);
+  GNUNET_RECLAIM_attestation_list_destroy (al);
   GNUNET_free (access_token);
   GNUNET_free (json_response);
   GNUNET_free (id_token);
@@ -1936,97 +2075,92 @@ token_endpoint (struct GNUNET_REST_RequestHandle *con_handle,
 
 
 /**
-     * Collects claims and stores them in handle
-     */
+ * Collects claims and stores them in handle
+ */
 static void
 consume_ticket (void *cls,
                 const struct GNUNET_CRYPTO_EcdsaPublicKey *identity,
-                const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
-                const struct GNUNET_RECLAIM_ATTESTATION_Claim *attest,
-                const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *reference)
+                const struct GNUNET_RECLAIM_Attribute *attr,
+                const struct GNUNET_RECLAIM_Attestation *attest)
 {
   struct RequestHandle *handle = cls;
+  handle->idp_op = NULL;
+
   if (NULL == identity)
   {
     GNUNET_SCHEDULER_add_now (&return_userinfo_response, handle);
     return;
   }
-  if (NULL != attr)
+  if (GNUNET_YES == GNUNET_RECLAIM_id_is_zero (&attr->attestation))
   {
     char *tmp_value;
     json_t *value;
-    tmp_value = GNUNET_RECLAIM_ATTRIBUTE_value_to_string (attr->type,
+    tmp_value = GNUNET_RECLAIM_attribute_value_to_string (attr->type,
                                                           attr->data,
                                                           attr->data_size);
     value = json_string (tmp_value);
     json_object_set_new (handle->oidc->response, attr->name, value);
     GNUNET_free (tmp_value);
+    return;
   }
-  else if ((NULL != attest) && (NULL != reference))
+  json_t *claim_sources;
+  json_t *claim_sources_jwt;
+  json_t *claim_names;
+  char *attest_val_str;
+  claim_sources = json_object_get (handle->oidc->response,"_claim_sources");
+  claim_names = json_object_get (handle->oidc->response,"_claim_names");
+  attest_val_str =
+    GNUNET_RECLAIM_attestation_value_to_string (attest->type,
+                                                attest->data,
+                                                attest->data_size);
+  if ((NULL == claim_sources) && (NULL == claim_names) )
   {
-    json_t *claim_sources;
-    json_t *claim_sources_jwt;
-    json_t *claim_names;
-    char *attest_val_str;
-    claim_sources=json_object_get(handle->oidc->response,"_claim_sources");
-    claim_names=json_object_get(handle->oidc->response,"_claim_names");
-    attest_val_str = GNUNET_RECLAIM_ATTESTATION_value_to_string (attest->type,
-                                                                 attest->data,
-                                                                 attest->
-                                                                 data_size);
-    if ((NULL == claim_sources) && (NULL == claim_names) )
-    {
-      claim_sources = json_object ();
-      claim_names = json_object ();
-    }
-    char *source_name;
-    int i = 0;
-    GNUNET_asprintf (&source_name,"src%d",i);
-    while (NULL != (claim_sources_jwt = json_object_get (claim_sources,
-                                                         source_name)))
-    {
-      if (0 == strcmp (json_string_value (json_object_get (claim_sources_jwt,
-                                                           "JWT")),
-                       attest_val_str))
-      {
-        // Adapt only the claim names
-        json_object_set_new (claim_names, reference->name, json_string (
-                               source_name));
-        json_object_set (handle->oidc->response, "_claim_names",claim_names);
-        handle->oidc->response = json_deep_copy(handle->oidc->response);
-        break;
-      }
-      i++;
-      GNUNET_asprintf (&source_name,"src%d",i);
-    }
-
-    // Create new one
-    if (NULL == claim_sources_jwt)
-    {
-      claim_sources_jwt = json_object ();
-      // Set the JWT for names
-      json_object_set_new (claim_names, reference->name, json_string (
-                             source_name));
-      // Set the JWT for the inner source
-      json_object_set_new (claim_sources_jwt, "JWT", json_string (
-                             attest_val_str));
-      // Set the JWT for the source
-      json_object_set_new (claim_sources, source_name,claim_sources_jwt);
-      // Set as claims
-      json_object_set (handle->oidc->response, "_claim_names", claim_names);
-      json_object_set (handle->oidc->response, "_claim_sources",claim_sources);
-      handle->oidc->response = json_deep_copy(handle->oidc->response);
-    }
-
-    json_decref (claim_sources);
-    json_decref (claim_names);
-    json_decref (claim_sources_jwt);
-    GNUNET_free (attest_val_str);
+    claim_sources = json_object ();
+    claim_names = json_object ();
   }
-  else
+  char *source_name;
+  int i = 0;
+  GNUNET_asprintf (&source_name, "src%d", i);
+  while (NULL != (claim_sources_jwt = json_object_get (claim_sources,
+                                                       source_name)))
   {
-    // REMARK: We should not find any claim, one of attest/ref is NULL
+    if (0 == strcmp (json_string_value (json_object_get (claim_sources_jwt,
+                                                         "JWT")),
+                     attest_val_str))
+    {
+      // Adapt only the claim names
+      json_object_set_new (claim_names, attr->data,
+                           json_string (source_name));
+      json_object_set (handle->oidc->response,
+                       "_claim_names", claim_names);
+      break;
+    }
+    i++;
+    GNUNET_free (source_name);
+    GNUNET_asprintf (&source_name, "src%d", i);
   }
+
+  // Create new one
+  if (NULL == claim_sources_jwt)
+  {
+    claim_sources_jwt = json_object ();
+    // Set the JWT for names
+    json_object_set_new (claim_names, attr->data,
+                         json_string (source_name));
+    // Set the JWT for the inner source
+    json_object_set_new (claim_sources_jwt, "JWT",
+                         json_string (attest_val_str));
+    // Set the JWT for the source
+    json_object_set_new (claim_sources, source_name, claim_sources_jwt);
+    // Set as claims
+    json_object_set (handle->oidc->response, "_claim_names", claim_names);
+    json_object_set (handle->oidc->response, "_claim_sources",claim_sources);
+  }
+
+  json_decref (claim_sources);
+  json_decref (claim_names);
+  json_decref (claim_sources_jwt);
+  GNUNET_free (attest_val_str);
 }
 
 
@@ -2266,10 +2400,16 @@ list_ego (void *cls,
       if (ego_entry->ego == ego)
         break;
     }
-    if (NULL != ego_entry)
-      GNUNET_CONTAINER_DLL_remove (handle->ego_head,
-                                   handle->ego_tail,
-                                   ego_entry);
+    if (NULL == ego_entry)
+      return; /* Not found */
+
+    GNUNET_CONTAINER_DLL_remove (handle->ego_head,
+                                 handle->ego_tail,
+                                 ego_entry);
+    GNUNET_free (ego_entry->identifier);
+    GNUNET_free (ego_entry->keystring);
+    GNUNET_free (ego_entry);
+    return;
   }
 }
 
@@ -2283,7 +2423,8 @@ rest_identity_process_request (struct GNUNET_REST_RequestHandle *rest_handle,
 
   handle->oidc = GNUNET_new (struct OIDC_Variables);
   if (NULL == OIDC_cookie_jar_map)
-    OIDC_cookie_jar_map = GNUNET_CONTAINER_multihashmap_create (10, GNUNET_NO);
+    OIDC_cookie_jar_map = GNUNET_CONTAINER_multihashmap_create (10,
+                                                                GNUNET_NO);
   if (NULL == OIDC_access_token_map)
     OIDC_access_token_map =
       GNUNET_CONTAINER_multihashmap_create (10, GNUNET_NO);
@@ -2308,11 +2449,11 @@ rest_identity_process_request (struct GNUNET_REST_RequestHandle *rest_handle,
 
 
 /**
- * Entry point for the plugin.
- *
- * @param cls Config info
- * @return NULL on error, otherwise the plugin context
- */
+   * Entry point for the plugin.
+   *
+   * @param cls Config info
+   * @return NULL on error, otherwise the plugin context
+   */
 void *
 libgnunet_plugin_rest_openid_connect_init (void *cls)
 {
@@ -2321,7 +2462,7 @@ libgnunet_plugin_rest_openid_connect_init (void *cls)
 
   cfg = cls;
   if (NULL != plugin.cfg)
-    return NULL; /* can only initialize once! */
+    return NULL;     /* can only initialize once! */
   memset (&plugin, 0, sizeof(struct Plugin));
   plugin.cfg = cfg;
   api = GNUNET_new (struct GNUNET_REST_Plugin);
@@ -2343,11 +2484,11 @@ libgnunet_plugin_rest_openid_connect_init (void *cls)
 
 
 /**
- * Exit point from the plugin.
- *
- * @param cls the plugin context (as returned by "init")
- * @return always NULL
- */
+   * Exit point from the plugin.
+   *
+   * @param cls the plugin context (as returned by "init")
+   * @return always NULL
+   */
 void *
 libgnunet_plugin_rest_openid_connect_done (void *cls)
 {
@@ -2361,19 +2502,21 @@ libgnunet_plugin_rest_openid_connect_done (void *cls)
   hashmap_it =
     GNUNET_CONTAINER_multihashmap_iterator_create (OIDC_cookie_jar_map);
   while (GNUNET_YES ==
-         GNUNET_CONTAINER_multihashmap_iterator_next (hashmap_it, NULL, value))
-    GNUNET_free_non_null (value);
+         GNUNET_CONTAINER_multihashmap_iterator_next (hashmap_it, NULL,
+                                                      value))
+    GNUNET_free (value);
   GNUNET_CONTAINER_multihashmap_iterator_destroy (hashmap_it);
   GNUNET_CONTAINER_multihashmap_destroy (OIDC_cookie_jar_map);
 
   hashmap_it =
     GNUNET_CONTAINER_multihashmap_iterator_create (OIDC_access_token_map);
   while (GNUNET_YES ==
-         GNUNET_CONTAINER_multihashmap_iterator_next (hashmap_it, NULL, value))
-    GNUNET_free_non_null (value);
+         GNUNET_CONTAINER_multihashmap_iterator_next (hashmap_it, NULL,
+                                                      value))
+    GNUNET_free (value);
   GNUNET_CONTAINER_multihashmap_destroy (OIDC_access_token_map);
   GNUNET_CONTAINER_multihashmap_iterator_destroy (hashmap_it);
-  GNUNET_free_non_null (allow_methods);
+  GNUNET_free (allow_methods);
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "OpenID Connect REST plugin is finished\n");
