@@ -28,7 +28,7 @@
 #include "gnunet_constants.h"
 #include "gnunet_mq_lib.h"
 #include "gnunet_protocols.h"
-#include "gnunet_reclaim_attribute_lib.h"
+#include "gnunet_reclaim_lib.h"
 #include "gnunet_reclaim_service.h"
 #include "reclaim.h"
 
@@ -71,6 +71,16 @@ struct GNUNET_RECLAIM_Operation
    */
   GNUNET_RECLAIM_AttributeResult ar_cb;
 
+  /**
+   * Attribute result callback
+   */
+  GNUNET_RECLAIM_AttributeTicketResult atr_cb;
+
+  /**
+   * Attestation result callback
+   */
+  GNUNET_RECLAIM_AttestationResult at_cb;
+
   /**
    * Revocation result callback
    */
@@ -228,6 +238,73 @@ struct GNUNET_RECLAIM_AttributeIterator
   uint32_t r_id;
 };
 
+/**
+ * Handle for a attestation iterator operation
+ */
+struct GNUNET_RECLAIM_AttestationIterator
+{
+  /**
+   * Kept in a DLL.
+   */
+  struct GNUNET_RECLAIM_AttestationIterator *next;
+
+  /**
+   * Kept in a DLL.
+   */
+  struct GNUNET_RECLAIM_AttestationIterator *prev;
+
+  /**
+   * Main handle to access the service.
+   */
+  struct GNUNET_RECLAIM_Handle *h;
+
+  /**
+   * Function to call on completion.
+   */
+  GNUNET_SCHEDULER_TaskCallback finish_cb;
+
+  /**
+   * Closure for @e finish_cb.
+   */
+  void *finish_cb_cls;
+
+  /**
+   * The continuation to call with the results
+   */
+  GNUNET_RECLAIM_AttestationResult proc;
+
+  /**
+   * Closure for @e proc.
+   */
+  void *proc_cls;
+
+  /**
+   * Function to call on errors.
+   */
+  GNUNET_SCHEDULER_TaskCallback error_cb;
+
+  /**
+   * Closure for @e error_cb.
+   */
+  void *error_cb_cls;
+
+  /**
+   * Envelope of the message to send to the service, if not yet
+   * sent.
+   */
+  struct GNUNET_MQ_Envelope *env;
+
+  /**
+   * Private key of the zone.
+   */
+  struct GNUNET_CRYPTO_EcdsaPrivateKey identity;
+
+  /**
+   * The operation id this zone iteration operation has
+   */
+  uint32_t r_id;
+};
+
 
 /**
  * Handle to the service.
@@ -269,6 +346,16 @@ struct GNUNET_RECLAIM_Handle
    */
   struct GNUNET_RECLAIM_AttributeIterator *it_tail;
 
+  /**
+   * Head of active iterations
+   */
+  struct GNUNET_RECLAIM_AttestationIterator *ait_head;
+
+  /**
+   * Tail of active iterations
+   */
+  struct GNUNET_RECLAIM_AttestationIterator *ait_tail;
+
   /**
    * Head of active iterations
    */
@@ -371,6 +458,23 @@ free_it (struct GNUNET_RECLAIM_AttributeIterator *it)
 }
 
 
+/**
+ * Free @a it.
+ *
+ * @param ait entry to free
+ */
+static void
+free_ait (struct GNUNET_RECLAIM_AttestationIterator *ait)
+{
+  struct GNUNET_RECLAIM_Handle *h = ait->h;
+
+  GNUNET_CONTAINER_DLL_remove (h->ait_head, h->ait_tail, ait);
+  if (NULL != ait->env)
+    GNUNET_MQ_discard (ait->env);
+  GNUNET_free (ait);
+}
+
+
 /**
  * Free @a op
  *
@@ -457,10 +561,13 @@ check_consume_ticket_result (void *cls,
 {
   size_t msg_len;
   size_t attrs_len;
+  size_t attests_len;
 
   msg_len = ntohs (msg->header.size);
   attrs_len = ntohs (msg->attrs_len);
-  if (msg_len != sizeof(struct ConsumeTicketResultMessage) + attrs_len)
+  attests_len = ntohs (msg->attestations_len);
+  if (msg_len !=
+      sizeof(struct ConsumeTicketResultMessage) + attrs_len + attests_len)
   {
     GNUNET_break (0);
     return GNUNET_SYSERR;
@@ -483,9 +590,12 @@ handle_consume_ticket_result (void *cls,
   struct GNUNET_RECLAIM_Handle *h = cls;
   struct GNUNET_RECLAIM_Operation *op;
   size_t attrs_len;
+  size_t attests_len;
   uint32_t r_id = ntohl (msg->id);
+  char *read_ptr;
 
   attrs_len = ntohs (msg->attrs_len);
+  attests_len = ntohs (msg->attestations_len);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Processing ticket result.\n");
 
 
@@ -496,42 +606,59 @@ handle_consume_ticket_result (void *cls,
     return;
 
   {
-    struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs;
-    struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le;
-    struct GNUNET_RECLAIM_ATTRIBUTE_ClaimListEntry *le2;
+    struct GNUNET_RECLAIM_AttributeList *attrs;
+    struct GNUNET_RECLAIM_AttributeListEntry *le;
+    struct GNUNET_RECLAIM_AttestationList *attests;
+    struct GNUNET_RECLAIM_AttestationListEntry *ale;
     attrs =
-      GNUNET_RECLAIM_ATTRIBUTE_list_deserialize ((char *) &msg[1], attrs_len);
-    if (NULL != op->ar_cb)
+      GNUNET_RECLAIM_attribute_list_deserialize ((char *) &msg[1], attrs_len);
+    read_ptr = ((char *) &msg[1]) + attrs_len;
+    attests =
+      GNUNET_RECLAIM_attestation_list_deserialize (read_ptr, attests_len);
+    if (NULL != op->atr_cb)
     {
       if (NULL == attrs)
       {
-        op->ar_cb (op->cls, &msg->identity, NULL, NULL, NULL);
+        op->atr_cb (op->cls, &msg->identity, NULL, NULL);
       }
       else
       {
         for (le = attrs->list_head; NULL != le; le = le->next)
         {
-          if (le->reference != NULL && le->attest == NULL)
+          if (GNUNET_NO ==
+              GNUNET_RECLAIM_id_is_zero (&le->attribute->attestation))
           {
-            for (le2 = attrs->list_head; NULL != le2; le2 = le2->next)
+            for (ale = attests->list_head; NULL != ale; ale = ale->next)
             {
-              if (le2->attest != NULL && le2->attest->id == le->reference->id_attest)
+              if (GNUNET_YES ==
+                  GNUNET_RECLAIM_id_is_equal (&le->attribute->attestation,
+                                              &ale->attestation->id))
               {
-                op->ar_cb (op->cls, &msg->identity, le->claim, le2->attest, le->reference);
+                op->atr_cb (op->cls, &msg->identity,
+                            le->attribute, ale->attestation);
                 break;
               }
 
             }
           }
+          else     // No attestations
+          {
+            op->atr_cb (op->cls, &msg->identity,
+                        le->attribute, NULL);
+          }
         }
-        GNUNET_RECLAIM_ATTRIBUTE_list_destroy (attrs);
+        if (NULL != attrs)
+          GNUNET_RECLAIM_attribute_list_destroy (attrs);
+        if (NULL != attests)
+          GNUNET_RECLAIM_attestation_list_destroy (attests);
         attrs = NULL;
+        attests = NULL;
       }
-      op->ar_cb (op->cls, NULL, NULL, NULL, NULL);
+      op->atr_cb (op->cls, NULL, NULL, NULL);
     }
     GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
     free_op (op);
-    GNUNET_free_non_null (attrs);
+    GNUNET_free (attrs);
     return;
   }
   GNUNET_assert (0);
@@ -611,7 +738,7 @@ handle_attribute_result (void *cls, const struct AttributeResultMessage *msg)
     if (NULL != op)
     {
       if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, NULL, NULL, NULL, NULL);
+        op->ar_cb (op->cls, NULL, NULL);
       GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
       free_op (op);
     }
@@ -619,17 +746,17 @@ handle_attribute_result (void *cls, const struct AttributeResultMessage *msg)
   }
 
   {
-    struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr;
-    attr = GNUNET_RECLAIM_ATTRIBUTE_deserialize ((char *) &msg[1], attr_len);
+    struct GNUNET_RECLAIM_Attribute *attr;
+    attr = GNUNET_RECLAIM_attribute_deserialize ((char *) &msg[1], attr_len);
     if (NULL != it)
     {
       if (NULL != it->proc)
-        it->proc (it->proc_cls, &msg->identity, attr, NULL, NULL);
+        it->proc (it->proc_cls, &msg->identity, attr);
     }
     else if (NULL != op)
     {
       if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, &msg->identity, attr, NULL, NULL);
+        op->ar_cb (op->cls, &msg->identity, attr);
     }
     GNUNET_free (attr);
     return;
@@ -637,23 +764,24 @@ handle_attribute_result (void *cls, const struct AttributeResultMessage *msg)
   GNUNET_assert (0);
 }
 
+
 /**
    * Handle an incoming message of type
-   * #GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_RESULT
+   * #GNUNET_MESSAGE_TYPE_RECLAIM_attestation_RESULT
    *
    * @param cls
    * @param msg the message we received
    * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
    */
 static int
-check_attestation_result (void *cls, const struct AttributeResultMessage *msg)
+check_attestation_result (void *cls, const struct AttestationResultMessage *msg)
 {
   size_t msg_len;
-  size_t attr_len;
+  size_t attest_len;
 
   msg_len = ntohs (msg->header.size);
-  attr_len = ntohs (msg->attr_len);
-  if (msg_len != sizeof(struct AttributeResultMessage) + attr_len)
+  attest_len = ntohs (msg->attestation_len);
+  if (msg_len != sizeof(struct AttestationResultMessage) + attest_len)
   {
     GNUNET_break (0);
     return GNUNET_SYSERR;
@@ -664,26 +792,27 @@ check_attestation_result (void *cls, const struct AttributeResultMessage *msg)
 
 /**
  * Handle an incoming message of type
- * #GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_RESULT
+ * #GNUNET_MESSAGE_TYPE_RECLAIM_attestation_RESULT
  *
  * @param cls
  * @param msg the message we received
  */
 static void
-handle_attestation_result (void *cls, const struct AttributeResultMessage *msg)
+handle_attestation_result (void *cls, const struct
+                           AttestationResultMessage *msg)
 {
   static struct GNUNET_CRYPTO_EcdsaPrivateKey identity_dummy;
   struct GNUNET_RECLAIM_Handle *h = cls;
-  struct GNUNET_RECLAIM_AttributeIterator *it;
+  struct GNUNET_RECLAIM_AttestationIterator *it;
   struct GNUNET_RECLAIM_Operation *op;
-  size_t attr_len;
+  size_t att_len;
   uint32_t r_id = ntohl (msg->id);
 
-  attr_len = ntohs (msg->attr_len);
+  att_len = ntohs (msg->attestation_len);
   LOG (GNUNET_ERROR_TYPE_DEBUG, "Processing attestation result.\n");
 
 
-  for (it = h->it_head; NULL != it; it = it->next)
+  for (it = h->ait_head; NULL != it; it = it->next)
     if (it->r_id == r_id)
       break;
   for (op = h->op_head; NULL != op; op = op->next)
@@ -705,12 +834,12 @@ handle_attestation_result (void *cls, const struct AttributeResultMessage *msg)
     {
       if (NULL != it->finish_cb)
         it->finish_cb (it->finish_cb_cls);
-      free_it (it);
+      free_ait (it);
     }
     if (NULL != op)
     {
-      if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, NULL, NULL, NULL, NULL);
+      if (NULL != op->at_cb)
+        op->at_cb (op->cls, NULL, NULL);
       GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
       free_op (op);
     }
@@ -718,128 +847,25 @@ handle_attestation_result (void *cls, const struct AttributeResultMessage *msg)
   }
 
   {
-    struct GNUNET_RECLAIM_ATTESTATION_Claim *attr;
-    attr = GNUNET_RECLAIM_ATTESTATION_deserialize ((char *) &msg[1], attr_len);
+    struct GNUNET_RECLAIM_Attestation *att;
+    att = GNUNET_RECLAIM_attestation_deserialize ((char *) &msg[1], att_len);
+
     if (NULL != it)
     {
       if (NULL != it->proc)
-        it->proc (it->proc_cls, &msg->identity, NULL, attr, NULL);
+        it->proc (it->proc_cls, &msg->identity, att);
     }
     else if (NULL != op)
     {
-      if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, &msg->identity, NULL, attr, NULL);
+      if (NULL != op->at_cb)
+        op->at_cb (op->cls, &msg->identity, att);
     }
-    GNUNET_free (attr);
+    GNUNET_free (att);
     return;
   }
   GNUNET_assert (0);
 }
 
-/**
-   * Handle an incoming message of type
-   * #GNUNET_MESSAGE_TYPE_RECLAIM_REFERENCE_RESULT
-   *
-   * @param cls
-   * @param msg the message we received
-   * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
-   */
-static int
-check_reference_result (void *cls, const struct ReferenceResultMessage *msg)
-{
-  size_t msg_len;
-  size_t attr_len;
-  size_t ref_len;
-
-  msg_len = ntohs (msg->header.size);
-  attr_len = ntohs (msg->attest_len);
-  ref_len = ntohs (msg->ref_len);
-  if (msg_len != sizeof(struct ReferenceResultMessage) + attr_len + ref_len)
-  {
-    GNUNET_break (0);
-    return GNUNET_SYSERR;
-  }
-  return GNUNET_OK;
-}
-
-/**
-* Handle an incoming message of type
-* #GNUNET_MESSAGE_TYPE_RECLAIM_REFERENCE_RESULT
-*
-* @param cls
-* @param msg the message we received
-*/
-static void
-handle_reference_result (void *cls, const struct ReferenceResultMessage *msg)
-{
-  static struct GNUNET_CRYPTO_EcdsaPrivateKey identity_dummy;
-  struct GNUNET_RECLAIM_Handle *h = cls;
-  struct GNUNET_RECLAIM_AttributeIterator *it;
-  struct GNUNET_RECLAIM_Operation *op;
-  size_t attest_len;
-  size_t ref_len;
-  uint32_t r_id = ntohl (msg->id);
-  attest_len = ntohs (msg->attest_len);
-  ref_len = ntohs (msg->ref_len);
-  LOG (GNUNET_ERROR_TYPE_DEBUG, "Processing reference result.\n");
-  for (it = h->it_head; NULL != it; it = it->next)
-    if (it->r_id == r_id)
-      break;
-  for (op = h->op_head; NULL != op; op = op->next)
-    if (op->r_id == r_id)
-      break;
-  if ((NULL == it) && (NULL == op))
-    return;
-
-  if ((0 ==
-       (memcmp (&msg->identity, &identity_dummy, sizeof(identity_dummy)))))
-  {
-    if ((NULL == it) && (NULL == op))
-    {
-      GNUNET_break (0);
-      force_reconnect (h);
-      return;
-    }
-    if (NULL != it)
-    {
-      if (NULL != it->finish_cb)
-        it->finish_cb (it->finish_cb_cls);
-      free_it (it);
-    }
-    if (NULL != op)
-    {
-      if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, NULL, NULL, NULL, NULL);
-      GNUNET_CONTAINER_DLL_remove (h->op_head, h->op_tail, op);
-      free_op (op);
-    }
-    return;
-  }
-
-  {
-    struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *ref;
-    struct GNUNET_RECLAIM_ATTESTATION_Claim *attest;
-    attest = GNUNET_RECLAIM_ATTESTATION_deserialize ((char *) &msg[1],
-                                                     attest_len);
-    ref = GNUNET_RECLAIM_ATTESTATION_REF_deserialize ((char *) &msg[1]
-                                                      + attest_len,
-                                                      ref_len);
-    if (NULL != it)
-    {
-      if (NULL != it->proc)
-        it->proc (it->proc_cls, &msg->identity, NULL, attest, ref);
-    }
-    else if (NULL != op)
-    {
-      if (NULL != op->ar_cb)
-        op->ar_cb (op->cls, &msg->identity, NULL, attest, ref);
-    }
-    GNUNET_free (ref);
-    GNUNET_free (attest);
-    return;
-  }
-  GNUNET_assert (0);
-}
 
 /**
  * Handle an incoming message of type
@@ -961,11 +987,7 @@ reconnect (struct GNUNET_RECLAIM_Handle *h)
                            h),
     GNUNET_MQ_hd_var_size (attestation_result,
                            GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_RESULT,
-                           struct AttributeResultMessage,
-                           h),
-    GNUNET_MQ_hd_var_size (reference_result,
-                           GNUNET_MESSAGE_TYPE_RECLAIM_REFERENCE_RESULT,
-                           struct ReferenceResultMessage,
+                           struct AttestationResultMessage,
                            h),
     GNUNET_MQ_hd_fixed_size (ticket_result,
                              GNUNET_MESSAGE_TYPE_RECLAIM_TICKET_RESULT,
@@ -1075,7 +1097,7 @@ struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attribute_store (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
+  const struct GNUNET_RECLAIM_Attribute *attr,
   const struct GNUNET_TIME_Relative *exp_interval,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
@@ -1090,7 +1112,7 @@ GNUNET_RECLAIM_attribute_store (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTRIBUTE_serialize_get_size (attr);
+  attr_len = GNUNET_RECLAIM_attribute_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (sam,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTRIBUTE_STORE);
@@ -1098,7 +1120,7 @@ GNUNET_RECLAIM_attribute_store (
   sam->id = htonl (op->r_id);
   sam->exp = GNUNET_htonll (exp_interval->rel_value_us);
 
-  GNUNET_RECLAIM_ATTRIBUTE_serialize (attr, (char *) &sam[1]);
+  GNUNET_RECLAIM_attribute_serialize (attr, (char *) &sam[1]);
 
   sam->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1122,7 +1144,7 @@ struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attribute_delete (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTRIBUTE_Claim *attr,
+  const struct GNUNET_RECLAIM_Attribute *attr,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
 {
@@ -1136,13 +1158,13 @@ GNUNET_RECLAIM_attribute_delete (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTRIBUTE_serialize_get_size (attr);
+  attr_len = GNUNET_RECLAIM_attribute_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (dam,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTRIBUTE_DELETE);
   dam->identity = *pkey;
   dam->id = htonl (op->r_id);
-  GNUNET_RECLAIM_ATTRIBUTE_serialize (attr, (char *) &dam[1]);
+  GNUNET_RECLAIM_attribute_serialize (attr, (char *) &dam[1]);
 
   dam->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1150,6 +1172,7 @@ GNUNET_RECLAIM_attribute_delete (
   return op;
 }
 
+
 /**
    * Store an attestation.  If the attestation is already present,
    * it is replaced with the new attestation.
@@ -1166,7 +1189,7 @@ struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attestation_store (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTESTATION_Claim *attr,
+  const struct GNUNET_RECLAIM_Attestation *attr,
   const struct GNUNET_TIME_Relative *exp_interval,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
@@ -1181,7 +1204,7 @@ GNUNET_RECLAIM_attestation_store (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTESTATION_serialize_get_size (attr);
+  attr_len = GNUNET_RECLAIM_attestation_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (sam,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_STORE);
@@ -1189,7 +1212,7 @@ GNUNET_RECLAIM_attestation_store (
   sam->id = htonl (op->r_id);
   sam->exp = GNUNET_htonll (exp_interval->rel_value_us);
 
-  GNUNET_RECLAIM_ATTESTATION_serialize (attr, (char *) &sam[1]);
+  GNUNET_RECLAIM_attestation_serialize (attr, (char *) &sam[1]);
 
   sam->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1197,6 +1220,7 @@ GNUNET_RECLAIM_attestation_store (
   return op;
 }
 
+
 /**
    * Delete an attestation. Tickets used to share this attestation are updated
    * accordingly.
@@ -1212,7 +1236,7 @@ struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attestation_delete (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTESTATION_Claim *attr,
+  const struct GNUNET_RECLAIM_Attestation *attr,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
 {
@@ -1226,13 +1250,13 @@ GNUNET_RECLAIM_attestation_delete (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTESTATION_serialize_get_size (attr);
+  attr_len = GNUNET_RECLAIM_attestation_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (dam,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_DELETE);
   dam->identity = *pkey;
   dam->id = htonl (op->r_id);
-  GNUNET_RECLAIM_ATTESTATION_serialize (attr, (char *) &dam[1]);
+  GNUNET_RECLAIM_attestation_serialize (attr, (char *) &dam[1]);
 
   dam->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1240,95 +1264,6 @@ GNUNET_RECLAIM_attestation_delete (
   return op;
 }
 
-/**
-   * Store an attestation reference.  If the reference is already present,
-   * it is replaced with the new reference.
-   *
-   * @param h handle to the re:claimID service
-   * @param pkey private key of the identity
-   * @param attr the reference value
-   * @param exp_interval the relative expiration interval for the reference
-   * @param cont continuation to call when done
-   * @param cont_cls closure for @a cont
-   * @return handle to abort the request
-   */
-struct GNUNET_RECLAIM_Operation *
-GNUNET_RECLAIM_attestation_reference_store (
-  struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *attr,
-  const struct GNUNET_TIME_Relative *exp_interval,
-  GNUNET_RECLAIM_ContinuationWithStatus cont,
-  void *cont_cls)
-{
-  struct GNUNET_RECLAIM_Operation *op;
-  struct AttributeStoreMessage *sam;
-  size_t attr_len;
-  op = GNUNET_new (struct GNUNET_RECLAIM_Operation);
-  op->h = h;
-  op->as_cb = cont;
-  op->cls = cont_cls;
-  op->r_id = h->r_id_gen++;
-  GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTESTATION_REF_serialize_get_size (attr);
-  op->env = GNUNET_MQ_msg_extra (sam,
-                                 attr_len,
-                                 GNUNET_MESSAGE_TYPE_RECLAIM_REFERENCE_STORE);
-  sam->identity = *pkey;
-  sam->id = htonl (op->r_id);
-  sam->exp = GNUNET_htonll (exp_interval->rel_value_us);
-
-  GNUNET_RECLAIM_ATTESTATION_REF_serialize (attr, (char *) &sam[1]);
-
-  sam->attr_len = htons (attr_len);
-  if (NULL != h->mq)
-    GNUNET_MQ_send_copy (h->mq, op->env);
-  return op;
-}
-
-/**
- * Delete an attestation reference. Tickets used to share this reference are updated
- * accordingly.
- *
- * @param h handle to the re:claimID service
- * @param pkey Private key of the identity to delete the reference from
- * @param attr The reference
- * @param cont Continuation to call when done
- * @param cont_cls Closure for @a cont
- * @return handle Used to to abort the request
- */
-struct GNUNET_RECLAIM_Operation *
-GNUNET_RECLAIM_attestation_reference_delete (
-  struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_EcdsaPrivateKey *pkey,
-  const struct GNUNET_RECLAIM_ATTESTATION_REFERENCE *attr,
-  GNUNET_RECLAIM_ContinuationWithStatus cont,
-  void *cont_cls)
-{
-
-  struct GNUNET_RECLAIM_Operation *op;
-  struct AttributeDeleteMessage *dam;
-  size_t attr_len;
-
-  op = GNUNET_new (struct GNUNET_RECLAIM_Operation);
-  op->h = h;
-  op->as_cb = cont;
-  op->cls = cont_cls;
-  op->r_id = h->r_id_gen++;
-  GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTESTATION_REF_serialize_get_size (attr);
-  op->env = GNUNET_MQ_msg_extra (dam,
-                                 attr_len,
-                                 GNUNET_MESSAGE_TYPE_RECLAIM_REFERENCE_DELETE);
-  dam->identity = *pkey;
-  dam->id = htonl (op->r_id);
-  GNUNET_RECLAIM_ATTESTATION_REF_serialize (attr, (char *) &dam[1]);
-
-  dam->attr_len = htons (attr_len);
-  if (NULL != h->mq)
-    GNUNET_MQ_send_copy (h->mq, op->env);
-  return op;
-}
 
 /**
  * List all attributes for a local identity.
@@ -1439,6 +1374,119 @@ GNUNET_RECLAIM_get_attributes_stop (struct GNUNET_RECLAIM_AttributeIterator *it)
 }
 
 
+/**
+ * List all attestations for a local identity.
+ * This MUST lock the `struct GNUNET_RECLAIM_Handle`
+ * for any other calls than #GNUNET_RECLAIM_get_attestations_next() and
+ * #GNUNET_RECLAIM_get_attestations_stop. @a proc will be called once
+ * immediately, and then again after
+ * #GNUNET_RECLAIM_get_attestations_next() is invoked.
+ *
+ * On error (disconnect), @a error_cb will be invoked.
+ * On normal completion, @a finish_cb proc will be
+ * invoked.
+ *
+ * @param h Handle to the re:claimID service
+ * @param identity Identity to iterate over
+ * @param error_cb Function to call on error (i.e. disconnect),
+ *        the handle is afterwards invalid
+ * @param error_cb_cls Closure for @a error_cb
+ * @param proc Function to call on each attestation
+ * @param proc_cls Closure for @a proc
+ * @param finish_cb Function to call on completion
+ *        the handle is afterwards invalid
+ * @param finish_cb_cls Closure for @a finish_cb
+ * @return an iterator Handle to use for iteration
+ */
+struct GNUNET_RECLAIM_AttestationIterator *
+GNUNET_RECLAIM_get_attestations_start (
+  struct GNUNET_RECLAIM_Handle *h,
+  const struct GNUNET_CRYPTO_EcdsaPrivateKey *identity,
+  GNUNET_SCHEDULER_TaskCallback error_cb,
+  void *error_cb_cls,
+  GNUNET_RECLAIM_AttestationResult proc,
+  void *proc_cls,
+  GNUNET_SCHEDULER_TaskCallback finish_cb,
+  void *finish_cb_cls)
+{
+  struct GNUNET_RECLAIM_AttestationIterator *ait;
+  struct GNUNET_MQ_Envelope *env;
+  struct AttestationIterationStartMessage *msg;
+  uint32_t rid;
+
+  rid = h->r_id_gen++;
+  ait = GNUNET_new (struct GNUNET_RECLAIM_AttestationIterator);
+  ait->h = h;
+  ait->error_cb = error_cb;
+  ait->error_cb_cls = error_cb_cls;
+  ait->finish_cb = finish_cb;
+  ait->finish_cb_cls = finish_cb_cls;
+  ait->proc = proc;
+  ait->proc_cls = proc_cls;
+  ait->r_id = rid;
+  ait->identity = *identity;
+  GNUNET_CONTAINER_DLL_insert_tail (h->ait_head, h->ait_tail, ait);
+  env =
+    GNUNET_MQ_msg (msg,
+                   GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_ITERATION_START);
+  msg->id = htonl (rid);
+  msg->identity = *identity;
+  if (NULL == h->mq)
+    ait->env = env;
+  else
+    GNUNET_MQ_send (h->mq, env);
+  return ait;
+}
+
+
+/**
+ * Calls the record processor specified in #GNUNET_RECLAIM_get_attestation_start
+ * for the next record.
+ *
+ * @param it the iterator
+ */
+void
+GNUNET_RECLAIM_get_attestations_next (struct
+                                      GNUNET_RECLAIM_AttestationIterator *ait)
+{
+  struct GNUNET_RECLAIM_Handle *h = ait->h;
+  struct AttestationIterationNextMessage *msg;
+  struct GNUNET_MQ_Envelope *env;
+
+  env =
+    GNUNET_MQ_msg (msg, GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_ITERATION_NEXT);
+  msg->id = htonl (ait->r_id);
+  GNUNET_MQ_send (h->mq, env);
+}
+
+
+/**
+ * Stops iteration and releases the handle for further calls. Must
+ * be called on any iteration that has not yet completed prior to calling
+ * #GNUNET_RECLAIM_disconnect.
+ *
+ * @param it the iterator
+ */
+void
+GNUNET_RECLAIM_get_attestations_stop (struct
+                                      GNUNET_RECLAIM_AttestationIterator *ait)
+{
+  struct GNUNET_RECLAIM_Handle *h = ait->h;
+  struct GNUNET_MQ_Envelope *env;
+  struct AttestationIterationStopMessage *msg;
+
+  if (NULL != h->mq)
+  {
+    env =
+      GNUNET_MQ_msg (msg,
+                     GNUNET_MESSAGE_TYPE_RECLAIM_ATTESTATION_ITERATION_STOP);
+    msg->id = htonl (ait->r_id);
+    GNUNET_MQ_send (h->mq, env);
+  }
+  free_ait (ait);
+}
+
+
 /**
  * Issues a ticket to another relying party. The identity may use
  * @GNUNET_RECLAIM_ticket_consume to consume the ticket
@@ -1457,7 +1505,7 @@ GNUNET_RECLAIM_ticket_issue (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *iss,
   const struct GNUNET_CRYPTO_EcdsaPublicKey *rp,
-  const struct GNUNET_RECLAIM_ATTRIBUTE_ClaimList *attrs,
+  const struct GNUNET_RECLAIM_AttributeList *attrs,
   GNUNET_RECLAIM_TicketCallback cb,
   void *cb_cls)
 {
@@ -1472,7 +1520,7 @@ GNUNET_RECLAIM_ticket_issue (
   op->cls = cb_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  attr_len = GNUNET_RECLAIM_ATTRIBUTE_list_serialize_get_size (attrs);
+  attr_len = GNUNET_RECLAIM_attribute_list_serialize_get_size (attrs);
   op->env = GNUNET_MQ_msg_extra (tim,
                                  attr_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ISSUE_TICKET);
@@ -1480,7 +1528,7 @@ GNUNET_RECLAIM_ticket_issue (
   tim->rp = *rp;
   tim->id = htonl (op->r_id);
 
-  GNUNET_RECLAIM_ATTRIBUTE_list_serialize (attrs, (char *) &tim[1]);
+  GNUNET_RECLAIM_attribute_list_serialize (attrs, (char *) &tim[1]);
 
   tim->attr_len = htons (attr_len);
   if (NULL != h->mq)
@@ -1506,7 +1554,7 @@ GNUNET_RECLAIM_ticket_consume (
   struct GNUNET_RECLAIM_Handle *h,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *identity,
   const struct GNUNET_RECLAIM_Ticket *ticket,
-  GNUNET_RECLAIM_AttributeResult cb,
+  GNUNET_RECLAIM_AttributeTicketResult cb,
   void *cb_cls)
 {
   struct GNUNET_RECLAIM_Operation *op;
@@ -1514,7 +1562,7 @@ GNUNET_RECLAIM_ticket_consume (
 
   op = GNUNET_new (struct GNUNET_RECLAIM_Operation);
   op->h = h;
-  op->ar_cb = cb;
+  op->atr_cb = cb;
   op->cls = cb_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
