@@ -160,7 +160,8 @@ struct STATcls
  *
  * @return corresponding enum
  */
-enum STAT_TYPE stat_str_2_type (const char *stat_str)
+enum STAT_TYPE
+stat_str_2_type (const char *stat_str)
 {
   if (0 == strncmp (stat_type_strings[STAT_TYPE_BLOCKS_NO_PULL],
                     stat_str,
@@ -890,9 +891,7 @@ tofile_ (const char *file_name, const char *line)
                 "Failed to write string to buffer (size: %i)\n",
                 size);
      return;
-     } */
-
-  size = strlen (line) * sizeof(char);
+     } */size = strlen (line) * sizeof(char);
 
   size2 = GNUNET_DISK_file_write (f, line, size);
   if (size != size2)
@@ -916,6 +915,7 @@ tofile_ (const char *file_name, const char *line)
   }
 }
 
+
 /**
  * This function is used to facilitate writing important information to disk
  */
@@ -1000,7 +1000,8 @@ make_oplist_entry ()
  * @return #GNUNET_YES if so
  *         #GNUNET_NO otherwise
  */
-static int check_statistics_collect_completed_single_peer (
+static int
+check_statistics_collect_completed_single_peer (
   const struct RPSPeer *rps_peer)
 {
   if (cur_test_run.stat_collect_flags !=
@@ -1011,6 +1012,8 @@ static int check_statistics_collect_completed_single_peer (
   }
   return GNUNET_YES;
 }
+
+
 /**
  * @brief Checks if all peers already received their statistics value from the
  * statistics service.
@@ -1018,7 +1021,8 @@ static int check_statistics_collect_completed_single_peer (
  * @return #GNUNET_YES if so
  *         #GNUNET_NO otherwise
  */
-static int check_statistics_collect_completed ()
+static int
+check_statistics_collect_completed ()
 {
   uint32_t i;
 
@@ -1039,6 +1043,7 @@ static int check_statistics_collect_completed ()
   return GNUNET_YES;
 }
 
+
 static void
 rps_disconnect_adapter (void *cls,
                         void *op_result);
@@ -1059,6 +1064,7 @@ cancel_pending_req (struct PendingRequest *pending_req)
   GNUNET_free (pending_req);
 }
 
+
 static void
 cancel_request (struct PendingReply *pending_rep)
 {
@@ -1078,6 +1084,7 @@ cancel_request (struct PendingReply *pending_rep)
   pending_rep = NULL;
 }
 
+
 void
 clean_peer (unsigned peer_index)
 {
@@ -1111,6 +1118,7 @@ clean_peer (unsigned peer_index)
   }
 }
 
+
 /**
  * Task run on timeout to shut everything down.
  */
@@ -1158,6 +1166,7 @@ shutdown_op (void *cls)
   close_all_files ();
 }
 
+
 static void
 trigger_shutdown (void *cls)
 {
@@ -1209,7 +1218,7 @@ post_test_op (void *cls)
     }
   }
   /* If we do not collect statistics, shut down directly */
-  if ((NO_COLLECT_STATISTICS == cur_test_run.have_collect_statistics)||
+  if ((NO_COLLECT_STATISTICS == cur_test_run.have_collect_statistics) ||
       (GNUNET_YES == check_statistics_collect_completed ()) )
   {
     GNUNET_SCHEDULER_cancel (shutdown_task);
@@ -1255,12 +1264,12 @@ info_cb (void *cb_cls,
 
   (void) op;
 
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
 
-  if ((NULL == pinfo)||(NULL != emsg))
+  if ((NULL == pinfo) || (NULL != emsg))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR, "Got Error: %s\n", emsg);
     GNUNET_TESTBED_operation_done (entry->op);
@@ -1309,7 +1318,7 @@ rps_connect_complete_cb (void *cls,
   struct RPSPeer *rps_peer = cls;
   struct GNUNET_RPS_Handle *rps = ca_result;
 
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
@@ -1361,6 +1370,7 @@ rps_connect_adapter (void *cls,
   return h;
 }
 
+
 /**
  * Called to open a connection to the peer's statistics
  *
@@ -1380,6 +1390,7 @@ stat_connect_adapter (void *cls,
   return peer->stats_h;
 }
 
+
 /**
  * Called to disconnect from peer's statistics service
  *
@@ -1401,6 +1412,7 @@ stat_disconnect_adapter (void *cls, void *op_result)
   peer->stats_h = NULL;
 }
 
+
 /**
  * Called after successfully opening a connection to a peer's statistics
  * service; we register statistics monitoring for CORE and NSE here.
@@ -1551,7 +1563,7 @@ request_peers (void *cls)
                                rps_peer->pending_req_tail,
                                pending_req);
   rps_peer->num_pending_reqs--;
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
     return;
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Requesting one peer\n");
@@ -1604,6 +1616,7 @@ schedule_missing_requests (struct RPSPeer *rps_peer)
   }
 }
 
+
 void
 cancel_pending_req_rep (struct RPSPeer *rps_peer)
 {
@@ -1617,6 +1630,7 @@ cancel_pending_req_rep (struct RPSPeer *rps_peer)
   GNUNET_assert (0 == rps_peer->num_pending_reps);
 }
 
+
 /***********************************
 * MALICIOUS
 ***********************************/
@@ -1624,7 +1638,8 @@ cancel_pending_req_rep (struct RPSPeer *rps_peer)
 /**
  * Initialise only non-mal RPSPeers
  */
-static void mal_init_peer (struct RPSPeer *rps_peer)
+static void
+mal_init_peer (struct RPSPeer *rps_peer)
 {
   if (rps_peer->index >= round (portion * num_peers))
     rps_peer->num_ids_to_request = 1;
@@ -1664,12 +1679,13 @@ mal_pre (struct RPSPeer *rps_peer, struct GNUNET_RPS_Handle *h)
   #endif /* ENABLE_MALICIOUS */
 }
 
+
 static void
 mal_cb (struct RPSPeer *rps_peer)
 {
   uint32_t num_mal_peers;
 
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
@@ -1690,6 +1706,7 @@ mal_cb (struct RPSPeer *rps_peer)
   #endif /* ENABLE_MALICIOUS */
 }
 
+
 /***********************************
 * CHURN
 ***********************************/
@@ -1711,13 +1728,13 @@ churn (void *cls);
 static void
 churn_test_cb (struct RPSPeer *rps_peer)
 {
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
 
   /* Start churn */
-  if ((HAVE_CHURN == cur_test_run.have_churn)&&(NULL == churn_task))
+  if ((HAVE_CHURN == cur_test_run.have_churn) && (NULL == churn_task))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Starting churn task\n");
@@ -1735,6 +1752,7 @@ churn_test_cb (struct RPSPeer *rps_peer)
   schedule_missing_requests (rps_peer);
 }
 
+
 /***********************************
 * PROFILER
 ***********************************/
@@ -1756,7 +1774,7 @@ churn_cb (void *cls,
 
   (void) op;
 
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
@@ -1828,6 +1846,7 @@ churn_cb (void *cls,
   //  run_round ();
 }
 
+
 /**
  * @brief Set the rps-service up or down for a specific peer
  *
@@ -1895,7 +1914,7 @@ churn (void *cls)
 
   (void) cls;
 
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
@@ -1956,7 +1975,8 @@ churn (void *cls)
 /**
  * Initialise given RPSPeer
  */
-static void profiler_init_peer (struct RPSPeer *rps_peer)
+static void
+profiler_init_peer (struct RPSPeer *rps_peer)
 {
   rps_peer->num_ids_to_request = cur_test_run.num_requests;
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "peer shall request %i peers\n",
@@ -2111,13 +2131,13 @@ profiler_reply_handle_info (void *cls,
 static void
 profiler_cb (struct RPSPeer *rps_peer)
 {
-  if ((GNUNET_YES == in_shutdown)||(GNUNET_YES == post_test))
+  if ((GNUNET_YES == in_shutdown) || (GNUNET_YES == post_test))
   {
     return;
   }
 
   /* Start churn */
-  if ((HAVE_CHURN == cur_test_run.have_churn)&&(NULL == churn_task))
+  if ((HAVE_CHURN == cur_test_run.have_churn) && (NULL == churn_task))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Starting churn task\n");
@@ -2139,6 +2159,7 @@ profiler_cb (struct RPSPeer *rps_peer)
     schedule_missing_requests (rps_peer);
 }
 
+
 /**
  * Function called from #profiler_eval with a filename.
  *
@@ -2175,6 +2196,7 @@ file_name_cb (void *cls, const char *filename)
   return GNUNET_OK;
 }
 
+
 /**
  * This is run after the test finished.
  *
@@ -2202,7 +2224,8 @@ profiler_eval (void)
  *
  * @return
  */
-static int is_in_view (uint32_t a, uint32_t b)
+static int
+is_in_view (uint32_t a, uint32_t b)
 {
   uint32_t i;
 
@@ -2218,7 +2241,9 @@ static int is_in_view (uint32_t a, uint32_t b)
   return GNUNET_NO;
 }
 
-static uint32_t get_idx_of_pid (const struct GNUNET_PeerIdentity *pid)
+
+static uint32_t
+get_idx_of_pid (const struct GNUNET_PeerIdentity *pid)
 {
   uint32_t i;
 
@@ -2238,6 +2263,7 @@ static uint32_t get_idx_of_pid (const struct GNUNET_PeerIdentity *pid)
   GNUNET_assert (0);
 }
 
+
 /**
  * @brief Counts number of peers in view of a that have b in their view
  *
@@ -2246,7 +2272,8 @@ static uint32_t get_idx_of_pid (const struct GNUNET_PeerIdentity *pid)
  *
  * @return
  */
-static uint32_t count_containing_views (uint32_t a, uint32_t b)
+static uint32_t
+count_containing_views (uint32_t a, uint32_t b)
 {
   uint32_t i;
   uint32_t peer_idx;
@@ -2263,13 +2290,15 @@ static uint32_t count_containing_views (uint32_t a, uint32_t b)
   return count;
 }
 
+
 /**
  * @brief Computes the probability for each other peer to be selected by the
  * sampling process based on the views of all peers
  *
  * @param peer_idx index of the peer that is about to sample
  */
-static void compute_probabilities (uint32_t peer_idx)
+static void
+compute_probabilities (uint32_t peer_idx)
 {
   // double probs[num_peers] = { 0 };
   double probs[num_peers];
@@ -2427,6 +2456,7 @@ static void compute_probabilities (uint32_t peer_idx)
   GNUNET_free (probs_as_str);
 }
 
+
 /**
  * @brief This counts the number of peers in which views a given peer occurs.
  *
@@ -2436,7 +2466,8 @@ static void compute_probabilities (uint32_t peer_idx)
  *
  * @return the number of occurrences
  */
-static uint32_t count_peer_in_views_2 (uint32_t peer_idx)
+static uint32_t
+count_peer_in_views_2 (uint32_t peer_idx)
 {
   uint32_t i, j;
   uint32_t count = 0;
@@ -2458,7 +2489,9 @@ static uint32_t count_peer_in_views_2 (uint32_t peer_idx)
   return count;
 }
 
-static uint32_t cumulated_view_sizes ()
+
+static uint32_t
+cumulated_view_sizes ()
 {
   uint32_t i;
 
@@ -2470,7 +2503,9 @@ static uint32_t cumulated_view_sizes ()
   return view_sizes;
 }
 
-static void count_peer_in_views (uint32_t *count_peers)
+
+static void
+count_peer_in_views (uint32_t *count_peers)
 {
   uint32_t i, j;
 
@@ -2488,7 +2523,9 @@ static void count_peer_in_views (uint32_t *count_peers)
   }
 }
 
-void compute_diversity ()
+
+void
+compute_diversity ()
 {
   uint32_t i;
   /* ith entry represents the numer of occurrences in other peer's views */
@@ -2531,7 +2568,9 @@ void compute_diversity ()
   GNUNET_free (deviation);
 }
 
-void print_view_sizes ()
+
+void
+print_view_sizes ()
 {
   uint32_t i;
 
@@ -2545,15 +2584,19 @@ void print_view_sizes ()
   }
 }
 
-void all_views_updated_cb ()
+
+void
+all_views_updated_cb ()
 {
   compute_diversity ();
   print_view_sizes ();
 }
 
-void view_update_cb (void *cls,
-                     uint64_t view_size,
-                     const struct GNUNET_PeerIdentity *peers)
+
+void
+view_update_cb (void *cls,
+                uint64_t view_size,
+                const struct GNUNET_PeerIdentity *peers)
 {
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "View was updated (%" PRIu64 ")\n", view_size);
@@ -2602,6 +2645,7 @@ void view_update_cb (void *cls,
   all_views_updated_cb ();
 }
 
+
 static void
 pre_profiler (struct RPSPeer *rps_peer, struct GNUNET_RPS_Handle *h)
 {
@@ -2612,7 +2656,9 @@ pre_profiler (struct RPSPeer *rps_peer, struct GNUNET_RPS_Handle *h)
   GNUNET_RPS_view_request (h, 0, view_update_cb, rps_peer);
 }
 
-void write_final_stats (void)
+
+void
+write_final_stats (void)
 {
   uint64_t sums[STAT_TYPE_MAX] = { 0 };
 
@@ -2732,6 +2778,7 @@ void write_final_stats (void)
            sums[STAT_TYPE_VIEW_SIZE_AIM]);
 }
 
+
 /**
  * Continuation called by #GNUNET_STATISTICS_get() functions.
  *
@@ -2766,7 +2813,7 @@ post_test_shutdown_ready_cb (void *cls,
     return;
   }
 
-  if ((NULL != rps_peer->stat_op)&&
+  if ((NULL != rps_peer->stat_op) &&
       (GNUNET_YES == check_statistics_collect_completed_single_peer (
          rps_peer)) )
   {
@@ -2788,6 +2835,7 @@ post_test_shutdown_ready_cb (void *cls,
   }
 }
 
+
 /**
  * Callback function to process statistic values.
  *
@@ -2907,7 +2955,7 @@ test_run (void *cls,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "RUN was called\n");
 
   /* Check whether we timed out */
-  if ((n_peers != num_peers)||
+  if ((n_peers != num_peers) ||
       (NULL == peers) ||
       (0 == links_succeeded) )
   {
@@ -3127,6 +3175,7 @@ run (void *cls,
                       NULL);
 }
 
+
 /**
  * Entry point for the testcase, sets up the testbed.
  *
@@ -3204,4 +3253,5 @@ main (int argc, char *argv[])
   return ret_value;
 }
 
+
 /* end of test_rps.c */
