@@ -207,8 +207,9 @@ decrypt_connect_complete (void *cls,
  * @param cls Plaintext
  * @param plaintext Plaintext
  */
-static void decrypt_cb (void *cls,
-                        const struct GNUNET_SECRETSHARING_Plaintext *plaintext)
+static void
+decrypt_cb (void *cls,
+            const struct GNUNET_SECRETSHARING_Plaintext *plaintext)
 {
   struct GNUNET_SECRETSHARING_DecryptionHandle **dhp = cls;
   unsigned int n = dhp - decrypt_handles;
@@ -244,7 +245,6 @@ static void decrypt_cb (void *cls,
 }
 
 
-
 /**
  * Adapter function called to establish a connection to
  * a service.
@@ -383,7 +383,6 @@ session_connect_adapter (void *cls,
 }
 
 
-
 /**
  * Adapter function called to destroy a connection to
  * a service.
