@@ -1,8 +1,8 @@
 /*
    This file is part of GNUnet.
    Copyright (C) 2010, 2011, 2012 GNUnet e.V.
-   Copyright (c) 2007, 2008, Andy Green <andy@warmcat.com>
-   Copyright Copyright (C) 2009 Thomas d'Otreppe
+   Copyright (C) 2007, 2008, Andy Green <andy@warmcat.com>
+   Copyright (C) 2009 Thomas d'Otreppe
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -21,7 +21,6 @@
  */
 #include "gnunet_config.h"
 
-#define SOCKTYPE int
 #include <bluetooth/bluetooth.h>
 #include <bluetooth/hci.h>
 #include <bluetooth/hci_lib.h>
@@ -116,7 +115,7 @@ struct SendBuffer
   char buf[MAXLINE * 2];
 };
 
-#ifdef LINUX
+#ifdef __linux__
 /**
  * Devices buffer used to keep a list with all the discoverable devices in
  * order to send them HELLO messages one by one when it receive a broadcast message.
@@ -446,6 +445,7 @@ do_align:
   return ret;
 }
 
+
 /**
  * Destroys a tokenizer.
  *
@@ -458,6 +458,7 @@ mst_destroy (struct MessageStreamTokenizer *mst)
   free (mst);
 }
 
+
 /**
  * Calculate crc32, the start of the calculation
  *
@@ -558,16 +559,15 @@ check_crc_buf_osdep (const unsigned char *buf, size_t len)
 
   crc = calc_crc_osdep (buf, len);
   buf += len;
-  if ((((crc) & 0xFF) == buf[0])&&(((crc >> 8) & 0xFF) == buf[1])&&
-      ( ((crc >> 16) & 0xFF) == buf[2]) &&( ((crc >> 24) & 0xFF) == buf[3]) )
+  if ((((crc) & 0xFF) == buf[0]) && (((crc >> 8) & 0xFF) == buf[1]) &&
+      ( ((crc >> 16) & 0xFF) == buf[2]) && ( ((crc >> 24) & 0xFF) == buf[3]) )
     return 0;
   return 1;
 }
 
 
-
 /* ************** end of clone  ***************** */
-#ifdef LINUX
+#ifdef __linux__
 /**
  * Function for assigning a port number
  *
@@ -593,6 +593,8 @@ bind_socket (int socket, struct sockaddr_rc *addr)
 
   return -1;
 }
+
+
 #endif
 
 /**
@@ -613,8 +615,7 @@ register_service (struct HardwareInfos *dev, int rc_channel)
    * 5. set the name, provider and description
    * 6. register the service record to the local SDP server
    * 7. cleanup
-   */
-  uint8_t svc_uuid_int[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+   */uint8_t svc_uuid_int[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                              dev->pl_mac.mac[5], dev->pl_mac.mac[4],
                              dev->pl_mac.mac[3],
                              dev->pl_mac.mac[2], dev->pl_mac.mac[1],
@@ -688,6 +689,7 @@ register_service (struct HardwareInfos *dev, int rc_channel)
   return 0;
 }
 
+
 /**
  * Function used for searching and browsing for a service. This will return the
  * port number on which the service is running.
@@ -706,8 +708,7 @@ get_channel (struct HardwareInfos *dev, bdaddr_t dest)
    * 2.2. get a list of service records with the specific UUID
    * 2.3. for each service record get a list of the protocol sequences and get
    *       the port number
-   */
-  uint8_t svc_uuid_int[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+   */uint8_t svc_uuid_int[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                              dest.b[5], dest.b[4], dest.b[3],
                              dest.b[2], dest.b[1], dest.b[0] };
   sdp_session_t *session = 0;
@@ -736,7 +737,7 @@ get_channel (struct HardwareInfos *dev, bdaddr_t dest)
   {
     for (it = response_list; it; it = it->next)
     {
-      sdp_record_t *record = (sdp_record_t*) it->data;
+      sdp_record_t *record = (sdp_record_t *) it->data;
       sdp_list_t *proto_list = 0;
       if (sdp_get_access_protos (record, &proto_list) == 0)
       {
@@ -763,6 +764,7 @@ get_channel (struct HardwareInfos *dev, bdaddr_t dest)
   return channel;
 }
 
+
 /**
  * Read from the socket and put the result into the buffer for transmission to 'stdout'.
  *
@@ -793,7 +795,7 @@ read_from_the_socket (void *sock,
     return -1;
   }
 
-  #ifdef LINUX
+  #ifdef __linux__
   /* Get the channel used */
   int len;
   struct sockaddr_rc rc_addr = { 0 };
@@ -954,7 +956,6 @@ open_device (struct HardwareInfos *dev)
   (void) close (fd_hci);
 
 
-
   /* Bind the rfcomm socket to the interface */
   memset (&rc_addr, 0, sizeof(rc_addr));
   rc_addr.rc_family = AF_BLUETOOTH;
@@ -1010,7 +1011,8 @@ mac_set (struct GNUNET_TRANSPORT_WLAN_Ieee80211Frame *taIeeeHeader,
   taIeeeHeader->addr2 = dev->pl_mac;
 }
 
-#ifdef LINUX
+
+#ifdef __linux__
 /**
  * Test if the given interface name really corresponds to a bluetooth
  * device.
@@ -1038,6 +1040,8 @@ test_bluetooth_interface (const char *iface)
   }
   return 0;
 }
+
+
 #endif
 
 /**
@@ -1112,7 +1116,8 @@ stdin_send_hw (void *cls, const struct GNUNET_MessageHeader *hdr)
   write_pout.size = sendsize;
 }
 
-#ifdef LINUX
+
+#ifdef __linux__
 /**
  * Broadcast a HELLO message for peer discovery
  *
@@ -1127,7 +1132,7 @@ send_broadcast (struct HardwareInfos *dev, int *sendsocket)
   int loops = 0;
 
 search_for_devices:
-  if (((neighbours.size == neighbours.pos)&&(new_device == 1)) ||
+  if (((neighbours.size == neighbours.pos) && (new_device == 1)) ||
       (neighbours.size == 0) )
   {
 inquiry_devices:      // skip the conditions and force a inquiry for new devices
@@ -1359,6 +1364,8 @@ inquiry_devices:      // skip the conditions and force a inquiry for new devices
 
   return 0;
 }
+
+
 #endif
 
 /**
@@ -1375,7 +1382,7 @@ inquiry_devices:      // skip the conditions and force a inquiry for new devices
 int
 main (int argc, char *argv[])
 {
-#ifdef LINUX
+#ifdef __linux__
   struct HardwareInfos dev;
   char readbuf[MAXLINE];
   int maxfd;
@@ -1606,9 +1613,9 @@ main (int argc, char *argv[])
 connect_retry:
           status = connect (sendsocket, (struct sockaddr *) &addr,
                             sizeof(addr));
-          if ((0 != status) &&(errno != EAGAIN) )
+          if ((0 != status) && (errno != EAGAIN) )
           {
-            if ((errno == ECONNREFUSED) &&(tries < 2) )
+            if ((errno == ECONNREFUSED) && (tries < 2) )
             {
               fprintf (stderr, "LOG : %.*s failed to connect. Trying again!\n",
                        IFNAMSIZ, dev.iface);
@@ -1668,7 +1675,7 @@ connect_retry:
         int retval = select (maxfd + 1, &rfds, &wfds, NULL, NULL);
         if ((-1 == retval) && (EINTR == errno))
           continue;
-        if ((0 > retval) &&(errno != EBADF) ) // we handle BADF errors later
+        if ((0 > retval) && (errno != EBADF) ) // we handle BADF errors later
         {
           fprintf (stderr, "select failed: %s\n", strerror (errno));
           break;
