@@ -384,7 +384,7 @@ struct GNUNET_PEERINFO_Handle *GST_peerinfo;
 /**
  * Our private key.
  */
-struct GNUNET_CRYPTO_EddsaPrivateKey *GST_my_private_key;
+struct GNUNET_CRYPTO_EddsaPrivateKey GST_my_private_key;
 
 /**
  * ATS scheduling handle.
@@ -529,7 +529,10 @@ client_disconnect_cb (void *cls,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Client %p disconnected, cleaning up.\n",
               tc);
-  GNUNET_CONTAINER_multipeermap_iterate (active_stccs, &mark_match_down, tc);
+  if (NULL != active_stccs)
+    GNUNET_CONTAINER_multipeermap_iterate (active_stccs,
+                                           &mark_match_down,
+                                           tc);
   for (struct AddressToStringContext *cur = a2s_head; NULL != cur;
        cur = cur->next)
   {
@@ -724,9 +727,9 @@ handle_send_transmit_continuation (void *cls,
                 stcc->uuid);
     send_ok_msg.header.size = htons (sizeof(send_ok_msg));
     send_ok_msg.header.type = htons (GNUNET_MESSAGE_TYPE_TRANSPORT_SEND_OK);
-    send_ok_msg.bytes_msg = htonl (bytes_payload);
+    send_ok_msg.bytes_msg = htons (bytes_payload);
     send_ok_msg.bytes_physical = htonl (bytes_on_wire);
-    send_ok_msg.success = htonl (success);
+    send_ok_msg.success = htons (success);
     send_ok_msg.peer = stcc->target;
     unicast (stcc->tc, &send_ok_msg.header, GNUNET_NO);
   }
@@ -2105,7 +2108,7 @@ free_blacklist_entry (void *cls,
 {
   char *be = value;
 
-  GNUNET_free_non_null (be);
+  GNUNET_free (be);
   return GNUNET_OK;
 }
 
@@ -2180,11 +2183,6 @@ shutdown_task (void *cls)
     GNUNET_STATISTICS_destroy (GST_stats, GNUNET_NO);
     GST_stats = NULL;
   }
-  if (NULL != GST_my_private_key)
-  {
-    GNUNET_free (GST_my_private_key);
-    GST_my_private_key = NULL;
-  }
 }
 
 
@@ -2513,7 +2511,7 @@ GST_blacklist_test_cancel (struct GST_BlacklistCheck *bc)
     GNUNET_SCHEDULER_cancel (bc->task);
     bc->task = NULL;
   }
-  GNUNET_free_non_null (bc->address);
+  GNUNET_free (bc->address);
   GNUNET_free (bc);
 }
 
@@ -2608,7 +2606,6 @@ run (void *cls,
      struct GNUNET_SERVICE_Handle *service)
 {
   char *keyfile;
-  struct GNUNET_CRYPTO_EddsaPrivateKey *pk;
   long long unsigned int max_fd_cfg;
   int max_fd_rlimit;
   int max_fd;
@@ -2635,17 +2632,22 @@ run (void *cls,
   {
     hello_expiration = GNUNET_CONSTANTS_HELLO_ADDRESS_EXPIRATION;
   }
-  pk = GNUNET_CRYPTO_eddsa_key_create_from_file (keyfile);
+  if (GNUNET_SYSERR ==
+      GNUNET_CRYPTO_eddsa_key_from_file (keyfile,
+                                         GNUNET_YES,
+                                         &GST_my_private_key))
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Failed to setup peer's private key\n");
+    GNUNET_SCHEDULER_shutdown ();
+    GNUNET_free (keyfile);
+    return;
+  }
   GNUNET_free (keyfile);
-  GNUNET_assert (NULL != pk);
-  GST_my_private_key = pk;
-
   GST_stats = GNUNET_STATISTICS_create ("transport", GST_cfg);
   GST_peerinfo = GNUNET_PEERINFO_connect (GST_cfg);
-  GNUNET_CRYPTO_eddsa_key_get_public (GST_my_private_key,
+  GNUNET_CRYPTO_eddsa_key_get_public (&GST_my_private_key,
                                       &GST_my_identity.public_key);
-  GNUNET_assert (NULL != GST_my_private_key);
-
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "My identity is `%s'\n",
               GNUNET_i2s_full (&GST_my_identity));
