@@ -615,7 +615,7 @@ main (int argc, char *const *argv)
                         options,
                         &run,
                         NULL);
-  GNUNET_free ((void *) argv);
+  GNUNET_free_nz ((void *) argv);
   if (GNUNET_OK == res)
     return ret;
   return 1;
