@@ -33,10 +33,30 @@
 #include "gnunet_hello_lib.h"
 #include "gnunet_signatures.h"
 #include "transport.h"
-
+#include <inttypes.h>
 
 #define LOG(kind, ...) GNUNET_log_from (kind, "transport-testing2", __VA_ARGS__)
 
+struct MyClient
+{
+  struct MyClient *prev;
+  struct MyClient *next;
+  /**
+   * @brief Handle to the client
+   */
+  struct GNUNET_SERVICE_Client *client;
+
+  /**
+   * @brief Handle to the client
+   */
+  struct GNUNET_MQ_Handle *c_mq;
+
+  /**
+   * The TCH
+   */
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc;
+
+};
 
 /**
  * @brief Handle to a transport communicator
@@ -44,8 +64,19 @@
 struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle
 {
   /**
-   * @brief Handle to the configuration
+   * Clients
    */
+  struct MyClient *client_head;
+  struct MyClient *client_tail;
+
+  /**
+  * @brief Handle to the client
+  */
+  struct GNUNET_MQ_Handle *c_mq;
+
+  /**
+    * @brief Handle to the configuration
+    */
   struct GNUNET_CONFIGURATION_Handle *cfg;
 
   /**
@@ -53,6 +84,8 @@ struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle
    */
   char *cfg_filename;
 
+  struct GNUNET_PeerIdentity peer_id;
+
   /**
    * @brief Handle to the transport service
    */
@@ -64,15 +97,6 @@ struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle
    */
   struct GNUNET_SCHEDULER_Task *ts_shutdown_task;
 
-  /**
-   * @brief Handle to the client
-   */
-  struct GNUNET_SERVICE_Client *client;
-
-  /**
-   * @brief Handle to the client
-   */
-  struct GNUNET_MQ_Handle *c_mq;
 
   /**
    * @brief Process of the communicator
@@ -84,6 +108,11 @@ struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle
    */
   struct GNUNET_OS_Process *nat_proc;
 
+  /**
+   * resolver service process
+   */
+  struct GNUNET_OS_Process *resolver_proc;
+
   /**
    * @brief Task that will be run on shutdown to stop and clean communicator
    */
@@ -203,10 +232,20 @@ struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue
   uint32_t nt;
 
   /**
-   * Maximum transmission unit, in NBO.  UINT32_MAX for unlimited.
+   * Maximum transmission unit.  UINT32_MAX for unlimited.
    */
   uint32_t mtu;
 
+  /**
+   * Queue length.  UINT64_MAX for unlimited.
+   */
+  uint64_t q_len;
+
+  /**
+   * Queue prio
+   */
+  uint32_t priority;
+
   /**
    * An `enum GNUNET_TRANSPORT_ConnectionStatus` in NBO.
    */
@@ -269,12 +308,18 @@ handle_communicator_available (
   void *cls,
   const struct GNUNET_TRANSPORT_CommunicatorAvailableMessage *msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
   uint16_t size;
+  tc_h->c_mq = client->c_mq;
 
   size = ntohs (msg->header.size) - sizeof(*msg);
   if (0 == size)
+  {
+    GNUNET_SERVICE_client_continue (client->client);
     return; /* receive-only communicator */
+  }
   tc_h->c_characteristics = ntohl (msg->cc);
   tc_h->c_addr_prefix = GNUNET_strdup ((const char *) &msg[1]);
   if (NULL != tc_h->communicator_available_cb)
@@ -285,7 +330,9 @@ handle_communicator_available (
                                      tc_h->c_characteristics,
                                      tc_h->c_addr_prefix);
   }
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "finished communicator_available_cb()\n");
+
 }
 
 
@@ -327,7 +374,9 @@ handle_communicator_backchannel (void *cls,
                                  GNUNET_TRANSPORT_CommunicatorBackchannel *
                                  bc_msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
   struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *other_tc_h;
   struct GNUNET_MessageHeader *msg;
   msg = (struct GNUNET_MessageHeader *) &bc_msg[1];
@@ -336,30 +385,31 @@ handle_communicator_backchannel (void *cls,
   struct GNUNET_TRANSPORT_CommunicatorBackchannelIncoming *cbi;
   struct GNUNET_MQ_Envelope *env;
 
-
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Received backchannel message\n");
   if (tc_h->bc_enabled != GNUNET_YES)
   {
-    GNUNET_SERVICE_client_continue (tc_h->client);
+    GNUNET_SERVICE_client_continue (client->client);
     return;
   }
   /* Find client providing this communicator */
   /* Finally, deliver backchannel message to communicator */
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Delivering backchannel message of type %u to %s\n",
-              ntohs (msg->type),
-              target_communicator);
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Delivering backchannel message of type %u to %s\n",
+       ntohs (msg->type),
+       target_communicator);
   other_tc_h = tc_h->bc_cb (tc_h, msg, (struct
                                         GNUNET_PeerIdentity*) &bc_msg->pid);
   env = GNUNET_MQ_msg_extra (
     cbi,
     isize,
     GNUNET_MESSAGE_TYPE_TRANSPORT_COMMUNICATOR_BACKCHANNEL_INCOMING);
-  cbi->pid = bc_msg->pid;
+  cbi->pid = tc_h->peer_id;
   memcpy (&cbi[1], msg, isize);
 
 
   GNUNET_MQ_send (other_tc_h->c_mq, env);
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -396,7 +446,9 @@ static void
 handle_add_address (void *cls,
                     const struct GNUNET_TRANSPORT_AddAddressMessage *msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
   uint16_t size;
   size = ntohs (msg->header.size) - sizeof(*msg);
   if (0 == size)
@@ -413,7 +465,7 @@ handle_add_address (void *cls,
                           msg->aid,
                           ntohl (msg->nt));
   }
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -452,14 +504,13 @@ static void
 handle_incoming_msg (void *cls,
                      const struct GNUNET_TRANSPORT_IncomingMessage *inc_msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
   struct GNUNET_MessageHeader *msg;
   msg = (struct GNUNET_MessageHeader *) &inc_msg[1];
   size_t payload_len = ntohs (msg->size) - sizeof (struct
                                                    GNUNET_MessageHeader);
-  LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "Incoming message from communicator!\n");
-
   if (NULL != tc_h->incoming_msg_cb)
   {
     tc_h->incoming_msg_cb (tc_h->cb_cls,
@@ -479,13 +530,14 @@ handle_incoming_msg (void *cls,
     struct GNUNET_TRANSPORT_IncomingMessageAck *ack;
 
     env = GNUNET_MQ_msg (ack, GNUNET_MESSAGE_TYPE_TRANSPORT_INCOMING_MSG_ACK);
+    GNUNET_assert (NULL != env);
     ack->reserved = htonl (0);
     ack->fc_id = inc_msg->fc_id;
     ack->sender = inc_msg->sender;
     GNUNET_MQ_send (tc_h->c_mq, env);
   }
 
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -499,13 +551,15 @@ static void
 handle_queue_create_ok (void *cls,
                         const struct GNUNET_TRANSPORT_CreateQueueResponse *msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
 
   if (NULL != tc_h->queue_create_reply_cb)
   {
     tc_h->queue_create_reply_cb (tc_h->cb_cls, tc_h, GNUNET_YES);
   }
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -523,13 +577,15 @@ handle_queue_create_fail (
   void *cls,
   const struct GNUNET_TRANSPORT_CreateQueueResponse *msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
 
   if (NULL != tc_h->queue_create_reply_cb)
   {
     tc_h->queue_create_reply_cb (tc_h->cb_cls, tc_h, GNUNET_NO);
   }
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -560,18 +616,19 @@ static void
 handle_add_queue_message (void *cls,
                           const struct GNUNET_TRANSPORT_AddQueueMessage *msg)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
   struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue;
 
-  tc_queue = tc_h->queue_head;
-  if (NULL != tc_queue)
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Got queue with ID %u\n", msg->qid);
+  for (tc_queue = tc_h->queue_head; NULL != tc_queue; tc_queue = tc_queue->next)
   {
-    while (tc_queue->qid != msg->qid)
-    {
-      tc_queue = tc_queue->next;
-    }
+    if (tc_queue->qid == msg->qid)
+      break;
   }
-  else
+  if (NULL == tc_queue)
   {
     tc_queue =
       GNUNET_new (struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue);
@@ -583,13 +640,55 @@ handle_add_queue_message (void *cls,
   GNUNET_assert (tc_queue->qid == msg->qid);
   GNUNET_assert (0 == GNUNET_memcmp (&tc_queue->peer_id, &msg->receiver));
   tc_queue->nt = msg->nt;
-  tc_queue->mtu = msg->mtu;
+  tc_queue->mtu = ntohl (msg->mtu);
   tc_queue->cs = msg->cs;
+  tc_queue->priority = ntohl (msg->priority);
+  tc_queue->q_len = GNUNET_ntohll (msg->q_len);
   if (NULL != tc_h->add_queue_cb)
   {
-    tc_h->add_queue_cb (tc_h->cb_cls, tc_h, tc_queue);
+    tc_h->add_queue_cb (tc_h->cb_cls, tc_h, tc_queue, tc_queue->mtu);
   }
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  GNUNET_SERVICE_client_continue (client->client);
+}
+
+
+/**
+ * @brief Handle new queue
+ *
+ * Store context and call client callback.
+ *
+ * @param cls Closure - communicator handle
+ * @param msg Message struct
+ */
+static void
+handle_update_queue_message (void *cls,
+                             const struct
+                             GNUNET_TRANSPORT_UpdateQueueMessage *msg)
+{
+  struct MyClient *client = cls;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h =
+    client->tc;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue;
+
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Received queue update message for %u with q_len %"PRIu64"\n",
+       msg->qid, GNUNET_ntohll(msg->q_len));
+  tc_queue = tc_h->queue_head;
+  if (NULL != tc_queue)
+  {
+    while (tc_queue->qid != msg->qid)
+    {
+      tc_queue = tc_queue->next;
+    }
+  }
+  GNUNET_assert (tc_queue->qid == msg->qid);
+  GNUNET_assert (0 == GNUNET_memcmp (&tc_queue->peer_id, &msg->receiver));
+  tc_queue->nt = msg->nt;
+  tc_queue->mtu = ntohl (msg->mtu);
+  tc_queue->cs = msg->cs;
+  tc_queue->priority = ntohl (msg->priority);
+  tc_queue->q_len += GNUNET_ntohll (msg->q_len);
+  GNUNET_SERVICE_client_continue (client->client);
 }
 
 
@@ -622,13 +721,20 @@ connect_cb (void *cls,
             struct GNUNET_MQ_Handle *mq)
 {
   struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
+  struct MyClient *new_c;
 
-  LOG (GNUNET_ERROR_TYPE_DEBUG, "Client connected.\n");
-  tc_h->client = client;
-  tc_h->c_mq = mq;
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "Client %p connected to %p.\n",
+       client, tc_h);
+  new_c = GNUNET_new (struct MyClient);
+  new_c->client = client;
+  new_c->c_mq = mq;
+  new_c->tc = tc_h;
+  GNUNET_CONTAINER_DLL_insert (tc_h->client_head,
+                               tc_h->client_tail,
+                               new_c);
 
   if (NULL == tc_h->queue_head)
-    return tc_h;
+    return new_c;
   /* Iterate over queues. They are yet to be opened. Request opening. */
   for (struct
        GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue_iter =
@@ -644,7 +750,7 @@ connect_cb (void *cls,
                     tc_queue_iter->open_queue_env);
     tc_queue_iter->open_queue_env = NULL;
   }
-  return tc_h;
+  return new_c;
 }
 
 
@@ -660,10 +766,22 @@ disconnect_cb (void *cls,
                struct GNUNET_SERVICE_Client *client,
                void *internal_cls)
 {
+  struct MyClient *cl = cls;
   struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
 
+  for (cl = tc_h->client_head; NULL != cl; cl = cl->next)
+  {
+    if (cl->client != client)
+      continue;
+    GNUNET_CONTAINER_DLL_remove (tc_h->client_head,
+                                 tc_h->client_tail,
+                                 cl);
+    if (cl->c_mq == tc_h->c_mq)
+      tc_h->c_mq = NULL;
+    GNUNET_free (cl);
+    break;
+  }
   LOG (GNUNET_ERROR_TYPE_DEBUG, "Client disconnected.\n");
-  tc_h->client = NULL;
 }
 
 
@@ -677,8 +795,8 @@ static void
 handle_send_message_ack (void *cls,
                          const struct GNUNET_TRANSPORT_SendMessageToAck *sma)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
-  GNUNET_SERVICE_client_continue (tc_h->client);
+  struct MyClient *client = cls;
+  GNUNET_SERVICE_client_continue (client->client);
   // NOP
 }
 
@@ -727,6 +845,10 @@ transport_communicator_start (
                            GNUNET_MESSAGE_TYPE_TRANSPORT_QUEUE_SETUP,
                            struct GNUNET_TRANSPORT_AddQueueMessage,
                            tc_h),
+    GNUNET_MQ_hd_fixed_size (update_queue_message,
+                             GNUNET_MESSAGE_TYPE_TRANSPORT_QUEUE_UPDATE,
+                             struct GNUNET_TRANSPORT_UpdateQueueMessage,
+                             tc_h),
     // GNUNET_MQ_hd_fixed_size (del_queue_message,
     //                         GNUNET_MESSAGE_TYPE_TRANSPORT_QUEUE_TEARDOWN,
     //                         struct GNUNET_TRANSPORT_DelQueueMessage,
@@ -760,11 +882,11 @@ shutdown_process (struct GNUNET_OS_Process *proc)
   if (0 != GNUNET_OS_process_kill (proc, SIGTERM))
   {
     LOG (GNUNET_ERROR_TYPE_WARNING,
-         "Error shutting down communicator with SIGERM, trying SIGKILL\n");
+         "Error shutting down process with SIGERM, trying SIGKILL\n");
     if (0 != GNUNET_OS_process_kill (proc, SIGKILL))
     {
       LOG (GNUNET_ERROR_TYPE_ERROR,
-           "Error shutting down communicator with SIGERM and SIGKILL\n");
+           "Error shutting down process with SIGERM and SIGKILL\n");
     }
   }
   GNUNET_OS_process_destroy (proc);
@@ -825,6 +947,45 @@ shutdown_nat (void *cls)
   shutdown_process (proc);
 }
 
+/**
+ * @brief Task run at shutdown to kill the resolver process
+ *
+ * @param cls Closure - Process of communicator
+ */
+static void
+shutdown_resolver (void *cls)
+{
+  struct GNUNET_OS_Process *proc = cls;
+  shutdown_process (proc);
+}
+
+static void
+resolver_start (struct
+                GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h)
+{
+  char *binary;
+
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "resolver_start\n");
+  binary = GNUNET_OS_get_libexec_binary_path ("gnunet-service-resolver");
+  tc_h->resolver_proc = GNUNET_OS_start_process (GNUNET_YES,
+                                                 GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
+                                                 NULL,
+                                                 NULL,
+                                                 NULL,
+                                                 binary,
+                                                 "gnunet-service-resolver",
+                                                 "-c",
+                                                 tc_h->cfg_filename,
+                                                 NULL);
+  if (NULL == tc_h->resolver_proc)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR, "Failed to start resolver service!");
+    return;
+  }
+  LOG (GNUNET_ERROR_TYPE_INFO, "started resolver service\n");
+  GNUNET_free (binary);
+
+}
 
 /**
  * @brief Start NAT
@@ -858,16 +1019,6 @@ nat_start (
 }
 
 
-static void
-do_shutdown (void *cls)
-{
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h = cls;
-  shutdown_communicator (tc_h->c_proc);
-  shutdown_service (tc_h->sh);
-  shutdown_nat (tc_h->nat_proc);
-}
-
-
 /**
  * @brief Start communicator part of transport service and communicator
  *
@@ -885,6 +1036,7 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_service_start (
   const char *service_name,
   const char *binary_name,
   const char *cfg_filename,
+  const struct GNUNET_PeerIdentity *peer_id,
   GNUNET_TRANSPORT_TESTING_CommunicatorAvailableCallback
   communicator_available_cb,
   GNUNET_TRANSPORT_TESTING_AddAddressCallback add_address_cb,
@@ -896,6 +1048,9 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_service_start (
 {
   struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h;
 
+  LOG (GNUNET_ERROR_TYPE_DEBUG,
+       "Starting new transport/communicator combo with config %s\n",
+       cfg_filename);
   tc_h =
     GNUNET_new (struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle);
   tc_h->cfg_filename = GNUNET_strdup (cfg_filename);
@@ -919,20 +1074,35 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_service_start (
   tc_h->add_queue_cb = add_queue_cb;
   tc_h->incoming_msg_cb = incoming_message_cb;
   tc_h->bc_cb = bc_cb;
+  tc_h->peer_id = *peer_id;
   tc_h->cb_cls = cb_cls;
 
   /* Start communicator part of service */
   transport_communicator_start (tc_h);
   /* Start NAT */
   nat_start (tc_h);
+  /* Start resolver service */
+  resolver_start (tc_h);
   /* Schedule start communicator */
   communicator_start (tc_h,
                       binary_name);
-  GNUNET_SCHEDULER_add_shutdown (&do_shutdown, tc_h);
   return tc_h;
 }
 
 
+void
+GNUNET_TRANSPORT_TESTING_transport_communicator_service_stop (
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h)
+{
+  shutdown_communicator (tc_h->c_proc);
+  shutdown_service (tc_h->sh);
+  shutdown_nat (tc_h->nat_proc);
+  shutdown_resolver (tc_h->resolver_proc);
+  GNUNET_CONFIGURATION_destroy (tc_h->cfg);
+  GNUNET_free (tc_h);
+}
+
+
 /**
  * @brief Instruct communicator to open a queue
  *
@@ -988,39 +1158,76 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_open_queue (
  * @brief Instruct communicator to send data
  *
  * @param tc_queue The queue to use for sending
+ * @param cont function to call when done sending
+ * @param cont_cls closure for @a cont
  * @param payload Data to send
- * @param payload_size Size of the payload
- *
- * @return Handle to the transmission
+ * @param payload_size Size of the @a payload
  */
-struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorTransmission *
+void
 GNUNET_TRANSPORT_TESTING_transport_communicator_send
-  (struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue,
+  (struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h,
+  GNUNET_SCHEDULER_TaskCallback cont,
+  void *cont_cls,
   const void *payload,
   size_t payload_size)
 {
-  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorTransmission *tc_t;
   struct GNUNET_MessageHeader *mh;
   struct GNUNET_TRANSPORT_SendMessageTo *msg;
   struct GNUNET_MQ_Envelope *env;
   size_t inbox_size;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue;
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue *tc_queue_tmp;
 
-  inbox_size = sizeof(struct GNUNET_MessageHeader) + payload_size;
-  mh = GNUNET_malloc (inbox_size);
+  tc_queue = NULL;
+  for (tc_queue_tmp = tc_h->queue_head;
+       NULL != tc_queue_tmp;
+       tc_queue_tmp = tc_queue_tmp->next)
+  {
+    if (tc_queue_tmp->q_len <= 0)
+      continue;
+    if (NULL == tc_queue)
+    {
+      LOG (GNUNET_ERROR_TYPE_DEBUG,
+           "Selecting queue with prio %u, len %" PRIu64 " and MTU %u\n",
+           tc_queue_tmp->priority,
+           tc_queue_tmp->q_len,
+           tc_queue_tmp->mtu);
+      tc_queue = tc_queue_tmp;
+      continue;
+    }
+    if (tc_queue->priority < tc_queue_tmp->priority)
+    {
+      LOG (GNUNET_ERROR_TYPE_DEBUG,
+           "Selecting queue with prio %u, len %" PRIu64 " and MTU %u\n",
+           tc_queue_tmp->priority,
+           tc_queue_tmp->q_len,
+           tc_queue_tmp->mtu);
+      tc_queue = tc_queue_tmp;
+    }
+  }
+  GNUNET_assert (NULL != tc_queue);
+  if (tc_queue->q_len != GNUNET_TRANSPORT_QUEUE_LENGTH_UNLIMITED)
+    tc_queue->q_len--;
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Sending message\n");
+  inbox_size = sizeof (struct GNUNET_MessageHeader) + payload_size;
+  env = GNUNET_MQ_msg_extra (msg,
+                             inbox_size,
+                             GNUNET_MESSAGE_TYPE_TRANSPORT_SEND_MSG);
+  GNUNET_assert (NULL != env);
+  msg->qid = htonl (tc_queue->qid);
+  msg->mid = tc_queue->mid++;
+  msg->receiver = tc_queue->peer_id;
+  mh = (struct GNUNET_MessageHeader *) &msg[1];
   mh->size = htons (inbox_size);
   mh->type = GNUNET_MESSAGE_TYPE_DUMMY;
   memcpy (&mh[1],
           payload,
           payload_size);
-  env = GNUNET_MQ_msg_extra (msg,
-                             inbox_size,
-                             GNUNET_MESSAGE_TYPE_TRANSPORT_SEND_MSG);
-  msg->qid = htonl (tc_queue->qid);
-  msg->mid = tc_queue->mid++;
-  msg->receiver = tc_queue->peer_id;
-  memcpy (&msg[1], mh, inbox_size);
-  GNUNET_free (mh);
-  GNUNET_MQ_send (tc_queue->tc_h->c_mq, env);
-  // GNUNET_assert (0); // FIXME: not iplemented!
-  return tc_t;
+  if (NULL != cont)
+    GNUNET_MQ_notify_sent (env,
+                           cont,
+                           cont_cls);
+  GNUNET_MQ_send (tc_queue->tc_h->c_mq,
+                  env);
 }
