@@ -132,7 +132,8 @@ typedef void
                                              *tc_h,
                                              struct
                                              GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue
-                                             *tc_queue);
+                                             *tc_queue,
+                                             size_t mtu);
 
 
 /**
@@ -171,6 +172,7 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_service_start (
   const char *service_name,
   const char *binary_name,
   const char *cfg_filename,
+  const struct GNUNET_PeerIdentity *peer_id,
   GNUNET_TRANSPORT_TESTING_CommunicatorAvailableCallback
   communicator_available_cb,
   GNUNET_TRANSPORT_TESTING_AddAddressCallback add_address_cb,
@@ -181,6 +183,11 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_service_start (
   void *cb_cls);
 
 
+void
+GNUNET_TRANSPORT_TESTING_transport_communicator_service_stop (
+  struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle *tc_h);
+
+
 /**
  * @brief Instruct communicator to open a queue
  *
@@ -202,14 +209,17 @@ GNUNET_TRANSPORT_TESTING_transport_communicator_open_queue (struct
  * @brief Instruct communicator to send data
  *
  * @param tc_queue The queue to use for sending
+ * @param cont function to call when done sending
+ * @param cont_cls closure for @a cont
  * @param payload Data to send
- * @param payload_size Size of the payload
- *
- * @return Handle to the transmission
+ * @param payload_size Size of the @a payload
  */
-struct GNUNET_TRANSPORT_TESTING_TransportCommunicatorTransmission *
+void
 GNUNET_TRANSPORT_TESTING_transport_communicator_send (struct
-                                                      GNUNET_TRANSPORT_TESTING_TransportCommunicatorQueue
-                                                      *tc_queue,
+                                                      GNUNET_TRANSPORT_TESTING_TransportCommunicatorHandle
+                                                      *tc_h,
+                                                      GNUNET_SCHEDULER_TaskCallback
+                                                      cont,
+                                                      void *cont_cls,
                                                       const void *payload,
                                                       size_t payload_size);
