@@ -270,11 +270,19 @@ RETRY:
   ret = GNUNET_NETWORK_socket_send (cstate->sock,
                                     &pos[cstate->msg_off],
                                     len - cstate->msg_off);
+  if ( (-1 == ret) &&
+       ( (EAGAIN == errno) ||
+         (EINTR == errno) ) )
+  {
+    /* ignore */
+    ret = 0;
+  }
   if (-1 == ret)
   {
     LOG (GNUNET_ERROR_TYPE_WARNING,
-         "Error during sending message of type %u\n",
-         ntohs (cstate->msg->type));
+         "Error during sending message of type %u: %s\n",
+         ntohs (cstate->msg->type),
+         strerror (errno));
     if (EINTR == errno)
     {
       LOG (GNUNET_ERROR_TYPE_DEBUG,
@@ -414,7 +422,7 @@ connection_client_destroy_impl (struct GNUNET_MQ_Handle *mq,
   }
   cancel_aps (cstate);
   GNUNET_free (cstate->service_name);
-  GNUNET_free_non_null (cstate->hostname);
+  GNUNET_free (cstate->hostname);
   GNUNET_MST_destroy (cstate->mst);
   GNUNET_free (cstate);
 }
@@ -555,7 +563,7 @@ try_unixpath (const char *service_name,
     if (NULL != sock)
       GNUNET_NETWORK_socket_close (sock);
   }
-  GNUNET_free_non_null (unixpath);
+  GNUNET_free (unixpath);
 #endif
   return NULL;
 }
@@ -739,7 +747,7 @@ test_service_configuration (const char *service_name,
                                _ ("not a valid filename"));
     return GNUNET_SYSERR;   /* UNIXPATH specified but invalid! */
   }
-  GNUNET_free_non_null (unixpath);
+  GNUNET_free (unixpath);
 #endif
 
   if ((GNUNET_YES ==
@@ -760,7 +768,7 @@ test_service_configuration (const char *service_name,
                                               &hostname)) &&
       (0 != strlen (hostname)))
     ret = GNUNET_OK;
-  GNUNET_free_non_null (hostname);
+  GNUNET_free (hostname);
   return ret;
 }
 
@@ -845,10 +853,8 @@ connection_client_send_impl (struct GNUNET_MQ_Handle *mq,
     return;   /* still waiting for connection */
   }
   cstate->send_task
-    = GNUNET_SCHEDULER_add_write_net (GNUNET_TIME_UNIT_FOREVER_REL,
-                                      cstate->sock,
-                                      &transmit_ready,
-                                      cstate);
+    = GNUNET_SCHEDULER_add_now (&transmit_ready,
+                                cstate);
 }
 
 
@@ -1037,7 +1043,7 @@ GNUNET_CLIENT_test (const struct GNUNET_CONFIGURATION_Handle *cfg,
     /* service running remotely */
     ret = GNUNET_OK;
   }
-  GNUNET_free_non_null (hostname);
+  GNUNET_free (hostname);
   return ret;
 }
 
