@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     Copyright (C) 2006, 2007, 2008, 2009, 2013 GNUnet e.V.
+     Copyright (C) 2006, 2007, 2008, 2009, 2013, 2020 GNUnet e.V.
 
      GNUnet is free software: you can redistribute it and/or modify it
      under the terms of the GNU Affero General Public License as published
@@ -17,16 +17,15 @@
 
      SPDX-License-Identifier: AGPL3.0-or-later
  */
-
 /**
  * @file src/util/configuration.c
  * @brief configuration management
  * @author Christian Grothoff
  */
-
 #include "platform.h"
 #include "gnunet_crypto_lib.h"
 #include "gnunet_strings_lib.h"
+#include "gnunet_os_lib.h"
 #include "gnunet_configuration_lib.h"
 #include "gnunet_disk_lib.h"
 
@@ -118,7 +117,85 @@ struct DiffHandle
 struct GNUNET_CONFIGURATION_Handle *
 GNUNET_CONFIGURATION_create ()
 {
-  return GNUNET_new (struct GNUNET_CONFIGURATION_Handle);
+  struct GNUNET_CONFIGURATION_Handle *cfg;
+  char *p;
+
+  cfg = GNUNET_new (struct GNUNET_CONFIGURATION_Handle);
+  /* make certain values from the project data available
+     as PATHS */
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "DATADIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_LIBDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "LIBDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_BINDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "BINDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_PREFIX);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "PREFIX",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_LOCALEDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "LOCALEDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_ICONDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "ICONDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DOCDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "DOCDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  p = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_LIBEXECDIR);
+  if (NULL != p)
+  {
+    GNUNET_CONFIGURATION_set_value_string (cfg,
+                                           "PATHS",
+                                           "LIBEXECDIR",
+                                           p);
+    GNUNET_free (p);
+  }
+  return cfg;
 }
 
 
@@ -209,7 +286,7 @@ GNUNET_CONFIGURATION_deserialize (struct GNUNET_CONFIGURATION_Handle *cfg,
   line_orig = NULL;
   while (r_bytes < size)
   {
-    GNUNET_free_non_null (line_orig);
+    GNUNET_free (line_orig);
     /* fgets-like behaviour on buffer */
     to_read = size - r_bytes;
     pos = memchr (&mem[r_bytes], '\n', to_read);
@@ -327,7 +404,7 @@ GNUNET_CONFIGURATION_deserialize (struct GNUNET_CONFIGURATION_Handle *cfg,
     ret = GNUNET_SYSERR;
     break;
   }
-  GNUNET_free_non_null (line_orig);
+  GNUNET_free (line_orig);
   GNUNET_free (section);
   GNUNET_assert ((GNUNET_OK != ret) || (r_bytes == size));
   return ret;
@@ -657,7 +734,7 @@ GNUNET_CONFIGURATION_remove_section (struct GNUNET_CONFIGURATION_Handle *cfg,
       {
         spos->entries = ent->next;
         GNUNET_free (ent->key);
-        GNUNET_free_non_null (ent->val);
+        GNUNET_free (ent->val);
         GNUNET_free (ent);
         cfg->dirty = GNUNET_YES;
       }
@@ -849,13 +926,13 @@ GNUNET_CONFIGURATION_set_value_string (struct GNUNET_CONFIGURATION_Handle *cfg,
   {
     if (NULL == value)
     {
-      GNUNET_free_non_null (e->val);
+      GNUNET_free (e->val);
       e->val = NULL;
     }
     else
     {
       nv = GNUNET_strdup (value);
-      GNUNET_free_non_null (e->val);
+      GNUNET_free (e->val);
       e->val = nv;
     }
     return;
@@ -1164,7 +1241,7 @@ GNUNET_CONFIGURATION_have_value (const struct GNUNET_CONFIGURATION_Handle *cfg,
  * @param cfg configuration to use for path expansion
  * @param orig string to $-expand (will be freed!)
  * @param depth recursion depth, used to detect recursive expansions
- * @return $-expanded string
+ * @return $-expanded string, never NULL unless @a orig was NULL
  */
 static char *
 expand_dollar (const struct GNUNET_CONFIGURATION_Handle *cfg,
@@ -1306,7 +1383,7 @@ expand_dollar (const struct GNUNET_CONFIGURATION_Handle *cfg,
   result = GNUNET_malloc (strlen (prefix) + strlen (post) + 1);
   strcpy (result, prefix);
   strcat (result, post);
-  GNUNET_free_non_null (def);
+  GNUNET_free (def);
   GNUNET_free (prefix);
   GNUNET_free (orig);
   return result;
@@ -1344,6 +1421,7 @@ GNUNET_CONFIGURATION_expand_dollar (
       continue;
     dup = GNUNET_strdup (orig + i);
     dup = expand_dollar (cfg, dup, 0);
+    GNUNET_assert (NULL != dup); /* make compiler happy */
     len = strlen (dup) + 1;
     orig = GNUNET_realloc (orig, i + len);
     GNUNET_memcpy (orig + i, dup, len);
