@@ -62,9 +62,7 @@ GNUNET_CRYPTO_kdf_v (void *result,
    * hash function."
    *
    * http://eprint.iacr.org/2010/264
-   */
-
-  return GNUNET_CRYPTO_hkdf_v (result,
+   */return GNUNET_CRYPTO_hkdf_v (result,
                                out_len,
                                GCRY_MD_SHA512,
                                GCRY_MD_SHA256,
@@ -134,7 +132,7 @@ GNUNET_CRYPTO_kdf_mod_mpi (gcry_mpi_t *r,
   gcry_error_t rc;
   unsigned int nbits;
   size_t rsize;
-  unsigned int ctr;
+  uint16_t ctr;
 
   nbits = gcry_mpi_get_nbits (n);
   /* GNUNET_assert (nbits > 512); */
@@ -145,12 +143,14 @@ GNUNET_CRYPTO_kdf_mod_mpi (gcry_mpi_t *r,
     /* Ain't clear if n is always divisible by 8 */
     uint8_t buf[ (nbits - 1) / 8 + 1 ];
 
+    uint16_t ctr_nbo = htons (ctr);
+
     rc = GNUNET_CRYPTO_kdf (buf,
                             sizeof(buf),
                             xts, xts_len,
                             skm, skm_len,
                             ctx, strlen (ctx),
-                            &ctr, sizeof(ctr),
+                            &ctr_nbo, sizeof(ctr_nbo),
                             NULL, 0);
     GNUNET_assert (GNUNET_YES == rc);
 
@@ -171,4 +171,5 @@ GNUNET_CRYPTO_kdf_mod_mpi (gcry_mpi_t *r,
   }
 }
 
+
 /* end of crypto_kdf.c */
