@@ -827,7 +827,6 @@ GNUNET_DISK_file_write (const struct GNUNET_DISK_FileHandle *h,
     return GNUNET_SYSERR;
   }
 
-
   return write (h->fd, buffer, n);
 }
 
@@ -1188,70 +1187,6 @@ GNUNET_DISK_file_change_owner (const char *filename, const char *user)
 }
 
 
-/**
- * Lock a part of a file
- *
- * @param fh file handle
- * @param lock_start absolute position from where to lock
- * @param lock_end absolute position until where to lock
- * @param excl #GNUNET_YES for an exclusive lock
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
- */
-int
-GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh,
-                       off_t lock_start,
-                       off_t lock_end,
-                       int excl)
-{
-  if (fh == NULL)
-  {
-    errno = EINVAL;
-    return GNUNET_SYSERR;
-  }
-
-  struct flock fl;
-
-  memset (&fl, 0, sizeof(struct flock));
-  fl.l_type = excl ? F_WRLCK : F_RDLCK;
-  fl.l_whence = SEEK_SET;
-  fl.l_start = lock_start;
-  fl.l_len = lock_end;
-
-  return fcntl (fh->fd, F_SETLK, &fl) != 0 ? GNUNET_SYSERR : GNUNET_OK;
-}
-
-
-/**
- * Unlock a part of a file
- *
- * @param fh file handle
- * @param unlock_start absolute position from where to unlock
- * @param unlock_end absolute position until where to unlock
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
- */
-int
-GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh,
-                         off_t unlock_start,
-                         off_t unlock_end)
-{
-  if (fh == NULL)
-  {
-    errno = EINVAL;
-    return GNUNET_SYSERR;
-  }
-
-  struct flock fl;
-
-  memset (&fl, 0, sizeof(struct flock));
-  fl.l_type = F_UNLCK;
-  fl.l_whence = SEEK_SET;
-  fl.l_start = unlock_start;
-  fl.l_len = unlock_end;
-
-  return fcntl (fh->fd, F_SETLK, &fl) != 0 ? GNUNET_SYSERR : GNUNET_OK;
-}
-
-
 /**
  * Open a file.  Note that the access permissions will only be
  * used if a new file is created and if the underlying operating
@@ -1621,8 +1556,8 @@ GNUNET_DISK_pipe_from_fd (int blocking_read, int blocking_write, int fd[2])
       GNUNET_break (0 == close (p->fd[0]->fd));
     if (p->fd[1]->fd >= 0)
       GNUNET_break (0 == close (p->fd[1]->fd));
-    GNUNET_free_non_null (p->fd[0]);
-    GNUNET_free_non_null (p->fd[1]);
+    GNUNET_free (p->fd[0]);
+    GNUNET_free (p->fd[1]);
     GNUNET_free (p);
     errno = eno;
     return NULL;
