@@ -297,7 +297,8 @@ done:
  * @param error the error type
  */
 void
-GNUNET_MQ_inject_error (struct GNUNET_MQ_Handle *mq, enum GNUNET_MQ_Error error)
+GNUNET_MQ_inject_error (struct GNUNET_MQ_Handle *mq,
+                        enum GNUNET_MQ_Error error)
 {
   if (NULL == mq->error_handler)
   {
@@ -306,7 +307,8 @@ GNUNET_MQ_inject_error (struct GNUNET_MQ_Handle *mq, enum GNUNET_MQ_Error error)
          (int) error);
     return;
   }
-  mq->error_handler (mq->error_handler_cls, error);
+  mq->error_handler (mq->error_handler_cls,
+                     error);
 }
 
 
@@ -350,7 +352,8 @@ GNUNET_MQ_get_length (struct GNUNET_MQ_Handle *mq)
  * @param ev the envelope with the message to send.
  */
 void
-GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq, struct GNUNET_MQ_Envelope *ev)
+GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq,
+                struct GNUNET_MQ_Envelope *ev)
 {
   GNUNET_assert (NULL != mq);
   GNUNET_assert (NULL == ev->parent_queue);
@@ -368,7 +371,9 @@ GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq, struct GNUNET_MQ_Envelope *ev)
   /* is the implementation busy? queue it! */
   if ((NULL != mq->current_envelope) || (NULL != mq->send_task))
   {
-    GNUNET_CONTAINER_DLL_insert_tail (mq->envelope_head, mq->envelope_tail, ev);
+    GNUNET_CONTAINER_DLL_insert_tail (mq->envelope_head,
+                                      mq->envelope_tail,
+                                      ev);
     return;
   }
   GNUNET_assert (NULL == mq->envelope_head);
@@ -379,7 +384,9 @@ GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq, struct GNUNET_MQ_Envelope *ev)
        ntohs (ev->mh->type),
        mq);
 
-  mq->send_impl (mq, ev->mh, mq->impl_state);
+  mq->send_impl (mq,
+                 ev->mh,
+                 mq->impl_state);
 }
 
 
@@ -471,7 +478,9 @@ impl_send_continue (void *cls)
        "sending message of type %u from queue\n",
        ntohs (mq->current_envelope->mh->type));
 
-  mq->send_impl (mq, mq->current_envelope->mh, mq->impl_state);
+  mq->send_impl (mq,
+                 mq->current_envelope->mh,
+                 mq->impl_state);
 }
 
 
@@ -872,7 +881,7 @@ GNUNET_MQ_destroy (struct GNUNET_MQ_Handle *mq)
     GNUNET_CONTAINER_multihashmap32_destroy (mq->assoc_map);
     mq->assoc_map = NULL;
   }
-  GNUNET_free_non_null (mq->handlers);
+  GNUNET_free (mq->handlers);
   GNUNET_free (mq);
 }
 
@@ -929,7 +938,8 @@ GNUNET_MQ_send_cancel (struct GNUNET_MQ_Envelope *ev)
     GNUNET_assert (GNUNET_NO == mq->in_flight);
     GNUNET_assert (0 < mq->queue_length);
     mq->queue_length--;
-    mq->cancel_impl (mq, mq->impl_state);
+    mq->cancel_impl (mq,
+                     mq->impl_state);
     /* continue sending the next message, if any */
     mq->current_envelope = mq->envelope_head;
     if (NULL != mq->current_envelope)
@@ -941,14 +951,17 @@ GNUNET_MQ_send_cancel (struct GNUNET_MQ_Envelope *ev)
       LOG (GNUNET_ERROR_TYPE_DEBUG,
            "sending canceled message of type %u queue\n",
            ntohs (ev->mh->type));
-
-      mq->send_impl (mq, mq->current_envelope->mh, mq->impl_state);
+      mq->send_impl (mq,
+                     mq->current_envelope->mh,
+                     mq->impl_state);
     }
   }
   else
   {
     /* simple case, message is still waiting in the queue */
-    GNUNET_CONTAINER_DLL_remove (mq->envelope_head, mq->envelope_tail, ev);
+    GNUNET_CONTAINER_DLL_remove (mq->envelope_head,
+                                 mq->envelope_tail,
+                                 ev);
     GNUNET_assert (0 < mq->queue_length);
     mq->queue_length--;
   }
@@ -1127,8 +1140,8 @@ GNUNET_MQ_destroy_notify (struct GNUNET_MQ_Handle *mq,
  * @param dnh handle for registration to cancel
  */
 void
-GNUNET_MQ_destroy_notify_cancel (
-  struct GNUNET_MQ_DestroyNotificationHandle *dnh)
+GNUNET_MQ_destroy_notify_cancel (struct
+                                 GNUNET_MQ_DestroyNotificationHandle *dnh)
 {
   struct GNUNET_MQ_Handle *mq = dnh->mq;
 
