@@ -70,6 +70,7 @@ static const struct GNUNET_OS_ProjectData default_pd = {
   .is_gnu = 1,
   .gettext_domain = PACKAGE,
   .gettext_path = NULL,
+  .agpl_url = GNUNET_AGPL_URL,
 };
 
 /**
@@ -562,11 +563,11 @@ GNUNET_OS_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
           (GNUNET_YES == GNUNET_DISK_directory_test (tmp, GNUNET_YES)))
       {
         GNUNET_free (execpath);
-        GNUNET_free_non_null (dirname);
+        GNUNET_free (dirname);
         return tmp;
       }
       GNUNET_free (tmp);
-      GNUNET_free_non_null (dirname);
+      GNUNET_free (dirname);
     }
     GNUNET_asprintf (&dirname,
                      DIR_SEPARATOR_STR "%s" DIR_SEPARATOR_STR,
@@ -611,10 +612,10 @@ GNUNET_OS_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
                        DIR_SEPARATOR_STR "lib" DIR_SEPARATOR_STR,
                        (NULL != multiarch) ? multiarch : "",
                        dirname);
+      GNUNET_free (dirname);
       if (GNUNET_YES == GNUNET_DISK_directory_test (tmp, GNUNET_YES))
       {
         GNUNET_free (execpath);
-        GNUNET_free (dirname);
         return tmp;
       }
       GNUNET_free (tmp);
@@ -642,11 +643,11 @@ GNUNET_OS_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind)
           (GNUNET_YES == GNUNET_DISK_directory_test (tmp, GNUNET_YES)))
       {
         GNUNET_free (execpath);
-        GNUNET_free_non_null (dirname);
+        GNUNET_free (dirname);
         return tmp;
       }
       GNUNET_free (tmp);
-      GNUNET_free_non_null (dirname);
+      GNUNET_free (dirname);
     }
     GNUNET_asprintf (&dirname,
                      DIR_SEPARATOR_STR "%s" DIR_SEPARATOR_STR
