@@ -875,7 +875,7 @@ GNUNET_OS_start_process_s (int pipe_control,
                                     binary_path,
                                     argv);
   while (argv_size > 0)
-    GNUNET_free (argv[--argv_size]);
+    GNUNET_free_nz (argv[--argv_size]);
   GNUNET_free (argv);
   return proc;
 }
@@ -951,7 +951,7 @@ process_status (struct GNUNET_OS_Process *proc,
 
 
 /**
- * Retrieve the status of a process, waiting on it if dead.
+ * Retrieve the status of a process.
  * Nonblocking version.
  *
  * @param proc process ID
@@ -975,7 +975,7 @@ GNUNET_OS_process_status (struct GNUNET_OS_Process *proc,
  * @param proc pointer to process structure
  * @param type status type
  * @param code return code/signal number
- * @return #GNUNET_OK on success, #GNUNET_NO if the process is still running, #GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
  */
 int
 GNUNET_OS_process_wait_status (struct GNUNET_OS_Process *proc,
