@@ -406,6 +406,11 @@ static enum GNUNET_SCHEDULER_Priority max_priority_added;
  */
 static int current_lifeness;
 
+/**
+ * Priority used currently in #GNUNET_SCHEDULER_do_work().
+ */
+static enum GNUNET_SCHEDULER_Priority work_priority;
+
 /**
  * Function to use as a select() in the scheduler.
  * If NULL, we use GNUNET_NETWORK_socket_select().
@@ -508,9 +513,9 @@ queue_ready_task (struct GNUNET_SCHEDULER_Task *task)
 {
   enum GNUNET_SCHEDULER_Priority p = check_priority (task->priority);
 
-  GNUNET_CONTAINER_DLL_insert (ready_head[p],
-                               ready_tail[p],
-                               task);
+  GNUNET_CONTAINER_DLL_insert_tail (ready_head[p],
+                                    ready_tail[p],
+                                    task);
   task->in_ready_list = GNUNET_YES;
   ready_count++;
 }
@@ -579,28 +584,26 @@ dump_backtrace (struct GNUNET_SCHEDULER_Task *t)
 static void
 destroy_task (struct GNUNET_SCHEDULER_Task *t)
 {
-  unsigned int i;
-
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "destroying task %p\n",
        t);
 
   if (GNUNET_YES == t->own_handles)
   {
-    for (i = 0; i != t->fds_len; ++i)
+    for (unsigned int i = 0; i != t->fds_len; ++i)
     {
       const struct GNUNET_NETWORK_Handle *fd = t->fds[i].fd;
       const struct GNUNET_DISK_FileHandle *fh = t->fds[i].fh;
       if (fd)
       {
-        GNUNET_NETWORK_socket_free_memory_only_ ((struct
-                                                  GNUNET_NETWORK_Handle *) fd);
+        GNUNET_NETWORK_socket_free_memory_only_ (
+          (struct GNUNET_NETWORK_Handle *) fd);
       }
       if (fh)
       {
         // FIXME: on WIN32 this is not enough! A function
         // GNUNET_DISK_file_free_memory_only would be nice
-        GNUNET_free ((void *) fh);
+        GNUNET_free_nz ((void *) fh);
       }
     }
   }
@@ -719,9 +722,11 @@ GNUNET_SCHEDULER_run (GNUNET_SCHEDULER_TaskCallback task,
 {
   struct GNUNET_SCHEDULER_Handle *sh;
   struct GNUNET_SCHEDULER_Driver *driver;
-  struct DriverContext context = { .scheduled_head = NULL,
-                                   .scheduled_tail = NULL,
-                                   .timeout = GNUNET_TIME_absolute_get () };
+  struct DriverContext context = {
+    .scheduled_head = NULL,
+    .scheduled_tail = NULL,
+    .timeout = GNUNET_TIME_absolute_get ()
+  };
 
   driver = GNUNET_SCHEDULER_driver_select ();
   driver->cls = &context;
@@ -763,7 +768,6 @@ GNUNET_SCHEDULER_get_task_context ()
 unsigned int
 GNUNET_SCHEDULER_get_load (enum GNUNET_SCHEDULER_Priority p)
 {
-  struct GNUNET_SCHEDULER_Task *pos;
   unsigned int ret;
 
   GNUNET_assert (NULL != active_task);
@@ -772,7 +776,9 @@ GNUNET_SCHEDULER_get_load (enum GNUNET_SCHEDULER_Priority p)
   if (p == GNUNET_SCHEDULER_PRIORITY_KEEP)
     p = current_priority;
   ret = 0;
-  for (pos = ready_head[check_priority (p)]; NULL != pos; pos = pos->next)
+  for (struct GNUNET_SCHEDULER_Task *pos = ready_head[check_priority (p)];
+       NULL != pos;
+       pos = pos->next)
     ret++;
   return ret;
 }
@@ -1109,6 +1115,7 @@ GNUNET_SCHEDULER_add_at_with_priority (struct GNUNET_TIME_Absolute at,
   struct GNUNET_SCHEDULER_Task *t;
   struct GNUNET_SCHEDULER_Task *pos;
   struct GNUNET_SCHEDULER_Task *prev;
+  struct GNUNET_TIME_Relative left;
 
   /* scheduler must be running */
   GNUNET_assert (NULL != scheduler_driver);
@@ -1125,6 +1132,17 @@ GNUNET_SCHEDULER_add_at_with_priority (struct GNUNET_TIME_Absolute at,
   t->timeout = at;
   t->priority = check_priority (priority);
   t->lifeness = current_lifeness;
+  init_backtrace (t);
+
+  left = GNUNET_TIME_absolute_get_remaining (at);
+  if (0 == left.rel_value_us)
+  {
+    queue_ready_task (t);
+    if (priority > work_priority)
+      work_priority = priority;
+    return t;
+  }
+
   /* try tail first (optimization in case we are
    * appending to a long list of tasks with timeouts) */
   if ((NULL == pending_timeout_head) ||
@@ -1159,11 +1177,9 @@ GNUNET_SCHEDULER_add_at_with_priority (struct GNUNET_TIME_Absolute at,
   }
   /* finally, update heuristic insertion point to last insertion... */
   pending_timeout_last = t;
-
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Adding task %p\n",
        t);
-  init_backtrace (t);
   return t;
 }
 
@@ -1280,9 +1296,24 @@ struct GNUNET_SCHEDULER_Task *
 GNUNET_SCHEDULER_add_now (GNUNET_SCHEDULER_TaskCallback task,
                           void *task_cls)
 {
-  return GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_ZERO,
-                                       task,
-                                       task_cls);
+  struct GNUNET_SCHEDULER_Task *t;
+
+  t = GNUNET_new (struct GNUNET_SCHEDULER_Task);
+  GNUNET_async_scope_get (&t->scope);
+  t->callback = task;
+  t->callback_cls = task_cls;
+  t->read_fd = -1;
+  t->write_fd = -1;
+#if PROFILE_DELAYS
+  t->start_time = GNUNET_TIME_absolute_get ();
+#endif
+  t->timeout = GNUNET_TIME_UNIT_ZERO_ABS;
+  t->priority = current_priority;
+  t->on_shutdown = GNUNET_YES;
+  t->lifeness = current_lifeness;
+  queue_ready_task (t);
+  init_backtrace (t);
+  return t;
 }
 
 
@@ -1971,7 +2002,6 @@ GNUNET_SCHEDULER_task_ready (struct GNUNET_SCHEDULER_Task *task,
 int
 GNUNET_SCHEDULER_do_work (struct GNUNET_SCHEDULER_Handle *sh)
 {
-  enum GNUNET_SCHEDULER_Priority p;
   struct GNUNET_SCHEDULER_Task *pos;
   struct GNUNET_TIME_Absolute now;
 
@@ -2047,19 +2077,21 @@ GNUNET_SCHEDULER_do_work (struct GNUNET_SCHEDULER_Handle *sh)
     GNUNET_assert (NULL == ready_head[GNUNET_SCHEDULER_PRIORITY_KEEP]);
     /* yes, p>0 is correct, 0 is "KEEP" which should
      * always be an empty queue (see assertion)! */
-    for (p = GNUNET_SCHEDULER_PRIORITY_COUNT - 1; p > 0; p--)
+    for (work_priority = GNUNET_SCHEDULER_PRIORITY_COUNT - 1;
+         work_priority > 0;
+         work_priority--)
     {
-      pos = ready_head[p];
+      pos = ready_head[work_priority];
       if (NULL != pos)
         break;
     }
     GNUNET_assert (NULL != pos);        /* ready_count wrong? */
 
     /* process all tasks at this priority level, then yield */
-    while (NULL != (pos = ready_head[p]))
+    while (NULL != (pos = ready_head[work_priority]))
     {
-      GNUNET_CONTAINER_DLL_remove (ready_head[p],
-                                   ready_tail[p],
+      GNUNET_CONTAINER_DLL_remove (ready_head[work_priority],
+                                   ready_tail[work_priority],
                                    pos);
       ready_count--;
       current_priority = pos->priority;
@@ -2213,9 +2245,12 @@ GNUNET_SCHEDULER_driver_init (const struct GNUNET_SCHEDULER_Driver *driver)
   /* Setup initial tasks */
   current_priority = GNUNET_SCHEDULER_PRIORITY_DEFAULT;
   current_lifeness = GNUNET_NO;
+  /* ensure this task runs first, by using a priority level reserved for
+     the scheduler (not really shutdown, but start-up ;-) */
   install_parent_control_task =
-    GNUNET_SCHEDULER_add_now (&install_parent_control_handler,
-                              NULL);
+    GNUNET_SCHEDULER_add_with_priority (GNUNET_SCHEDULER_PRIORITY_SHUTDOWN,
+                                        &install_parent_control_handler,
+                                        NULL);
   shutdown_pipe_task =
     GNUNET_SCHEDULER_add_read_file (GNUNET_TIME_UNIT_FOREVER_REL,
                                     pr,
@@ -2290,6 +2325,8 @@ select_loop (struct GNUNET_SCHEDULER_Handle *sh,
          (GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us !=
           context->timeout.abs_value_us))
   {
+    struct GNUNET_TIME_Relative time_remaining;
+
     LOG (GNUNET_ERROR_TYPE_DEBUG,
          "select timeout = %s\n",
          GNUNET_STRINGS_absolute_time_to_string (context->timeout));
@@ -2310,8 +2347,9 @@ select_loop (struct GNUNET_SCHEDULER_Handle *sh,
         GNUNET_NETWORK_fdset_set_native (ws, pos->fdi->sock);
       }
     }
-    struct GNUNET_TIME_Relative time_remaining =
-      GNUNET_TIME_absolute_get_remaining (context->timeout);
+    time_remaining = GNUNET_TIME_absolute_get_remaining (context->timeout);
+    if (0 < ready_count)
+      time_remaining = GNUNET_TIME_UNIT_ZERO;
     if (NULL == scheduler_select)
     {
       select_result = GNUNET_NETWORK_socket_select (rs,
