@@ -468,7 +468,6 @@ check_ipv6_listed (const struct GNUNET_STRINGS_IPv6NetworkPolicy *list,
                    const struct in6_addr *ip)
 {
   unsigned int i;
-  unsigned int j;
 
   if (NULL == list)
     return GNUNET_NO;
@@ -476,7 +475,7 @@ check_ipv6_listed (const struct GNUNET_STRINGS_IPv6NetworkPolicy *list,
 NEXT:
   while (0 != GNUNET_is_zero (&list[i].network))
   {
-    for (j = 0; j < sizeof(struct in6_addr) / sizeof(int); j++)
+    for (unsigned int j = 0; j < sizeof(struct in6_addr) / sizeof(int); j++)
       if (((((int *) ip)[j] & ((int *) &list[i].netmask)[j])) !=
           (((int *) &list[i].network)[j] & ((int *) &list[i].netmask)[j]))
       {
@@ -506,12 +505,12 @@ do_send (void *cls)
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "service: sending message with type %u\n",
        ntohs (client->msg->type));
-
-
   client->send_task = NULL;
   buf = (const char *) client->msg;
   left = ntohs (client->msg->size) - client->msg_pos;
-  ret = GNUNET_NETWORK_socket_send (client->sock, &buf[client->msg_pos], left);
+  ret = GNUNET_NETWORK_socket_send (client->sock,
+                                    &buf[client->msg_pos],
+                                    left);
   GNUNET_assert (ret <= (ssize_t) left);
   if (0 == ret)
   {
@@ -581,11 +580,8 @@ service_mq_send (struct GNUNET_MQ_Handle *mq,
        ntohs (msg->size));
   client->msg = msg;
   client->msg_pos = 0;
-  client->send_task =
-    GNUNET_SCHEDULER_add_write_net (GNUNET_TIME_UNIT_FOREVER_REL,
-                                    client->sock,
-                                    &do_send,
-                                    client);
+  client->send_task = GNUNET_SCHEDULER_add_now (&do_send,
+                                                client);
 }
 
 
@@ -1148,7 +1144,7 @@ get_server_addresses (const char *service_name,
           (EACCES == errno))
       {
         LOG_STRERROR (GNUNET_ERROR_TYPE_ERROR, "socket");
-        GNUNET_free_non_null (hostname);
+        GNUNET_free (hostname);
         GNUNET_free (unixpath);
         return GNUNET_SYSERR;
       }
@@ -1174,7 +1170,7 @@ get_server_addresses (const char *service_name,
          _ (
            "Have neither PORT nor UNIXPATH for service `%s', but one is required\n"),
          service_name);
-    GNUNET_free_non_null (hostname);
+    GNUNET_free (hostname);
     return GNUNET_SYSERR;
   }
   if (0 == port)
@@ -1182,8 +1178,8 @@ get_server_addresses (const char *service_name,
     saddrs = GNUNET_new_array (2, struct sockaddr *);
     saddrlens = GNUNET_new_array (2, socklen_t);
     add_unixpath (saddrs, saddrlens, unixpath);
-    GNUNET_free_non_null (unixpath);
-    GNUNET_free_non_null (hostname);
+    GNUNET_free (unixpath);
+    GNUNET_free (hostname);
     *addrs = saddrs;
     *addr_lens = saddrlens;
     return 1;
@@ -1207,7 +1203,7 @@ get_server_addresses (const char *service_name,
            hostname,
            gai_strerror (ret));
       GNUNET_free (hostname);
-      GNUNET_free_non_null (unixpath);
+      GNUNET_free (unixpath);
       return GNUNET_SYSERR;
     }
     next = res;
@@ -1227,7 +1223,7 @@ get_server_addresses (const char *service_name,
            hostname);
       freeaddrinfo (res);
       GNUNET_free (hostname);
-      GNUNET_free_non_null (unixpath);
+      GNUNET_free (unixpath);
       return GNUNET_SYSERR;
     }
     resi = i;
@@ -1334,7 +1330,7 @@ get_server_addresses (const char *service_name,
       ((struct sockaddr_in *) saddrs[i])->sin_port = htons (port);
     }
   }
-  GNUNET_free_non_null (unixpath);
+  GNUNET_free (unixpath);
   *addrs = saddrs;
   *addr_lens = saddrlens;
   return resi;
@@ -1561,8 +1557,8 @@ setup_service (struct GNUNET_SERVICE_Handle *sh)
       }
       GNUNET_CONTAINER_DLL_insert (sh->slc_head, sh->slc_tail, slc);
     }
-    GNUNET_free_non_null (addrlens);
-    GNUNET_free_non_null (addrs);
+    GNUNET_free (addrlens);
+    GNUNET_free (addrs);
     if ((0 != num) && (NULL == sh->slc_head))
     {
       /* All attempts to bind failed, hard failure */
@@ -1570,7 +1566,7 @@ setup_service (struct GNUNET_SERVICE_Handle *sh)
         GNUNET_ERROR_TYPE_ERROR,
         _ (
           "Could not bind to any of the ports I was supposed to, refusing to run!\n"));
-      GNUNET_free_non_null (csocks);
+      GNUNET_free (csocks);
       return GNUNET_SYSERR;
     }
   }
@@ -1797,10 +1793,10 @@ teardown_service (struct GNUNET_SERVICE_Handle *sh)
 {
   struct ServiceListenContext *slc;
 
-  GNUNET_free_non_null (sh->v4_denied);
-  GNUNET_free_non_null (sh->v6_denied);
-  GNUNET_free_non_null (sh->v4_allowed);
-  GNUNET_free_non_null (sh->v6_allowed);
+  GNUNET_free (sh->v4_denied);
+  GNUNET_free (sh->v6_denied);
+  GNUNET_free (sh->v4_allowed);
+  GNUNET_free (sh->v6_allowed);
   while (NULL != (slc = sh->slc_head))
   {
     GNUNET_CONTAINER_DLL_remove (sh->slc_head, sh->slc_tail, slc);
@@ -1827,9 +1823,10 @@ return_agpl (void *cls, const struct GNUNET_MessageHeader *msg)
   struct GNUNET_MQ_Envelope *env;
   struct GNUNET_MessageHeader *res;
   size_t slen;
+  const struct GNUNET_OS_ProjectData *pd = GNUNET_OS_project_data_get ();
 
   (void) msg;
-  slen = strlen (GNUNET_AGPL_URL) + 1;
+  slen = strlen (pd->agpl_url) + 1;
   env = GNUNET_MQ_msg_extra (res, GNUNET_MESSAGE_TYPE_RESPONSE_AGPL, slen);
   memcpy (&res[1], GNUNET_AGPL_URL, slen);
   mq = GNUNET_SERVICE_client_get_mq (client);
@@ -1893,7 +1890,7 @@ GNUNET_SERVICE_start (const char *service_name,
   sh->handlers = GNUNET_MQ_copy_handlers2 (handlers, &return_agpl, NULL);
   if (GNUNET_OK != setup_service (sh))
   {
-    GNUNET_free_non_null (sh->handlers);
+    GNUNET_free (sh->handlers);
     GNUNET_free (sh);
     return NULL;
   }
@@ -1916,7 +1913,7 @@ GNUNET_SERVICE_stop (struct GNUNET_SERVICE_Handle *srv)
   while (NULL != (client = srv->clients_head))
     GNUNET_SERVICE_client_drop (client);
   teardown_service (srv);
-  GNUNET_free_non_null (srv->handlers);
+  GNUNET_free (srv->handlers);
   GNUNET_free (srv);
 }
 
@@ -2023,7 +2020,9 @@ GNUNET_SERVICE_run_ (int argc,
   sh.connect_cb = connect_cb;
   sh.disconnect_cb = disconnect_cb;
   sh.cb_cls = cls;
-  sh.handlers = GNUNET_MQ_copy_handlers (handlers);
+  sh.handlers = (NULL == pd->agpl_url)
+    ? GNUNET_MQ_copy_handlers (handlers)
+    : GNUNET_MQ_copy_handlers2 (handlers, &return_agpl, NULL);
   sh.service_name = service_name;
   sh.ret = 0;
   /* setup subsystems */
@@ -2160,13 +2159,13 @@ shutdown:
   }
 #endif
   teardown_service (&sh);
-  GNUNET_free_non_null (sh.handlers);
+  GNUNET_free (sh.handlers);
   GNUNET_SPEEDUP_stop_ ();
   GNUNET_CONFIGURATION_destroy (cfg);
-  GNUNET_free_non_null (logfile);
-  GNUNET_free_non_null (loglev);
+  GNUNET_free (logfile);
+  GNUNET_free (loglev);
   GNUNET_free (cfg_filename);
-  GNUNET_free_non_null (opt_cfg_filename);
+  GNUNET_free (opt_cfg_filename);
 
   return err ? GNUNET_SYSERR : sh.ret;
 }
