@@ -62,25 +62,25 @@
  *         (or number of bytes that would have been written)
  */
 size_t
-GNUNET_STRINGS_buffer_fill (char *buffer, size_t size, unsigned int count, ...)
+GNUNET_STRINGS_buffer_fill (char *buffer,
+                            size_t size,
+                            unsigned int count, ...)
 {
   size_t needed;
-  size_t slen;
-  const char *s;
   va_list ap;
 
   needed = 0;
   va_start (ap, count);
   while (count > 0)
   {
-    s = va_arg (ap, const char *);
+    const char *s = va_arg (ap, const char *);
+    size_t slen = strlen (s) + 1;
 
-    slen = strlen (s) + 1;
-    if (buffer != NULL)
-    {
-      GNUNET_assert (needed + slen <= size);
-      GNUNET_memcpy (&buffer[needed], s, slen);
-    }
+    GNUNET_assert (slen <= size - needed);
+    if (NULL != buffer)
+      GNUNET_memcpy (&buffer[needed],
+                     s,
+                     slen);
     needed += slen;
     count--;
   }
@@ -104,6 +104,7 @@ GNUNET_STRINGS_pp2s (const struct GNUNET_PeerIdentity *pids,
   size_t off;
   size_t plen = num_pids * 5 + 1;
 
+  GNUNET_assert (num_pids < UINT32_MAX / 5);
   off = 0;
   buf = GNUNET_malloc (plen);
   for (unsigned int i = 0; i < num_pids; i++)
@@ -266,11 +267,14 @@ convert_with_table (const char *input,
   const char *tok;
   unsigned long long last;
   unsigned int i;
+  char *sptr;
 
   ret = 0;
   last = 0;
   in = GNUNET_strdup (input);
-  for (tok = strtok (in, " "); tok != NULL; tok = strtok (NULL, " "))
+  for (tok = strtok_r (in, " ", &sptr);
+       tok != NULL;
+       tok = strtok_r (NULL, " ", &sptr))
   {
     do
     {
@@ -518,9 +522,14 @@ fail:
  *  string is returned.
  */
 char *
-GNUNET_STRINGS_to_utf8 (const char *input, size_t len, const char *charset)
+GNUNET_STRINGS_to_utf8 (const char *input,
+                        size_t len,
+                        const char *charset)
 {
-  return GNUNET_STRINGS_conv (input, len, charset, "UTF-8");
+  return GNUNET_STRINGS_conv (input,
+                              len,
+                              charset,
+                              "UTF-8");
 }
 
 
@@ -536,9 +545,14 @@ GNUNET_STRINGS_to_utf8 (const char *input, size_t len, const char *charset)
  *  string is returned.
  */
 char *
-GNUNET_STRINGS_from_utf8 (const char *input, size_t len, const char *charset)
+GNUNET_STRINGS_from_utf8 (const char *input,
+                          size_t len,
+                          const char *charset)
 {
-  return GNUNET_STRINGS_conv (input, len, "UTF-8", charset);
+  return GNUNET_STRINGS_conv (input,
+                              len,
+                              "UTF-8",
+                              charset);
 }
 
 
@@ -687,7 +701,7 @@ const char *
 GNUNET_STRINGS_relative_time_to_string (struct GNUNET_TIME_Relative delta,
                                         int do_round)
 {
-  static char buf[128];
+  static GNUNET_THREAD_LOCAL char buf[128];
   const char *unit = _ (/* time unit */ "µs");
   uint64_t dval = delta.rel_value_us;
 
@@ -741,7 +755,7 @@ GNUNET_STRINGS_relative_time_to_string (struct GNUNET_TIME_Relative delta,
 const char *
 GNUNET_STRINGS_absolute_time_to_string (struct GNUNET_TIME_Absolute t)
 {
-  static char buf[255];
+  static GNUNET_THREAD_LOCAL char buf[255];
   time_t tt;
   struct tm *tp;
 
@@ -868,6 +882,7 @@ GNUNET_STRINGS_data_to_string (const void *data,
   unsigned int vbit;
   const unsigned char *udata;
 
+  GNUNET_assert (size < SIZE_MAX / 8 - 4);
   udata = data;
   if (out_size < (size * 8 + 4) / 5)
   {
@@ -927,7 +942,10 @@ GNUNET_STRINGS_data_to_string_alloc (const void *buf, size_t size)
     len += 5 - len % 5;
   len /= 5;
   str_buf = GNUNET_malloc (len + 1);
-  end = GNUNET_STRINGS_data_to_string (buf, size, str_buf, len);
+  end = GNUNET_STRINGS_data_to_string (buf,
+                                       size,
+                                       str_buf,
+                                       len);
   if (NULL == end)
   {
     GNUNET_free (str_buf);
@@ -954,14 +972,14 @@ GNUNET_STRINGS_string_to_data (const char *enc,
                                void *out,
                                size_t out_size)
 {
-  unsigned int rpos;
-  unsigned int wpos;
+  size_t rpos;
+  size_t wpos;
   unsigned int bits;
   unsigned int vbit;
   int ret;
   int shift;
   unsigned char *uout;
-  unsigned int encoded_len = out_size * 8;
+  size_t encoded_len;
 
   if (0 == enclen)
   {
@@ -969,6 +987,8 @@ GNUNET_STRINGS_string_to_data (const char *enc,
       return GNUNET_OK;
     return GNUNET_SYSERR;
   }
+  GNUNET_assert (out_size < SIZE_MAX / 8);
+  encoded_len = out_size * 8;
   uout = out;
   wpos = out_size;
   rpos = enclen;
@@ -1128,7 +1148,7 @@ GNUNET_STRINGS_path_is_absolute (const char *filename,
       if (r_uri_scheme)
         *r_uri_scheme = uri;
       else
-        GNUNET_free_non_null (uri);
+        GNUNET_free (uri);
 
       return GNUNET_STRINGS_path_is_absolute (post_scheme_path,
                                               GNUNET_NO,
@@ -1169,7 +1189,7 @@ GNUNET_STRINGS_check_filename (const char *filename,
             & (GNUNET_STRINGS_CHECK_EXISTS | GNUNET_STRINGS_CHECK_IS_DIRECTORY
                | GNUNET_STRINGS_CHECK_IS_LINK)))
   {
-    if (0 != stat (filename, &st))
+    if (0 != lstat (filename, &st))
     {
       if (0 != (checks & GNUNET_STRINGS_CHECK_EXISTS))
         return GNUNET_NO;
@@ -1401,15 +1421,14 @@ static char *const *
 _make_continuous_arg_copy (int argc, char *const *argv)
 {
   size_t argvsize = 0;
-  int i;
   char **new_argv;
   char *p;
 
-  for (i = 0; i < argc; i++)
+  for (int i = 0; i < argc; i++)
     argvsize += strlen (argv[i]) + 1 + sizeof(char *);
   new_argv = GNUNET_malloc (argvsize + sizeof(char *));
   p = (char *) &new_argv[argc + 1];
-  for (i = 0; i < argc; i++)
+  for (int i = 0; i < argc; i++)
   {
     new_argv[i] = p;
     strcpy (p, argv[i]);
@@ -1859,6 +1878,7 @@ GNUNET_STRINGS_base64_encode (const void *in, size_t len, char **output)
   char *opt;
 
   ret = 0;
+  GNUNET_assert (len / 4 < SIZE_MAX);
   opt = GNUNET_malloc (2 + (len * 4 / 3) + 8);
   for (size_t i = 0; i < len; ++i)
   {
@@ -1897,6 +1917,42 @@ GNUNET_STRINGS_base64_encode (const void *in, size_t len, char **output)
 }
 
 
+/**
+ * Encode into Base64url. RFC7515
+ *
+ * @param in the data to encode
+ * @param len the length of the input
+ * @param output where to write the output (*output should be NULL,
+ *   is allocated)
+ * @return the size of the output
+ */
+size_t
+GNUNET_STRINGS_base64url_encode (const void *in, size_t len, char **output)
+{
+  char *enc;
+  size_t pos;
+
+  GNUNET_STRINGS_base64_encode (in, len, output);
+  enc = *output;
+  /* Replace with correct characters for base64url */
+  pos = 0;
+  while ('\0' != enc[pos])
+  {
+    if ('+' == enc[pos])
+      enc[pos] = '-';
+    if ('/' == enc[pos])
+      enc[pos] = '_';
+    if ('=' == enc[pos])
+    {
+      enc[pos] = '\0';
+      break;
+    }
+    pos++;
+  }
+  return strlen (enc);
+}
+
+
 #define cvtfind(a)                        \
   ((((a) >= 'A') && ((a) <= 'Z'))         \
    ? (a) - 'A'                          \
@@ -1932,6 +1988,7 @@ GNUNET_STRINGS_base64_decode (const char *data, size_t len, void **out)
       goto END;                                                   \
   }
 
+  GNUNET_assert (len / 3 < SIZE_MAX);
   output = GNUNET_malloc ((len * 3 / 4) + 8);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "base64_decode decoding len=%d\n",
@@ -1978,4 +2035,57 @@ END:
 }
 
 
+/**
+ * Decode from Base64url. RFC7515
+ *
+ * @param data the data to decode
+ * @param len the length of the input
+ * @param output where to write the output (*output should be NULL,
+ *   is allocated)
+ * @return the size of the output
+ */
+size_t
+GNUNET_STRINGS_base64url_decode (const char *data, size_t len, void **out)
+{
+  char *s;
+  int padding;
+  size_t ret;
+
+  /* make enough space for padding */
+  GNUNET_assert (len < SIZE_MAX - 3);
+  s = GNUNET_malloc (len + 3);
+  memcpy (s, data, len);
+
+  for (int i = 0; i < strlen (s); i++)
+  {
+    if (s[i] == '-')
+      s[i] = '+';
+    if (s[i] == '_')
+      s[i] = '/';
+  }
+  padding = len % 4;
+  switch (padding) // Pad with trailing '='s
+  {
+  case 0:
+    break;   // No pad chars in this case
+  case 2:
+    memcpy (&s[len],
+            "==",
+            2);
+    len += 2;
+    break;         // Two pad chars
+  case 3:
+    s[len] = '=';
+    len++;
+    break;         // One pad char
+  default:
+    GNUNET_assert (0);
+    break;
+  }
+  ret = GNUNET_STRINGS_base64_decode (s, len, out);
+  GNUNET_free (s);
+  return ret;
+}
+
+
 /* end of strings.c */
