@@ -27,12 +27,13 @@
 
 
 static int
-check ()
+check (void)
 {
 #define MAX_TESTVAL 1024
   char *ptrs[MAX_TESTVAL];
   unsigned int **a2;
   char ***a3;
+  char *tmp;
   int i;
   int j;
   int k;
@@ -55,9 +56,9 @@ check ()
     GNUNET_free (ptrs[i]);
   }
 
-  /* GNUNET_free_non_null test */
-  GNUNET_free_non_null (NULL);
-  GNUNET_free_non_null (GNUNET_malloc (4));
+  /* GNUNET_free test */
+  tmp = GNUNET_malloc (4);
+  GNUNET_free (tmp);
 
   /* GNUNET_strdup tests */
   ptrs[0] = GNUNET_strdup ("bar");
@@ -134,6 +135,28 @@ check ()
 }
 
 
+static int
+check2 (void)
+{
+  char *a1 = NULL;
+  unsigned int a1_len = 0;
+  const char *a2 = "test";
+
+  GNUNET_array_append (a1,
+                       a1_len,
+                       'x');
+  GNUNET_array_concatenate (a1,
+                            a1_len,
+                            a2,
+                            4);
+  GNUNET_assert (0 == strncmp ("xtest",
+                               a1,
+                               5));
+  GNUNET_assert (5 == a1_len);
+  return 0;
+}
+
+
 int
 main (int argc, char *argv[])
 {
@@ -142,7 +165,7 @@ main (int argc, char *argv[])
   GNUNET_log_setup ("test-common-allocation",
                     "WARNING",
                     NULL);
-  ret = check ();
+  ret = check () | check2 ();
   if (ret != 0)
     fprintf (stderr,
              "ERROR %d.\n",
